# We have to override the new %%install behavior because, well... the kernel is special.
%global __spec_install_pre %{___build_pre}

Summary: The Linux kernel

# For a kernel released for public testing, released_kernel should be 1.
# For internal testing builds during development, it should be 0.
%global released_kernel 0

%global distro_build 107

# Sign the x86_64 kernel for secure boot authentication
%ifarch x86_64
%global signkernel 1
%else
%global signkernel 0
%endif

# Sign modules on all arches
%global signmodules 1

# Compress modules only for architectures that build modules
%ifarch noarch
%global zipmodules 0
%else
%global zipmodules 1
%endif

%if %{zipmodules}
%global zipsed -e 's/\.ko$/\.ko.xz/'
%endif

# define buildid .local

%define rpmversion 4.18.0
%define pkgrelease 107.rt20.48.el8

# allow pkg_release to have configurable %%{?dist} tag
%define specrelease 107.rt20.48%{?dist}

%define pkg_release %{specrelease}%{?buildid}

# What parts do we want to build?  We must build at least one kernel.
# These are the kernels that are built IF the architecture allows it.
# All should default to 1 (enabled) and be flipped to 0 (disabled)
# by later arch-specific checks.

# The following build options are enabled by default.
# Use either --without <opt> in your rpmbuild command or force values
# to 0 in here to disable them.
#
# standard kernel
%define with_up        %{?_without_up:        0} %{?!_without_up:        1}
# kernel-debug
%define with_debug     %{?_without_debug:     0} %{?!_without_debug:     1}
# kernel-headers
# realtime
%define with_realtime %{?_without_realtime:   0} %{?!_without_realtime:  1}
%define with_headers   %{?_without_headers:   0} %{?!_without_headers:   1}
%define with_cross_headers   %{?_without_cross_headers:   0} %{?!_without_cross_headers:   1}
# perf
%define with_perf      %{?_without_perf:      0} %{?!_without_perf:      1}
# tools
%define with_tools     %{?_without_tools:     0} %{?!_without_tools:     1}
# bpf tool
%define with_bpftool   %{?_without_bpftool:   0} %{?!_without_bpftool:   1}
# kernel-debuginfo
%define with_debuginfo %{?_without_debuginfo: 0} %{?!_without_debuginfo: 1}
# Want to build a the vsdo directories installed
%define with_vdso_install %{?_without_vdso_install: 0} %{?!_without_vdso_install: 1}
# kernel-zfcpdump (s390 specific kernel for zfcpdump)
%define with_zfcpdump  %{?_without_zfcpdump:  0} %{?!_without_zfcpdump:  1}
# kernel-abi-whitelists
%define with_kernel_abi_whitelists %{?_without_kernel_abi_whitelists: 0} %{?!_without_kernel_abi_whitelists: 1}
#
# Optional packages
#
%define with_bpf_samples %{?_with_bpf_samples: 1} %{?!_with_bpf_samples: 0}
#
# Additional options for user-friendly one-off kernel building:
#
# Only build the base kernel (--with baseonly):
%define with_baseonly  %{?_with_baseonly:     1} %{?!_with_baseonly:     0}
# Only build the debug kernel (--with dbgonly):
%define with_dbgonly   %{?_with_dbgonly:      1} %{?!_with_dbgonly:      0}
# Control whether we perform a compat. check against published ABI.
%define with_kabichk   %{?_without_kabichk:   0} %{?!_without_kabichk:   1}
# Control whether we perform a compat. check against DUP ABI.
%define with_kabidupchk %{?_with_kabidupchk:  1} %{?!_with_kabidupchk:   0}
#
# Control whether to run an extensive DWARF based kABI check.
# Note that this option needs to have baseline setup in SOURCE300.
%define with_kabidwchk %{?_without_kabidwchk: 0} %{?!_without_kabidwchk: 1}
%define with_kabidw_base %{?_with_kabidw_base: 1} %{?!_with_kabidw_base: 0}
#
# should we do C=1 builds with sparse
%define with_sparse    %{?_with_sparse:       1} %{?!_with_sparse:       0}
#
# Cross compile requested?
%define with_cross    %{?_with_cross:         1} %{?!_with_cross:        0}
#
# build a release kernel on rawhide
%define with_release   %{?_with_release:      1} %{?!_with_release:      0}

# The kernel tarball/base version
%define kversion 4.18

%define with_gcov %{?_with_gcov: 1} %{?!_with_gcov: 0}

# turn off debug kernel and kabichk for gcov builds
%if %{with_gcov}
%define with_debug 0
%define with_kabichk 0
%define with_kabidupchk 0
%define with_kabidwchk 0
%endif

# turn off kABI DWARF-based check if we're generating the base dataset
%if %{with_kabidw_base}
%define with_kabidwchk 0
%endif

%if %{with_realtime}
# The preempt RT patch level
%global rttag .rt20
# realtimeN
%global rtbuild .48
%define with_headers 0
%define with_cross_headers 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_zfcpdump 0
%define with_kabichk  0
%define with_kernel_abi_whitelists 0
%define with_bpf_samples 0
%define with_kabidw_base 0
%endif

%define make_target bzImage
%define image_install_path boot

%define KVERREL %{version}-%{release}.%{_target_cpu}
%define KVERREL_RE %(echo %KVERREL | sed 's/+/[+]/g')
%define hdrarch %_target_cpu
%define asmarch %_target_cpu

%if !%{with_debuginfo}
%define _enable_debug_packages 0
%endif
%define debuginfodir /usr/lib/debug
# Needed because we override almost everything involving build-ids
# and debuginfo generation. Currently we rely on the old alldebug setting.
%global _build_id_links alldebug

# if requested, only build base kernel
%if %{with_baseonly}
%define with_debug 0
%endif

# if requested, only build debug kernel
%if %{with_dbgonly}
%define with_up 0
%define with_tools 0
%define with_perf 0
%define with_bpftool 0
%endif

# turn off kABI DUP check and DWARF-based check if kABI check is disabled
%if !%{with_kabichk}
%define with_kabidupchk 0
%define with_kabidwchk 0
%endif

%ifnarch noarch
%define with_kernel_abi_whitelists 0
%endif

# Overrides for generic default options

# don't build noarch kernels or headers (duh)
%ifarch noarch
%define with_up 0
%define with_headers 0
%define with_cross_headers 0
%define with_tools 0
%define with_perf 0
%define with_bpftool 0
%define with_bpf_samples 0
%define with_debug 0
%define all_arch_configs %{name}-*.config
%endif

# sparse blows up on ppc
%ifnarch ppc64le
%define with_sparse 0
%endif

# zfcpdump mechanism is s390 only
%ifnarch s390x
%define with_zfcpdump 0
%endif

# Per-arch tweaks

%ifarch i686
%define asmarch x86
%define hdrarch i386
%endif

%ifarch x86_64
%define asmarch x86
%define all_arch_configs %{name}-%{version}-x86_64*.config
%define kernel_image arch/x86/boot/bzImage
%endif

%ifarch ppc64le
%define asmarch powerpc
%define hdrarch powerpc
%define make_target vmlinux
%define kernel_image vmlinux
%define kernel_image_elf 1
%define all_arch_configs %{name}-%{version}-ppc64le*.config
%define kcflags -O3
%endif

%ifarch s390x
%define asmarch s390
%define hdrarch s390
%define all_arch_configs %{name}-%{version}-s390x*.config
%define kernel_image arch/s390/boot/bzImage
%endif

%ifarch aarch64
%define all_arch_configs %{name}-%{version}-aarch64*.config
%define asmarch arm64
%define hdrarch arm64
%define make_target Image.gz
%define kernel_image arch/arm64/boot/Image.gz
%endif

# We only build kernel headers package on the following, for being able to do
# builds with a different bit length (eg. 32-bit build on a 64-bit environment).
# Do not remove them from ExclusiveArch tag below
%define nobuildarches i686 ppc s390 ppc64 ppc64le aarch64

%ifarch %nobuildarches
%define with_up 0
%define with_debug 0
%define with_debuginfo 0
%define with_perf 0
%define with_tools 0
%define with_bpftool 0
%define with_bpf_samples 0
%define _enable_debug_packages 0
%endif

# Architectures we build tools/cpupower on
%define cpupowerarchs x86_64 ppc64le aarch64


#
# Packages that need to be installed before the kernel is, because the %%post
# scripts use them.
#
%define kernel_prereq  coreutils, systemd >= 203-2, /usr/bin/kernel-install
%define initrd_prereq  dracut >= 027


Name: kernel-rt%{?variant}
Group: System Environment/Kernel
License: GPLv2 and Redistributable, no modification permitted
URL: http://www.kernel.org/
Version: %{rpmversion}
Release: %{pkg_release}
# Ok, we know we're not building RT for anything other than x86_64, so just
# set the ExclusiveArch
#ExclusiveArch: aarch64 i686 noarch ppc ppc64le s390 s390x x86_64
ExclusiveArch: x86_64
ExclusiveOS: Linux
%ifnarch %{nobuildarches}
Requires: %{name}-core-uname-r = %{KVERREL}%{?variant}
Requires: %{name}-modules-uname-r = %{KVERREL}%{?variant}
Requires: rt-setup
%endif


#
# List the packages used during the kernel build
#
BuildRequires: kmod, patch, bash, tar, git
BuildRequires: bzip2, xz, findutils, gzip, m4, perl-interpreter, perl-Carp, perl-devel, perl-generators, make, diffutils, gawk
BuildRequires: gcc, binutils, redhat-rpm-config, hmaccalc, python3-devel
BuildRequires: net-tools, hostname, bc, bison, flex, elfutils-devel
%if %{with_sparse}
BuildRequires: sparse
%endif
%if %{with_perf}
BuildRequires: zlib-devel binutils-devel newt-devel perl(ExtUtils::Embed) bison flex xz-devel
BuildRequires: audit-libs-devel
BuildRequires: java-devel
%ifnarch s390x
BuildRequires: numactl-devel
%endif
%endif
%if %{with_tools}
BuildRequires: gettext ncurses-devel
%ifnarch s390x
BuildRequires: pciutils-devel
%endif
%endif
%if %{with_bpftool}
BuildRequires: python3-docutils
BuildRequires: zlib-devel binutils-devel
%endif
%if %{with_bpf_samples}
BuildRequires: libcap-devel libcap-ng-devel glibc-static rsync llvm-toolset
%endif
BuildConflicts: rhbuildsys(DiskFree) < 500Mb
%if %{with_debuginfo}
BuildRequires: rpm-build, elfutils
BuildConflicts: rpm < 4.13.0.1-19
# Most of these should be enabled after more investigation
%undefine _include_minidebuginfo
%undefine _find_debuginfo_dwz_opts
%undefine _unique_build_ids
%undefine _unique_debug_names
%undefine _unique_debug_srcs
%undefine _debugsource_packages
%undefine _debuginfo_subpackages
%global _find_debuginfo_opts -r
%global _missing_build_ids_terminate_build 1
%global _no_recompute_build_ids 1
%endif
%if %{with_kabidwchk} || %{with_kabidw_base}
BuildRequires: kabi-dw
%endif

%if %{signkernel}%{signmodules}
BuildRequires: openssl openssl-devel
%if %{signkernel}
BuildRequires: nss-tools
BuildRequires: pesign >= 0.10-4
%endif
%endif

%if %{with_cross}
BuildRequires: binutils-%{_build_arch}-linux-gnu, gcc-%{_build_arch}-linux-gnu
%define cross_opts CROSS_COMPILE=%{_build_arch}-linux-gnu-
%endif

# These below are required to build man pages
%if %{with_perf}
BuildRequires: xmlto
%endif
%if %{with_perf} || %{with_tools}
BuildRequires: asciidoc
%endif

Source0: linux-%{rpmversion}-%{pkgrelease}.tar.xz

Source11: x509.genkey
%if %{?released_kernel}
Source13: securebootca.cer
Source14: secureboot.cer
%define pesign_name redhatsecureboot301
%else
Source13: redhatsecurebootca2.cer
Source14: redhatsecureboot003.cer
%define pesign_name redhatsecureboot003
%endif
Source16: mod-extra.list
Source17: mod-extra.sh
Source18: mod-sign.sh
Source90: filter-x86_64.sh
Source93: filter-aarch64.sh
Source96: filter-ppc64le.sh
Source97: filter-s390x.sh
Source99: filter-modules.sh
%define modsign_cmd %{SOURCE18}

Source20: %{name}-aarch64.config
Source21: %{name}-aarch64-debug.config
Source32: %{name}-ppc64le.config
Source33: %{name}-ppc64le-debug.config
Source36: %{name}-s390x.config
Source37: %{name}-s390x-debug.config
Source38: %{name}-s390x-zfcpdump.config
Source39: %{name}-x86_64.config
Source40: %{name}-x86_64-debug.config
Source41: generate_all_configs.sh

Source42: process_configs.sh
Source43: generate_bls_conf.sh

%if %{with_kabichk}
Source200: check-kabi

Source201: Module.kabi_aarch64
Source202: Module.kabi_ppc64le
Source203: Module.kabi_s390x
Source204: Module.kabi_x86_64

Source210: Module.kabi_dup_aarch64
Source211: Module.kabi_dup_ppc64le
Source212: Module.kabi_dup_s390x
Source213: Module.kabi_dup_x86_64

Source300: kernel-abi-whitelists-%{rpmversion}-%{distro_build}.tar.bz2
Source301: kernel-kabi-dw-%{rpmversion}-%{distro_build}.tar.bz2
%endif

# Sources for kernel-tools
Source2000: cpupower.service
Source2001: cpupower.config

## Patches needed for building this package

# END OF PATCH DEFINITIONS

BuildRoot: %{_tmppath}/%{name}-%{KVERREL}-root

%description
The %{name} meta package

#
# This macro does requires, provides, conflicts, obsoletes for a kernel package.
#	%%kernel_reqprovconf <subpackage>
# It uses any kernel_<subpackage>_conflicts and kernel_<subpackage>_obsoletes
# macros defined above.
#
%define kernel_reqprovconf \
Provides: %{name} = %{rpmversion}-%{pkg_release}\
Provides: %{name}-%{_target_cpu} = %{rpmversion}-%{pkg_release}%{?1:+%{1}}\
Provides: kernel-drm-nouveau = 16\
Provides: %{name}-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Requires(pre): %{kernel_prereq}\
Requires(pre): %{initrd_prereq}\
Requires(pre): linux-firmware >= 20150904-56.git6ebf5d57\
Requires(preun): systemd >= 200\
Conflicts: xfsprogs < 4.3.0-1\
Conflicts: xorg-x11-drv-vmmouse < 13.0.99\
%{expand:%%{?kernel%{?1:_%{1}}_conflicts:Conflicts: %%{kernel%{?1:_%{1}}_conflicts}}}\
%{expand:%%{?kernel%{?1:_%{1}}_obsoletes:Obsoletes: %%{kernel%{?1:_%{1}}_obsoletes}}}\
%{expand:%%{?kernel%{?1:_%{1}}_provides:Provides: %%{kernel%{?1:_%{1}}_provides}}}\
# We can't let RPM do the dependencies automatic because it'll then pick up\
# a correct but undesirable perl dependency from the module headers which\
# isn't required for the kernel proper to function\
AutoReq: no\
AutoProv: yes\
%{nil}

%package headers
Summary: Header files for the Linux kernel for use by glibc
Group: Development/System
Obsoletes: glibc-kernheaders < 3.0-46
Provides: glibc-kernheaders = 3.0-46
%if "0%{?variant}"
Obsoletes: kernel-headers < %{rpmversion}-%{pkg_release}
Provides: kernel-headers = %{rpmversion}-%{pkg_release}
%endif
%description headers
Kernel-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
glibc package.

%package cross-headers
Summary: Header files for the Linux kernel for use by cross-glibc
Group: Development/System
%description cross-headers
Kernel-cross-headers includes the C header files that specify the interface
between the Linux kernel and userspace libraries and programs.  The
header files define structures and constants that are needed for
building most standard programs and are also needed for rebuilding the
cross-glibc package.


%package debuginfo-common-%{_target_cpu}
Summary: Kernel source files used by %{name}-debuginfo packages
Group: Development/Debug
Provides: installonlypkg(kernel)
%description debuginfo-common-%{_target_cpu}
This package is required by %{name}-debuginfo subpackages.
It provides the kernel source files common to all builds.

%if %{with_perf}
%package -n perf
Summary: Performance monitoring for the Linux kernel
Group: Development/System
License: GPLv2
%description -n perf
This package contains the perf tool, which enables performance monitoring
of the Linux kernel.

%package -n perf-debuginfo
Summary: Debug information for package perf
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n perf-debuginfo
This package provides debug information for the perf package.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_bindir}/perf(\.debug)?|.*%%{_libexecdir}/perf-core/.*|.*%%{_libdir}/traceevent/plugins/.*|XXX' -o perf-debuginfo.list}

%package -n python3-perf
Summary: Python bindings for apps which will manipulate perf events
Group: Development/Libraries
%description -n python3-perf
The python3-perf package contains a module that permits applications
written in the Python programming language to use the interface
to manipulate perf events.

%package -n python3-perf-debuginfo
Summary: Debug information for package perf python bindings
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n python3-perf-debuginfo
This package provides debug information for the perf python bindings.

# the python_sitearch macro should already be defined from above
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{python3_sitearch}/perf.*so(\.debug)?|XXX' -o python3-perf-debuginfo.list}


%endif # with_perf

%if %{with_tools}
%package -n %{name}-tools
Summary: Assortment of tools for the Linux kernel
Group: Development/System
License: GPLv2
%ifarch %{cpupowerarchs}
Provides:  cpupowerutils = 1:009-0.6.p1
Obsoletes: cpupowerutils < 1:009-0.6.p1
Provides:  cpufreq-utils = 1:009-0.6.p1
Provides:  cpufrequtils = 1:009-0.6.p1
Obsoletes: cpufreq-utils < 1:009-0.6.p1
Obsoletes: cpufrequtils < 1:009-0.6.p1
Obsoletes: cpuspeed < 1:1.5-16
Requires: %{name}-tools-libs = %{version}-%{release}
%endif
%define __requires_exclude ^%{_bindir}/python
%description -n %{name}-tools
This package contains the tools/ directory from the kernel source
and the supporting documentation.

%package -n %{name}-tools-libs
Summary: Libraries for the %{name}-tools
Group: Development/System
License: GPLv2
%description -n %{name}-tools-libs
This package contains the libraries built from the tools/ directory
from the kernel source.

%package -n %{name}-tools-libs-devel
Summary: Assortment of tools for the Linux kernel
Group: Development/System
License: GPLv2
Requires: %{name}-tools = %{version}-%{release}
%ifarch %{cpupowerarchs}
Provides:  cpupowerutils-devel = 1:009-0.6.p1
Obsoletes: cpupowerutils-devel < 1:009-0.6.p1
%endif
Requires: %{name}-tools-libs = %{version}-%{release}
Provides: %{name}-tools-devel
%description -n %{name}-tools-libs-devel
This package contains the development files for the tools/ directory from
the kernel source.

%package -n %{name}-tools-debuginfo
Summary: Debug information for package %{name}-tools
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n %{name}-tools-debuginfo
This package provides debug information for package %{name}-tools.

# Note that this pattern only works right to match the .build-id
# symlinks because of the trailing nonmatching alternation and
# the leading .*, because of find-debuginfo.sh's buggy handling
# of matching the pattern against the symlinks file.
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_bindir}/centrino-decode(\.debug)?|.*%%{_bindir}/powernow-k8-decode(\.debug)?|.*%%{_bindir}/cpupower(\.debug)?|.*%%{_libdir}/libcpupower.*|.*%%{_bindir}/turbostat(\.debug)?|.*%%{_bindir}/x86_energy_perf_policy(\.debug)?|.*%%{_bindir}/tmon(\.debug)?|.*%%{_bindir}/lsgpio(\.debug)?|.*%%{_bindir}/gpio-hammer(\.debug)?|.*%%{_bindir}/gpio-event-mon(\.debug)?|.*%%{_bindir}/iio_event_monitor(\.debug)?|.*%%{_bindir}/iio_generic_buffer(\.debug)?|.*%%{_bindir}/lsiio(\.debug)?|XXX' -o %{name}-tools-debuginfo.list}

%endif # with_tools

%if %{with_bpftool}

%package -n bpftool
Summary: Inspection and simple manipulation of eBPF programs and maps
License: GPLv2
%description -n bpftool
This package contains the bpftool, which allows inspection and simple
manipulation of eBPF programs and maps.

%package -n bpftool-debuginfo
Summary: Debug information for package bpftool
Group: Development/Debug
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}
AutoReqProv: no
%description -n bpftool-debuginfo
This package provides debug information for the bpftool package.

%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '.*%%{_sbindir}/bpftool(\.debug)?|XXX' -o bpftool-debuginfo.list}

%endif # with_bpftool

%if %{with_bpf_samples}

%package -n bpf-samples
Summary: eBPF samples and selftests
License: GPLv2
%description -n bpf-samples
eBPF sample programs and selftests.

%endif # with_bpf_samples

%if %{with_gcov}
%package gcov
Summary: gcov graph and source files for coverage data collection.
Group: Development/System
%description gcov
kernel-gcov includes the gcov graph and source files for gcov coverage collection.
%endif

%package -n %{name}-abi-whitelists
Summary: The Red Hat Enterprise Linux kernel ABI symbol whitelists
Group: System Environment/Kernel
AutoReqProv: no
%description -n %{name}-abi-whitelists
The kABI package contains information pertaining to the Red Hat Enterprise
Linux kernel ABI, including lists of kernel symbols that are needed by
external Linux kernel modules, and a yum plugin to aid enforcement.

%if %{with_kabidw_base}
%package kabidw-base
Summary: The baseline dataset for kABI verification using DWARF data
Group: System Environment/Kernel
AutoReqProv: no
%description kabidw-base
The kabidw-base package contains data describing the current ABI of the Red Hat
Enterprise Linux kernel, suitable for the kabi-dw tool.
%endif

#
# This macro creates a kernel-<subpackage>-debuginfo package.
#	%%kernel_debuginfo_package <subpackage>
#
%define kernel_debuginfo_package() \
%package %{?1:%{1}-}debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}\
Group: Development/Debug\
Requires: %{name}-debuginfo-common-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-debuginfo-%{_target_cpu} = %{version}-%{release}\
Provides: installonlypkg(kernel)\
AutoReqProv: no\
%description %{?1:%{1}-}debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:-%{1}}-%{KVERREL}.\
%{expand:%%global _find_debuginfo_opts %{?_find_debuginfo_opts} -p '/.*/%%{KVERREL_RE}%{?1:[+]%{1}}/.*|/.*%%{KVERREL_RE}%{?1:\+%{1}}(\.debug)?' -o debuginfo%{?1}.list}\
%{nil}

#
# This macro creates a kernel-<subpackage>-devel package.
#	%%kernel_devel_package <subpackage> <pretty-name>
#
%define kernel_devel_package() \
%package %{?1:%{1}-}devel\
Summary: Development package for building kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: %{name}%{?1:-%{1}}-devel-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}-devel-%{_target_cpu} = %{version}-%{release}%{?1:+%{1}}\
Provides: %{name}-devel-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Provides: installonlypkg(kernel)\
AutoReqProv: no\
Requires(pre): findutils\
Requires: findutils\
Requires: perl-interpreter\
%description %{?1:%{1}-}devel\
This package provides kernel headers and makefiles sufficient to build modules\
against the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules-extra package.
#	%%kernel_modules_extra_package <subpackage> <pretty-name>
#
%define kernel_modules_extra_package() \
%package %{?1:%{1}-}modules-extra\
Summary: Extra kernel modules to match the %{?2:%{2} }kernel\
Group: System Environment/Kernel\
Provides: %{name}%{?1:-%{1}}-modules-extra-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}%{?1:-%{1}}-modules-extra-%{_target_cpu} = %{version}-%{release}%{?1:+%{1}}\
Provides: %{name}%{?1:-%{1}}-modules-extra = %{version}-%{release}%{?1:+%{1}}\
Provides: installonlypkg(kernel-module)\
Provides: %{name}%{?1:-%{1}}-modules-extra-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Requires: %{name}-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Requires: %{name}%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules-extra\
This package provides less commonly used kernel modules for the %{?2:%{2} }kernel package.\
%{nil}

#
# This macro creates a kernel-<subpackage>-modules package.
#	%%kernel_modules_package <subpackage> <pretty-name>
#
%define kernel_modules_package() \
%package %{?1:%{1}-}modules\
Summary: kernel modules to match the %{?2:%{2}-}core kernel\
Group: System Environment/Kernel\
Provides: %{name}%{?1:-%{1}}-modules-%{_target_cpu} = %{version}-%{release}\
Provides: %{name}-modules-%{_target_cpu} = %{version}-%{release}%{?1:+%{1}}\
Provides: %{name}-modules = %{version}-%{release}%{?1:+%{1}}\
Provides: installonlypkg(kernel-module)\
Provides: %{name}%{?1:-%{1}}-modules-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Requires: %{name}-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
AutoReq: no\
AutoProv: yes\
%description %{?1:%{1}-}modules\
This package provides commonly used kernel modules for the %{?2:%{2}-}core kernel package.\
%{nil}

#
# this macro creates a kernel-<subpackage> meta package.
#	%%kernel_meta_package <subpackage>
#
%define kernel_meta_package() \
%package %{1}\
summary: kernel meta-package for the %{1} kernel\
group: system environment/kernel\
Requires: %{name}-%{1}-core-uname-r = %{KVERREL}%{?variant}+%{1}\
Requires: %{name}-%{1}-modules-uname-r = %{KVERREL}%{?variant}+%{1}\
Provides: installonlypkg(kernel)\
%description %{1}\
The meta-package for the %{1} kernel\
%{nil}

%if %{with_realtime}
#
# this macro creates a kernel-rt-<subpackage>-kvm package
# %%kernel_kvm_package <subpackage>
#
%define kernel_kvm_package() \
%package %{?1:%{1}-}kvm\
Summary: KVM modules for package %{name}%{?1:-%{1}}\
Group: System Environment/Kernel\
Requires: %{name}%{?1:-%{1}} = %{version}-%{release}\
Provides: installonlypkg(kernel-module)\
Provides: %{name}%{?1:-%{1}}-kvm-%{_target_cpu} = %{version}-%{release}\
AutoReq: no\
%description -n %{name}%{?1:-%{1}}-kvm\
This package provides KVM modules for package %{name}%{?1:-%{1}}.\
%{nil}

#
# This macro creates a kernel-rt-<subpackage>-kvm-debuginfo package.
#	%%kernel_kvm_debuginfo_package <subpackage>
#
%define kernel_kvm_debuginfo_package() \
%package %{?1:%{1}-}kvm-debuginfo\
Summary: Debug information for package %{name}%{?1:-%{1}}-kvm\
Group: Development/Debug\
Provides: %{name}%{?1:-%{1}}-kvm-debuginfo = %{version}-%{release}\
AutoReqProv: no\
%description -n %{name}%{?1:-%{1}}-kvm-debuginfo\
This package provides debug information for package %{name}%{?1:-%{1}}.\
This is required to use SystemTap with %{name}%{?1:-%{1}}-%{KVERREL}.\
%{expand:%%global debuginfo_args %{?debuginfo_args} -p '/.*/%%{KVERREL}%{?1:\.%{1}}/.*|/.*%%{KVERREL}%{?1:\.%{1}}(\.debug)?' -o debuginfo%{?1}-kvm.list}\
%{nil}
%endif

#
# This macro creates a %%{name}-<subpackage> and its -devel and -debuginfo too.
#	%%define variant_summary The Linux kernel compiled for <configuration>
#	%%kernel_variant_package [-n <pretty-name>] <subpackage>
#
%define kernel_variant_package(n:) \
%package %{?1:%{1}-}core\
Summary: %{variant_summary}\
Group: System Environment/Kernel\
Provides: %{name}-%{?1:%{1}-}core-uname-r = %{KVERREL}%{?variant}%{?1:+%{1}}\
Provides: installonlypkg(kernel)\
%{expand:%%kernel_reqprovconf}\
%if %{?1:1} %{!?1:0} \
%{expand:%%kernel_meta_package %{?1:%{1}}}\
%endif\
%{expand:%%kernel_devel_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%{expand:%%kernel_modules_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%{expand:%%kernel_modules_extra_package %{?1:%{1}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%{expand:%%kernel_debuginfo_package %{?1:%{1}}}\
%if %{with_realtime} \
%{expand:%%kernel_kvm_package %{?1:%{1}}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%{expand:%%kernel_kvm_debuginfo_package %{?1:%{1}}} %{!?{-n}:%{1}}%{?{-n}:%{-n*}}}\
%endif \
%{nil}

# Now, each variant package.

%if %{with_zfcpdump}
%define variant_summary The Linux kernel compiled for zfcpdump usage
%kernel_variant_package zfcpdump
%description zfcpdump-core
The kernel package contains the Linux kernel (vmlinuz) for use by the
zfcpdump infrastructure.
%endif # with_zfcpdump

%define variant_summary The Linux kernel compiled with extra debugging enabled
%kernel_variant_package debug
%description debug-core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system:  memory allocation, process allocation, device
input and output, etc.

This variant of the kernel has numerous debugging options enabled.
It should only be installed when trying to gather additional information
on kernel bugs, as some of these options impact performance noticably.

# And finally the main -core package

%define variant_summary The Real-Time Linux kernel
%kernel_variant_package
%description core
The kernel package contains the Linux kernel (vmlinuz), the core of any
Linux operating system.  The kernel handles the basic functions
of the operating system: memory allocation, process allocation, device
input and output, etc.


%prep
# do a few sanity-checks for --with *only builds
%if %{with_baseonly}
%if !%{with_up}
echo "Cannot build --with baseonly, up build is disabled"
exit 1
%endif
%endif

# more sanity checking; do it quietly
if [ "%{patches}" != "%%{patches}" ] ; then
  for patch in %{patches} ; do
    if [ ! -f $patch ] ; then
      echo "ERROR: Patch  ${patch##/*/}  listed in specfile but is missing"
      exit 1
    fi
  done
fi 2>/dev/null

patch_command='patch -p1 -F1 -s'
ApplyPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  if ! grep -E "^Patch[0-9]+: $patch\$" %{_specdir}/${RPM_PACKAGE_NAME%%%%%{?variant}}.spec ; then
    if [ "${patch:0:8}" != "patch-4." ] ; then
      echo "ERROR: Patch  $patch  not listed as a source patch in specfile"
      exit 1
    fi
  fi 2>/dev/null
  case "$patch" in
  *.bz2) bunzip2 < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.gz)  gunzip  < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *.xz)  unxz    < "$RPM_SOURCE_DIR/$patch" | $patch_command ${1+"$@"} ;;
  *) $patch_command ${1+"$@"} < "$RPM_SOURCE_DIR/$patch" ;;
  esac
}

# don't apply patch if it's empty
ApplyOptionalPatch()
{
  local patch=$1
  shift
  if [ ! -f $RPM_SOURCE_DIR/$patch ]; then
    exit 1
  fi
  local C=$(wc -l $RPM_SOURCE_DIR/$patch | awk '{print $1}')
  if [ "$C" -gt 9 ]; then
    ApplyPatch $patch ${1+"$@"}
  fi
}

%setup -q -n %{name}-%{rpmversion}-%{pkgrelease} -c
mv linux-%{rpmversion}-%{pkgrelease} linux-%{KVERREL}

cd linux-%{KVERREL}

# END OF PATCH APPLICATIONS

# Any further pre-build tree manipulations happen here.

%if %{with_realtime}
# remove the localversion-rt file since it screws around with
# the uname output
if [ -f localversion-rt ]; then
   rm -f localversion-rt
fi
%endif

chmod +x scripts/checkpatch.pl
mv COPYING COPYING-%{version}

# This Prevents scripts/setlocalversion from mucking with our version numbers.
touch .scmversion

# Do not use "ambiguous" python shebangs. RHEL 8 now has a new script
# (/usr/lib/rpm/redhat/brp-mangle-shebangs), which forces us to specify a
# "non-ambiguous" python shebang for scripts we ship in buildroot. This
# script throws an error like below:
# *** ERROR: ambiguous python shebang in /usr/bin/kvm_stat: #!/usr/bin/python. Change it to python3 (or python2) explicitly.
# We patch all sources below for which we got a report/error.
pathfix.py -i %{__python3} -p -n \
	tools/kvm/kvm_stat/kvm_stat \
	scripts/show_delta \
	scripts/diffconfig \
	scripts/bloat-o-meter \
	tools/perf/tests/attr.py \
	tools/perf/scripts/python/stat-cpi.py \
	tools/perf/scripts/python/sched-migration.py

# only deal with configs if we are going to build for the arch
%ifnarch %nobuildarches

if [ -L configs ]; then
	rm -f configs
fi
mkdir configs
cd configs

# Drop some necessary files from the source dir into the buildroot
cp $RPM_SOURCE_DIR/kernel-*.config .
cp %{SOURCE41} .
VERSION=%{version} ./generate_all_configs.sh %{name}

%define make make %{?cross_opts} HOSTCFLAGS="${RPM_OPT_FLAGS}" HOSTLDFLAGS="%{__global_ldflags}"

# enable GCOV kernel config options if gcov is on
%if %{with_gcov}
for i in *.config
do
  sed -i 's/# CONFIG_GCOV_KERNEL is not set/CONFIG_GCOV_KERNEL=y\nCONFIG_GCOV_PROFILE_ALL=y\n/' $i
done
%endif

cp %{SOURCE42} .
./process_configs.sh -w %{name} %{rpmversion}

# end of kernel config
%endif

cd ..
# # End of Configs stuff

# get rid of unwanted files resulting from patch fuzz
find . \( -name "*.orig" -o -name "*~" \) -exec rm -f {} \; >/dev/null

# remove unnecessary SCM files
find . -name .gitignore -exec rm -f {} \; >/dev/null

cd ..

###
### build
###
%build

%if %{with_sparse}
%define sparse_mflags	C=1
%endif

cp_vmlinux()
{
  eu-strip --remove-comment -o "$2" "$1"
}

BuildKernel() {
    MakeTarget=$1
    KernelImage=$2
    Flavour=$4
    DoVDSO=$3
    Flav=${Flavour:++${Flavour}}
    InstallName=${5:-vmlinuz}

    DoModules=1
    if [ "$Flavour" = "zfcpdump" ]; then
	    DoModules=0
    fi

    # Pick the right config file for the kernel we're building
    Config=%{name}-%{version}-%{_target_cpu}${Flavour:+-${Flavour}}.config
    DevelDir=/usr/src/kernels/%{KVERREL}${Flav}

    # When the bootable image is just the ELF kernel, strip it.
    # We already copy the unstripped file into the debuginfo package.
    if [ "$KernelImage" = vmlinux ]; then
      CopyKernel=cp_vmlinux
    else
      CopyKernel=cp
    fi

    KernelVer=%{version}-%{release}.%{_target_cpu}${Flav}
    echo BUILDING A KERNEL FOR ${Flavour} %{_target_cpu}...

    # make sure EXTRAVERSION says what we want it to say
    perl -p -i -e "s/^EXTRAVERSION.*/EXTRAVERSION = -%{release}.%{_target_cpu}${Flav}/" Makefile

    # and now to start the build process

    %{make} -s mrproper
    cp configs/$Config .config

    %if %{signkernel}%{signmodules}
    cp %{SOURCE11} certs/.
    %endif

    Arch=`head -1 .config | cut -b 3-`
    echo USING ARCH=$Arch

    %{make} -s ARCH=$Arch oldnoconfig >/dev/null
    %{make} -s ARCH=$Arch V=1 %{?_smp_mflags} KCFLAGS="%{?kcflags}" WITH_GCOV="%{?with_gcov}" $MakeTarget %{?sparse_mflags} %{?kernel_mflags}
    if [ $DoModules -eq 1 ]; then
	%{make} -s ARCH=$Arch V=1 %{?_smp_mflags} KCFLAGS="%{?kcflags}" WITH_GCOV="%{?with_gcov}" modules %{?sparse_mflags} || exit 1
    fi

    mkdir -p $RPM_BUILD_ROOT/%{image_install_path}
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer
%if %{with_debuginfo}
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/%{image_install_path}
%endif

%ifarch aarch64
    %{make} -s ARCH=$Arch V=1 dtbs dtbs_install INSTALL_DTBS_PATH=$RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer
    cp -r $RPM_BUILD_ROOT/%{image_install_path}/dtb-$KernelVer $RPM_BUILD_ROOT/lib/modules/$KernelVer/dtb
    find arch/$Arch/boot/dts -name '*.dtb' -type f | xargs rm -f
%endif

    # Start installing the results
    install -m 644 .config $RPM_BUILD_ROOT/boot/config-$KernelVer
    install -m 644 .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/config
    install -m 644 System.map $RPM_BUILD_ROOT/boot/System.map-$KernelVer
    install -m 644 System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/System.map

    # We estimate the size of the initramfs because rpm needs to take this size
    # into consideration when performing disk space calculations. (See bz #530778)
    dd if=/dev/zero of=$RPM_BUILD_ROOT/boot/initramfs-$KernelVer.img bs=1M count=20

    if [ -f arch/$Arch/boot/zImage.stub ]; then
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/%{image_install_path}/zImage.stub-$KernelVer || :
      cp arch/$Arch/boot/zImage.stub $RPM_BUILD_ROOT/lib/modules/$KernelVer/zImage.stub-$KernelVer || :
    fi
    %if %{signkernel}
    # Sign the image if we're using EFI
    %pesign -s -i $KernelImage -o vmlinuz.signed -a %{SOURCE13} -c %{SOURCE14} -n %{pesign_name}
    if [ ! -s vmlinuz.signed ]; then
        echo "pesigning failed"
        exit 1
    fi
    mv vmlinuz.signed $KernelImage
    %endif
    $CopyKernel $KernelImage \
                $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    chmod 755 $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    cp $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer $RPM_BUILD_ROOT/lib/modules/$KernelVer/$InstallName

    # hmac sign the kernel for FIPS
    echo "Creating hmac file: $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac"
    ls -l $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer
    sha512hmac $RPM_BUILD_ROOT/%{image_install_path}/$InstallName-$KernelVer | sed -e "s,$RPM_BUILD_ROOT,," > $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac;
    cp $RPM_BUILD_ROOT/%{image_install_path}/.vmlinuz-$KernelVer.hmac $RPM_BUILD_ROOT/lib/modules/$KernelVer/.vmlinuz.hmac

    if [ $DoModules -eq 1 ]; then
	# Override $(mod-fw) because we don't want it to install any firmware
	# we'll get it from the linux-firmware package and we don't want conflicts
	%{make} -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT modules_install KERNELRELEASE=$KernelVer mod-fw=
    fi

%if %{with_gcov}
    # install gcov-needed files to $BUILDROOT/$BUILD/...:
    #   gcov_info->filename is absolute path
    #   gcno references to sources can use absolute paths (e.g. in out-of-tree builds)
    #   sysfs symlink targets (set up at compile time) use absolute paths to BUILD dir
    find . \( -name '*.gcno' -o -name '*.[chS]' \) -exec install -D '{}' "$RPM_BUILD_ROOT/$(pwd)/{}" \;
%endif

    if [ $DoVDSO -ne 0 ]; then
        %{make} -s ARCH=$Arch INSTALL_MOD_PATH=$RPM_BUILD_ROOT vdso_install KERNELRELEASE=$KernelVer
        if [ ! -s ldconfig-kernel.conf ]; then
          echo > ldconfig-kernel.conf "\
    # Placeholder file, no vDSO hwcap entries used in this kernel."
        fi
        %{__install} -D -m 444 ldconfig-kernel.conf \
            $RPM_BUILD_ROOT/etc/ld.so.conf.d/%{name}-$KernelVer.conf
        rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/vdso/.build-id
    fi

    # And save the headers/makefiles etc for building modules against
    #
    # This all looks scary, but the end result is supposed to be:
    # * all arch relevant include/ files
    # * all Makefile/Kconfig files
    # * all script/ files

    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/source
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    (cd $RPM_BUILD_ROOT/lib/modules/$KernelVer ; ln -s build source)
    # dirs for additional modules per module-init-tools, kbuild/modules.txt
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/extra
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/updates
    mkdir -p $RPM_BUILD_ROOT/lib/modules/$KernelVer/weak-updates
    # first copy everything
    cp --parents `find  -type f -name "Makefile*" -o -name "Kconfig*"` $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp Module.symvers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp System.map $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    if [ -s Module.markers ]; then
      cp Module.markers $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    fi

    # create the kABI metadata for use in packaging
    # NOTENOTE: the name symvers is used by the rpm backend
    # NOTENOTE: to discover and run the /usr/lib/rpm/fileattrs/kabi.attr
    # NOTENOTE: script which dynamically adds exported kernel symbol
    # NOTENOTE: checksums to the rpm metadata provides list.
    # NOTENOTE: if you change the symvers name, update the backend too
    echo "**** GENERATING kernel ABI metadata ****"
    gzip -c9 < Module.symvers > $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz
    cp $RPM_BUILD_ROOT/boot/symvers-$KernelVer.gz $RPM_BUILD_ROOT/lib/modules/$KernelVer/symvers.gz

%if %{with_kabichk}
    echo "**** kABI checking is enabled in kernel SPEC file. ****"
    chmod 0755 $RPM_SOURCE_DIR/check-kabi
    if [ -e $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Flavour ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_%{_target_cpu}$Flavour $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        rm $RPM_BUILD_ROOT/Module.kabi # for now, don't keep it around.
    else
        echo "**** NOTE: Cannot find reference Module.kabi file. ****"
    fi
%endif

%if %{with_kabidupchk}
    echo "**** kABI DUP checking is enabled in kernel SPEC file. ****"
    if [ -e $RPM_SOURCE_DIR/Module.kabi_dup_%{_target_cpu}$Flavour ]; then
        cp $RPM_SOURCE_DIR/Module.kabi_dup_%{_target_cpu}$Flavour $RPM_BUILD_ROOT/Module.kabi
        $RPM_SOURCE_DIR/check-kabi -k $RPM_BUILD_ROOT/Module.kabi -s Module.symvers || exit 1
        rm $RPM_BUILD_ROOT/Module.kabi # for now, don't keep it around.
    else
        echo "**** NOTE: Cannot find DUP reference Module.kabi file. ****"
    fi
%endif

%if %{with_kabidw_base}
    # Don't build kabi base for debug kernels
    if [ "$Flavour" != "kdump" -a "$Flavour" != "debug" ]; then
        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf
        tar xjvf %{SOURCE301} -C $RPM_BUILD_ROOT/kabi-dwarf

        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf/whitelists
        tar xjvf %{SOURCE300} -C $RPM_BUILD_ROOT/kabi-dwarf/whitelists

        echo "**** GENERATING DWARF-based kABI baseline dataset ****"
        chmod 0755 $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh
        $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh generate \
            "$RPM_BUILD_ROOT/kabi-dwarf/whitelists/kabi-current/kabi_whitelist_%{_target_cpu}" \
            "$(pwd)" \
            "$RPM_BUILD_ROOT/kabidw-base/%{_target_cpu}${Flavour:+.${Flavour}}" || :

        rm -rf $RPM_BUILD_ROOT/kabi-dwarf
    fi
%endif

%if %{with_kabidwchk}
    if [ "$Flavour" != "kdump" ]; then
        mkdir -p $RPM_BUILD_ROOT/kabi-dwarf
        tar xjvf %{SOURCE301} -C $RPM_BUILD_ROOT/kabi-dwarf
        if [ -d "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Flavour:+.${Flavour}}" ]; then
            mkdir -p $RPM_BUILD_ROOT/kabi-dwarf/whitelists
            tar xjvf %{SOURCE300} -C $RPM_BUILD_ROOT/kabi-dwarf/whitelists

            echo "**** GENERATING DWARF-based kABI dataset ****"
            chmod 0755 $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh
            $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh generate \
                "$RPM_BUILD_ROOT/kabi-dwarf/whitelists/kabi-current/kabi_whitelist_%{_target_cpu}" \
                "$(pwd)" \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Flavour:+.${Flavour}}.tmp" || :

            echo "**** kABI DWARF-based comparison report ****"
            $RPM_BUILD_ROOT/kabi-dwarf/run_kabi-dw.sh compare \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Flavour:+.${Flavour}}" \
                "$RPM_BUILD_ROOT/kabi-dwarf/base/%{_target_cpu}${Flavour:+.${Flavour}}.tmp" || :
            echo "**** End of kABI DWARF-based comparison report ****"
        else
            echo "**** Baseline dataset for kABI DWARF-BASED comparison report not found ****"
        fi

        rm -rf $RPM_BUILD_ROOT/kabi-dwarf
    fi
%endif

    # then drop all but the needed Makefiles/Kconfig files
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Documentation
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
    cp .config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    cp -a scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build
    rm -rf $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/tracing
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/spdxcheck.py
    if [ -f tools/objtool/objtool ]; then
      cp -a tools/objtool/objtool $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/tools/objtool/ || :
    fi
    if [ -d arch/$Arch/scripts ]; then
      cp -a arch/$Arch/scripts $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch} || :
    fi
    if [ -f arch/$Arch/*lds ]; then
      cp -a arch/$Arch/*lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/arch/%{_arch}/ || :
    fi
    if [ -f arch/%{asmarch}/kernel/module.lds ]; then
      cp -a --parents arch/%{asmarch}/kernel/module.lds $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*.o
    rm -f $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/scripts/*/*.o
%ifarch ppc64le
    cp -a --parents arch/powerpc/lib/crtsavres.[So] $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    if [ -d arch/%{asmarch}/include ]; then
      cp -a --parents arch/%{asmarch}/include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    fi
%ifarch aarch64
    # arch/arm64/include/asm/xen references arch/arm
    cp -a --parents arch/arm/include/asm/xen $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    # arch/arm64/include/asm/opcodes.h references arch/arm
    cp -a --parents arch/arm/include/asm/opcodes.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    cp -a include $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include
%ifarch x86_64
    # files for 'make prepare' to succeed with kernel-devel
    cp -a --parents arch/x86/entry/syscalls/syscall_32.tbl $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/entry/syscalls/syscalltbl.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/entry/syscalls/syscallhdr.sh $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/entry/syscalls/syscall_64.tbl $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_32.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_64.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs_common.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/tools/relocs.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents tools/include/tools/le_byteshift.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/purgatory.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/stack.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/string.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/setup-x86_64.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/purgatory/entry64.S $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/string.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/string.c $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
    cp -a --parents arch/x86/boot/ctype.h $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/
%endif
    # Make sure the Makefile and version.h have a matching timestamp so that
    # external modules can be built
    touch -r $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/Makefile $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/generated/uapi/linux/version.h

    # Copy .config to include/config/auto.conf so "make prepare" is unnecessary.
    cp $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/.config $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/include/config/auto.conf

%if %{with_debuginfo}
    eu-readelf -n vmlinux | grep "Build ID" | awk '{print $NF}' > vmlinux.id
    cp vmlinux.id $RPM_BUILD_ROOT/lib/modules/$KernelVer/build/vmlinux.id

    #
    # save the vmlinux file for kernel debugging into the kernel-debuginfo rpm
    #
    mkdir -p $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
    cp vmlinux $RPM_BUILD_ROOT%{debuginfodir}/lib/modules/$KernelVer
%endif

    find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name "*.ko" -type f >modnames

    # mark modules executable so that strip-to-file can strip them
    xargs --no-run-if-empty chmod u+x < modnames

    # Generate a list of modules for block and networking.

    grep -F /drivers/ modnames | xargs --no-run-if-empty nm -upA |
    sed -n 's,^.*/\([^/]*\.ko\):  *U \(.*\)$,\1 \2,p' > drivers.undef

    collect_modules_list()
    {
      sed -r -n -e "s/^([^ ]+) \\.?($2)\$/\\1/p" drivers.undef |
        LC_ALL=C sort -u > $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      if [ ! -z "$3" ]; then
        sed -r -e "/^($3)\$/d" -i $RPM_BUILD_ROOT/lib/modules/$KernelVer/modules.$1
      fi
    }

    collect_modules_list networking \
      'register_netdev|ieee80211_register_hw|usbnet_probe|phy_driver_register|rt(l_|2x00)(pci|usb)_probe|register_netdevice'
    collect_modules_list block \
      'ata_scsi_ioctl|scsi_add_host|scsi_add_host_with_dma|blk_alloc_queue|blk_init_queue|register_mtd_blktrans|scsi_esp_register|scsi_register_device_handler|blk_queue_physical_block_size' 'pktcdvd.ko|dm-mod.ko'
    collect_modules_list drm \
      'drm_open|drm_init'
    collect_modules_list modesetting \
      'drm_crtc_init'
%if %{with_realtime}
    collect_modules_list kvm \
      'kvm_init|kvmgt_init'
%endif

    # detect missing or incorrect license tags
    ( find $RPM_BUILD_ROOT/lib/modules/$KernelVer -name '*.ko' | xargs /sbin/modinfo -l | \
        grep -E -v 'GPL( v2)?$|Dual BSD/GPL$|Dual MPL/GPL$|GPL and additional rights$' ) && exit 1

    # remove files that will be auto generated by depmod at rpm -i time
    pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/
        rm -f modules.{alias*,builtin.bin,dep*,*map,symbols*,devname,softdep}
    popd

    # Call the modules-extra script to move things around
    %{SOURCE17} $RPM_BUILD_ROOT/lib/modules/$KernelVer %{SOURCE16}

    #
    # Generate the kernel-core and kernel-modules files lists
    #

    # Copy the System.map file for depmod to use, and create a backup of the
    # full module tree so we can restore it after we're done filtering
    cp System.map $RPM_BUILD_ROOT/.
    pushd $RPM_BUILD_ROOT
    mkdir restore
    cp -r lib/modules/$KernelVer/* restore/.

    # don't include anything going into k-m-e in the file lists
    rm -rf lib/modules/$KernelVer/extra

    if [ $DoModules -eq 1 ]; then
	# Find all the module files and filter them out into the core and
	# modules lists.  This actually removes anything going into -modules
	# from the dir.
	find lib/modules/$KernelVer/kernel -name *.ko | sort -n > modules.list
	cp $RPM_SOURCE_DIR/filter-*.sh .
	%{SOURCE99} modules.list %{_target_cpu}
	rm filter-*.sh

	# Run depmod on the resulting module tree and make sure it isn't broken
	depmod -b . -aeF ./System.map $KernelVer &> depmod.out
	if [ -s depmod.out ]; then
	    echo "Depmod failure"
	    cat depmod.out
	    exit 1
	else
	    rm depmod.out
	fi
    else
	# Ensure important files/directories exist to let the packaging succeed
	echo '%%defattr(-,-,-)' > modules.list
	echo '%%defattr(-,-,-)' > k-d.list
	mkdir -p lib/modules/$KernelVer/kernel
	# Add files usually created by make modules, needed to prevent errors
	# thrown by depmod during package installation
	touch lib/modules/$KernelVer/modules.order
	touch lib/modules/$KernelVer/modules.builtin
    fi

    # remove files that will be auto generated by depmod at rpm -i time
    pushd $RPM_BUILD_ROOT/lib/modules/$KernelVer/
        rm -f modules.{alias*,builtin.bin,dep*,*map,symbols*,devname,softdep}
    popd

    # Go back and find all of the various directories in the tree.  We use this
    # for the dir lists in kernel-core
    find lib/modules/$KernelVer/kernel -mindepth 1 -type d | sort -n > module-dirs.list

    # Cleanup
    rm System.map
    cp -r restore/* lib/modules/$KernelVer/.
    rm -rf restore
    popd

    # Make sure the files lists start with absolute paths or rpmbuild fails.
    # Also add in the dir entries
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/k-d.list > ../%{name}${Flavour:+-${Flavour}}-modules.list
    sed -e 's/^lib*/%dir \/lib/' %{?zipsed} $RPM_BUILD_ROOT/module-dirs.list > ../%{name}${Flavour:+-${Flavour}}-core.list
    sed -e 's/^lib*/\/lib/' %{?zipsed} $RPM_BUILD_ROOT/modules.list >> ../%{name}${Flavour:+-${Flavour}}-core.list

    # Cleanup
    rm -f $RPM_BUILD_ROOT/k-d.list
    rm -f $RPM_BUILD_ROOT/modules.list
    rm -f $RPM_BUILD_ROOT/module-dirs.list

%if %{signmodules}
    if [ $DoModules -eq 1 ]; then
	# Save the signing keys so we can sign the modules in __modsign_install_post
	cp certs/signing_key.pem certs/signing_key.pem.sign${Flav}
	cp certs/signing_key.x509 certs/signing_key.x509.sign${Flav}
    fi
%endif

    # Move the devel headers out of the root file system
    mkdir -p $RPM_BUILD_ROOT/usr/src/kernels
    mv $RPM_BUILD_ROOT/lib/modules/$KernelVer/build $RPM_BUILD_ROOT/$DevelDir

    # This is going to create a broken link during the build, but we don't use
    # it after this point.  We need the link to actually point to something
    # when kernel-devel is installed, and a relative link doesn't work across
    # the F17 UsrMove feature.
    ln -sf $DevelDir $RPM_BUILD_ROOT/lib/modules/$KernelVer/build

    # prune junk from kernel-devel
    find $RPM_BUILD_ROOT/usr/src/kernels -name ".*.cmd" -exec rm -f {} \;

    # build a BLS config for this kernel
    %{SOURCE43} "$KernelVer" "$RPM_BUILD_ROOT" "%{?variant}"

    # Red Hat UEFI Secure Boot CA cert, which can be used to authenticate the kernel
    mkdir -p $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer
    install -m 0644 %{SOURCE13} $RPM_BUILD_ROOT%{_datadir}/doc/kernel-keys/$KernelVer/kernel-signing-ca.cer

}

###
# DO it...
###

# prepare directories
rm -rf $RPM_BUILD_ROOT
mkdir -p $RPM_BUILD_ROOT/boot
mkdir -p $RPM_BUILD_ROOT%{_libexecdir}

cd linux-%{KVERREL}


%if %{with_debug}
BuildKernel %make_target %kernel_image %{with_vdso_install} debug
%endif

%if %{with_zfcpdump}
BuildKernel %make_target %kernel_image %{with_vdso_install} zfcpdump
%endif

%if %{with_up}
BuildKernel %make_target %kernel_image %{with_vdso_install}
%endif

%global perf_make \
  make EXTRA_CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags}" %{?cross_opts} -C tools/perf V=1 NO_PERF_READ_VDSO32=1 NO_PERF_READ_VDSOX32=1 WERROR=0 NO_LIBUNWIND=1 HAVE_CPLUS_DEMANGLE=1 NO_GTK2=1 NO_STRLCPY=1 NO_BIONIC=1 prefix=%{_prefix} PYTHON=%{__python3}
%if %{with_perf}
# perf
# make sure check-headers.sh is executable
chmod +x tools/perf/check-headers.sh
%{perf_make} DESTDIR=$RPM_BUILD_ROOT all
%endif

%global tools_make \
  %{make} CFLAGS="${RPM_OPT_FLAGS}" LDFLAGS="%{__global_ldflags}" V=1

%if %{with_tools}
%ifarch %{cpupowerarchs}
# cpupower
# make sure version-gen.sh is executable.
chmod +x tools/power/cpupower/utils/version-gen.sh
%{tools_make} -C tools/power/cpupower CPUFREQ_BENCH=false DEBUG=false
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    %{tools_make} centrino-decode powernow-k8-decode
    popd
%endif
%ifarch x86_64
   pushd tools/power/x86/x86_energy_perf_policy/
   %{make}
   popd
   pushd tools/power/x86/turbostat
   %{make}
   popd
%endif #turbostat/x86_energy_perf_policy
%endif
pushd tools/thermal/tmon/
%{make}
popd
pushd tools/iio/
%{make}
popd
pushd tools/gpio/
%{make}
popd
%endif

%global bpftool_make \
  make EXTRA_CFLAGS="${RPM_OPT_FLAGS}" EXTRA_LDFLAGS="%{__global_ldflags}" DESTDIR=$RPM_BUILD_ROOT V=1
%if %{with_bpftool}
pushd tools/bpf/bpftool
%{bpftool_make}
popd
%endif

%if %{with_bpf_samples}
# Unfortunately, samples/bpf/Makefile expects that the headers are installed
# in the source tree. We installed them previously to $RPM_BUILD_ROOT/usr
# but there's no way to tell the Makefile to take them from there.
make headers_install
%{make} -s ARCH=$Arch V=1 samples/bpf/
pushd tools/testing/selftests
# We need to install here because we need to call make with ARCH set which
# doesn't seem possible to do in the install section.
%{make} -s ARCH=$Arch V=1 TARGETS=bpf INSTALL_PATH=%{buildroot}%{_libexecdir}/bpf-samples/selftests install
popd
%endif

# In the modsign case, we do 3 things.  1) We check the "flavour" and hard
# code the value in the following invocations.  This is somewhat sub-optimal
# but we're doing this inside of an RPM macro and it isn't as easy as it
# could be because of that.  2) We restore the .tmp_versions/ directory from
# the one we saved off in BuildKernel above.  This is to make sure we're
# signing the modules we actually built/installed in that flavour.  3) We
# grab the arch and invoke mod-sign.sh command to actually sign the modules.
#
# We have to do all of those things _after_ find-debuginfo runs, otherwise
# that will strip the signature off of the modules.
#
# Don't sign modules for the zfcpdump flavour as it is monolithic.

%define __modsign_install_post \
  if [ "%{signmodules}" -eq "1" ]; then \
    if [ "%{with_debug}" -ne "0" ]; then \
      %{modsign_cmd} certs/signing_key.pem.sign+debug certs/signing_key.x509.sign+debug $RPM_BUILD_ROOT/lib/modules/%{KVERREL}+debug/ \
    fi \
    if [ "%{with_up}" -ne "0" ]; then \
      %{modsign_cmd} certs/signing_key.pem.sign certs/signing_key.x509.sign $RPM_BUILD_ROOT/lib/modules/%{KVERREL}/ \
    fi \
  fi \
  if [ "%{zipmodules}" -eq "1" ]; then \
    find $RPM_BUILD_ROOT/lib/modules/ -type f -name '*.ko' | xargs xz; \
  fi \
%{nil}

###
### Special hacks for debuginfo subpackages.
###

# This macro is used by %%install, so we must redefine it before that.
%define debug_package %{nil}

%if %{with_debuginfo}

%ifnarch noarch
%global __debug_package 1
%files -f debugfiles.list debuginfo-common-%{_target_cpu}
%defattr(-,root,root)
%endif

%endif

#
# Disgusting hack alert! We need to ensure we sign modules *after* all
# invocations of strip occur, which is in __debug_install_post if
# find-debuginfo.sh runs, and __os_install_post if not.
#
%define __spec_install_post \
  %{?__debug_package:%{__debug_install_post}}\
  %{__arch_install_post}\
  %{__os_install_post}\
  %{__modsign_install_post}

###
### install
###

%install

cd linux-%{KVERREL}

# We have to do the headers install before the tools install because the
# kernel headers_install will remove any header files in /usr/include that
# it doesn't install itself.

%if %{with_headers}
# Install kernel headers
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr headers_install

find $RPM_BUILD_ROOT/usr/include \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) | xargs rm -f

%endif

%if %{with_cross_headers}
mkdir -p $RPM_BUILD_ROOT/usr/tmp-headers
make ARCH=%{hdrarch} INSTALL_HDR_PATH=$RPM_BUILD_ROOT/usr/tmp-headers headers_install_all

find $RPM_BUILD_ROOT/usr/tmp-headers/include \
     \( -name .install -o -name .check -o \
        -name ..install.cmd -o -name ..check.cmd \) | xargs rm -f

# Copy all the architectures we care about to their respective asm directories
for arch in arm64 powerpc s390 x86 ; do
mkdir -p $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include
mv $RPM_BUILD_ROOT/usr/tmp-headers/include/arch-${arch}/asm $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include/
cp -a $RPM_BUILD_ROOT/usr/tmp-headers/include/asm-generic $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include/.
done

# Remove the rest of the architectures
rm -rf $RPM_BUILD_ROOT/usr/tmp-headers/include/arch*
rm -rf $RPM_BUILD_ROOT/usr/tmp-headers/include/asm-*

# Copy the rest of the headers over
for arch in arm64 powerpc s390 x86 ; do
cp -a $RPM_BUILD_ROOT/usr/tmp-headers/include/* $RPM_BUILD_ROOT/usr/${arch}-linux-gnu/include/.
done

rm -rf $RPM_BUILD_ROOT/usr/tmp-headers
%endif

%if %{with_kernel_abi_whitelists}
# kabi directory
INSTALL_KABI_PATH=$RPM_BUILD_ROOT/lib/modules/
mkdir -p $INSTALL_KABI_PATH

# install kabi releases directories
tar xjvf %{SOURCE300} -C $INSTALL_KABI_PATH
%endif  # with_kernel_abi_whitelists

%if %{with_perf}
# perf tool binary and supporting scripts/binaries
%{perf_make} DESTDIR=$RPM_BUILD_ROOT lib=%{_lib} install-bin install-traceevent-plugins
# remove the 'trace' symlink.
rm -f %{buildroot}%{_bindir}/trace
# remove the perf-tips
rm -rf %{buildroot}%{_docdir}/perf-tip

# For both of the below, yes, this should be using a macro but right now
# it's hard coded and we don't actually want it anyway right now.
# Whoever wants examples can fix it up!

# remove examples
rm -rf %{buildroot}/usr/lib/examples/perf
# remove the stray header file that somehow got packaged in examples
rm -rf %{buildroot}/usr/lib/include/perf/bpf/bpf.h

# python-perf extension
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-python_ext

# perf man pages (note: implicit rpm magic compresses them later)
mkdir -p %{buildroot}/%{_mandir}/man1
%{perf_make} DESTDIR=$RPM_BUILD_ROOT install-man
%endif

%if %{with_tools}
%ifarch %{cpupowerarchs}
%{make} -C tools/power/cpupower DESTDIR=$RPM_BUILD_ROOT libdir=%{_libdir} mandir=%{_mandir} CPUFREQ_BENCH=false install
rm -f %{buildroot}%{_libdir}/*.{a,la}
%find_lang cpupower
mv cpupower.lang ../
%ifarch x86_64
    pushd tools/power/cpupower/debug/x86_64
    install -m755 centrino-decode %{buildroot}%{_bindir}/centrino-decode
    install -m755 powernow-k8-decode %{buildroot}%{_bindir}/powernow-k8-decode
    popd
%endif
chmod 0755 %{buildroot}%{_libdir}/libcpupower.so*
mkdir -p %{buildroot}%{_unitdir} %{buildroot}%{_sysconfdir}/sysconfig
install -m644 %{SOURCE2000} %{buildroot}%{_unitdir}/cpupower.service
install -m644 %{SOURCE2001} %{buildroot}%{_sysconfdir}/sysconfig/cpupower
%endif
%ifarch x86_64
   mkdir -p %{buildroot}%{_mandir}/man8
   pushd tools/power/x86/x86_energy_perf_policy
   %{tools_make} DESTDIR=%{buildroot} install
   popd
   pushd tools/power/x86/turbostat
   %{tools_make} DESTDIR=%{buildroot} install
   popd
%endif #turbostat/x86_energy_perf_policy
pushd tools/thermal/tmon
%{tools_make} INSTALL_ROOT=%{buildroot} install
popd
pushd tools/iio
%{tools_make} DESTDIR=%{buildroot} install
popd
pushd tools/gpio
%{tools_make} DESTDIR=%{buildroot} install
popd
pushd tools/kvm/kvm_stat
make INSTALL_ROOT=%{buildroot} install-tools
make INSTALL_ROOT=%{buildroot} install-man
popd
%endif

%if %{with_bpftool}
pushd tools/bpf/bpftool
%{bpftool_make} prefix=%{_prefix} bash_compdir=%{_sysconfdir}/bash_completion.d/ mandir=%{_mandir} install doc-install
popd
%endif

%if %{with_bpf_samples}
pushd samples/bpf
install -d %{buildroot}%{_libexecdir}/bpf-samples
find -type f -executable -exec install -m755 {} %{buildroot}%{_libexecdir}/bpf-samples \;
install -m755 *.sh %{buildroot}%{_libexecdir}/bpf-samples
# test_lwt_bpf.sh compiles test_lwt_bpf.c when run; this works only from the
# kernel tree. Just remove it.
rm %{buildroot}%{_libexecdir}/bpf-samples/test_lwt_bpf.sh
install -m644 *_kern.o %{buildroot}%{_libexecdir}/bpf-samples
install -m644 tcp_bpf.readme %{buildroot}%{_libexecdir}/bpf-samples
popd
%endif

# We have to do the headers checksum calculation after the tools install because
# these might end up installing their own set of headers on top of kernel's
%if %{with_headers}
# compute a content hash to export as Provides: kernel-headers-checksum
HEADERS_CHKSUM=$(export LC_ALL=C; find $RPM_BUILD_ROOT/usr/include -type f -name "*.h" \
			! -path $RPM_BUILD_ROOT/usr/include/linux/version.h | \
		 sort | xargs cat | sha1sum - | cut -f 1 -d ' ');
# export the checksum via usr/include/linux/version.h, so the dynamic
# find-provides can grab the hash to update it accordingly
echo "#define KERNEL_HEADERS_CHECKSUM \"$HEADERS_CHKSUM\"" >> $RPM_BUILD_ROOT/usr/include/linux/version.h
%endif

###
### clean
###

%clean
rm -rf $RPM_BUILD_ROOT

###
### scripts
###

%if %{with_tools}
%post -n %{name}-tools-libs
/sbin/ldconfig

%postun -n %{name}-tools-libs
/sbin/ldconfig
%endif

#
# This macro defines a %%post script for a kernel*-devel package.
#	%%kernel_devel_post [<subpackage>]
#
%define kernel_devel_post() \
%{expand:%%post %{?1:%{1}-}devel}\
if [ -f /etc/sysconfig/kernel ]\
then\
    . /etc/sysconfig/kernel || exit $?\
fi\
if [ "$HARDLINK" != "no" -a -x /usr/sbin/hardlink ]\
then\
    (cd /usr/src/kernels/%{KVERREL}%{?1:+%{1}} &&\
     /usr/bin/find . -type f | while read f; do\
       hardlink -c /usr/src/kernels/*%{?dist}.*/$f $f\
     done)\
fi\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules-extra package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_extra_post [<subpackage>]
#
%define kernel_modules_extra_post() \
%{expand:%%post %{?1:%{1}-}modules-extra}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules-extra}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

#
# This macro defines a %%post script for a kernel*-modules package.
# It also defines a %%postun script that does the same thing.
#	%%kernel_modules_post [<subpackage>]
#
%define kernel_modules_post() \
%{expand:%%post %{?1:%{1}-}modules}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}\
%{expand:%%postun %{?1:%{1}-}modules}\
/sbin/depmod -a %{KVERREL}%{?1:+%{1}}\
%{nil}

# This macro defines a %%posttrans script for a kernel package.
#	%%kernel_variant_posttrans [<subpackage>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_posttrans() \
%{expand:%%posttrans %{?1:%{1}-}core}\
%if !%{with_realtime}\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --add-kernel %{KVERREL}%{?1:+%{1}} || exit $?\
fi\
%endif\
/bin/kernel-install add %{KVERREL}%{?1:+%{1}} /lib/modules/%{KVERREL}%{?1:+%{1}}/vmlinuz || exit $?\
%{nil}

#
# This macro defines a %%post script for a kernel package and its devel package.
#	%%kernel_variant_post [-v <subpackage>] [-r <replace>]
# More text can follow to go at the end of this variant's %%post.
#
%define kernel_variant_post(v:r:) \
%{expand:%%kernel_devel_post %{?-v*}}\
%{expand:%%kernel_modules_post %{?-v*}}\
%{expand:%%kernel_modules_extra_post %{?-v*}}\
%{expand:%%kernel_variant_posttrans %{?-v*}}\
%{expand:%%post %{?-v*:%{-v*}-}core}\
%{-r:\
if [ `uname -i` == "x86_64" -o `uname -i` == "i386" ] &&\
   [ -f /etc/sysconfig/kernel ]; then\
  /bin/sed -r -i -e 's/^DEFAULTKERNEL=%{-r*}$/DEFAULTKERNEL=kernel%{?-v:-%{-v*}}/' /etc/sysconfig/kernel || exit $?\
fi}\
%{nil}

%if %{with_realtime}
# This macro defines a %%post script for a kernel-rt-kvm package.
#	%%kernel_kvm_variant_post <subpackage>
#
%define kernel_kvm_variant_post() \
%{expand:%%post %{?1:%{1}-}kvm}\
depmod %{KVERREL}%{?1:+%{1}} || exit $?\
%{nil}
%endif

#
# This macro defines a %%preun script for a kernel package.
#	%%kernel_variant_preun <subpackage>
#
%define kernel_variant_preun() \
%{expand:%%preun %{?1:%{1}-}core}\
/bin/kernel-install remove %{KVERREL}%{?1:+%{1}} /lib/modules/%{KVERREL}%{?1:+%{1}}/vmlinuz || exit $?\
%if !%{with_realtime}\
if [ -x %{_sbindir}/weak-modules ]\
then\
    %{_sbindir}/weak-modules --remove-kernel %{KVERREL}%{?1:+%{1}} || exit $?\
fi\
%endif\
%{nil}

%if %{with_realtime}
# This macro defines a %%postun script for a kernel-rt-kvm package.
#	%%kernel_kvm_variant_postun <subpackage>
#
%define kernel_kvm_variant_postun() \
%{expand:%%postun %{?1:%{1}-}kvm}\
depmod %{KVERREL}%{?1:+%{1}} || exit $?\
%{nil}
%endif

%kernel_variant_preun
%kernel_variant_post
%if %{with_realtime}
%kernel_kvm_variant_post
%kernel_kvm_variant_postun
%endif

%kernel_variant_preun debug
%kernel_variant_post -v debug
%if %{with_realtime}
%kernel_kvm_variant_post debug
%kernel_kvm_variant_postun debug
%endif

%if %{with_zfcpdump}
%kernel_variant_preun zfcpdump
%kernel_variant_post -v zfcpdump
%endif

if [ -x /sbin/ldconfig ]
then
    /sbin/ldconfig -X || exit $?
fi

###
### file lists
###

%if %{with_headers}
%files headers
%defattr(-,root,root)
/usr/include/*
%endif

%if %{with_cross_headers}
%files cross-headers
%defattr(-,root,root)
/usr/*-linux-gnu/include/*
%endif

%if %{with_kernel_abi_whitelists}
%files -n kernel-abi-whitelists
%defattr(-,root,root,-)
/lib/modules/kabi-*
%endif

%if %{with_kabidw_base}
%ifarch x86_64 s390x ppc64 ppc64le aarch64
%files kabidw-base
%defattr(-,root,root)
/kabidw-base/%{_target_cpu}/*
%endif
%endif

%if %{with_perf}
%files -n perf
%defattr(-,root,root)
%{_bindir}/perf
%{_libdir}/libperf-jvmti.so
%dir %{_libdir}/traceevent/plugins
%{_libdir}/traceevent/plugins/*
%dir %{_libexecdir}/perf-core
%{_libexecdir}/perf-core/*
%{_datadir}/perf-core/*
%{_mandir}/man[1-8]/perf*
%{_sysconfdir}/bash_completion.d/perf
%doc linux-%{KVERREL}/tools/perf/Documentation/examples.txt

%files -n python3-perf
%defattr(-,root,root)
%{python3_sitearch}/*

%if %{with_debuginfo}
%files -f perf-debuginfo.list -n perf-debuginfo
%defattr(-,root,root)

%files -f python3-perf-debuginfo.list -n python3-perf-debuginfo
%defattr(-,root,root)
%endif
%endif # with_perf

%if %{with_tools}
%files -n kernel-tools
%defattr(-,root,root)
%ifarch %{cpupowerarchs}
%files -n %{name}-tools -f cpupower.lang
%{_bindir}/cpupower
%ifarch x86_64
%{_bindir}/centrino-decode
%{_bindir}/powernow-k8-decode
%endif
%{_unitdir}/cpupower.service
%{_mandir}/man[1-8]/cpupower*
%config(noreplace) %{_sysconfdir}/sysconfig/cpupower
%ifarch x86_64
%{_bindir}/x86_energy_perf_policy
%{_mandir}/man8/x86_energy_perf_policy*
%{_bindir}/turbostat
%{_mandir}/man8/turbostat*
%endif
%endif # cpupowerarchs
%{_bindir}/tmon
%{_bindir}/iio_event_monitor
%{_bindir}/iio_generic_buffer
%{_bindir}/lsiio
%{_bindir}/lsgpio
%{_bindir}/gpio-hammer
%{_bindir}/gpio-event-mon
%{_mandir}/man1/kvm_stat*
%{_bindir}/kvm_stat

%if %{with_debuginfo}
%files -f %{name}-tools-debuginfo.list -n %{name}-tools-debuginfo
%defattr(-,root,root)
%endif

%ifarch %{cpupowerarchs}
%files -n %{name}-tools-libs
%{_libdir}/libcpupower.so.0
%{_libdir}/libcpupower.so.0.0.1

%files -n %{name}-tools-libs-devel
%{_libdir}/libcpupower.so
%{_includedir}/cpufreq.h
%endif
%endif # with_tools

%if %{with_bpftool}
%files -n bpftool
%{_sbindir}/bpftool
%{_sysconfdir}/bash_completion.d/bpftool
%{_mandir}/man8/bpftool-cgroup.8.gz
%{_mandir}/man8/bpftool-map.8.gz
%{_mandir}/man8/bpftool-prog.8.gz
%{_mandir}/man8/bpftool-perf.8.gz
%{_mandir}/man8/bpftool.8.gz

%if %{with_debuginfo}
%files -f bpftool-debuginfo.list -n bpftool-debuginfo
%defattr(-,root,root)
%endif
%endif

%if %{with_bpf_samples}
%files -n bpf-samples
%{_libexecdir}/bpf-samples
%endif

# empty meta-package
%ifnarch %nobuildarches noarch
%files
%defattr(-,root,root)
%endif

%if %{with_gcov}
%ifarch x86_64 s390x ppc64le aarch64
%files gcov
%defattr(-,root,root)
%{_builddir}
%endif
%endif

# This is %%{image_install_path} on an arch where that includes ELF files,
# or empty otherwise.
%define elf_image_install_path %{?kernel_image_elf:%{image_install_path}}

#
# This macro defines the %%files sections for a kernel package
# and its devel and debuginfo packages.
#	%%kernel_variant_files [-k vmlinux] <condition> <subpackage>
#
%define kernel_variant_files(k:) \
%if %{2}\
%{expand:%%files -f %{name}-%{?3:%{3}-}core.list %{?3:%{3}-}core}\
%defattr(-,root,root)\
%if %{with_realtime}\
%exclude /lib/modules/%{KVERREL}%{?3:+%{3}}/kernel/arch/x86/kvm\
%exclude /lib/modules/%{KVERREL}%{?3:+%{3}}/kernel/drivers/gpu/drm/i915/gvt\
%exclude /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.kvm\
%exclude /lib/modules/%{KVERREL}%{?3:+%{3}}/kernel/drivers/ptp/ptp_kvm*\
%endif\
%{!?_licensedir:%global license %%doc}\
%license linux-%{KVERREL}/COPYING-%{version}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/%{?-k:%{-k*}}%{!?-k:vmlinuz}\
%ghost /%{image_install_path}/%{?-k:%{-k*}}%{!?-k:vmlinuz}-%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/.vmlinuz.hmac \
%ghost /%{image_install_path}/.vmlinuz-%{KVERREL}%{?3:+%{3}}.hmac \
%ifarch aarch64\
/lib/modules/%{KVERREL}%{?3:+%{3}}/dtb \
%ghost /%{image_install_path}/dtb-%{KVERREL}%{?3:+%{3}} \
%endif\
%attr(600,root,root) /lib/modules/%{KVERREL}%{?3:+%{3}}/System.map\
%ghost /boot/System.map-%{KVERREL}%{?3:+%{3}}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/symvers.gz\
/lib/modules/%{KVERREL}%{?3:+%{3}}/config\
%ghost /boot/symvers-%{KVERREL}%{?3:+%{3}}.gz\
%ghost /boot/config-%{KVERREL}%{?3:+%{3}}\
%ghost /boot/initramfs-%{KVERREL}%{?3:+%{3}}.img\
%dir /lib/modules\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}\
%dir /lib/modules/%{KVERREL}%{?3:+%{3}}/kernel\
/lib/modules/%{KVERREL}%{?3:+%{3}}/build\
/lib/modules/%{KVERREL}%{?3:+%{3}}/source\
/lib/modules/%{KVERREL}%{?3:+%{3}}/updates\
/lib/modules/%{KVERREL}%{?3:+%{3}}/weak-updates\
/lib/modules/%{KVERREL}%{?3:+%{3}}/bls.conf\
%{_datadir}/doc/kernel-keys/%{KVERREL}%{?3:+%{3}}/kernel-signing-ca.cer\
%if %{1}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/vdso\
/etc/ld.so.conf.d/%{name}-%{KVERREL}%{?3:+%{3}}.conf\
%endif\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.*\
%{expand:%%files -f %{name}-%{?3:%{3}-}modules.list %{?3:%{3}-}modules}\
%defattr(-,root,root)\
%if %{with_realtime}\
%exclude /lib/modules/%{KVERREL}%{?3:+%{3}}/kernel/arch/x86/kvm\
%exclude /lib/modules/%{KVERREL}%{?3:+%{3}}/kernel/drivers/gpu/drm/i915/gvt\
%exclude /lib/modules/%{KVERREL}%{?3:+%{3}}/modules.kvm\
%exclude /lib/modules/%{KVERREL}%{?3:+%{3}}/kernel/drivers/ptp/ptp_kvm*\
%endif\
%{expand:%%files %{?3:%{3}-}devel}\
%defattr(-,root,root)\
%defverify(not mtime)\
/usr/src/kernels/%{KVERREL}%{?3:+%{3}}\
%{expand:%%files %{?3:%{3}-}modules-extra}\
%defattr(-,root,root)\
/lib/modules/%{KVERREL}%{?3:+%{3}}/extra\
%if %{with_debuginfo}\
%ifnarch noarch\
%{expand:%%files -f debuginfo%{?3}.list %{?3:%{3}-}debuginfo}\
%defattr(-,root,root)\
%if %{with_realtime}\
%exclude /lib/modules/%{KVERREL}%{?3:+%{3}}/kernel/arch/x86/kvm\
%exclude /lib/modules/%{KVERREL}%{?3:+%{3}}/kernel/drivers/gpu/drm/i915/gvt\
%endif\
%endif\
%endif\
%if %{?3:1} %{!?3:0}\
%{expand:%%files %{3}}\
%defattr(-,root,root)\
%endif\
%endif\
%if %{with_realtime}\
%{expand:%%files %{?3:%{3}-}kvm}\
/lib/modules/%{KVERREL}%{?3:+%{3}}/modules.kvm\
/lib/modules/%{KVERREL}%{?3:+%{3}}/kernel/arch/x86/kvm\
/lib/modules/%{KVERREL}%{?3:+%{3}}/kernel/drivers/gpu/drm/i915/gvt/kvmgt.ko*\
/lib/modules/%{KVERREL}%{?3:+%{3}}/kernel/drivers/ptp/ptp_kvm.ko*\
%if %{with_debuginfo}\
%{expand:%%files %{?3:%{3}-}kvm-debuginfo}\
%dir %{debuginfodir}/lib/modules/%{KVERREL}%{?3:+%{3}}/kernel/arch/x86/kvm\
%{debuginfodir}/lib/modules/%{KVERREL}%{?3:+%{3}}/kernel/arch/x86/kvm\
%{debuginfodir}/lib/modules/%{KVERREL}%{?3:+%{3}}/kernel/drivers/gpu/drm/i915/gvt\
%{debuginfodir}/lib/modules/%{KVERREL}%{?3:+%{3}}/kernel/drivers/ptp/ptp_kvm*\
%endif\
%endif\
%{nil}

%kernel_variant_files  %{with_vdso_install} %{with_up}
%kernel_variant_files  %{with_vdso_install} %{with_debug} debug
%if %{with_zfcpdump}
%kernel_variant_files  %{with_vdso_install} %{with_zfcpdump} zfcpdump
%endif

# plz don't put in a version string unless you're going to tag
# and build.
#
#
%changelog
* Fri Jun 14 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-107.rt20.48.el8]
- [rt] kernel-rt-4.18.0-107.rt20.47.el8 (Juri Lelli) [1678887]
- [rt] locking: Fix RT build issues (Juri Lelli)
- [tools] kvm: selftests: make hyperv_cpuid test pass on AMD (Vitaly Kuznetsov) [1718501]
- [scsi] vmw_pvscsi: Fixed to work with SG_CHAIN (Ewan Milne) [1717278]
- [x86] mark AMD Rome processors supported (David Arcari) [1520002]
- [fs] ext4: zero out the unused memory region in the extent tree block (Lukas Czerner) [1715276] {CVE-2019-11833}
- [s390] s390/smp: Fix calling smp_call_ipl_cpu() from ipl CPU (David Hildenbrand) [1715041]
- [vfio] vfio/type1: Limit DMA mappings per container (Alex Williamson) [1695592] {CVE-2019-3882}
- [tools] selftests/powerpc: Remove Power9 paste tests (Diego Domingos) [1662374]
- [tools] selftests/powerpc: Remove Power9 copy_unaligned test (Diego Domingos) [1662374]
- [tools] selftests/powerpc: Fix ptrace tm failure (Diego Domingos) [1662374]
- [netdrv] mlxsw: core: Prevent reading unsupported slave address from SFP EEPROM (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Prevent QSFP module initialization for old hardware (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Fix autoneg status in ethtool (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Reincrease PCI reset timeout (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Put MC TCs into DWRR mode (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Add a multicast pool for Spectrum-2 (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Test VRF MAC vetoing (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Do not check VRF MAC address (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Do not use WQ_MEM_RECLAIM for mlxsw workqueue (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Do not use WQ_MEM_RECLAIM for mlxsw ordered workqueue (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Do not use WQ_MEM_RECLAIM for EMAD workqueue (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Add MDB entries in prepare phase (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: mlxsw: core: avoid -Wint-in-bool-context warning (Ivan Vecera) [1680241]
- [netdrv] mlxsw: minimal: Initialize base_mac (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Prevent duplication during QSFP module initialization (Ivan Vecera) [1680241]
- [netdrv] mellanox: Switch to bitmap_zalloc() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: i2c: Extend initialization by querying resources data (Ivan Vecera) [1680241]
- [netdrv] mlxsw: i2c: Extend input parameters list of command API (Ivan Vecera) [1680241]
- [netdrv] mlxsw: i2c: Modify input parameter name in initialization API (Ivan Vecera) [1680241]
- [netdrv] mlxsw: i2c: Fix comment misspelling (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Move resource query API to common location (Ivan Vecera) [1680241]
- [netdrv] mlxsw: minimal: Add ethtool support (Ivan Vecera) [1680241]
- [netdrv] mlxsw: minimal: Make structures and variables names shorter (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Move ethtool module callbacks to a common location (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Make mlxsw_sp_acl_tcam_vregion_rehash() return void (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Remember where to continue rehash migration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Allow to interrupt/continue rehash work (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Do rollback as another call to mlxsw_sp_acl_tcam_vchunk_migrate_all() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Put vchunk migrate start/end code into separate functions (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Put this_is_rollback to rehash context struct (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Rename variables in mlxsw_sp_acl_tcam_ventry_migrate() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: assign vchunk->chunk by the newly created chunk (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: assign vregion->region by the newly created region (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Push code start/end from mlxsw_sp_acl_tcam_vregion_migrate() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Push rehash start/end code into separate functions (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce new rehash context struct and save hint_priv there (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Don't migrate already migrated entry (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Push rehash dw struct into rehash sub-struct (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Handle SWITCHDEV_PORT_ATTR_SET (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Use struct_size() in kzalloc() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: remove set but not used variable 'autoneg_status' (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: spectrum-2: Add massive delta rehash test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: spectrum-2: Check migrate end trace (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add vregion migration end tracepoint (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: spectrum-2: Add IPv6 variant of simple delta rehash test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Don't take mutex in mlxsw_sp_acl_tcam_vregion_rehash_work() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Remove RTNL lock assertions from ERP code (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Don't take rtnl lock during vregion_rehash_intrvl_set() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce a mutex to guard objagg instance manipulation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Enable vregion rehash per-profile (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce mutex to guard Bloom Filter updates (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce vregion mutex (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Refactor vregion association code (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce a mutex to guard region list updates (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Split TCAM group structure into two (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Remove unused ops field from group structure (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add Spectrum-2 ASIC support for new port types and speeds (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add Spectrum-2 ASIC port type-speed operations (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add new port type-speed fields for PTYS register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: 80 columns wrapping change (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Rename p_eth_proto_adm to full name p_eth_proto_admin (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add port type-speed operations (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Rename port type-speed functions to ASIC specific (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Query port connector type from firmware (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Remove unsupported eth_proto_lp_advertise field in PTYS (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Remove duplicate port link mode entry (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Avoid -Wformat-truncation warnings (Ivan Vecera) [1680241]
- [netdrv] net: Remove SWITCHDEV_ATTR_ID_PORT_BRIDGE_FLAGS_SUPPORT (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Reject overlarge headroom size requests (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Update port headroom configuration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Add Spectrum-2 shared buffer configuration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep mlxsw_sp_sb_mm in sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep mlxsw_sp_sb_cm in sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep mlxsw_sp_sb_prs in mlxsw_sp_sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep mlxsw_sp_sb_pms in mlxsw_sp_sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep pool descriptors in mlxsw_sp_sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Allocate prs & pms dynamically (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add struct mlxsw_sp_sb_vals (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Change IP2ME CPU policer rate and burst size values (Ivan Vecera) [1680241]
- [netdrv] mlxsw: __mlxsw_sp_port_headroom_set(): Fix a use of local variable (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add some missing configuration symbols (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: fix spelling mistake "temprature" -> "temperature" (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Extend thermal module with per QSFP module thermal zones (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Allow thermal zone binding to an external cooling device (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Add QSFP module temperature label attribute to hwmon (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Extend hwmon interface with QSFP module temperature attributes (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Extend hwmon interface with fan fault attribute (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Rename cooling device (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Replace thermal temperature trips with defines (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Modify thermal zone definition (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Set different thermal polling time based on bus frequency capability (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Add API for QSFP module temperature thresholds reading (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Fan Out of Range Event Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Management Temperature Bulk Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Move QSFP EEPROM definitions to common location (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Remove unused variables (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: avoid double sourcing of lib.sh (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_flower: Fix VLAN modify action support (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Drop unnecessary WARN_ON_ONCE() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Set LAG port collector only when active (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Remove getting PORT_BRIDGE_FLAGS (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Use struct_size() in kzalloc() (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: spectrum-2: Add simple delta rehash test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add couple of vregion rehash tracepoints (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: add "acl_region_rehash_interval" devlink param (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Implement region migration according to hints (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add multi field to PAGT register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Pass hints priv all the way to ERP code (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Implement basic ERP rehash hits creation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Split entry struct into entry and ventry (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Split chunk struct into chunk and vchunk (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Split region struct into region and vregion (Ivan Vecera) [1680241]
- [netdrv] lib: objagg: implement optimization hints assembly and use hints for object creation (Ivan Vecera) [1680241]
- [netdrv] devlink: publish params only after driver init is done (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test for blackhole routes (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Offload blackhole routes (Ivan Vecera) [1680241]
- [netdrv] mlxsw: Implement ndo_get_port_parent_id() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Trace EMAD errors (Ivan Vecera) [1680241]
- [netdrv] drivers: net: use flow action infrastructure (Ivan Vecera) [1680241]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_flower: Fix test result handling (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_bridge_1q_lag: Ignore ARP (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_bridge_1q_lag: Enable forwarding (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_bridge_1q_lag: Flush neighbors (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_vlan_bridge_1q: Fix roaming test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_lib: Wait for tardy mirrored packets (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_changes: Fix TTL test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Update ping limits (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_lib: Update ping limits (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Make ping timeout configurable (Ivan Vecera) [1680241]
- [tools] selftests: spectrum-2: Add delta two masks one key test (Ivan Vecera) [1680241]
- [tools] selftests: spectrum-2: Fix multiple_masks_test (Ivan Vecera) [1680241]
- [tools] selftests: spectrum-2: Extend and move trace helpers (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add C-TCAM spill tracepoint (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Include delta bits into hashtable key (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Use OK instead of PASS in test output (Ivan Vecera) [1680241]
- [tools] selftests: net: forwarding: change devlink resource support checking (Ivan Vecera) [1680241]
- [documentation] Documentation: add devlink param file for mlxsw driver (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Add more extack messages (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Fix rul/rule typo (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Move mr_ruleset and mr_rule structs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Remove unnecessary arg on action_replace call path (Ivan Vecera) [1680241]
- [netdrv] mlxfw: Replace license text with SPDX identifiers and adjust copyrights (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Enable VXLAN on Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Add support for VXLAN on Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Breakout common code to a common function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Expose functions to create and destroy underlay RIF (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test case for ARP suppression (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test for VXLAN symmetric routing (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test case for ARP decapsulation (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test for VXLAN asymmetric routing (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE hierarchical topology with keys test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE hierarchical topology with key test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE hierarchical topology test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE flat topology with keys test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE flat topology with key test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP-in-IP GRE flat topology test (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add IP tunneling lib (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Add GRE tunnel support for Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Update tunnel decap properties (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Support RIF without device (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Change mlxsw_sp_ipip_lb_ul_vr_id() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Add underlay RIF ID support (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Mark RIF index as taken before creation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Adjust loopback RIF configuration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Set RIF ops per ASIC type (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Split RIF ops array for Spectrum-2 support (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add underlay egress RIF field in RTDP register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add fields to RITR - Router Interface Table Register (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test case for externally learned FDB entries (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Test FDB offload indication (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Do not treat static FDB entries as sticky (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Update dummy FID index (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Return error on PCI reset timeout (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Increase PCI SW reset timeout (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Ring CQ's doorbell before RDQ's (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Test veto of unsupported VXLAN FDBs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add extack messages to VXLAN FDB rejection (Ivan Vecera) [1680241]
- [netdrv] mlxsw: Add extack to mlxsw_sp_nve_ops.fdb_replay (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Use struct_size() in kzalloc() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl_bloom_filter: use struct_size() in kzalloc() (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add a test for VLAN deletion (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Set PVID correctly during VLAN deletion (Ivan Vecera) [1680241]
- [net] net: bridge: Fix VLANs memory leak (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test case for VLAN addition error flow (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Replace error code with EINVAL (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Avoid returning errors in commit phase (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add VXLAN dependency for spectrum (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Disable lag port TX before removing it (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Remove ASSERT_RTNL()s in module removal flow (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add cleanup after C-TCAM update error condition (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: drop useless LIST_HEAD (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add router test with VID 1 (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Adjust test regarding VID 1 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Remove limitation regarding VID 1 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Switch to VID 4095 as default VID (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add an helper function to cleanup VLAN entries (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Store pointer to default port VLAN in port struct (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Allow controlling destruction of default port VLAN (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Set PVID during port initialization (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Replace hard-coded default VID with a define (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test case for L3 VNI (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Do not force specific configuration order (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add rtnetlink tests (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Hold a reference on RIF's netdev (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Make RIF deletion more robust (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Propagate 'struct mlxsw_sp' further (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Properly cleanup LAG uppers when removing port from LAG (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Remove reference count from VLAN entries (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Handle VLAN device unlinking (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Remove unused function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Do not destroy RIFs based on FID's reference count (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Sanitize VLAN interface's uppers (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Fix memory leak upon driver reload (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add trap for decapsulated ARP packets (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Increase timeout during firmware flash process (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Update the supported firmware to version 13.1910.622 (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add Bloom delta test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add Bloom filter complex test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add Bloom filter simple test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Activate Bloom filter (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Set master RP index on transition to eRP (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Update Bloom filter on eRP transitions (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Set A-TCAM rules in Bloom filter (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add Bloom filter update (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add Bloom filter handling (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Introduce Bloom filter (Ivan Vecera) [1680241]
- [netdrv] mlxsw: resources: Add Spectrum-2 Bloom filter resource (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy Engine Algorithmic Bloom Filter Entries Register (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Test FID RIF MAC vetoing (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Test RIF MAC vetoing (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Veto unsupported RIF MAC addresses (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add mlxsw_sp.mac_mask (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Generalize mlxsw_sp_netdevice_router_port_event() (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: extack: Test VLAN add on a port device (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: extack: Test VLAN add on a VXLAN device (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Propagate extack on port VLAN events (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Propagate extack on VXLAN VLAN events (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add multicast routing test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Add Multicast routing support for Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Limit priority value (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Support rule creation without action creation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add replace rule action operation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add multicast router profile operations (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add Spectrum-2 keys (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Change stage of ACL initialization (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy Engine Multicast Router Binding Table Register (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add PVID test case for VXLAN with VLAN-aware bridges (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: vxlan: Test FDB un/marking on VXLAN join/leave (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Un/offload FDB on nve_fid_disable/enable (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add mlxsw_sp_fid_ops.fdb_clear_offload (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Add mlxsw_sp_nve_ops.fdb_clear_offload (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Add mlxsw_sp_nve_ops.fdb_replay (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Publish mlxsw_sp_switchdev_notifier (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Track NVE type at FIDs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Fix VLAN device deletion via ioctl (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Relax GRE decap matching check (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Avoid leaking FID's reference count (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Remove easily triggerable warnings (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a new test extack.sh (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add one-armed router test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Mirror loopbacked packets instead of trapping them (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Load firmware version based on devlink parameter (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Reset firmware after flash during driver initialization (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add VxLAN test with a VLAN-aware bridge (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test for VxLAN configuration with a VLAN-aware bridge (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Consider VLAN-aware bridges as valid (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Enable VxLAN enslavement to VLAN-aware bridges (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Prepare function for VLAN-aware bridges (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Unify VxLAN leave function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Add API to lookup 802.1Q FIDs without creating them (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Flip driver to use emulated 802.1Q FIDs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Introduce emulated VLAN RIFs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Introduce emulated 802.1Q FIDs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Make flood index calculation more robust (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Do not set field when it is reserved (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Consider VxLAN learning enabled as valid (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Allow VxLAN learning (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Allow deletion of learned FDB entries (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Process learned VxLAN FDB entries (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Add API to resolve learned IP addresses (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Allow FID lookup by its index (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Store ifindex of NVE device in FID (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add definition of unicast tunnel record for SFN register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Extend cooling device with cooling levels (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test for VxLAN flooding (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test for VxLAN configuration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Expose discard counters via ethtool (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: spectrum-2: Add simple delta test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Implement delta for ERP (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Push code related to num_ctcam_erps inc/dec into separate helpers (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Remove mlxsw_afk_encode() block range args and key/mask check (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Don't encode the key again in mlxsw_sp_acl_atcam_12kb_lkey_id_get() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl: Change order of args of ops->encode_block() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl: Pass key pointer to master_mask_set/clear (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: acl_erp: Convert to use objagg for tracking ERPs (Ivan Vecera) [1680241]
- [tools] selftests: Adjust spectrum-2 ctcam_two_atcam_masks_test (Ivan Vecera) [1680241]
- [tools] selftests: Adjust spectrum-2 two_mask_test (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Fix IP2ME CPU policer configuration (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: qos_mc_aware: Add a test for UC awareness (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: qos_mc_aware: Tweak for min shaper (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Set minimum shaper on MC TCs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: QEEC: Add minimum shaper fields (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Fix devlink unregister flow (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Don't ignore deletions of learned MACs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Add support for VxLAN encapsulation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Enable VxLAN enslavement to bridges (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Configure matching local routes for NVE decap (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Clear NVE configuration when destroying 802.1D FIDs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Implement VxLAN operations (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_nve: Implement common NVE core (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Allow querying VR ID based on table ID (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Enable local routes promotion to perform NVE decap (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Add APIs to lookup FID without creating it (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_fid: Allow setting and clearing NVE properties on FID (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: Fix use-after-free when flashing firmware during init (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add NVE packet traps (Ivan Vecera) [1680241]
- [netdrv] mlxsw: resources: Add NVE resources (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Monitoring Parsing State Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add definition of unicast tunnel record for SFD register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE QoS Default Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE QoS Configuration Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE Decapsulation ECN Mapping Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE Encapsulation ECN Mapping Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE Underlay Multicast Table Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunnel Port Configuration Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Tunneling NVE General Configuration Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Seed LAG hash function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Extend FDB flush types for NVE (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add a new type of KVD linear record (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Move L3 protocol and address definitions to global header file (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Do not assume notifier information type (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Check notification relevance based on upper device (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Prepare for VxLAN FDB notifications (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Remove misuses of private header file (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: qos_mc_aware: Make executable (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Have lldpad_app_wait_set() wait for unknown, too (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Fix a typo (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Delete RIF when VLAN device is removed (Ivan Vecera) [1680241]
- [netdrv] mlxsw: pci: Derive event type from event queue number (Ivan Vecera) [1680241]
- [netdrv] mlxsw: Make MLXSW_SP1_FWREV_MINOR a hard requirement (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Bump required firmware version (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add a test for UC behavior under MC flood (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Add mtu_set(), mtu_restore() (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Add ethtool_stats_get() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Tweak SBMM configuration (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Configure MC pool (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Allow configuration of static pools (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Pass SBPM min_size in cells (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Allow an infinite maximum for per-TC pool limit (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Allow pools of infinite size (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Keep shared buffer size in mlxsw_sp_sb (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Split TC_COUNT into ingress and egress (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Use devlink pool indices throughout (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Init shaper for TCs 8..15 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_buffers: Set up a dedicated pool for BUM traffic (Ivan Vecera) [1680241]
- [netdrv] mlxsw: remove unused arrays mlxsw_i2c_driver_name and mlxsw_pci_driver_name (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core: remove unnecessary function mlxsw_core_driver_put (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Expose counter for all 16 TCs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Include RFC-2819 counters in stats length (Ivan Vecera) [1680241]
- [netdrv] mlxsw: Replace license text with SPDX identifiers and adjust copyrights (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add TC flower test for Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Reset FW after flash (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Update the supported firmware to version 13.1702.6 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_flower: Disallow usage of vlan_id key on egress (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_flower: use PTR_ERR_OR_ZERO() (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: gre_multipath: Update next-hop statistics match criteria (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Configure MC-aware mode on mlxsw ports (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Fix a typo (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add QoS Switch Traffic Class Table is Multicast-Aware Register (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add test for ip_forward_update_priority (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Move DSCP capture to lib.sh (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Move lldpad waiting to lib.sh (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Handle sysctl_ip_fwd_update_priority (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Extract work-scheduling into a new function (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test mirror-to-gretap w/ UL team LACP (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test mirror-to-gretap w/ UL team (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Introduce $ARPING (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Support team devices (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Add require_command() (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: qos_dscp_bridge: Fix (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add test for trust-DSCP (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Support ieee_setapp, ieee_delapp (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add QoS Priority to DSCP Mapping Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add QoS ReWrite Enable Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add QoS Priority Trust State Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add QoS Port DSCP to Priority Mapping Register (Ivan Vecera) [1680241]
- [tools] selftests: add a selftest for directed broadcast forwarding (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: add tests for TC chain get and dump operations (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Start using A-TCAM (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add A-TCAM rule insertion and deletion (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Pass C-TCAM region and entry to insert function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add A-TCAM region initialization (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Make global TCAM resources available to regions (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Encapsulate C-TCAM region in A-TCAM region (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add A-TCAM initialization (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Allow encoding a partial key (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Extend Spectrum-2 region struct (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add support for C-TCAM eRPs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Enable C-TCAM only mode in eRP core (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Implement common eRP core (Ivan Vecera) [1680241]
- [netdrv] mlxsw: resources: Add Spectrum-2 eRP resources (Ivan Vecera) [1680241]
- [netdrv] mlxsw: resources: Add Spectrum-2 maximum large key ID resource (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine eRP Table Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine TCAM Entry Register Version 3 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Prepare PERERP register for A-TCAM usage (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_flower: Add extack messages (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add extack messages (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl_flex_actions: Add extack messages (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Propagate extack pointer (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: gre_multipath: Drop IPv6 tests (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Implement chain template hinting (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Extend to support Spectrum-2 ASIC (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add initial Spectrum-2 ACL implementation (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add region association callback (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add support for Spectrum-2 block encoding (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Prepare for Spectrum-2 block encoding (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine General Configuration Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine Region eRP Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine Region Configuration Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Policy-Engine Region Association Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: acl: Introduce activity get operation for action block/set (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add support for activity information from PEFA register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Introduce flex key blocks for Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add Spectrum-2 variant of flex actions ops (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_mr_tcam: Add Spectrum-2 stubs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add KVDL manager implementation for Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add Infrastructure Entry Delete Register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Expose counters for various packet sizes (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Optimize processing of VRRP MACs (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Add VRRP traps (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Direct macvlans' MACs to router (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Enable macvlan upper devices (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_nh: Unset rp_filter on host VRF (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_span: Change LAG lower selection (Ivan Vecera) [1680241]
- [netdrv] mlxsw: resources: Add couple of Spectrum-2 KVD resources (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Prepare for multiple FW versions for Spectrum and Spectrum-2 (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Implement priority setting for rules inserted to TCAM (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Add priority field for PTCEV2 register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Move block items encoding into Spectrum op (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Convert mlxsw_afk_create args to ops (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Add tcam init/fini ops (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Split TCAM handling 3 ways (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_mr_tcam: Push Spectrum-specific operations into a separate file (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_kvdl: Pass entry_count to free function (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_kvdl: Pass entry type to alloc/free (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_kvdl: Push out KVD linear management into ops (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_lib: Tighten up VLAN capture (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl_flex_actions: Fix helper to get the first KVD linear index (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl_flex_actions: Allow the first set to be dummy (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Put pointer to flex action ops to mlxsw_sp (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl_flex_keys: Change SRC_SYS_PORT flex key element size (Ivan Vecera) [1680241]
- [netdrv] mlxsw: core_acl_flex_keys: Split MAC and IP address flex key elements (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_acl: Ignore always-zeroed bits in tp->prio (Ivan Vecera) [1680241]
- [netdrv] mlxsw: reg: Introduce Flex2 key type for PTAR register (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum: Change name of mlxsw_sp_afk_blocks to mlxsw_sp1_afk_blocks (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: avoid uninitialized variable access (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add mlxsw-specific test for mirror to gretap (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Allow importing dependent libraries (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: test for bridge port isolation (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test mirror-to-gretap w/ UL 802.1q (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test mirror-to-gretap w/ UL 802.1d (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add scale test for resources (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add target for mirror-to-gretap test on spectrum (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add scale test for mirror-to-gretap (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add target for tc flower test on spectrum (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add tc flower scale test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add target for router test on spectrum (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add router test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add devlink KVD resource test (Ivan Vecera) [1680241]
- [tools] selftests: mlxsw: Add devlink_lib_spectrum.sh (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Add devlink_lib.sh (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Parameterize NUM_NETIFS in two functions (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Add check_err_fail() (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Allow lib.sh sourcing from other directories (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_changes: Fix waiting for neighbor (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: lib: Split out setup_wait_dev() (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test multipath tunneling (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: mirror_gre_vlan_bridge_1q: Unset rp_filter (Ivan Vecera) [1680241]
- [tools] selftests: forwarding: Test routed bridge interface (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_switchdev: Ban PVID change if bridge has a RIF (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Add mlxsw_sp_rif_fid() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Publish mlxsw_sp_rif_find_by_dev() (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Allocate FID according to PVID (Ivan Vecera) [1680241]
- [netdrv] mlxsw: spectrum_router: Propagate extack to .fid_get() (Ivan Vecera) [1680241]
- [netdrv] net: phy: realtek: Dummy IRQ calls for RTL8366RB (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: add generic Realtek PHY driver (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: use new PHYID matching macros (Corinna Vinschen) [1680528]
- [include] net: phy: add macros for PHYID matching (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: load driver for all PHYs with a Realtek OUI (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: fix RTL8201F sysfs name (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: Support RTL8366RB variant (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: add missing entry for RTL8211C to mdio_device_id table (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: add support for RTL8211C (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: add missing entry for RTL8211 to mdio_device_id table (Corinna Vinschen) [1680528]
- [netdrv] net: phy: realtek: add support for RTL8211 (Corinna Vinschen) [1680528]
- [netdrv] r8169: change irq handler to always trigger NAPI polling (Corinna Vinschen) [1680528]
- [netdrv] r8169: create function pointer array for chip hw init functions (Corinna Vinschen) [1680528]
- [netdrv] r8169: create function pointer array for PHY init functions (Corinna Vinschen) [1680528]
- [netdrv] r8169: disable ASPM again (Corinna Vinschen) [1680528]
- [netdrv] r8169: disable tx interrupt coalescing on RTL8168 (Corinna Vinschen) [1680528]
- [netdrv] Revert "r8169: use netif_receive_skb_list batching" (Corinna Vinschen) [1680528]
- [netdrv] r8169: use netif_receive_skb_list batching (Corinna Vinschen) [1680528]
- [netdrv] r8169: disable default rx interrupt coalescing on RTL8168 (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix cable re-plugging issue (Corinna Vinschen) [1680528]
- [netdrv] r8169: use netif_start_queue instead of netif_wake_qeueue in rtl8169_start_xmit (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't read interrupt mask register in interrupt handler (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove unneeded mmiowb barriers (Corinna Vinschen) [1680528]
- [netdrv] Revert "r8169: make use of xmit_more and __netdev_sent_queue" (Corinna Vinschen) [1680528]
- [netdrv] Revert "r8169: remove unneeded mmiowb barriers" (Corinna Vinschen) [1680528]
- [netdrv] r8169: Avoid pointer aliasing (Corinna Vinschen) [1680528]
- [netdrv] r8169: Load MAC address from device tree if present (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove rtl_wol_pll_power_down (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve WoL handling (Corinna Vinschen) [1680528]
- [netdrv] r8169: enable EEE per default on RTL8168f (Corinna Vinschen) [1680528]
- [netdrv] r8169: add EEE support for RTL8168f (Corinna Vinschen) [1680528]
- [netdrv] r8169: enable EEE per default on chip versions from RTL8168g (Corinna Vinschen) [1680528]
- [netdrv] r8169: add general EEE support for chip versions from RTL8168g (Corinna Vinschen) [1680528]
- [netdrv] r8169: factor out PHY init sequence adjusting 10M and ALDPS (Corinna Vinschen) [1680528]
- [netdrv] r8169: factor out disabling ALDPS (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve firmware handling (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove PCI DAC support (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve rx buffer allocation (Corinna Vinschen) [1680528]
- [netdrv] r8169: factor out getting ether_clk (Corinna Vinschen) [1680528]
- [netdrv] r8169: replace mii_bus member with phy_device member in struct rtl8169_private (Corinna Vinschen) [1680528]
- [netdrv] r8169: reset chip synchronously in __rtl8169_resume (Corinna Vinschen) [1680528]
- [netdrv] r8169: add helpers for locking / unlocking the config registers (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve rtl_pcie_state_l2l3_enable (Corinna Vinschen) [1680528]
- [netdrv] r8169: initialize task workqueue only once (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove unneeded call in pcierr (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove rtl_get_events (Corinna Vinschen) [1680528]
- [netdrv] r8169: load Realtek PHY driver module before r8169 (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't try to read counters if chip is in a PCI power-save state (Corinna Vinschen) [1680528]
- [netdrv] r8169: Add support for new Realtek Ethernet (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix WoL device wakeup enable (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve spurious interrupt detection (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix crash if CONFIG_DEBUG_SHIRQ is enabled (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove unneeded mmiowb barriers (Corinna Vinschen) [1680528]
- [netdrv] ethernet/realtek: Replace synchronize_sched() with synchronize_rcu() (Corinna Vinschen) [1680528]
- [netdrv] r8169: make use of xmit_more and __netdev_sent_queue (Corinna Vinschen) [1680528]
- [netdrv] r8169: replace macro TX_FRAGS_READY_FOR with a function (Corinna Vinschen) [1680528]
- [netdrv] r8169: use napi_consume_skb where possible (Corinna Vinschen) [1680528]
- [netdrv] r8169: simplify detecting chip versions with same XID (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove default chip versions (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove ancient GCC bug workaround in a second place (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve chip version identification (Corinna Vinschen) [1680528]
- [netdrv] r8169: simplify ocp functions (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove workaround for ancient gcc bug (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove manual padding in struct ring_info (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove "not PCI Express" message (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove print_mac_version (Corinna Vinschen) [1680528]
- [netdrv] r8169: use PCI_VDEVICE macro (Corinna Vinschen) [1680528]
- [netdrv] r8169: replace event_slow with irq_mask (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove unused interrupt sources (Corinna Vinschen) [1680528]
- [netdrv] r8169: use dev_get_drvdata where possible (Corinna Vinschen) [1680528]
- [netdrv] r8169: merge rtl_irq_enable and rtl_irq_enable_all (Corinna Vinschen) [1680528]
- [pci] PCI: add USR vendor id and use it in r8169 and w6692 driver (Corinna Vinschen) [1680528]
- [netdrv] net: ethernet: Convert phydev advertize and supported from u32 to link mode (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix broken Wake-on-LAN from S5 (poweroff) (Corinna Vinschen) [1680528]
- [netdrv] r8169: add support for Byte Queue Limits (Corinna Vinschen) [1680528]
- [netdrv] r8169: handle all interrupt events in the hard irq handler (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix NAPI handling under high load (Corinna Vinschen) [1680528]
- [netdrv] r8169: re-enable MSI-X on RTL8168g (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove unneeded call to netif_stop_queue in rtl8169_net_suspend (Corinna Vinschen) [1680528]
- [netdrv] r8169: simplify rtl8169_set_magic_reg (Corinna Vinschen) [1680528]
- [netdrv] r8169: Enable MSI-X on RTL8106e (Corinna Vinschen) [1680528]
- [netdrv] r8169: set RX_MULTI_EN bit in RxConfig for 8168F-family chips (Corinna Vinschen) [1680528]
- [netdrv] r8169: always autoneg on resume (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix network stalls due to missing bit TXCFG_AUTO_FIFO (Corinna Vinschen) [1680528]
- [netdrv] r8169: Disable clk during suspend / resume (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve a check in rtl_init_one (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve rtl8169_irq_mask_and_ack (Corinna Vinschen) [1680528]
- [netdrv] r8169: use default watchdog timeout (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix autoneg issue on resume with RTL8168E (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove duplicated RTL8169s PHY initialization steps (Corinna Vinschen) [1680528]
- [netdrv] r8169: simplify RTL8169 PHY initialization (Corinna Vinschen) [1680528]
- [netdrv] r8169: Get and enable optional ether_clk clock (Corinna Vinschen) [1680528]
- [netdrv] r8169: enable ASPM on RTL8106E (Corinna Vinschen) [1680528]
- [netdrv] r8169: Align ASPM/CLKREQ setting function with vendor driver (Corinna Vinschen) [1680528]
- [netdrv] r8169: Clear RTL_FLAG_TASK_*_PENDING when clearing RTL_FLAG_TASK_ENABLED (Corinna Vinschen) [1680528]
- [netdrv] r8169: set TxConfig register after TX / RX is enabled, just like RxConfig (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't configure max jumbo frame size per chip version (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't configure csum function per chip version (Corinna Vinschen) [1680528]
- [netdrv] r8169: simplify interrupt handler (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't include asm headers directly (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove version info (Corinna Vinschen) [1680528]
- [netdrv] r8169: restore previous behavior to accept BIOS WoL settings (Corinna Vinschen) [1680528]
- [netdrv] r8169: power down chip in probe (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't read chip phy status register (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove mii_if_info member from struct rtl8169_private (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove rtl8169_set_speed_xmii (Corinna Vinschen) [1680528]
- [netdrv] r8169: use phy_speed_down / phy_speed_up (Corinna Vinschen) [1680528]
- [netdrv] r8169: use phy_mii_ioctl (Corinna Vinschen) [1680528]
- [netdrv] r8169: use phy_ethtool_nway_reset (Corinna Vinschen) [1680528]
- [netdrv] r8169: use phy_ethtool_(g|s)et_link_ksettings (Corinna Vinschen) [1680528]
- [netdrv] r8169: replace open-coded PHY soft reset with genphy_soft_reset (Corinna Vinschen) [1680528]
- [netdrv] r8169: use phy_resume/phy_suspend (Corinna Vinschen) [1680528]
- [netdrv] r8169: add basic phylib support (Corinna Vinschen) [1680528]
- [netdrv] r8169: fix runtime suspend (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove old PHY reset hack (Corinna Vinschen) [1680528]
- [netdrv] r8169: remove TBI 1000BaseX support (Corinna Vinschen) [1680528]
- [netdrv] r8169: use standard debug output functions (Corinna Vinschen) [1680528]
- [netdrv] r8169: reject unsupported WoL options (Corinna Vinschen) [1680528]
- [netdrv] r8169: don't check WoL when powering down PHY and interface is down (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve saved_wolopts handling (Corinna Vinschen) [1680528]
- [netdrv] Revert "r8169: restore previous behavior to accept BIOS WoL settings" (Corinna Vinschen) [1680528]
- [netdrv] r8169: improve phy initialization when resuming (Corinna Vinschen) [1680528]
- [netdrv] r8169: enable ASPM on RTL8168E-VL (Corinna Vinschen) [1680528]
- [netdrv] r8169: align ASPM entry latency setting with vendor driver (Corinna Vinschen) [1680528]
- [netdrv] r8169: Reinstate ASPM Support (Corinna Vinschen) [1680528]
- [netdrv] r8169: Don't disable ASPM in the driver (Corinna Vinschen) [1680528]
- [kernel] kernel/sched/psi.c: expose pressure metrics on root cgroup (Waiman Long) [1678388]
- [kernel] psi: introduce psi monitor (Waiman Long) [1678388]
- [spi] include/: refactor headers to allow kthread.h inclusion in psi_types.h (Waiman Long) [1678388]
- [kernel] psi: track changed states (Waiman Long) [1678388]
- [kernel] psi: split update_stats into parts (Waiman Long) [1678388]
- [kernel] psi: rename psi fields in preparation for psi trigger addition (Waiman Long) [1678388]
- [kernel] psi: make psi_enable static (Waiman Long) [1678388]
- [kernel] psi: introduce state_mask to represent stalled psi states (Waiman Long) [1678388]
- [kernel] kernel: cgroup: add poll file operation (Waiman Long) [1678388]
- [fs] fs: kernfs: add poll file operation (Waiman Long) [1678388]
- [documentation] psi: clarify the units used in pressure files (Waiman Long) [1678388]
- [kernel] psi: avoid divide-by-zero crash inside virtual machines (Waiman Long) [1678388]
- [init] psi: clarify the Kconfig text for the default-disable option (Waiman Long) [1678388]
- [kernel] psi: fix aggregation idle shut-off (Waiman Long) [1678388]
- [init] psi: fix reference to kernel commandline enable (Waiman Long) [1678388]
- [kernel] psi: make disabling/enabling easier for vendor kernels (Waiman Long) [1678388]
- [kernel] kernel/sched/psi.c: simplify cgroup_move_task() (Waiman Long) [1678388]
- [kernel] psi: cgroup support (Waiman Long) [1678388]
- [kernel] psi: pressure stall information for CPU, memory, and IO (Waiman Long) [1678388]
- [kernel] sched: introduce this_rq_lock_irq() (Waiman Long) [1678388]
- [kernel] sched: sched.h: make rq locking and clock functions available in stats.h (Waiman Long) [1678388]
- [kernel] sched: loadavg: make calc_load_n() public (Waiman Long) [1678388]
- [kernel] sched: loadavg: consolidate LOAD_INT, LOAD_FRAC, CALC_LOAD (Waiman Long) [1678388]
- [kernel] delayacct: track delays from thrashing cache pages (Waiman Long) [1678388]
- [mm] mm: workingset: tell cache transitions from workingset thrashing (Waiman Long) [1678388]
- [mm] mm: workingset: don't drop refault information prematurely (Waiman Long) [1678388]
- [scsi] scsi: ibmvfc: Add failed PRLI to cmd_status lookup array (Diego Domingos) [1665716]
- [scsi] scsi: ibmvfc: Byte swap status and error codes when logging (Diego Domingos) [1665716]
- [scsi] scsi: ibmvfc: Remove "failed" from logged errors (Diego Domingos) [1665716]
- [scsi] scsi: ibmvfc: Clean up transport events (Diego Domingos) [1665716]
- [scsi] scsi: ibmvscsi: Don't use rc uninitialized in ibmvscsi_do_work (Gustavo Duarte) [1665715]
- [scsi] scsi: ibmvscsi: fix tripping of blk_mq_run_hw_queue WARN_ON (Gustavo Duarte) [1665715]
- [scsi] scsi: ibmvscsi: redo driver work thread to use enum action states (Gustavo Duarte) [1665715]
- [scsi] scsi: ibmvscsi: Wire up host_reset() in the driver's scsi_host_template (Gustavo Duarte) [1665715]
- [scsi] scsi: ibmvscsi: change strncpy+truncation to strlcpy (Gustavo Duarte) [1665715]
- [fs] ext4: avoid panic during forced reboot due to aborted journal (Lukas Czerner) [1717831]
- [fs] ext4: fix use-after-free in dx_release() (Lukas Czerner) [1717831]
- [fs] ext4: fix data corruption caused by overlapping unaligned and aligned IO (Lukas Czerner) [1717831]
- [fs] ext4: avoid drop reference to iloc.bh twice (Lukas Czerner) [1717831]
- [nvme] nvme-tcp: mark NVMe/TCP as a technical preview (Chris Leech) [1696451]
- [nvme] nvme-tcp: fix possible null deref on a timed out io queue connect (Chris Leech) [1696451]
- [nvme] nvme-tcp: rename function to have nvme_tcp prefix (Chris Leech) [1696451]
- [nvme] nvme-tcp: fix a NULL deref when an admin connect times out (Chris Leech) [1696451]
- [nvme] nvmet-tcp: don't fail maxr2t greater than 1 (Chris Leech) [1696451]
- [nvme] nvmet-tcp: implement C2HData SUCCESS optimization (Chris Leech) [1696451]
- [nvme] nvme-tcp: fix an endianess miss-annotation (Chris Leech) [1696451]
- [nvme] nvme-tcp: support C2HData with SUCCESS flag (Chris Leech) [1696451]
- [nvme] nvme-tcp: use older iov_iter API to fix panic (Chris Leech) [1696451]
- [nvme] nvmet: fix building bvec from sg list (Ming Lei) [1690287]
- [nvme] nvmet: set loop queue's segment boundary mask as PAGE_SIZE - 1 (Ming Lei) [1690287]
- [x86] x86/qspinlock: Fix compile error (Waiman Long) [1709451]
- [kernel] locking/rwsem: Prevent unneeded warning during locking selftest (Waiman Long) [1709451]
- [kernel] locking/rwsem: Enable lock event counting (Waiman Long) [1709451]
- [kernel] locking/lock_events: Don't show pvqspinlock events on bare metal (Waiman Long) [1709451]
- [kernel] locking/lock_events: Make lock_events available for all archs & other locks (Waiman Long) [1709451]
- [kernel] locking/qspinlock_stat: Introduce generic lockevent_*() counting APIs (Waiman Long) [1709451]
- [kernel] locking/rwsem: Enhance DEBUG_RWSEMS_WARN_ON() macro (Waiman Long) [1709451]
- [kernel] locking/rwsem: Add debug check for __down_read*() (Waiman Long) [1709451]
- [kernel] locking/rwsem: Micro-optimize rwsem_try_read_lock_unqueued() (Waiman Long) [1709451]
- [kernel] locking/rwsem: Move rwsem internal function declarations to rwsem-xadd.h (Waiman Long) [1709451]
- [kernel] locking/rwsem: Move owner setting code from rwsem.c to rwsem.h (Waiman Long) [1709451]
- [kernel] locking/rwsem: Relocate rwsem_down_read_failed() (Waiman Long) [1709451]
- [kernel] locking/rwsem: Optimize down_read_trylock() (Waiman Long) [1709451]
- [kernel] locking/rwsem: Remove rwsem-spinlock.c & use rwsem-xadd.c for all archs (Waiman Long) [1709451]
- [x86] locking/rwsem: Remove arch specific rwsem files (Waiman Long) [1709451]
- [kernel] locking/qspinlock: Remove unnecessary BUG_ON() call (Waiman Long) [1709451]
- [kernel] locking/qspinlock_stat: Track the no MCS node available case (Waiman Long) [1709451]
- [kernel] locking/qspinlock: Handle > 4 slowpath nesting levels (Waiman Long) [1709451]
- [kernel] locking/pvqspinlock: Extend node size when pvqspinlock is configured (Waiman Long) [1709451]
- [kernel] locking/qspinlock_stat: Count instances of nested lock slowpaths (Waiman Long) [1709451]
- [kernel] locking/qspinlock, x86: Provide liveness guarantee (Waiman Long) [1709451]
- [kernel] locking/qspinlock: Rework some comments (Waiman Long) [1709451]
- [kernel] locking/qspinlock: Re-order code (Waiman Long) [1709451]
- [x86] x86/headers: Fix -Wmissing-prototypes warning (Waiman Long) [1709451]
- [x86] Revert "x86/refcount: Work around GCC inlining bug" (Waiman Long) [1709451]
- [x86] x86/asm: 'Simplify' GEN_*_RMWcc() macros (Waiman Long) [1709451]
- [x86] x86/refcount: Work around GCC inlining bug (Waiman Long) [1709451]
- [lib] locking/refcounts: Include fewer headers in <linux/refcount.h> (Waiman Long) [1709451]
- [media] media: stk1160: Set the vb2_queue lock before calling vb2_queue_init (Torez Smith) [1697664]
- [usb] USB: typec: fsusb302: Drop empty set_current_limit implementation (Torez Smith) [1697664]
- [usb] USB: mark expected switch fall-throughs (Torez Smith) [1697664]
- [usb] USB: musb: mark expected switch fall-throughs (Torez Smith) [1697664]
- [usb] usb: wusbcore: security: cast sizeof to int for comparison (Torez Smith) [1697664]
- [usb] usb: typec: tcpm: Support for Alternate Modes (Torez Smith) [1697664]
- [usb] usb: typec: pi3usb30532: Start using generic state values (Torez Smith) [1697664]
- [usb] usb: typec: Add driver for DisplayPort alternate mode (Torez Smith) [1697664]
- [usb] usb: typec: Bus type for alternate modes (Torez Smith) [1697664]
- [usb] usb: typec: Register a device for every mode (Torez Smith) [1697664]
- [usb] usb: typec: mux: Get the mux identifier from function parameter (Torez Smith) [1697664]
- [usb] usb: update for tcpci drivers moving out of staging (Torez Smith) [1697664]
- [netdrv] net: usb: Mark expected switch fall-throughs (Torez Smith) [1697664]
- [media] media: tm6000: add error handling for dvb_register_adapter (Torez Smith) [1697664]
- [usb] usb: typec: function for checking cable plug orientation (Torez Smith) [1697664]
- [include] usb: pd: include kernel.h (Torez Smith) [1697664]
- [staging] staging: typec: tcpci: move tcpci drivers out of staging (Torez Smith) [1697664]
- [usb] typec: tcpm: add starting value for drp toggling (Torez Smith) [1697664]
- [usb] usb: typec: tcpm: support get typec and pd config from device properties (Torez Smith) [1697664]
- [usb] usb: typec: add API to get typec basic port power and data config (Torez Smith) [1697664]
- [staging] usb: typec: add fwnode to tcpc (Torez Smith) [1697664]
- [documentation] dt-bindings: usb: add documentation for typec port controller(TCPCI) (Torez Smith) [1697664]
- [documentation] dt-bindings: connector: add properties for typec (Torez Smith) [1697664]
- [usb] usb: typec: tps6598x: Remove VLA usage (Torez Smith) [1697664]
- [usb] usb: cdc-wdm: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: cdc-wdm: don't enable interrupts in USB-giveback (Torez Smith) [1697664]
- [usb] usb: legousbtower: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: ldusb: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: iowarrior: remove intr_idx_lock (Torez Smith) [1697664]
- [usb] usb: adutux: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: wusbcore: remove excessive irqsave (Torez Smith) [1697664]
- [usb] usb: usb-skeleton: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: usblp: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: usbfs: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: core: use irqsave() in sg_complete() complete callback (Torez Smith) [1697664]
- [usb] usb: cdc-acm: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: host: ehci-npcm7xx: Fix some error codes in probe (Torez Smith) [1697664]
- [media] media: cx231xx: fix RC_CORE dependency (Torez Smith) [1697664]
- [usb] USB: serial: digi_acceleport: rename tty flag variable (Torez Smith) [1697664]
- [usb] USB: serial: usb_wwan: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: ti_usb_3410_5052: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: symbolserial: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: sierra: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: sierra: fix potential deadlock at close (Torez Smith) [1697664]
- [usb] USB: serial: quatech2: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: mos7840: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: mos7720: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: io_ti: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: io_edgeport: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: digi_acceleport: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] USB: serial: cyberjack: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [usb] usb: chipidea: tegra: Use aligned DMA on Tegra114/124 (Torez Smith) [1697664]
- [documentation] dt-bindings: usb: new ehci-npcm7xx dt (Torez Smith) [1697664]
- [usb] USB host: Add USB ehci support for nuvoton npcm7xx platform (Torez Smith) [1697664]
- [usb] usb: cdc-acm: Decrement tty port's refcount if probe() fail (Torez Smith) [1697664]
- [usb] USB: mon: use ktime_get_real_ts64 instead of getnstimeofday64 (Torez Smith) [1697664]
- [usb] USB: xhci-hcd: Add get_resuming_ports method (Torez Smith) [1697664]
- [usb] USB: ehci-hcd: Add get_resuming_ports method (Torez Smith) [1697664]
- [usb] USB: Report wakeup events on root-hub ports (Torez Smith) [1697664]
- [usb] USB: serial: cast sizeof() to int when comparing with error code (Torez Smith) [1697664]
- [netdrv] net: drivers/net: Convert random_ether_addr to eth_random_addr (Torez Smith) [1697664]
- [netdrv] net: usb: rtl8150: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [netdrv] net: usb: r8152: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [netdrv] net: usb: kaweth: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [netdrv] net: usb: hso: use irqsave() in USB's complete callback (Torez Smith) [1697664]
- [netdrv] net: usb: cdc-phonet: use irqsave() in USB's complete callback (Torez Smith) [1697664]

* Fri Jun 14 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-106.rt20.47.el8]
- [rt] kernel-rt-4.18.0-106.rt20.46.el8 (Juri Lelli) [1678887]
- [net] selftests/tls: add test for sleeping even though there is data (Sabrina Dubroca) [1711821]
- [net] tls: fix no wakeup on partial reads (Sabrina Dubroca) [1711821]
- [net] selftests/tls: test for lowat overshoot with multiple records (Sabrina Dubroca) [1711821]
- [net] tls: fix lowat calculation if some data came from previous record (Sabrina Dubroca) [1711821]
- [net] tls: don't ignore netdev notifications if no TLS features (Sabrina Dubroca) [1711821]
- [net] tls: fix state removal with feature flags off (Sabrina Dubroca) [1711821]
- [net] tls: handle errors from padding_length() (Sabrina Dubroca) [1711821]
- [net] tls: avoid NULL pointer deref on nskb->sk in fallback (Sabrina Dubroca) [1711821]
- [net] tls: byte swap device req TCP seq no upon setting (Sabrina Dubroca) [1711821]
- [net] tls: remove old exports of sk_destruct functions (Sabrina Dubroca) [1711821]
- [net] tls: don't log errors every time offload can't proceed (Sabrina Dubroca) [1711821]
- [net] tls: fix refcount adjustment in fallback (Sabrina Dubroca) [1711821]
- [net] strparser: make it explicitly non-modular (Sabrina Dubroca) [1711821]
- [net] strparser: partially revert "strparser: Call skb_unclone conditionally" (Sabrina Dubroca) [1711821]
- [net] tls: fix the IV leaks (Sabrina Dubroca) [1711821]
- [net] strparser: fix comment (Sabrina Dubroca) [1711821]
- [net] tls: prevent false connection termination with offload (Sabrina Dubroca) [1711821]
- [net] tls: Replace kfree_skb() with consume_skb() (Sabrina Dubroca) [1711821]
- [net] strparser: fix a missing check for create_singlethread_workqueue (Sabrina Dubroca) [1711821]
- [net] tls: Fix tls_device receive (Sabrina Dubroca) [1711821]
- [net] tls: Fix mixing between async capable and async (Sabrina Dubroca) [1711821]
- [net] tls: Return type of non-data records retrieved using MSG_PEEK in recvmsg (Sabrina Dubroca) [1711821]
- [net] selftest/tls: Add test to verify received 'type' of non-data record (Sabrina Dubroca) [1711821]
- [net] tls: Move protocol constants from cipher context to tls context (Sabrina Dubroca) [1711821]
- [net] tls: Do not use async crypto for non-data records (Sabrina Dubroca) [1711821]
- [net] tls: Disable async decrytion for tls1.3 (Sabrina Dubroca) [1711821]
- [net] tls: Set async_capable for tls zerocopy only if we see EINPROGRESS (Sabrina Dubroca) [1711821]
- [net] tls: Add tests for TLS 1.3 (Sabrina Dubroca) [1711821]
- [net] tls: Add tls 1.3 support (Sabrina Dubroca) [1711821]
- [net] tls: Refactor control message handling on recv (Sabrina Dubroca) [1711821]
- [net] tls: Refactor tls aad space size calculation (Sabrina Dubroca) [1711821]
- [net] tls: Support 256 bit keys (Sabrina Dubroca) [1711821]
- [net] tls: free ctx in sock destruct (Sabrina Dubroca) [1711821]
- [net] tls: build_protos moved to common routine (Sabrina Dubroca) [1711821]
- [net] tls: Fix recvmsg() to be able to peek across multiple records (Sabrina Dubroca) [1711821]
- [net] tls: Make function tls_sw_do_sendpage static (Sabrina Dubroca) [1711821]
- [net] tls: remove unused function tls_sw_sendpage_locked (Sabrina Dubroca) [1711821]
- [net] Optimize sk_msg_clone() by data merge to end dst sg entry (Sabrina Dubroca) [1711821]
- [net] selftests/tls: Fix recv partial/large_buff test cases (Sabrina Dubroca) [1711821]
- [net] tls: allocate tls context using GFP_ATOMIC (Sabrina Dubroca) [1711821]
- [net] tls: Init routines in create_ctx (Sabrina Dubroca) [1711821]
- [net] selftests/tls: Fix recv(MSG_PEEK) & splice() test cases (Sabrina Dubroca) [1711821]
- [net] tls: fix currently broken MSG_PEEK behavior (Sabrina Dubroca) [1711821]
- [net] selftests/tls: Add MSG_WAITALL in recv() syscall (Sabrina Dubroca) [1711821]
- [net] tls: async support causes out-of-bounds access in crypto APIs (Sabrina Dubroca) [1711821]
- [net] selftests/tls: Add test for recv(PEEK) spanning across multiple records (Sabrina Dubroca) [1711821]
- [net] tls: Add support for async decryption of tls records (Sabrina Dubroca) [1711821]
- [net] tls: Calculate nsg for zerocopy path without skb_cow_data (Sabrina Dubroca) [1711821]
- [net] strparser: remove redundant variable 'rd_desc' (Sabrina Dubroca) [1711821]
- [net] tls: Use kmemdup to simplify the code (Sabrina Dubroca) [1711821]
- [net] tls: Use socket data_ready callback on record availability (Sabrina Dubroca) [1711821]
- [net] selftests: tls: add selftests for TLS sockets (Sabrina Dubroca) [1711821]
- [net] strparser: Call skb_unclone conditionally (Sabrina Dubroca) [1711821]
- [net] tls: Remove VLA usage on nonce (Sabrina Dubroca) [1711821]
- [net] tls: Removed unused variable (Sabrina Dubroca) [1711821]
- [netdrv] veth: use generic helper to report timestamping info (Jiri Benc) [1718938]
- [netdrv] veth: Fix -Wformat-truncation (Jiri Benc) [1718938]
- [netdrv] veth: Mark expected switch fall-throughs (Jiri Benc) [1718938]
- [net] Add extack argument to rtnl_create_link (Jiri Benc) [1718938]
- [netdrv] veth: Add ethtool statistics support for XDP (Jiri Benc) [1718938]
- [netdrv] veth: Account for XDP packet statistics on rx side (Jiri Benc) [1718938]
- [netdrv] veth: Account for packet drops in ndo_xdp_xmit (Jiri Benc) [1718938]
- [netdrv] veth: rename pcpu_vstats as pcpu_lstats (Jiri Benc) [1718938]
- [netdrv] net: move definition of pcpu_lstats to header file (Jiri Benc) [1718938]
- [netdrv] veth: add software timestamping (Jiri Benc) [1718938]
- [net] tcp: tcp_grow_window() needs to respect tcp_space() (Marcelo Leitner) [1718344]
- [net] tcp: fix a potential NULL pointer dereference in tcp_sk_exit (Marcelo Leitner) [1718344]
- [net] tcp: do not use ipv6 header for ipv4 flow (Marcelo Leitner) [1718344]
- [net] tcp: Don't access TCP_SKB_CB before initializing it (Marcelo Leitner) [1718344]
- [net] tcp: do not report TCP_CM_INQ of 0 for closed connections (Marcelo Leitner) [1718344]
- [net] tcp: clear icsk_backoff in tcp_write_queue_purge() (Marcelo Leitner) [1718344]
- [net] tcp: allow MSG_ZEROCOPY transmission also in CLOSE_WAIT state (Marcelo Leitner) [1718344]
- [net] tcp: change txhash on SYN-data timeout (Marcelo Leitner) [1718344]
- [net] tcp: lack of available data can also cause TSO defer (Marcelo Leitner) [1718344]
- [net] tcp: fix NULL ref in tail loss probe (Marcelo Leitner) [1718344]
- [net] tcp: Do not underestimate rwnd_limited (Marcelo Leitner) [1718344]
- [net] tcp: defer SACK compression after DupThresh (Marcelo Leitner) [1718344]
- [net] tcp: do not release socket ownership in tcp_close() (Marcelo Leitner) [1718344]
- [net] tcp: Fix SOF_TIMESTAMPING_RX_HARDWARE to use the latest timestamp during TCP coalescing (Marcelo Leitner) [1718344]
- [net] inet: make sure to grab rcu_read_lock before using ireq->ireq_opt (Marcelo Leitner) [1718344]
- [net] tcp/dccp: fix lockdep issue when SYN is backlogged (Marcelo Leitner) [1718344]
- [net] xfrm4: Fix uninitialized memory read in _decode_session4 (Sabrina Dubroca) [1718812]
- [net] esp4: add length check for UDP encapsulation (Sabrina Dubroca) [1718812]
- [net] xfrm: clean up xfrm protocol checks (Sabrina Dubroca) [1718812]
- [net] xfrm6_tunnel: Fix potential panic when unloading xfrm6_tunnel module (Sabrina Dubroca) [1718812]
- [net] xfrm: Reset secpath in xfrm failure (Sabrina Dubroca) [1718812]
- [net] xfrm: policy: Fix out-of-bound array accesses in __xfrm_policy_unlink (Sabrina Dubroca) [1718812]
- [net] xfrm: destroy xfrm_state synchronously on net exit path (Sabrina Dubroca) [1718812]
- [net] esp: Skip TX bytes accounting when sending from a request socket (Sabrina Dubroca) [1718812]
- [net] xfrm: refine validation of template and selector families (Sabrina Dubroca) [1718812]
- [net] xfrm: policy: increment xfrm_hash_generation on hash rebuild (Sabrina Dubroca) [1718812]
- [net] xfrm6_tunnel: Fix spi check in __xfrm6_tunnel_alloc_spi (Sabrina Dubroca) [1718812]
- [net] xfrm_user: fix freeing of xfrm states on acquire (Sabrina Dubroca) [1718812]
- [net] xfrm: Fix NULL pointer dereference in xfrm_input when skb_dst_force clears the dst_entry (Sabrina Dubroca) [1718812]
- [net] xfrm: Fix error return code in xfrm_output_one() (Sabrina Dubroca) [1718812]
- [net] vti4: eliminated some duplicate code (Guillaume Nault) [1718443]
- [net] vti4: removed duplicate log message (Guillaume Nault) [1718443]
- [net] vti4: ipip tunnel deregistration fixes (Guillaume Nault) [1718443]
- [net] vti4: Fix a ipip packet processing bug in 'IPCOMP' virtual tunnel (Guillaume Nault) [1718443]
- [net] fou: do not use guehdr after iptunnel_pull_offloads in gue_udp_recv (Guillaume Nault) [1718443]
- [netdrv] vxlan: test dev->flags & IFF_UP before calling gro_cells_receive() (Guillaume Nault) [1718443]
- [netdrv] vxlan: test dev->flags & IFF_UP before calling netif_rx() (Guillaume Nault) [1718443]
- [net] devlink: turn devlink into a built-in (Petr Oros) [1717458]
- [net] ipv6: fix EFAULT on sendto with icmpv6 and hdrincl (Stefano Brivio) [1718503]
- [net] ipv6: use READ_ONCE() for inet->hdrincl as in ipv4 (Stefano Brivio) [1718503]
- [net] ipv6: Fix redirect with VRF (Stefano Brivio) [1718503]
- [net] ipv6: Consider sk_bound_dev_if when binding a raw socket to an address (Stefano Brivio) [1718503]
- [net] ipv6: prevent possible fib6 leaks (Stefano Brivio) [1718503]
- [net] vrf: sit mtu should not be updated when vrf netdev is the link (Stefano Brivio) [1718503]
- [net] ipv6: A few fixes on dereferencing rt->from (Stefano Brivio) [1718503]
- [tools] selftests: fib_rule_tests: Fix icmp proto with ipv6 (Stefano Brivio) [1718503]
- [net] ipv6: fix races in ip6_dst_destroy() (Stefano Brivio) [1718503]
- [net] ipv6/flowlabel: wait rcu grace period before put_pid() (Stefano Brivio) [1718503]
- [net] ipv6: invert flowlabel sharing check in process and user mode (Stefano Brivio) [1718503]
- [net] route: Avoid crash from dereferencing NULL rt->from (Stefano Brivio) [1718503]
- [net] udpv6: Check address length before reading address family (Stefano Brivio) [1718503]
- [net] ip6_gre: fix possible use-after-free in ip6erspan_rcv (Stefano Brivio) [1718503]
- [net] ip6_gre: remove gre_hdr_len from ip6erspan_rcv (Stefano Brivio) [1718503]
- [net] ipv6: Fix dangling pointer when ipv6 fragment (Stefano Brivio) [1718503]
- [net] ip6_tunnel: Match to ARPHRD_TUNNEL6 for dev type (Stefano Brivio) [1718503]
- [net] inet: switch IP ID generator to siphash (Stefano Brivio) [1718503]
- [net] sit: fix UBSAN Undefined behaviour in check_6rd (Stefano Brivio) [1718503]
- [net] ip6mr: Do not call __IP6_INC_STATS() from preemptible context (Stefano Brivio) [1718503]
- [net] sit: fix memory leak in sit_init_net() (Stefano Brivio) [1718503]
- [net] ipv4: Add ICMPv6 support when parse route ipproto (Stefano Brivio) [1718503]
- [net] ipv6: Return error for RTA_VIA attribute (Stefano Brivio) [1718503]
- [net] Set rtm_table to RT_TABLE_COMPAT for ipv6 for tables > 255 (Stefano Brivio) [1718503]
- [net] ip6_gre: do not report erspan_ver for ip6gre or ip6gretap (Stefano Brivio) [1718503]
- [net] ipv6: route: enforce RCU protection in rt6_update_exception_stamp_rt() (Stefano Brivio) [1718503]
- [net] ipv6: route: enforce RCU protection in ip6_route_check_nh_onlink() (Stefano Brivio) [1718503]
- [net] ipv6: propagate genlmsg_reply return code (Stefano Brivio) [1718503]
- [net] fix IPv6 prefix route residue (Stefano Brivio) [1718503]
- [net] ip6mr: Fix notifiers call on mroute_clean_tables() (Stefano Brivio) [1718503]
- [net] af_packet: fix raw sockets over 6in4 tunnel (Stefano Brivio) [1718503]
- [net] ip6_gre: fix tunnel list corruption for x-netns (Stefano Brivio) [1718503]
- [net] ipv6: fix kernel-infoleak in ipv6_local_error() (Stefano Brivio) [1718503]
- [net] ip: on queued skb use skb_header_pointer instead of pskb_may_pull (Stefano Brivio) [1718503]
- [net] ipv4: fix use-after-free in ip_cmsg_recv_dstaddr() (Stefano Brivio) [1718503]
- [net] ipv6: Take rcu_read_lock in __inet6_bind for mapped addresses (Stefano Brivio) [1718503]
- [net] ipv6: Consider sk_bound_dev_if when binding a socket to a v4 mapped address (Stefano Brivio) [1718503]
- [net] ipv6: Consider sk_bound_dev_if when binding a socket to an address (Stefano Brivio) [1718503]
- [net] ip: validate header length on virtual device xmit (Stefano Brivio) [1718503]
- [net] ipv6: Fix a test against 'ipv6_find_idev()' return value (Stefano Brivio) [1718503]
- [net] ipv6: tunnels: fix two use-after-free (Stefano Brivio) [1718503]
- [net] ipv6: add missing tx timestamping on IPPROTO_RAW (Stefano Brivio) [1718503]
- [net] clear skb->tstamp in forwarding paths (Stefano Brivio) [1718503]
- [net] ipv6: sr: properly initialize flowi6 prior passing to ip6_route_output (Stefano Brivio) [1718503]
- [net] always initialize pagedlen (Stefano Brivio) [1718503]
- [net] ipv6: Fix PMTU updates for UDP/raw sockets in presence of VRF (Stefano Brivio) [1718503]
- [net] ipv6: gro: do not use slow memcmp() in ipv6_gro_receive() (Stefano Brivio) [1718503]
- [net] xfrm: fix out-of-bounds packet access (Stefano Brivio) [1718503]
- [net] ipv6: take rcu lock in rawv6_send_hdrinc() (Stefano Brivio) [1718503]
- [net] ip6_tunnel: be careful when accessing the inner header (Stefano Brivio) [1718503]
- [net] revert "ipv6: fix double refcount of fib6_metrics" (Stefano Brivio) [1718503]
- [net] ipv6: fix memory leak on dst->_metrics (Stefano Brivio) [1718503]
- [net] ipv6: fix cleanup ordering for ip6_mr failure (Stefano Brivio) [1718503]
- [net] ipv6: fix cleanup ordering for pingv6 registration (Stefano Brivio) [1718503]
- [net] ip6_tunnel: collect_md xmit: Use ip_tunnel_key's provided src address (Stefano Brivio) [1718503]
- [net] ipv6: fix addrconf_sysctl_addr_gen_mode (Stefano Brivio) [1718503]
- [net] ipv6: don't reinitialize ndev->cnf.addr_gen_mode on new inet6_dev (Stefano Brivio) [1718503]
- [net] ipv6: reserve room for IFLA_INET6_ADDR_GEN_MODE (Stefano Brivio) [1718503]
- [net] ipv6: propagate net.ipv6.conf.all.addr_gen_mode to devices (Stefano Brivio) [1718503]
- [net] openvswitch: check for null pointer return from nla_nest_start_noflag (Stefano Brivio) [1718408]
- [net] openvswitch: add seqadj extension when NAT is used (Stefano Brivio) [1718408]
- [net] netfilter: Replace spin_is_locked() with lockdep (Stefano Brivio) [1718392]
- [net] netfilter: ipset: do not call ipset_nest_end after nla_nest_cancel (Stefano Brivio) [1718392]
- [net] netfilter: ipset: Fix calling ip_set() macro at dumping (Stefano Brivio) [1718392]
- [include] netfilter: ipset: Correct rcu_dereference() call in ip_set_put_comment() (Stefano Brivio) [1718392]
- [net] netfilter: ipset: fix ip_set_list allocation failure (Stefano Brivio) [1718392]
- [net] netfilter: ipset: Make invalid MAC address checks consistent (Stefano Brivio) [1649087]
- [net] netfilter: ipset: Allow matching on destination MAC address for mac and ipmac sets (Stefano Brivio) [1649087]
- [netdrv] rocker: Handle SWITCHDEV_PORT_ATTR_SET (Ivan Vecera) [1717892]
- [net] switchdev: Add SWITCHDEV_PORT_ATTR_SET (Ivan Vecera) [1717892]
- [netdrv] rocker: Add missing break for PRE_BRIDGE_FLAGS (Ivan Vecera) [1717892]
- [net] bridge: Stop calling switchdev_port_attr_get() (Ivan Vecera) [1717892]
- [netdrv] rocker: Check Handle PORT_PRE_BRIDGE_FLAGS (Ivan Vecera) [1717892]
- [netdrv] mlxsw: spectrum: Handle PORT_PRE_BRIDGE_FLAGS (Ivan Vecera) [1717892]
- [include] net: switchdev: Add PORT_PRE_BRIDGE_FLAGS (Ivan Vecera) [1717892]
- [netdrv] rocker: Remove port_attr_bridge_flags_get assignment (Ivan Vecera) [1717892]
- [netdrv] rocker: Remove getting PORT_BRIDGE_FLAGS (Ivan Vecera) [1717892]
- [net] pktgen: do not sleep with the thread lock held (Paolo Abeni) [1715575]
- [include] ipv6: fix the check before getting the cookie in rt6_get_cookie (Xin Long) [1709166]
- [net] ipv4: not do cache for local delivery if bc_forwarding is enabled (Xin Long) [1712657]
- [net] sctp: avoid running the sctp state machine recursively (Xin Long) [1717316]
- [netdrv] netdevsim: use skb_sec_path helper (Hangbin Liu) [1711810]
- [netdrv] netdevsim: convert to DEFINE_SHOW_ATTRIBUTE (Hangbin Liu) [1711810]
- [netdrv] netdevsim: make debug dirs' dentries static (Hangbin Liu) [1711810]
- [tools] selftests: rtnetlink: use internal netns switch for ip commands (Hangbin Liu) [1711810]
- [tools] selftests: rtnetlink: add testcases for vxlan flag sets (Hangbin Liu) [1711810]
- [tools] selftests: rtnetlink: Add a test case for multipath route get (Hangbin Liu) [1711810]
- [tools] selftests: rtnetlink.sh: add testcase for neigh get (Hangbin Liu) [1711810]
- [tools] selftests: net: rtnetlink.sh: add fdb get test (Hangbin Liu) [1711810]
- [tools] selftests: rtnetlink.sh explicitly requires bash (Hangbin Liu) [1711810]
- [net] udp: with udp_segment release on error path (Paolo Abeni) [1718079]
- [net] ipv6: explicitly initialize udp6_addr in udp_sock_create6() (Paolo Abeni) [1718079]
- [netdrv] geneve: Don't assume linear buffers in vxlan_err_lookup() (Stefano Brivio) [1652222]
- [netdrv] vxlan: Don't assume linear buffers in vxlan_err_lookup() (Stefano Brivio) [1652222]
- [netdrv] geneve: Initialize addr6 with memset (Stefano Brivio) [1652222]
- [net] ip_tunnel: don't force DF when MTU is locked (Stefano Brivio) [1652222]
- [netdrv] geneve: ICMP error lookup handler (Stefano Brivio) [1652222]
- [netdrv] vxlan: ICMP error lookup handler (Stefano Brivio) [1652222]
- [net] udp: Handle ICMP errors for tunnels with same destination port on both endpoints (Stefano Brivio) [1652222]
- [net] udp: gro behind static key (Stefano Brivio) [1652222]
- [net] bpf: in __bpf_redirect_no_mac pull mac only if present (Jiri Benc) [1687471]
- [net] lwt_bpf: remove unnecessary rcu_read_lock in run_lwt_bpf (Jiri Benc) [1687471]
- [net] bpf: add End.DT6 action to bpf_lwt_seg6_action helper (Jiri Benc) [1687471]
- [net] bpf: fix out-of-bounds read in __bpf_skc_lookup (Jiri Benc) [1687459]
- [net] bpf: Check sk_fullsock() before returning from bpf_sk_lookup() (Jiri Benc) [1687459]
- [net] flow_dissector: disable preemption around BPF calls (Jiri Benc) [1687459]
- [net] bpf: sockmap, only stop/flush strp if it was enabled at some point (Jiri Benc) [1687459]
- [net] bpf: Stop the psock parser before canceling its work (Jiri Benc) [1687459]
- [net] bpf: only test gso type on gso packets (Jiri Benc) [1687459]
- [tools] selftests: add dummy xdp test helper (Jiri Benc) [1687459]
- [net] filter: mark expected switch fall-through (Jiri Benc) [1687459]
- [documentation] Update references to netdev-FAQ (Jiri Benc) [1687459]
- [net] bpfilter: remove trailing newline (Jiri Benc) [1687459]
- [net] core: filter: mark expected switch fall-through (Jiri Benc) [1687459]
- [net] revert "xsk: simplify AF_XDP socket teardown" (Jiri Benc) [1687459]
- [net] bpf/test_run: fix unkillable BPF_PROG_TEST_RUN (Jiri Benc) [1687459]
- [net] xsk: share the mmap_sem for page pinning (Jiri Benc) [1687459]
- [net] xsk: add missing smp_rmb() in xsk_mmap (Jiri Benc) [1687459]
- [net] bpf: only adjust gso_size on bytestream protocols (Jiri Benc) [1687459]
- [net] sk_msg: Always cancel strp work before freeing the psock (Jiri Benc) [1687459]
- [net] bpf: sock recvbuff must be limited by rmem_max in bpf_setsockopt() (Jiri Benc) [1687459]
- [net] bpf: fix SO_MAX_PACING_RATE to support TCP internal pacing (Jiri Benc) [1687459]
- [net] bpf: bpf_setsockopt: reset sock dst on SO_MARK changes (Jiri Benc) [1687459]
- [net] bpf: correctly set initial window on active Fast Open sender (Jiri Benc) [1687459]
- [net] xsk: simplify AF_XDP socket teardown (Jiri Benc) [1687459]
- [net] bpf: fix doc of bpf_skb_adjust_room() in uapi (Jiri Benc) [1687459]
- [net] bpf: do not blindly change rlimit in reuseport net selftest (Jiri Benc) [1687459]
- [net] xsk: proper AF_XDP socket teardown ordering (Jiri Benc) [1687459]
- [net] bpf: typo fix in Documentation/networking/af_xdp.rst (Jiri Benc) [1687459]
- [net] xdp: split code for map vs non-map redirect (Jiri Benc) [1687459]
- [net] xdp: explicit inline __xdp_map_lookup_elem (Jiri Benc) [1687459]
- [net] xdp: unlikely instrumentation for xdp map redirect (Jiri Benc) [1687459]
- [net] xdp: remove redundant variable 'headroom' (Jiri Benc) [1687459]
- [net] xsk: include XDP meta data in AF_XDP frames (Jiri Benc) [1687459]
- [net] bpf: Enable BPF_PROG_TYPE_SK_REUSEPORT bpf prog in reuseport selection (Jiri Benc) [1687459]
- [net] revert "xdp: add NULL pointer check in __xdp_return()" (Jiri Benc) [1687459]
- [lib] test_rhashtable: Make test_insert_dup() allocate its hash table dynamically (Jiri Benc) [1717066]
- [lib] test_rhashtable: remove semaphore usage (Jiri Benc) [1717066]
- [lib] rhashtable: detect when object movement between tables might have invalidated a lookup (Jiri Benc) [1717066]
- [lib] rhashtable: remove duplicated include from rhashtable.c (Jiri Benc) [1717066]
- [lib] rhashtable: clean up dereference of ->future_tbl (Jiri Benc) [1717066]
- [lib] rhashtable: use cmpxchg() to protect ->future_tbl (Jiri Benc) [1717066]
- [lib] rhashtable: simplify nested_table_alloc() and rht_bucket_nested_insert() (Jiri Benc) [1717066]
- [lib] rhashtable: simplify INIT_RHT_NULLS_HEAD() (Jiri Benc) [1717066]
- [lib] rhashtable: remove nulls_base and related code (Jiri Benc) [1717066]
- [lib] rhashtable: split rhashtable.h (Jiri Benc) [1717066]
- [lib] rhashtable: silence RCU warning in rhashtable_test (Jiri Benc) [1717066]
- [net] devlink: publish params only after driver init is done (Ivan Vecera) [1715929]
- [net] iptunnel: NULL pointer deref for ip_md_tunnel_xmit (Hangbin Liu) [1712792]
- [net] ip_gre: Refactor collect metatdata mode tunnel xmit to ip_md_tunnel_xmit (Hangbin Liu) [1712792]
- [net] ip_tunnel: Fix route fl4 init in ip_md_tunnel_xmit (Hangbin Liu) [1712792]
- [net] ip_tunnel: Add tnl_update_pmtu in ip_md_tunnel_xmit (Hangbin Liu) [1712792]
- [net] ip_tunnel: Add ip tunnel dst_cache in ip_md_tunnel_xmit (Hangbin Liu) [1712792]
- [net] vlan: Mark expected switch fall-through (Hangbin Liu) [1664359]
- [net] vlan: disable SIOCSHWTSTAMP in container (Hangbin Liu) [1664359]
- [netdrv] macvlan: Mark expected switch fall-through (Hangbin Liu) [1664359]
- [netdrv] macvlan: disable SIOCSHWTSTAMP in container (Hangbin Liu) [1664359]
- [netdrv] macvlan: pass get_ts_info and SIOC[SG]HWTSTAMP ioctl to real device (Hangbin Liu) [1664359]
- [net] ethtool: add compat for flash update (Petr Oros) [1708339]
- [net] devlink: add flash update command (Petr Oros) [1708339]
- [net] devlink: Fix list access without lock while reading region (Petr Oros) [1708339]
- [net] devlink: Return right error code in case of errors for region read (Petr Oros) [1708339]
- [net] devlink: use direct return of genlmsg_reply (Petr Oros) [1708339]
- [net] devlink: Rename devlink health attributes (Petr Oros) [1709874]
- [net] devlink: Modify reply of DEVLINK_CMD_HEALTH_REPORTER_GET (Petr Oros) [1709874]
- [net] devlink: Update reporter state to error even if recover aborted (Petr Oros) [1709874]
- [documentation] devlink: Add Documentation/networking/devlink-health.txt (Petr Oros) [1709874]
- [net] devlink: Add health dump {get, clear} commands (Petr Oros) [1709874]
- [net] devlink: Add health diagnose command (Petr Oros) [1709874]
- [net] devlink: Add health recover command (Petr Oros) [1709874]
- [net] devlink: Add health set command (Petr Oros) [1709874]
- [net] devlink: Add health get command (Petr Oros) [1709874]
- [net] devlink: Add health report functionality (Petr Oros) [1709874]
- [net] devlink: Add health reporter create/destroy functionality (Petr Oros) [1709874]
- [net] devlink: Add devlink formatted message (fmsg) API (Petr Oros) [1709874]
- [net] devlink: add hardware errors tracing facility (Petr Oros) [1709874]
- [net] cnb: devlink: report cell size of shared buffers (Petr Oros) [1708348]
- [net] devlink: skip info_get op call if it is not defined in dumpit (Petr Oros) [1708342]
- [include] devlink: add a generic board.manufacture version name (Petr Oros) [1708342]
- [net] devlink: don't allocate attrs on the stack (Petr Oros) [1708342]
- [net] devlink: fix condition for compat device info (Petr Oros) [1708342]
- [net] ethtool: add compat for devlink info (Petr Oros) [1708342]
- [include] devlink: add generic info version names (Petr Oros) [1708342]
- [net] devlink: add version reporting to devlink info API (Petr Oros) [1708342]
- [net] devlink: add device information API (Petr Oros) [1708342]
- [net] devlink: Add devlink notifications support for port params (Petr Oros) [1710228]
- [net] devlink: Add support for driverinit set value for devlink_port (Petr Oros) [1710228]
- [net] devlink: Add support for driverinit get value for devlink_port (Petr Oros) [1710228]
- [net] devlink: Add port param set command (Petr Oros) [1710228]
- [net] devlink: Add port param get command (Petr Oros) [1710228]
- [net] devlink: Add devlink_param for port register and unregister (Petr Oros) [1710228]
- [net] ipv6: properly check return value in inet6_dump_all() (Petr Oros) [1714656]
- [net] Don't return invalid table id error when dumping all families (Petr Oros) [1714656]
- [net] ipmr_base: Do not reset index in mr_table_dump (Petr Oros) [1714656]
- [net] ipv6: Fix dump of specific table with strict checking (Petr Oros) [1714656]
- [net] ipv4: avoid compile error in fib_info_nh_uses_dev (Petr Oros) [1714656]
- [net] ipv4: Bail early if user only wants prefix entries (Petr Oros) [1714656]
- [net] ipv6: Bail early if user only wants cloned entries (Petr Oros) [1714656]
- [net] mpls: Handle kernel side filtering of route dumps (Petr Oros) [1714656]
- [net] Enable kernel side filtering of route dumps (Petr Oros) [1714656]
- [net] Plumb support for filtering ipv4 and ipv6 multicast route dumps (Petr Oros) [1714656]
- [net] ipmr: Refactor mr_rtm_dumproute (Petr Oros) [1714656]
- [net] mpls: Plumb support for filtering route dumps (Petr Oros) [1714656]
- [net] ipv6: Plumb support for filtering route dumps (Petr Oros) [1714656]
- [net] netfilter: nft_fib: Convert nft_fib4_eval to new dev helper (Petr Oros) [1714656]
- [net] netfilter: rpfilter: Convert rpfilter_lookup_reverse to new dev helper (Petr Oros) [1714656]
- [net] ipv4: Move device validation to helper (Petr Oros) [1714656]
- [net] ipv4: Plumb support for filtering route dumps (Petr Oros) [1714656]
- [net] Add struct for fib dump filter (Petr Oros) [1714656]
- [lib] iov_iter: Fix build error without CONFIG_CRYPTO (Ivan Vecera) [1714213]
- [net] datagram: introduce skb_copy_and_hash_datagram_iter helper (Ivan Vecera) [1714213]
- [lib] iov_iter: introduce hash_and_copy_to_iter helper (Ivan Vecera) [1714213]
- [net] datagram: consolidate datagram copy to iter helpers (Ivan Vecera) [1714213]
- [lib] iov_iter: pass void csum pointer to csum_and_copy_to_iter (Ivan Vecera) [1714213]
- [net] datagram: open-code copy_page_to_iter (Ivan Vecera) [1714213]
- [include] net: enable mpls_ptr in net_device (Hangbin Liu) [1350011]
- [net] netfilter: ipset: actually allow allowable CIDR 0 in hash:net, port, net (Stefano Brivio) [1680512]
- [net] netfilter: ipset: fix ip_set_byindex function (Stefano Brivio) [1680512]
- [net] netfilter: ipset: Introduction of new commands and protocol version 7 (Stefano Brivio) [1680512]
- [net] ipv6: don't return positive numbers when nothing was dumped (Petr Oros) [1700306]
- [net] rtnetlink: restore handling of dumpit return value in rtnl_dump_all() (Petr Oros) [1700306]
- [net] netlink: fixup regression in RTM_GETADDR (Petr Oros) [1700306]
- [net] {ipv4, ipv6}: Do not put target net if input nsid is invalid (Petr Oros) [1700306]
- [net] rtnl_dump_all needs to propagate error from dumpit function (Petr Oros) [1700306]
- [net] rtnetlink: Move ifm in valid_fdb_dump_legacy to closer to use (Petr Oros) [1700306]
- [net] neighbor: NTF_PROXY is a valid ndm_flag for a dump request (Petr Oros) [1700306]
- [net] mpls: Implement handler for strict data checking on dumps (Petr Oros) [1700306]
- [net] rtnetlink: Update comment in rtnl_stats_dump regarding strict data checking (Petr Oros) [1700306]
- [net] ipv6: Put target net when address dump fails due to bad attributes (Petr Oros) [1700306]
- [net] ipv4: Put target net when address dump fails due to bad attributes (Petr Oros) [1700306]
- [tools] headers uapi: Update linux/netlink.h header copy (Petr Oros) [1700306]
- [net] neigh: fix NULL deref in pneigh_dump_table() (Petr Oros) [1700306]
- [net] ipv6: Add support for dumping addresses for a specific device (Petr Oros) [1700306]
- [net] ipv4: Add support for dumping addresses for a specific device (Petr Oros) [1700306]
- [net] ipv6: Remove ip_idx arg to in6_dump_addrs (Petr Oros) [1700306]
- [net] ipv4: Move loop over addresses on a device into in_dev_dump_addr (Petr Oros) [1700306]
- [net] netlink: Add answer_flags to netlink_callback (Petr Oros) [1700306]
- [net] rtnetlink: Update rtnl_fdb_dump for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Move input checking for rtnl_fdb_dump to helper (Petr Oros) [1700306]
- [net] bridge: Update br_mdb_dump for strict data checking (Petr Oros) [1700306]
- [net] Update netconf dump handlers for strict data checking (Petr Oros) [1700306]
- [net] ipv6: Update ip6addrlbl_dump for strict data checking (Petr Oros) [1700306]
- [net] fib_rules: Update fib_nl_dumprule for strict data checking (Petr Oros) [1700306]
- [net] namespace: Update rtnl_net_dumpid for strict data checking (Petr Oros) [1700306]
- [net] neighbor: Update neightbl_dump_info for strict data checking (Petr Oros) [1700306]
- [net] neighbor: Update neigh_dump_info for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update fib dumps for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update ipmr_rtm_dumplink for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update inet6_dump_ifinfo for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update rtnl_stats_dump for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update rtnl_bridge_getlink for strict data checking (Petr Oros) [1700306]
- [net] rtnetlink: Update rtnl_dump_ifinfo for strict data checking (Petr Oros) [1700306]
- [net] ipv6: Update inet6_dump_addr for strict data checking (Petr Oros) [1700306]
- [net] ipv4: Update inet_dump_ifaddr for strict data checking (Petr Oros) [1700306]
- [net] netlink: Add new socket option to enable strict checking on dumps (Petr Oros) [1700306]
- [net] ipv6: Refactor address dump to push inet6_fill_args to in6_dump_addrs (Petr Oros) [1700306]
- [lib] netlink: Add strict version of nlmsg_parse and nla_parse (Petr Oros) [1700306]
- [net] Add extack to nlmsg_parse (Petr Oros) [1700306]
- [include] netlink: Add extack message to nlmsg_parse for invalid header length (Petr Oros) [1700306]
- [net] netlink: Pass extack to dump handlers (Petr Oros) [1700306]
- [net] neigh: Extend dump filter to proxy neighbor dumps (Petr Oros) [1700306]
- [lib] netlink: add nested array policy validation (Petr Oros) [1700306]
- [lib] netlink: allow NLA_NESTED to specify nested policy to validate (Petr Oros) [1700306]
- [lib] netlink: move extack setting into validate_nla() (Petr Oros) [1700306]
- [lib] netlink: make validation_data const (Petr Oros) [1700306]
- [lib] netlink: remove NLA_NESTED_COMPAT (Petr Oros) [1700306]
- [lib] netlink: add ethernet address policy types (Petr Oros) [1700306]
- [net] sched: cls_u32: add res to offload information (Ivan Vecera) [1711377]
- [net] sched: gred: support reporting stats from offloads (Ivan Vecera) [1711377]
- [net] sched: gred: add basic Qdisc offload (Ivan Vecera) [1711377]
- [net] sched: gred: allow manipulating per-DP RED flags (Ivan Vecera) [1711377]
- [net] sched: gred: store red flags per virtual queue (Ivan Vecera) [1711377]
- [net] sched: gred: provide a better structured dump and expose stats (Ivan Vecera) [1711377]
- [net] sched: gred: store bytesin as a 64 bit value (Ivan Vecera) [1711377]
- [net] sched: gred: use extack to provide more details on configuration errors (Ivan Vecera) [1711377]
- [net] sched: gred: pass extack to nla_parse_nested() (Ivan Vecera) [1711377]
- [net] sched: gred: separate error and non-error path in gred_change() (Ivan Vecera) [1711377]
- [net] netlink: add NLA_REJECT policy type (Ivan Vecera) [1711377]
- [lib] netlink: Return extack message if attribute validation fails (Ivan Vecera) [1711377]
- [net] sched: red: notify drivers about RED's limit parameter (Ivan Vecera) [1711039]
- [net] sched: mq: offload a graft notification (Ivan Vecera) [1711039]
- [net] sched: red: offload a graft notification (Ivan Vecera) [1711039]
- [net] sched: provide notification for graft on root (Ivan Vecera) [1711039]
- [net] sched: prio: delay destroying child qdiscs on change (Ivan Vecera) [1711039]
- [net] sched: red: delay destroying child qdisc on replace (Ivan Vecera) [1711039]
- [net] sched: refactor grafting Qdiscs with a parent (Ivan Vecera) [1711039]
- [net] sched: add an offload graft helper (Ivan Vecera) [1711039]
- [net] sched: set TCQ_F_OFFLOADED flag for MQ (Ivan Vecera) [1711039]
- [net] sched: red: remove unnecessary red_dump_offload_stats parameter (Ivan Vecera) [1711039]
- [net] sched: add an offload dump helper (Ivan Vecera) [1711039]
- [netdrv] netdevsim: Implement ndo_get_port_parent_id() (Ivan Vecera) [1708368]
- [netdrv] rocker: Implement ndo_get_port_parent_id() (Ivan Vecera) [1708368]
- [net] Introduce ndo_get_port_parent_id() (Ivan Vecera) [1708368]
- [net] use indirect calls helpers at early demux stage (Paolo Abeni) [1700747]
- [net] use indirect calls helpers for L3 handler hooks (Paolo Abeni) [1700747]
- [net] use indirect calls helpers at the socket layer (Paolo Abeni) [1700747]
- [net] use indirect calls helpers for ptype hook (Paolo Abeni) [1700747]
- [net] add documentation to socket.c (Paolo Abeni) [1700747]
- [net] udp: use indirect call wrappers for GRO socket lookup (Paolo Abeni) [1700747]
- [net] use indirect call wrappers at GRO transport layer (Paolo Abeni) [1700747]
- [net] use indirect call wrappers at GRO network layer (Paolo Abeni) [1700747]
- [net] indirect call wrappers: helpers to speed-up indirect calls of builtin (Paolo Abeni) [1700747]
- [powerpc] powerpc: bpf: Fix generation of load/store DW instructions (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier: propagate liveness on all frames (Yauheni Kaliuta) [1700846]
- [net] bpf: do not restore dst_reg when cur_state is freed (Yauheni Kaliuta) [1700846]
- [tools] tools lib bpf: Fix the build by adding a missing stdarg.h include (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: fix version info and add it to shared object (Yauheni Kaliuta) [1700846]
- [tools] btf: fix bug with resolving STRUCT/UNION into corresponding FWD (Yauheni Kaliuta) [1700846]
- [tools] tools/libbpf: signedness bug in btf_dedup_ref_type() (Yauheni Kaliuta) [1700846]
- [tools] libbpf: fix libbpf_print (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: simplify libbpf API function libbpf_set_print() (Yauheni Kaliuta) [1700846]
- [tools] tools/bpftool: move set_max_rlimit() before __bpf_object__open_xattr() (Yauheni Kaliuta) [1700846]
- [include] bpf: promote bpf_perf_event.h to mandatory UAPI header (Yauheni Kaliuta) [1700846]
- [net] bpf: Avoid unnecessary instruction in convert_bpf_ld_abs() (Yauheni Kaliuta) [1700846]
- [kernel] bpf: fix check of allowed specifiers in bpf_trace_printk (Yauheni Kaliuta) [1700846]
- [documentation] bpf, doc: Document Jump X addressing mode (Yauheni Kaliuta) [1700846]
- [tools] tools: bpf: fix license for a compat header file (Yauheni Kaliuta) [1700846]
- [documentation] docs: bpf: Capitalise document heading (Yauheni Kaliuta) [1700846]
- [documentation] docs: Add bpf/index to top level index (Yauheni Kaliuta) [1700846]
- [documentation] docs: bpf: Add toctree to index (Yauheni Kaliuta) [1700846]
- [documentation] docs: bpf: Rename README.rst to index.rst (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: skip verifier tests for unsupported map types (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: skip verifier tests for unsupported program types (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: skip sockmap in test_maps if kernel doesn't have support (Yauheni Kaliuta) [1700846]
- [rpmspec] rpmspec: pack bpf-helpers, bpftool-net, bpftool-feature manpages (Yauheni Kaliuta) [1700846]
- [net] bpf, tcp: correctly handle DONT_WAIT flags and timeo == 0 (Yauheni Kaliuta) [1700846]
- [kernel] bpf: mark bpf_event_notify and bpf_event_init as static (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap fix msg->sg.size account on ingress skb (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap remove duplicate queue free (Yauheni Kaliuta) [1700846]
- [net] net/tls: remove set but not used variables (Yauheni Kaliuta) [1700846]
- [media] bpf: add map helper functions push, pop, peek in more BPF programs (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix infinite loop in map create (Yauheni Kaliuta) [1700846]
- [net] net/tls: fix build without CONFIG_TLS_DEVICE (Yauheni Kaliuta) [1700846]
- [net] net/tls: don't leak partially sent record in device mode (Yauheni Kaliuta) [1700846]
- [net] xdp: fix cpumap redirect SKB creation bug (Yauheni Kaliuta) [1700846]
- [net] net/core: Document reuseport_add_sock() bind_inany argument (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: clarify bump in libbpf version info (Yauheni Kaliuta) [1700846]
- [net] net/tls: Inform user space about send buffer availability (Yauheni Kaliuta) [1700846]
- [tools] libbpf: handle BTF parsing and loading properly (Yauheni Kaliuta) [1700846]
- [net] bpf: fix warning about using plain integer as NULL (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: fixing leak when kernel does not support btf (Yauheni Kaliuta) [1700846]
- [net] tls: Fix write space handling (Yauheni Kaliuta) [1700846]
- [net] tls: Fix tls_device handling of partial records (Yauheni Kaliuta) [1700846]
- [tools] bpf: bpftool, fix documentation for attach types (Yauheni Kaliuta) [1700846]
- [tools] btf: separate btf creation and loading (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix a selftest test_btf failure (Yauheni Kaliuta) [1700846]
- [tools] selftests/btf: add initial BTF dedup tests (Yauheni Kaliuta) [1700846]
- [tools] btf: add BTF types deduplication algorithm (Yauheni Kaliuta) [1700846]
- [tools] btf: extract BTF type size calculation (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: silence a libbpf unnecessary warning (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: implement libbpf btf__get_map_kv_tids() API function (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: expose functions btf_ext__* as API functions (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Add a support for getting xdp prog id on ifindex (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Add a helper for retrieving a map fd for a given name (Yauheni Kaliuta) [1700846]
- [tools] libbpf: introduce bpf_map_lookup_elem_flags() (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add bash completion for bpftool probes (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for a network device (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add C-style "#define" output for probes (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for eBPF helper functions (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for eBPF map types (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for eBPF program types (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for kernel configuration options (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add probes for /proc/ eBPF parameters (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add basic probe capability, probe syscall availability (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: print out btf log at LIBBPF_WARN level (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: move libbpf pr_* debug print functions to headers (Yauheni Kaliuta) [1700846]
- [net] net: tls: Fix deadlock in free_resources tx (Yauheni Kaliuta) [1700846]
- [net] net: tls: Save iv in tls_rec for async crypto requests (Yauheni Kaliuta) [1700846]
- [tools] bpf: pull in pkt_sched.h header for tooling to fix bpftool build (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: change section name of bpfilter UMH blob (Yauheni Kaliuta) [1700846]
- [netdrv] tap: call skb_probe_transport_header after setting skb->dev (Yauheni Kaliuta) [1700846]
- [net] Prevent overflow of sk_msg in sk_msg_clone() (Yauheni Kaliuta) [1700846]
- [net] tls: Do not call sk_memcopy_from_iter with zero length (Yauheni Kaliuta) [1700846]
- [net] net: ipv4: Set skb->dev for output route resolution (Yauheni Kaliuta) [1700846]
- [net] bpf: refactor bpf_test_run() to separate own failures and test program result (Yauheni Kaliuta) [1700846]
- [include] bpf: fix pointer offsets in context for 32 bit (Yauheni Kaliuta) [1700846]
- [tools] tools/bpftool: copy a few net uapi headers to tools directory (Yauheni Kaliuta) [1700846]
- [net] bpf: tcp_bpf_recvmsg should return EAGAIN when nonblocking and no data (Yauheni Kaliuta) [1700846]
- [net] bpf: skmsg, fix psock create on existing kcm/tls port (Yauheni Kaliuta) [1700846]
- [net] tcp, ulp: remove socket lock assertion on ULP cleanup (Yauheni Kaliuta) [1700846]
- [lib] bpf: test_bpf: add init_net to dev for flow_dissector (Yauheni Kaliuta) [1700846]
- [net] flow_dissector: lookup netns by skb->sk if skb->dev is NULL (Yauheni Kaliuta) [1700846]
- [net] tls: Fixed uninitialised vars warning (Yauheni Kaliuta) [1700846]
- [include] cgroup: Simplify cgroup_ancestor (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Orphan skb before GRO (Yauheni Kaliuta) [1700846]
- [net] net/core/filter: fix unused-variable warning (Yauheni Kaliuta) [1700846]
- [net] bpf: fix build error with clang (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Free queues on link delete (Yauheni Kaliuta) [1700846]
- [net] bpf: fix sanitation rewrite in case of non-pointers (Yauheni Kaliuta) [1700846]
- [net] bpf: drop refcount if bpf_map_new_fd() fails in map_create() (Yauheni Kaliuta) [1700846]
- [net] bpf: decrease usercnt if bpf_map_new_fd() fails in bpf_map_get_fd_by_id() (Yauheni Kaliuta) [1700846]
- [net] bpf, lpm: fix lookup bug in map_delete_elem (Yauheni Kaliuta) [1700846]
- [net] bpf: fix lockdep false positive in stackmap (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix narrow load on a bpf_sock returned from sk_lookup() (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix syscall's stackmap lookup potential deadlock (Yauheni Kaliuta) [1700846]
- [kernel] bpf: fix potential deadlock in bpf_prog_register (Yauheni Kaliuta) [1700846]
- [net] bpf: fix lockdep false positive in percpu_freelist (Yauheni Kaliuta) [1700846]
- [net] bpf: run bpf programs with preemption disabled (Yauheni Kaliuta) [1700846]
- [tools] bpf, selftests: fix handling of sparse CPU allocations (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix test_btf for typedef func_proto case (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: allow typedef func_proto (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix crash with un-owned prog arrays (Yauheni Kaliuta) [1700846]
- [tools] bpftool: fix percpu maps updating (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: Cleanup license mess (Yauheni Kaliuta) [1700846]
- [net] bpf: Annotate implicit fall through in cgroup_dev_func_proto (Yauheni Kaliuta) [1700846]
- [net] bpf: Make function btf_name_offset_valid static (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: retry tests that expect build-id (Yauheni Kaliuta) [1700846]
- [net] bpf: zero out build_id for BPF_STACK_BUILD_ID_IP (Yauheni Kaliuta) [1700846]
- [net] bpf: don't assume build-id length is always 20 bytes (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: properly account for libbfd variations (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: retry loading program on EAGAIN (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: workaround clang asm goto compilation errors (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: install with_tunnels.sh for test_flow_dissector.sh (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: disallow to remove bpfilter module while being used (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: Fix type cast and pointer warnings (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: restart bpfilter_umh when error occurred (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: use cleanup callback to release umh_info (Yauheni Kaliuta) [1700846]
- [kernel] umh: add exit routine for UMH process (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: Set user mode helper's command line (Yauheni Kaliuta) [1700846]
- [kernel] umh: Add command line to user mode helpers (Yauheni Kaliuta) [1700846]
- [net] net: bpfilter: use get_pid_task instead of pid_task (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix bpftool map dump with bitfields (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: test btf bitfield with >=256 struct member offset (Yauheni Kaliuta) [1700846]
- [net] bpf: fix bpffs bitfield pretty print (Yauheni Kaliuta) [1700846]
- [net] bpf: fix panic in stack_map_get_build_id() on i386 and arm32 (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: install files tcp_(server|client)*.py (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: user proper argument index (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add missing executables to .gitignore (Yauheni Kaliuta) [1700846]
- [tools] bpf, doc: add note for libbpf's stand-alone build (Yauheni Kaliuta) [1700846]
- [documentation] bpf, doc: update design qa to reflect kern_version requirement (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix incorrect users of create_and_get_cgroup (Yauheni Kaliuta) [1700846]
- [tools] bpf: add various test cases for alu op on mixed dst register types (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test [::] -> [::1] rewrite in sys_sendmsg in test_sock_addr (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix [::] -> [::1] rewrite in sys_sendmsg (Yauheni Kaliuta) [1700846]
- [tools] bpf: add various test cases to selftests (Yauheni Kaliuta) [1700846]
- [net] bpf: fix check_map_access smin_value test when pointer contains offset (Yauheni Kaliuta) [1700846]
- [net] bpf: restrict stack pointer arithmetic for unprivileged (Yauheni Kaliuta) [1700846]
- [net] bpf: restrict map value pointer arithmetic for unprivileged (Yauheni Kaliuta) [1700846]
- [net] bpf: enable access to ax register also from verifier rewrite (Yauheni Kaliuta) [1700846]
- [net] bpf: move tmp variable into ax register in interpreter (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix error printing in test_devmap() (Yauheni Kaliuta) [1700846]
- [tools] bpf: fix segfault in test_verifier selftest (Yauheni Kaliuta) [1700846]
- [net] bpf: tls_sw, init TLS ULP removes BPF proto hooks (Yauheni Kaliuta) [1700846]
- [net] bpf: sk_msg, sock{map|hash} redirect through ULP (Yauheni Kaliuta) [1700846]
- [net] bpf: sk_msg, zap ingress queue on psock down (Yauheni Kaliuta) [1700846]
- [net] bpf: sk_msg, fix socket data_ready events (Yauheni Kaliuta) [1700846]
- [net] bpf: skb_verdict, support SK_PASS on RX BPF path (Yauheni Kaliuta) [1700846]
- [net] bpf: skmsg, replace comments with BUILD bug (Yauheni Kaliuta) [1700846]
- [net] bpf: sk_msg, improve offset chk in _is_valid_access (Yauheni Kaliuta) [1700846]
- [tools] bpf: sk_msg, fix sk_msg_md access past end test (Yauheni Kaliuta) [1700846]
- [net] bpf/cpumap: make sure frame_size for build_skb is aligned if headroom isn't (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: add missing executables to .gitignore (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier: reorder stack size check with dead code sanitization (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: verifier: add tests for JSET interpretation (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier: teach the verifier to reason about the BPF_JSET instruction (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: add trivial JSET tests (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add BPF_LD_IMM64 to the line_info test (Yauheni Kaliuta) [1700846]
- [net] bpf: Ensure line_info.insn_off cannot point to insn with zero code (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: do not force gcc as CC (Yauheni Kaliuta) [1700846]
- [tools] bpf: fix up uapi helper description and sync bpf header with tools (Yauheni Kaliuta) [1700846]
- [net] bpf: log struct/union attribute for forward type (Yauheni Kaliuta) [1700846]
- [tools] bpf: sk_msg, add tests for size field (Yauheni Kaliuta) [1700846]
- [tools] bpf: add tools lib/include support sk_msg_md size field (Yauheni Kaliuta) [1700846]
- [include] bpf: sockmap, metadata support for reporting size of msg (Yauheni Kaliuta) [1700846]
- [net] bpf: correct slot_type marking logic to allow more stack slot sharing (Yauheni Kaliuta) [1700846]
- [kernel] bpf: support raw tracepoints in modules (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add an option to prevent auto-mount of bpffs, tracefs (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: attempt to mount tracefs if required for tracelog cmd (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: check precise {func, line, jited_line}_info_rec_size in test_btf (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: fix memleak by freeing line_info (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: support pretty print with kind_flag set (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: refactor btf_dumper_int_bits() (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: test kernel bpffs map pretty print with struct kind_flag (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add test_btf unit tests for kind_flag (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: sync btf.h header from kernel to tools (Yauheni Kaliuta) [1700846]
- [net] bpf: enable cgroup local storage map pretty print with kind_flag (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: fix struct/union/fwd types with kind_flag (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: refactor btf_int_bits_seq_show() (Yauheni Kaliuta) [1700846]
- [net] bpf: remove useless version check for prog load (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix -Wmissing declaration warnings (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix warning on struct bpf_prog_linfo definition (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add a prog array map update example to documentation (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix examples in documentation for bpftool prog (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add doc for -m option to bpftool-prog.rst (Yauheni Kaliuta) [1700846]
- [net] bpf: add self-check logic to liveness analysis (Yauheni Kaliuta) [1700846]
- [net] bpf: improve stacksafe state comparison (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: check insn processed in test_verifier (Yauheni Kaliuta) [1700846]
- [net] bpf: speed up stacksafe check (Yauheni Kaliuta) [1700846]
- [net] bpf: verbose log bpf_line_info in verifier (Yauheni Kaliuta) [1700846]
- [net] bpf: Create a new btf_name_by_offset() for non type name use case (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Fix sk lookup usage in test_sock_addr (Yauheni Kaliuta) [1700846]
- [net] bpf: remove obsolete prog->aux sanitation in bpf_insn_prepare_dump (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier: make sure callees don't prune with caller differences (Yauheni Kaliuta) [1700846]
- [tools] bpf: sync tools/include/uapi/linux/bpf.h (Yauheni Kaliuta) [1700846]
- [net] bpf: include sub program tags in bpf_prog_info (Yauheni Kaliuta) [1700846]
- [tools] bpf: Remove !func_info and !line_info check from test_btf and bpftool (Yauheni Kaliuta) [1700846]
- [net] bpf: Remove bpf_dump_raw_ok() check for func_info and line_info (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: dual license all files (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: replace Netronome boilerplate with SPDX license headers (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix SPDX format in headers (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add btf annotations for cgroup_local_storage maps (Yauheni Kaliuta) [1700846]
- [net] bpf: add bpffs pretty print for cgroup local storage maps (Yauheni Kaliuta) [1700846]
- [net] bpf: pass struct btf pointer to the map_check_btf() callback (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: use __bpf_constant_htons in test_prog.c (Yauheni Kaliuta) [1700846]
- [net] bpf: fix bpf_jit_limit knob for PAGE_SIZE >= 64K (Yauheni Kaliuta) [1700846]
- [arm64] bpf: arm64: Enable arm64 jit to provide bpf_line_info (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: use proper type when passing prog_type (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: rename *_info_cnt to nr_*_info (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: sync kernel uapi bpf.h to tools directory (Yauheni Kaliuta) [1700846]
- [net] bpf: rename *_info_cnt to nr_*_info in bpf_prog_info (Yauheni Kaliuta) [1700846]
- [net] bpf: clean up bpf_prog_get_info_by_fd() (Yauheni Kaliuta) [1700846]
- [tools] bpf: bpftool: Fix newline and p_err issue (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add missing pointer dereference for map stacktrace fixup (Yauheni Kaliuta) [1700846]
- [net] bpf: relax verifier restriction on BPF_MOV | BPF_ALU (Yauheni Kaliuta) [1700846]
- [tools] media: bpf: add bpf function to report mouse movement (Yauheni Kaliuta) [1700846]
- [include] bpf: fix documentation for eBPF helpers (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: bpftool: Print bpf_line_info during prog dump (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: Add btf_line_info support to libbpf (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: Refactor and bug fix on the bpf_func_info loading logic (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add unit tests for bpf_line_info (Yauheni Kaliuta) [1700846]
- [tools] bpf: Refactor and bug fix in test_func_type in test_btf.c (Yauheni Kaliuta) [1700846]
- [tools] bpf: tools: Sync uapi bpf.h (Yauheni Kaliuta) [1700846]
- [include] bpf: Add bpf_line_info support (Yauheni Kaliuta) [1700846]
- [net] net/flow_dissector: correctly cap nhoff and thoff in case of BPF (Yauheni Kaliuta) [1700846]
- [net] selftests/bpf: use thoff instead of nhoff in BPF flow dissector (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: update testcases for BPF_ALU | BPF_ARSH (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier remove the rejection on BPF_ALU | BPF_ARSH (Yauheni Kaliuta) [1700846]
- [net] bpf: interpreter support BPF_ALU | BPF_ARSH (Yauheni Kaliuta) [1700846]
- [s390] s390: bpf: implement jitting of BPF_ALU | BPF_ARSH | BPF_* (Yauheni Kaliuta) [1700846]
- [powerpc] ppc: bpf: implement jitting of BPF_ALU | BPF_ARSH | BPF_* (Yauheni Kaliuta) [1700846]
- [tools] bpf: Expect !info.func_info and insn_off name changes in test_btf/libbpf/bpftool (Yauheni Kaliuta) [1700846]
- [tools] bpf: tools: Sync uapi bpf.h for the name changes in bpf_func_info (Yauheni Kaliuta) [1700846]
- [net] bpf: Change insn_offset to insn_off in bpf_func_info (Yauheni Kaliuta) [1700846]
- [net] bpf: Improve the info.func_info and info.func_info_rec_size behavior (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add a command to dump the trace pipe (Yauheni Kaliuta) [1700846]
- [arm64] arm64/bpf: don't allocate BPF JIT programs in module memory (Yauheni Kaliuta) [1700846]
- [net] bpf: add __weak hook for allocating executable memory (Yauheni Kaliuta) [1700846]
- [net] bpf: add per-insn complexity limit (Yauheni Kaliuta) [1700846]
- [net] bpf: improve verifier branch analysis (Yauheni Kaliuta) [1700846]
- [net] bpf: check pending signals while verifying programs (Yauheni Kaliuta) [1700846]
- [tools] selftests: add a test for bpf_prog_test_run_xattr (Yauheni Kaliuta) [1700846]
- [tools] libbpf: add bpf_prog_test_run_xattr (Yauheni Kaliuta) [1700846]
- [tools] tools: sync uapi/linux/bpf.h (Yauheni Kaliuta) [1700846]
- [net] bpf: respect size hint to BPF_PROG_TEST_RUN if present (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: fix: seg fault with NULL pointer arg (Yauheni Kaliuta) [1700846]
- [powerpc] bpf: powerpc64: optimize JIT passes for bpf function calls (Yauheni Kaliuta) [1700846]
- [tools] bpf: allow BPF read access to qdisc pkt_len (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Fix license in README.rst (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix memleak in aux->func_info and aux->btf (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: get ifindex from ifname (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: improve xdp1 example (Yauheni Kaliuta) [1700846]
- [tools] bpf: Apply F_NEEDS_EFFICIENT_UNALIGNED_ACCESS to more ACCEPT test cases (Yauheni Kaliuta) [1700846]
- [tools] bpf: Make more use of 'any' alignment in test_verifier.c (Yauheni Kaliuta) [1700846]
- [tools] bpf: Adjust F_NEEDS_EFFICIENT_UNALIGNED_ACCESS handling in test_verifier.c (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add BPF_F_ANY_ALIGNMENT (Yauheni Kaliuta) [1700846]
- [tools] bpf: Improve socket lookup reuseport documentation (Yauheni Kaliuta) [1700846]
- [tools] bpf: Support sk lookup in netns with id 0 (Yauheni Kaliuta) [1700846]
- [tools] bpf: Fix verifier log string check for bad alignment (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add owner_prog_type and owner_jited to bpftool output (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: mark offloaded programs more explicitly in plain output (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix bash completion for new map types (queue and stack) (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix bash completion for bpftool prog (attach|detach) (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: use "/proc/self/" i.o. crafting links with getpid() (Yauheni Kaliuta) [1700846]
- [arm64] arm64/bpf: use movn/movk/movk sequence to generate kernel addresses (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: make libbpf _GNU_SOURCE friendly (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix a bitfield pretty print issue (Yauheni Kaliuta) [1700846]
- [tools] bpf: Fix various lib and testsuite build failures on 32-bit (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add addition type tests to test_btf (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix two test_btf unit test cases (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: check name validity for various types (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add config fragment CONFIG_FTRACE_SYSCALLS (Yauheni Kaliuta) [1700846]
- [tools] bpf: test_sockmap, add options for msg_pop_data() helper (Yauheni Kaliuta) [1700846]
- [tools] bpf: add msg_pop_data helper to tools (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Document API and ABI conventions (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Verify versioned symbols (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Add version script for DSO (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Name changing for btf_get_from_id (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: change selftest test_btf for both jit and non-jit (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: support proper non-jit func info (Yauheni Kaliuta) [1700846]
- [arm64] bpf, arm64: fix getting subprog addr from aux for calls (Yauheni Kaliuta) [1700846]
- [net] bpf, ppc64: generalize fetching subprog into bpf_jit_get_func_addr (Yauheni Kaliuta) [1700846]
- [tools] bpf: align map type names formatting (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: fix spelling mistake "Memmber" -> "Member" (Yauheni Kaliuta) [1700846]
- [net] bpf, tags: Fix DEFINE_PER_CPU expansion (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add BPF_MAP_TYPE_QUEUE and BPF_MAP_TYPE_STACK to bpftool-map (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: fix: error handling regarding kprobe_events (Yauheni Kaliuta) [1700846]
- [tools] libbpf: make bpf_object__open default to UNSPEC (Yauheni Kaliuta) [1700846]
- [tools] bpf: add skb->tstamp r/w access from tc clsact and cg skb progs (Yauheni Kaliuta) [1700846]
- [net] bpf: fix integer overflow in queue_stack_map (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix spelling mistake "memeory" -> "memory" (Yauheni Kaliuta) [1700846]
- [net] bpf, lpm: make longest_prefix_match() faster (Yauheni Kaliuta) [1700846]
- [tools] bpf: adding tests for map_in_map helpber in libbpf (Yauheni Kaliuta) [1700846]
- [tools] bpf: adding support for map in map in libbpf (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: don't specify prog name if kernel doesn't support it (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: remove map name retry from bpf_create_map_xattr (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: introduce bpf_object__probe_caps to test BPF capabilities (Yauheni Kaliuta) [1700846]
- [tools] libbpf: make sure bpf headers are c++ include-able (Yauheni Kaliuta) [1700846]
- [tools] bpf: fix a libbpf loader issue (Yauheni Kaliuta) [1700846]
- [include] bpf: fix a compilation error when CONFIG_BPF_SYSCALL is not defined (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool: add support for func types (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: enhance test_btf file testing to test func info (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: refactor to implement btf_get_from_id() in lib/bpf (Yauheni Kaliuta) [1700846]
- [samples] tools/bpf: do not use pahole if clang/llvm can generate BTF sections (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add support to read .BTF.ext sections (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: extends test_btf to test load/retrieve func_type info (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add new fields for program load in lib/bpf (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: sync kernel uapi bpf.h header to tools directory (Yauheni Kaliuta) [1700846]
- [net] bpf: Introduce bpf_func_info (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: Add tests for BTF_KIND_FUNC_PROTO and BTF_KIND_FUNC (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: Sync kernel btf.h header (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: Add BTF_KIND_FUNC and BTF_KIND_FUNC_PROTO (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: Break up btf_type_is_void() (Yauheni Kaliuta) [1700846]
- [tools] tools: add selftest for BPF_F_ZERO_SEED (Yauheni Kaliuta) [1700846]
- [tools] tools: sync linux/bpf.h (Yauheni Kaliuta) [1700846]
- [include] bpf: move BPF_F_QUERY_EFFECTIVE after map flags (Yauheni Kaliuta) [1700846]
- [net] bpf: allow zero-initializing hash map seed (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: retry map creation without the name (Yauheni Kaliuta) [1700846]
- [net] bpf: allocate local storage buffers using GFP_ATOMIC (Yauheni Kaliuta) [1700846]
- [net] bpf: fix off-by-one error in adjust_subprog_starts (Yauheni Kaliuta) [1700846]
- [net] bpf: fix null pointer dereference on pointer offload (Yauheni Kaliuta) [1700846]
- [tools] bpftool: make libbfd optional (Yauheni Kaliuta) [1700846]
- [net] net/bpf: split VLAN_PRESENT bit handling from VLAN_TCI (Yauheni Kaliuta) [1700846]
- [powerpc] net/bpf_jit: PPC: split VLAN_PRESENT bit handling from VLAN_TCI (Yauheni Kaliuta) [1700846]
- [net] net/skbuff: add macros for VLAN_PRESENT bit (Yauheni Kaliuta) [1700846]
- [tools] selftest/bpf: Use bpf_sk_lookup_{tcp, udp} in test_sock_addr (Yauheni Kaliuta) [1700846]
- [net] bpf: Support socket lookup in CGROUP_SOCK_ADDR progs (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix IPv6 dport byte order in bpf_sk_lookup_udp (Yauheni Kaliuta) [1700846]
- [net] bpf: Extend the sk_lookup() helper to XDP hookpoint (Yauheni Kaliuta) [1700846]
- [net] bpf: helper to pop data from messages (Yauheni Kaliuta) [1700846]
- [net] bpf: fix wrong helper enablement in cgroup local storage (Yauheni Kaliuta) [1700846]
- [include] bpf: sk_msg program helper bpf_msg_push_data (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix IPv6 dport byte-order in bpf_sk_lookup (Yauheni Kaliuta) [1700846]
- [net] bpf: Allow sk_lookup with IPv6 module (Yauheni Kaliuta) [1700846]
- [net] net: core: Fix build with CONFIG_IPV6=m (Yauheni Kaliuta) [1700846]
- [net] bpf: Fix dev pointer dereference from sk_skb (Yauheni Kaliuta) [1700846]
- [net] bpf: fix building without CONFIG_INET (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf: Fix bpf_program__next() API (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Fix uninitialized duration warning (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test narrow loads with off > 0 for bpf_sock_addr (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test narrow loads with off > 0 in test_verifier (Yauheni Kaliuta) [1700846]
- [net] bpf: Allow narrow loads with offset > 0 (Yauheni Kaliuta) [1700846]
- [tools] bpftool: support loading flow dissector (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add pinmaps argument to the load/loadall (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add loadall command (Yauheni Kaliuta) [1700846]
- [tools] libbpf: add internal pin_name (Yauheni Kaliuta) [1700846]
- [tools] libbpf: bpf_program__pin: add special case for instances.nr == 1 (Yauheni Kaliuta) [1700846]
- [tools] libbpf: cleanup after partial failure in bpf_object__pin (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: rename flow dissector section to flow_dissector (Yauheni Kaliuta) [1700846]
- [netdrv] bpf: do not pass netdev to translate() and prepare() offload callbacks (Yauheni Kaliuta) [1700846]
- [net] bpf: pass prog instead of env to bpf_prog_offload_verifier_prep() (Yauheni Kaliuta) [1700846]
- [netdrv] bpf: pass destroy() as a callback and remove its ndo_bpf subcommand (Yauheni Kaliuta) [1700846]
- [include] bpf: pass translate() as a callback and remove its ndo_bpf subcommand (Yauheni Kaliuta) [1700846]
- [netdrv] bpf: call verifier_prep from its callback in struct bpf_offload_dev (Yauheni Kaliuta) [1700846]
- [net] bpf: call finalize() from its callback in struct bpf_offload_dev (Yauheni Kaliuta) [1700846]
- [net] bpf: call verify_insn from its callback in struct bpf_offload_dev (Yauheni Kaliuta) [1700846]
- [netdrv] bpf: pass a struct with offload callbacks to bpf_offload_dev_create() (Yauheni Kaliuta) [1700846]
- [tools] kselftests/bpf: use ping6 as the default ipv6 ping binary when it exists (Yauheni Kaliuta) [1700846]
- [tools] bpftool: Improve handling of ENOENT on map dumps (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add a test case for sock_ops perf-event notification (Yauheni Kaliuta) [1700846]
- [net] bpf: add perf event notificaton support for sock_ops (Yauheni Kaliuta) [1700846]
- [net] bpf: let verifier to calculate and record max_pkt_offset (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: update references to other man pages in documentation (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: pass an argument to silence open_obj_pinned() (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix plain output and doc for --bpffs option (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: prevent infinite loop in get_fdinfo() (Yauheni Kaliuta) [1700846]
- [samples] bpf_load: add map name to load_maps error message (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: adjust rlimit RLIMIT_MEMLOCK when loading programs, maps (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: enable (uncomment) all tests in test_libbpf.sh (Yauheni Kaliuta) [1700846]
- [net] bpf: fix bpf_prog_get_info_by_fd to return 0 func_lens for unpriv (Yauheni Kaliuta) [1700846]
- [net] bpf: show main program address and length in bpf_prog_info (Yauheni Kaliuta) [1700846]
- [net] bpf: show real jited address in bpf_prog_info->jited_ksyms (Yauheni Kaliuta) [1700846]
- [net] bpf: show real jited prog address in /proc/kallsyms (Yauheni Kaliuta) [1700846]
- [tools] bpf: test make sure to run unpriv test cases in test_verifier (Yauheni Kaliuta) [1700846]
- [tools] bpf: add various test cases to test_verifier (Yauheni Kaliuta) [1700846]
- [net] bpf: don't set id on after map lookup with ptr_to_map_val return (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Fix compile error in libbpf_attach_type_by_name (Yauheni Kaliuta) [1700846]
- [tools] kselftests/bpf: use ping6 as the default ipv6 ping binary if it exists (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add unlimited rlimit for flow_dissector_load (Yauheni Kaliuta) [1700846]
- [net] bpf: add bpf_jit_limit knob to restrict unpriv allocations (Yauheni Kaliuta) [1700846]
- [net] bpf: make direct packet write unclone more robust (Yauheni Kaliuta) [1700846]
- [net] bpf: fix leaking uninitialized memory on pop/peek helpers (Yauheni Kaliuta) [1700846]
- [net] bpf: fix direct packet write into pop/peek helpers (Yauheni Kaliuta) [1700846]
- [net] bpf: fix cg_skb types to hint access type in may_access_direct_pkt_data (Yauheni Kaliuta) [1700846]
- [net] bpf: fix direct packet access for flow dissector progs (Yauheni Kaliuta) [1700846]
- [net] bpf: disallow direct packet access for unpriv in cg_skb (Yauheni Kaliuta) [1700846]
- [tools] bpf: fix test suite to enable all unpriv program types (Yauheni Kaliuta) [1700846]
- [net] bpf, btf: fix a missing check bug in btf_parse (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add config fragments BPF_STREAM_PARSER and XDP_SOCKETS (Yauheni Kaliuta) [1700846]
- [net] bpf: devmap: fix wrong interface selection in notifier_call (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: fix completion for "bpftool map update" (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: print nb of cmds to stdout (not stderr) for batch mode (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: document restriction on '.' in names to pin in bpffs (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix return value comparison for tests in test_libbpf.sh (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: simplify and cleanup perf ring buffer walk (Yauheni Kaliuta) [1700846]
- [net] bpf, verifier: avoid retpoline for map push/pop/peek operation (Yauheni Kaliuta) [1700846]
- [net] bpf, verifier: remove unneeded flow key in check_helper_mem_access (Yauheni Kaliuta) [1700846]
- [net] bpf, verifier: reject xadd on flow key memory (Yauheni Kaliuta) [1700846]
- [net] bpf, verifier: fix register type dump in xadd and st (Yauheni Kaliuta) [1700846]
- [net] ulp: remove uid and user_visible members (Yauheni Kaliuta) [1700846]
- [tools] bpf: test_sockmap add options to use msg_push_data (Yauheni Kaliuta) [1700846]
- [tools] bpf: libbpf support for msg_push_data (Yauheni Kaliuta) [1700846]
- [tools] Sync uapi/bpf.h to tools/include (Yauheni Kaliuta) [1700846]
- [net] bpf: add tests for direct packet access from CGROUP_SKB (Yauheni Kaliuta) [1700846]
- [net] bpf: add cg_skb_is_valid_access for BPF_PROG_TYPE_CGROUP_SKB (Yauheni Kaliuta) [1700846]
- [tools] bpf, libbpf: use correct barriers in perf ring buffer walk (Yauheni Kaliuta) [1700846]
- [tools] tools, perf: add and use optimized ring_buffer_{read_head, write_tail} helpers (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add missing executables to .gitignore (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add test cases for queue and stack maps (Yauheni Kaliuta) [1700846]
- [net] bpf: add MAP_LOOKUP_AND_DELETE_ELEM syscall (Yauheni Kaliuta) [1700846]
- [net] bpf: add queue and stack maps (Yauheni Kaliuta) [1700846]
- [net] bpf/verifier: add ARG_PTR_TO_UNINIT_MAP_VALUE (Yauheni Kaliuta) [1700846]
- [net] bpf/syscall: allow key to be null in map functions (Yauheni Kaliuta) [1700846]
- [net] bpf: rename stack trace map operations (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: use 4 context mode for the NFP disasm (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix file resource leak in load_kallsyms (Yauheni Kaliuta) [1700846]
- [tools] bpf: sockmap, add msg_peek tests to test_sockmap (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap, support for msg_peek in sk_msg with redirect ingress (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap, fix skmsg recvmsg handler to track size correctly (Yauheni Kaliuta) [1700846]
- [include] bpf: skmsg, improve sk_msg_used_element to work in cork context (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Per-symbol visibility for DSO (Yauheni Kaliuta) [1700846]
- [tools] bpf, tls: add tls header to tools infrastructure (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: add map create command (Yauheni Kaliuta) [1700846]
- [tools] bpf: bpftool, add flag to allow non-compat map definitions (Yauheni Kaliuta) [1700846]
- [tools] bpf: bpftool, add support for attaching programs to maps (Yauheni Kaliuta) [1700846]
- [maintainers] bpf, doc: add maintainers entry to related files (Yauheni Kaliuta) [1700846]
- [tools] bpf: add tls support for testing in test_sockmap (Yauheni Kaliuta) [1700846]
- [net] tls: add bpf support to sk_msg handling (Yauheni Kaliuta) [1700846]
- [net] tls: replace poll implementation with read hook (Yauheni Kaliuta) [1700846]
- [net] tls: convert to generic sk_msg interface (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: convert to generic sk_msg interface (Yauheni Kaliuta) [1700846]
- [net] tcp, ulp: remove ulp bits from sockmap (Yauheni Kaliuta) [1700846]
- [net] tcp, ulp: enforce sock_owned_by_me upon ulp init and cleanup (Yauheni Kaliuta) [1700846]
- [net] net/tls: Make function get_rec() static (Yauheni Kaliuta) [1700846]
- [net] net/tls: Mark the end in scatterlist table (Yauheni Kaliuta) [1700846]
- [net] tls: Fixed a memory leak during socket close (Yauheni Kaliuta) [1700846]
- [net] net/tls: Removed redundant checks for non-NULL (Yauheni Kaliuta) [1700846]
- [net] tls: Add support for inplace records encryption (Yauheni Kaliuta) [1700846]
- [net] tls: Remove redundant vars from tls record structure (Yauheni Kaliuta) [1700846]
- [net] net/tls: Fixed race condition in async encryption (Yauheni Kaliuta) [1700846]
- [net] tls: Fix socket mem accounting error under async encryption (Yauheni Kaliuta) [1700846]
- [net] net/tls: Add support for async encryption of records for performance (Yauheni Kaliuta) [1700846]
- [net] tls: Remove dead code in tls_sw_sendmsg (Yauheni Kaliuta) [1700846]
- [net] net/tls: Fixed return value when tls_complete_pending_work() fails (Yauheni Kaliuta) [1700846]
- [net] bpf: wait for running BPF programs when updating map-in-map (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: install script with_addr.sh (Yauheni Kaliuta) [1700846]
- [tools] selftests: bpf: add config fragment LWTUNNEL (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: use proper type and uapi perf_event.h header for libbpf (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add XDP selftests for modifying and popping VLAN headers (Yauheni Kaliuta) [1700846]
- [tools] bpf: make TC vlan bpf_helpers avail to selftests (Yauheni Kaliuta) [1700846]
- [net] net: fix generic XDP to handle if eth header was mangled (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: test_verifier, check bpf_map_lookup_elem access in bpf prog (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: test_verifier, change names of fixup maps (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool, print strerror when map lookup error occurs (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool, split the function do_dump() (Yauheni Kaliuta) [1700846]
- [net] bpf: return EOPNOTSUPP when map lookup isn't supported (Yauheni Kaliuta) [1700846]
- [net] bpf: error handling when map_lookup_elem isn't supported (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: Fix a missing check bug (Yauheni Kaliuta) [1700846]
- [net] bpf: allow offload of programs with BPF-to-BPF function calls (Yauheni Kaliuta) [1700846]
- [net] bpf: add verifier callback to get stack usage info for offloaded progs (Yauheni Kaliuta) [1700846]
- [tools] libbpf: relicense libbpf as LGPL-2.1 OR BSD-2-Clause (Yauheni Kaliuta) [1700846]
- [samples] bpf, tracex3_user: erase "ARRAY_SIZE" redefined (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Use __u32 instead of u32 in bpf_program__load (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Make include guards consistent (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Consistent prefixes for interfaces in str_error.h (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Consistent prefixes for interfaces in nlattr.h (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Consistent prefixes for interfaces in libbpf.h (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Move __dump_nlmsg_t from API to implementation (Yauheni Kaliuta) [1700846]
- [documentation] Documentation: Describe bpf reference tracking (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Add C tests for reference tracking (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Support loading individual progs (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Add tests for reference tracking (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Generalize dummy program types (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add helper to retrieve socket in BPF (Yauheni Kaliuta) [1700846]
- [include] bpf: Introduce bpf_skb_ancestor_cgroup_id helper (Yauheni Kaliuta) [1700846]
- [tools] bpf: sync include/uapi/linux/bpf.h to tools/include/uapi/linux/bpf.h (Yauheni Kaliuta) [1700846]
- [tools] bpf: sync bpf.h uapi with tools/ (Yauheni Kaliuta) [1700846]
- [tools] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1700846]
- [tools] bpf: Sync bpf.h uapi to tools/ (Yauheni Kaliuta) [1700846]
- [tools] bpf: sync bpf.h to tools/ (Yauheni Kaliuta) [1700846]
- [net] bpf: Add reference tracking to verifier (Yauheni Kaliuta) [1700846]
- [net] bpf: Macrofy stack state copy (Yauheni Kaliuta) [1700846]
- [include] bpf: Add PTR_TO_SOCKET verifier type (Yauheni Kaliuta) [1700846]
- [net] bpf: Generalize ptr_or_null regs check (Yauheni Kaliuta) [1700846]
- [net] bpf: Reuse canonical string formatter for ctx errs (Yauheni Kaliuta) [1700846]
- [net] bpf: Add iterator for spilled registers (Yauheni Kaliuta) [1700846]
- [net] bpf: don't accept cgroup local storage with zero value size (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: cgroup local storage-based network counters (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: extend test_cgrp2_attach2 test to use per-cpu cgroup storage (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: extend the storage test to test per-cpu cgroup storage (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add verifier per-cpu cgroup storage tests (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add support for PERCPU_CGROUP_STORAGE maps (Yauheni Kaliuta) [1700846]
- [net] bpf: don't allow create maps of per-cpu cgroup local storages (Yauheni Kaliuta) [1700846]
- [net] bpf: introduce per-cpu cgroup local storage (Yauheni Kaliuta) [1700846]
- [net] bpf: rework cgroup storage pointer passing (Yauheni Kaliuta) [1700846]
- [net] bpf: extend cgroup bpf core to allow multiple cgroup storage types (Yauheni Kaliuta) [1700846]
- [net] bpf/test_run: support cgroup local storage (Yauheni Kaliuta) [1700846]
- [net] bpf: harden flags check in cgroup_storage_update_elem() (Yauheni Kaliuta) [1700846]
- [net] bpf: permit CGROUP_DEVICE programs accessing helper bpf_get_current_cgroup_id() (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test libbpf_{prog,attach}_type_by_name (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Use libbpf_attach_type_by_name in test_socket_cookie (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Support sk_skb/stream_{parser, verdict} section names (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Support cgroup_skb/{e,in}gress section names (Yauheni Kaliuta) [1700846]
- [tools] libbpf: Introduce libbpf_attach_type_by_name (Yauheni Kaliuta) [1700846]
- [tools] bpftool: Fix bpftool net output (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add support for BPF_MAP_TYPE_REUSEPORT_SOCKARRAY maps (Yauheni Kaliuta) [1700846]
- [tools] bpf: test_maps, only support ESTABLISHED socks (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap, fix transition through disconnect without close (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap only allow ESTABLISHED sock state (Yauheni Kaliuta) [1700846]
- [net] bpf: remove redundant null pointer check before consume_skb (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: fix compilation failure (Yauheni Kaliuta) [1700846]
- [net] flow_dissector: fix build failure without CONFIG_NET (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: fix a compilation failure (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: remove duplicated includes (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool: improve output format for bpftool net (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix bpf_flow.c build (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: test bpf flow dissection (Yauheni Kaliuta) [1700846]
- [tools] flow_dissector: implements eBPF parser (Yauheni Kaliuta) [1700846]
- [tools] bpf: support flow dissector in libbpf and bpftool (Yauheni Kaliuta) [1700846]
- [include] flow_dissector: implements flow dissector BPF hook (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: Fix end boundary calculation for type section (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix a netlink recv issue (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool: support prog array map and map of maps (Yauheni Kaliuta) [1700846]
- [net] bpf: add bpffs pretty print for program array map (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool: add net support (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add more netlink functionalities in lib/bpf (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: move bpf/lib netlink related functions into a new file (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf/test_progs: do not check errno == 0 (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add missing executables to .gitignore (Yauheni Kaliuta) [1700846]
- [net] bpf/verifier: fix verifier instability (Yauheni Kaliuta) [1700846]
- [net] bpf: avoid misuse of psock when TCP_ULP_BPF collides with another ULP (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool, add xskmap in map types (Yauheni Kaliuta) [1700846]
- [tools] bpf: add selftest for bpf's (set|get)_sockopt for SAVE_SYN (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: xdpsock, minor fixes (Yauheni Kaliuta) [1700846]
- [samples] bpf: add TCP_SAVE_SYN/TCP_SAVED_SYN sample program (Yauheni Kaliuta) [1700846]
- [net] bpf: add TCP_SAVE_SYN/TCP_SAVED_SYN options for bpf_(set|get)sockopt (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: bpftool: add btf percpu map formated dump (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add bpffs percpu map pretty print tests in test_btf (Yauheni Kaliuta) [1700846]
- [net] bpf: add bpffs pretty print for percpu arraymap/hash/lru_hash (Yauheni Kaliuta) [1700846]
- [net] bpf/verifier: display non-spill stack slot types in print_verifier_state (Yauheni Kaliuta) [1700846]
- [tools] bpf: use --cgroup in test_suite if supplied (Yauheni Kaliuta) [1700846]
- [tools] bpf: sockmap test remove shutdown() calls (Yauheni Kaliuta) [1700846]
- [net] bpf: remove duplicated include from syscall.c (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap, decrement copied count correctly in redirect error case (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix psock refcount leak in bpf_tcp_recvmsg (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix potential use after free in bpf_tcp_close (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: return from do_event_pipe() on bad arguments (Yauheni Kaliuta) [1700846]
- [net] bpf: use per htab salt for bucket hash (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap: write_space events need to be passed to TCP handler (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix sock hash count in alloc_sock_hash_elem (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix sock_hash_alloc and reject zero-sized keys (Yauheni Kaliuta) [1700846]
- [net] bpf: fix redirect to map under tail calls (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Support per queue XDP ring (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Add XDP TX and REDIRECT (Yauheni Kaliuta) [1700846]
- [net] xdp: Helpers for disabling napi_direct of xdp_return_frame (Yauheni Kaliuta) [1700846]
- [net] bpf: Make redirect_info accessible from modules (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Add ndo_xdp_xmit (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Handle xdp_frames in xdp napi ring (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Avoid drops by oversized packets when XDP is enabled (Yauheni Kaliuta) [1700846]
- [netdrv] veth: Add driver XDP (Yauheni Kaliuta) [1700846]
- [net] net: Export skb_headers_offset_update (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: fix bpf selftest test_cgroup_storage failure (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix sock_map_ctx_update_elem race with exist/noexist (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix map elem deletion race with smap_stop_sock (Yauheni Kaliuta) [1700846]
- [net] bpf, sockmap: fix leakage of smap_psock_map_entry (Yauheni Kaliuta) [1700846]
- [net] bpf: fix a rcu usage warning in bpf_prog_array_copy_core() (Yauheni Kaliuta) [1700846]
- [tools] bpf: test: fix spelling mistake "REUSEEPORT" -> "REUSEPORT" (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Selftest for bpf_skb_ancestor_cgroup_id (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Add cgroup id helpers to bpf_helpers.h (Yauheni Kaliuta) [1700846]
- [net] bpf: decouple btf from seq bpf fs dump and enable more maps (Yauheni Kaliuta) [1700846]
- [tools] bpf: Test BPF_PROG_TYPE_SK_REUSEPORT (Yauheni Kaliuta) [1700846]
- [tools] bpf: test BPF_MAP_TYPE_REUSEPORT_SOCKARRAY (Yauheni Kaliuta) [1700846]
- [tools] bpf: Refactor ARRAY_SIZE macro to bpf_util.h (Yauheni Kaliuta) [1700846]
- [net] bpf: Introduce BPF_PROG_TYPE_SK_REUSEPORT (Yauheni Kaliuta) [1700846]
- [net] bpf: Introduce BPF_MAP_TYPE_REUSEPORT_SOCKARRAY (Yauheni Kaliuta) [1700846]
- [net] net: Add ID (if needed) to sock_reuseport and expose reuseport_lock (Yauheni Kaliuta) [1700846]
- [tools] tools/bpf: add bpffs pretty print btf test for hash/lru_hash maps (Yauheni Kaliuta) [1700846]
- [net] bpf: btf: add pretty print for hash/lru_hash maps (Yauheni Kaliuta) [1700846]
- [net] bpf: fix bpffs non-array map seq_show issue (Yauheni Kaliuta) [1700846]
- [powerpc] powerpc/Makefiles: Convert ifeq to ifdef where possible (Yauheni Kaliuta) [1700846]
- [net] bpf: introduce update_effective_progs() (Yauheni Kaliuta) [1700846]
- [s390] s390: fix br_r1_trampoline for machines without exrl (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: fix a typo in map in map test (Yauheni Kaliuta) [1700846]
- [tools] tools: bpf: fix BTF code added twice to different trees (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: extend test_cgrp2_attach2 test to use cgroup storage (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add a cgroup storage test (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: add verifier cgroup storage tests (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add support for CGROUP_STORAGE maps (Yauheni Kaliuta) [1700846]
- [net] bpf: introduce the bpf_get_local_storage() helper function (Yauheni Kaliuta) [1700846]
- [net] bpf: don't allow create maps of cgroup local storages (Yauheni Kaliuta) [1700846]
- [net] bpf/verifier: introduce BPF_PTR_TO_MAP_VALUE (Yauheni Kaliuta) [1700846]
- [net] bpf: extend bpf_prog_array to store pointers to the cgroup storage (Yauheni Kaliuta) [1700846]
- [net] bpf: allocate cgroup storage entries on attaching bpf programs (Yauheni Kaliuta) [1700846]
- [net] bpf: pass a pointer to a cgroup storage using pcpu variable (Yauheni Kaliuta) [1700846]
- [net] bpf: introduce cgroup storage maps (Yauheni Kaliuta) [1700846]
- [net] bpf: add ability to charge bpf maps memory dynamically (Yauheni Kaliuta) [1700846]
- [net] bpf: verifier: MOV64 don't mark dst reg unbounded (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test for get_socket_cookie (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Add bpf_get_socket_cookie to bpf_helpers.h (Yauheni Kaliuta) [1700846]
- [tools] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1700846]
- [net] bpf: Support bpf_get_socket_cookie in more prog types (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: convert xdpsock_user.c to libbpf (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: convert xdp_fwd_user.c to libbpf (Yauheni Kaliuta) [1700846]
- [tools] tools: libbpf: add bpf_object__find_program_by_title() (Yauheni Kaliuta) [1700846]
- [tools] tools: libbpf: handle NULL program gracefully in bpf_program__nth_fd() (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: Add BTF build flags to Makefile (Yauheni Kaliuta) [1700846]
- [tools] tools/bpftool: ignore build products (Yauheni Kaliuta) [1700846]
- [tools] bpf: Add Python 3 support to selftests scripts for bpf (Yauheni Kaliuta) [1700846]
- [tools] bpf: btf: fix inconsistent IS_ERR and PTR_ERR (Yauheni Kaliuta) [1700846]
- [net] bpf: sockmap: remove redundant pointer sg (Yauheni Kaliuta) [1700846]
- [net] bpf: bpf_prog_array_alloc() should return a generic non-rcu pointer (Yauheni Kaliuta) [1700846]
- [tools] tools: bpftool: don't pass FEATURES_DUMP to libbpf (Yauheni Kaliuta) [1700846]
- [tools] tools: libbpf: remove libelf-getphdrnum feature detection (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: test_cgrp2_sock2: fix an off by one (Yauheni Kaliuta) [1700846]
- [samples] samples: bpf: ensure that we don't load over MAX_PROGS programs (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test case for BPF_SOCK_OPS_TCP_LISTEN_CB (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Better verification in test_tcpbpf (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Switch test_tcpbpf_user to cgroup_helpers (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Fix const'ness in cgroup_helpers (Yauheni Kaliuta) [1700846]
- [tools] bpf: Sync bpf.h to tools/ (Yauheni Kaliuta) [1700846]
- [net] bpf: Add BPF_SOCK_OPS_TCP_LISTEN_CB (Yauheni Kaliuta) [1700846]
- [tools] bpf: btf: print map dump and lookup with btf info (Yauheni Kaliuta) [1700846]
- [tools] bpf: btf: add btf print functionality (Yauheni Kaliuta) [1700846]
- [tools] bpf: btf: export btf types and name by offset from lib (Yauheni Kaliuta) [1700846]
- [tools] tools: bpf: build and install man page for eBPF helpers from bpftool/ (Yauheni Kaliuta) [1700846]
- [tools] tools: bpf: synchronise BPF UAPI header with tools (Yauheni Kaliuta) [1700846]
- [include] bpf: fix documentation for eBPF helpers (Yauheni Kaliuta) [1700846]
- [tools] bpftool: add bash completion for cgroup tree command (Yauheni Kaliuta) [1700846]
- [tools] bpftool: document cgroup tree command (Yauheni Kaliuta) [1700846]
- [tools] bpftool: introduce cgroup tree command (Yauheni Kaliuta) [1700846]
- [tools] selftests/bpf: Test sys_connect BPF hooks with TFO (Yauheni Kaliuta) [1700846]
- [samples] samples/bpf: Add xdp_sample_pkts example (Yauheni Kaliuta) [1700846]
- [tools] trace_helpers.c: Add helpers to poll multiple perf FDs for events (Yauheni Kaliuta) [1700846]
- [net] bpf: deal with kABI breakage in cgroups (Yauheni Kaliuta) [1700846]
- [netdrv] nfp: bpf: fix static check error through tightening shift amount adjustment (Pablo Cascon) [1663986]
- [netdrv] nfp: disable netpoll on representors (Pablo Cascon) [1663986]
- [netdrv] nfp: validate the return code from dev_queue_xmit() (Pablo Cascon) [1663986]
- [netdrv] nfp: fix simple vNIC mailbox length (Pablo Cascon) [1663986]
- [netdrv] nfp: nsp: set higher timeout for flash bundle (Pablo Cascon) [1663986]
- [netdrv] nfp: nsp: allow the use of DMA buffer (Pablo Cascon) [1663986]
- [netdrv] nfp: nsp: move default buffer handling into its own function (Pablo Cascon) [1663986]
- [netdrv] nfp: nsp: use fractional size of the buffer (Pablo Cascon) [1663986]
- [netdrv] nfp: report RJ45 connector in ethtool (Pablo Cascon) [1663986]
- [netdrv] nfp: remove ethtool flashing fallback (Pablo Cascon) [1663986]
- [netdrv] nfp: Remove switchdev.h inclusion (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: fix code-gen bug on BPF_ALU | BPF_XOR | BPF_K (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: allow flashing the device via devlink (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: include vendor/product info in serial number (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: use the generic manufacture identifier instead of vendor (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: cmsg: use struct_size() helper (Pablo Cascon) [1663986]
- [netdrv] nfp: Implement ndo_get_port_parent_id() (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: complete ALU32 logic shift supports (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: correct the behavior for shifts by zero (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: report the running and flashed versions (Pablo Cascon) [1663986]
- [netdrv] nfp: nsp: add support for versions command (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: report fixed versions (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink: report driver name and serial number (Pablo Cascon) [1663986]
- [netdrv] nfp: use struct_size() in kzalloc() (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: enable MAC address sharing for offloadable devs (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: ensure MAC cleanup on address change (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: add infastructure for non-repr priv data (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: ensure deletion of old offloaded MACs (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: remove list infastructure from MAC offload (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: ignore offload of VF and PF repr MAC addresses (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: tidy tunnel related private data (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: support multiple memory units for filter offloads (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: increase cmesg reply timeout (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: optimize codegen for JSET with a constant (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: remove the trivial JSET optimization (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: fix cb_ident duplicate in indirect block register (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: allow to opt-out of RED offload (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: ensure TCP flags can be placed in IPv6 frame (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: implement jitting of BPF_ALU | BPF_ARSH | BPF_* (Pablo Cascon) [1663986]
- [netdrv] nfp: convert to DEFINE_SHOW_ATTRIBUTE (Pablo Cascon) [1663986]
- [netdrv] nfp: report more info when reconfiguration fails (Pablo Cascon) [1663986]
- [netdrv] nfp: add offset to all TLV parsing errors (Pablo Cascon) [1663986]
- [netdrv] nfp: add offloads on representors (Pablo Cascon) [1663986]
- [netdrv] nfp: add locking around representor changes (Pablo Cascon) [1663986]
- [netdrv] nfp: run don't require Qdiscs on representor netdevs (Pablo Cascon) [1663986]
- [netdrv] nfp: run representor TX locklessly (Pablo Cascon) [1663986]
- [netdrv] nfp: avoid oversized TSO headers with metadata prepend (Pablo Cascon) [1663986]
- [netdrv] nfp: correct descriptor offsets in presence of metadata (Pablo Cascon) [1663986]
- [netdrv] nfp: move queue variable init (Pablo Cascon) [1663986]
- [netdrv] nfp: move temporary variables in nfp_net_tx_complete() (Pablo Cascon) [1663986]
- [netdrv] nfp: copy only the relevant part of the TX descriptor for frags (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: prevent offload if rhashtable insert fails (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: release metadata on offload failure (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: add support for more threshold actions (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: add cls_u32 offload for simple band classification (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: add functions to update DSCP -> virtual queue map (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: calculate PRIO map len and check mailbox size (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: add GRED offload (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: wrap RED parameters in bands (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: add up bands for sto/non-sto stats (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: switch to extended stats for reading packet/byte counts (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: size threshold table to account for bands (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: pass band parameter to functions (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: map per-band symbols (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: restructure Qdisc handling (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: save RED's parameters (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: reset RED's child based on limit (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: build full Qdisc hierarchy based on graft notifications (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: allocate Qdisc child table (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: remember which Qdisc is root (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: track all offload-enabled qdiscs (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: keep track of all RED thresholds (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: rename qdiscs -> red_qdiscs (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: remove unnecessary code in flow lookup (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: remove TC egdev offloads (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: offload tunnel decap rules via indirect TC blocks (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: increase scope of netdev checking functions (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: allow non repr netdev offload (Pablo Cascon) [1663986]
- [netdrv] nfp: use the new __netdev_tx_sent_queue() BQL optimisation (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: refuse RED offload with harddrop set (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: don't set negative threshold (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: provide more precise info about offload parameter validation (Pablo Cascon) [1663986]
- [netdrv] nfp: parse vNIC TLV capabilities at alloc time (Pablo Cascon) [1663986]
- [netdrv] nfp: pass ctrl_bar pointer to nfp_net_alloc (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: split qdisc offload code into a separate file (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: include geneve as supported offload tunnel type (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: use geneve and vxlan helpers (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: use the common netdev notifier (Pablo Cascon) [1663986]
- [netdrv] nfp: register a notifier handler in a central location for the device (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: make nfp_fl_lag_changels_event() void (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: don't try to nack device unregister events (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: remove unnecessary iteration over devices (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: protect against mis-initializing atomic counters (Pablo Cascon) [1663986]
- [netdrv] nfp: devlink port split support for 1x100G CXP NIC (Pablo Cascon) [1663986]
- [netdrv] nfp: replace long license headers with SPDX (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: support pointers to other stack frames for BPF-to-BPF calls (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: account for BPF-to-BPF calls when preparing nfp JIT (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: ignore helper-related checks for BPF calls in nfp verifier (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: rename nfp_prog->stack_depth as nfp_prog->stack_frame_depth (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: allow control message sizing for map ops (Pablo Cascon) [1663986]
- [netdrv] nfp: allow apps to request larger MTU on control vNIC (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: parse global BPF ABI version capability (Pablo Cascon) [1663986]
- [netdrv] nfp: warn on experimental TLV types (Pablo Cascon) [1663986]
- [netdrv] nfp: remove ndo_poll_controller (Pablo Cascon) [1663986]
- [netdrv] nfp: replace spin_lock_bh with spin_lock in tasklet callback (Pablo Cascon) [1663986]
- [netdrv] nfp: separate VXLAN and GRE feature handling (Pablo Cascon) [1663986]
- [netdrv] nfp: validate rtsym accesses fall within the symbol (Pablo Cascon) [1663986]
- [netdrv] nfp: prefix rtsym error messages with symbol name (Pablo Cascon) [1663986]
- [netdrv] nfp: fix readq on absolute RTsyms (Pablo Cascon) [1663986]
- [netdrv] nfp: make RTsym users handle absolute symbols correctly (Pablo Cascon) [1663986]
- [netdrv] nfp: support access to absolute RTsyms (Pablo Cascon) [1663986]
- [netdrv] nfp: convert all RTsym users to use new read/write helpers (Pablo Cascon) [1663986]
- [netdrv] nfp: convert existing RTsym helpers to full target decoding (Pablo Cascon) [1663986]
- [netdrv] nfp: pass cpp_id to nfp_cpp_map_area() (Pablo Cascon) [1663986]
- [netdrv] nfp: add RTsym access helpers (Pablo Cascon) [1663986]
- [netdrv] nfp: add basic errors messages to target logic (Pablo Cascon) [1663986]
- [netdrv] nfp: save the MU locality field offset (Pablo Cascon) [1663986]
- [netdrv] nfp: refactor the per-chip PCIe config (Pablo Cascon) [1663986]
- [netdrv] nfp: add support for NFP5000 (Pablo Cascon) [1663986]
- [netdrv] nfp: abm: look up MAC addresses via management FW (Pablo Cascon) [1663986]
- [netdrv] nfp: add support for indirect HWinfo lookup (Pablo Cascon) [1663986]
- [netdrv] nfp: interpret extended FW load result codes (Pablo Cascon) [1663986]
- [netdrv] nfp: attempt FW load from flash (Pablo Cascon) [1663986]
- [netdrv] nfp: encapsulate NSP command arguments into structs (Pablo Cascon) [1663986]
- [netdrv] nfp: clean up return types in kdoc comments (Pablo Cascon) [1663986]
- [netdrv] nfp: flower: allow matching on ipv4 UDP tunnel tos and ttl (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: xdp_adjust_tail support (Pablo Cascon) [1663986]
- [netdrv] nfp: fix variable dereferenced before check in nfp_app_ctrl_rx_raw() (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: improve map offload info messages (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: remember maps by ID (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: allow receiving perf events on data queues (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: pass raw data buffer to nfp_bpf_event_output() (Pablo Cascon) [1663986]
- [netdrv] nfp: allow control message reception on data queues (Pablo Cascon) [1663986]
- [netdrv] nfp: move repr handling on RX path (Pablo Cascon) [1663986]
- [netdrv] nfp: protect from theoretical size overflows on HW descriptor ring (Pablo Cascon) [1663986]
- [netdrv] nfp: restore correct ordering of fields in rx ring structure (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: allow program sharing within ASIC (Pablo Cascon) [1663986]
- [netdrv] nfp: add .ndo_init() and .ndo_uninit() callbacks (Pablo Cascon) [1663986]
- [netdrv] nfp: add support for simultaneous driver and hw XDP (Pablo Cascon) [1663986]
- [netdrv] nfp: avoid using getnstimeofday64() (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: migrate to advanced reciprocal divide in reciprocal_div.h (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: support u32 divide using reciprocal_div.h (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: support u16 and u32 multiplications (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: copy range info for all operands of all ALU operations (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: rename umin/umax to umin_src/umax_src (Pablo Cascon) [1663986]
- [netdrv] nfp: make use of napi_consume_skb() (Pablo Cascon) [1663986]
- [netdrv] nfp: implement netpoll ndo (thus enabling netconsole) (Pablo Cascon) [1663986]
- [netdrv] nfp: fail probe if serial or interface id is missing (Pablo Cascon) [1663986]
- [netdrv] nfp: expose ring stats of inactive rings via ethtool (Pablo Cascon) [1663986]
- [netdrv] nfp: bpf: allow source ptr type be map ptr in memcpy optimization (Pablo Cascon) [1663986]
- [netdrv] bpf: offload: keep the offload state per-ASIC (Pablo Cascon) [1663986]
- [netdrv] bpf: offload: aggregate offloads per-device (Pablo Cascon) [1663986]
- [tools] selftests/bpf: add test for sharing objects between netdevs (Ivan Vecera) [1708399]
- [netdrv] netdevsim: allow program sharing between devices (Ivan Vecera) [1708399]
- [net] bpf: offload: allow program and map sharing per-ASIC (Ivan Vecera) [1708399]
- [netdrv] bpf: offload: keep the offload state per-ASIC (Ivan Vecera) [1708399]
- [netdrv] bpf: offload: aggregate offloads per-device (Ivan Vecera) [1708399]
- [net] bpf: offload: rename bpf_offload_dev_match() to bpf_offload_prog_map_match() (Ivan Vecera) [1708399]
- [netdrv] netdevsim: associate bound programs with shared dev (Ivan Vecera) [1708399]
- [netdrv] netdevsim: add shared netdevsim devices (Ivan Vecera) [1708399]
- [netdrv] netdevsim: add switch_id attribute (Ivan Vecera) [1708399]

* Wed Jun 12 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-105.rt20.46.el8]
- [rt] kernel-rt-4.18.0-105.rt20.45.el8 (Juri Lelli) [1678887]
- [infiniband] IB/mlx5: Remove set but not used variable (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: WQE dump jumps over first 16 bytes (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Fix false compilation warning (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Remove redundant assignment (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Fix compilation warning in en_tc.c (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Fix compilation warning in eq.c (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Fix the max MTU check in case of XDP (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Fix use-after-free after xdp_return_frame (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Fix scatter to CQE in DCT QP creation (Alaa Hleihel) [1691238]
- [netdrv] Revert "net/mlx5e: Enable reporting checksum unnecessary also for L3 packets" (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Rx, Check ip headers sanity (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: FPGA, tls, idr remove on flow delete (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: FPGA, tls, hold rcu read lock a bit longer (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Consider tunnel type for encap contexts (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: E-Switch, Fix esw manager vport indication for more vport commands (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Correctly use the namespace type when allocating pedit action (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: ethtool, Allow legacy link-modes configuration via non-extended ptys (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: ethtool, Fix type analysis of advertised link-mode (Alaa Hleihel) [1691238]
- [netdrv] net: mlx5: Add a missing check on idr_find, free buf (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Allow IPv4 ttl & IPv6 hop_limit rewrite for all L4 protocols (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Use mlx5 core to create/destroy a DEVX DCT (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Fix DCT creation bad flow (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Fix bad flow upon DEVX mkey creation (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Add support for ODP for DEVX indirection mkey (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Manage indirection mkey upon DEVX flow for ODP (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: DEVX handling for indirection MKEY (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Fix access to non-existing receive queue (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Properly get the PF number phys port name ndo (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Consolidate update FTE for all removal changes (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Add a locked flag to node removal functions (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Add modify FTE helper function (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Fix multiple updates of steering rules in parallel (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Validate correct PD before prefetch MR (Alaa Hleihel) [1691238]
- [infiniband] RDMA/mlx5: Introduce and reuse helper to identify ODP MR (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Protect against prefetch of invalid MR (Alaa Hleihel) [1691238]
- [infiniband] net/mlx5: Make mlx5_cmd_exec_cb() a safe API (Alaa Hleihel) [1691238]
- [infiniband] RDMA: Clean structures from CONFIG_INFINIBAND_ON_DEMAND_PAGING (Alaa Hleihel) [1691238]
- [infiniband] RDMA/mlx5: Embed into the code flow the ODP config option (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5e: Add missing static function annotation (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Do not use hw_access_flags for be and CPU data (Alaa Hleihel) [1691238]
- [netdrv] net/mlx5: Fix code style issue in mlx driver (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Fix the locking of SRQ objects in ODP events (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Make mlx5_ib_stage_odp_cleanup() static (Alaa Hleihel) [1691238]
- [infiniband] IB/mlx5: Declare local functions 'static' (Alaa Hleihel) [1691238]
- [netdrv] RDMA/mlx5: Delete declaration of already removed function (Alaa Hleihel) [1691238]
- [netdrv] mlx5-core: Mark ConnectX-6 Dx as unsupported device (Alaa Hleihel) [1691236 1687434]
- [netdrv] net/mlx5: Update the list of the PCI supported devices (Alaa Hleihel) [1691236 1687434]
- [infiniband] IB/mlx5: Fix mapping of link-mode to IB width and speed (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: ethtool, Add ethtool support for 50Gbps per lane link modes (Alaa Hleihel) [1691236 1683102]
- [infiniband] IB/mlx5: Add support for 50Gbps per lane link modes (Alaa Hleihel) [1691236 1683102]
- [netdrv] net/mlx5: Add support to ext_* fields introduced in Port Type and Speed register (Alaa Hleihel) [1691236 1683102]
- [include] net/mlx5: Add new fields to Port Type and Speed register (Alaa Hleihel) [1691236 1683102]
- [netdrv] net/mlx5: Refactor queries to speed fields in Port Type and Speed register (Alaa Hleihel) [1691236 1683102]
- [netdrv] net/mlx5e: Set peer flow needed also for multipath (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Update check for merged eswitch device (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Use hint to resolve route when in HW multipath mode (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Always query offloaded tc peer rule counter (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Re-attempt to offload flows on multipath port affinity events (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5: Emit port affinity event for multipath offloads (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Allow one failure when offloading tc encap rules under multipath (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Don't inherit flow flags on peer flow creation (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Activate HW multipath and handle port affinity based on FIB events (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5: Add multipath mode (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5: Use own workqueue for lag netdev events processing (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5: Expose lag operations in header file (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5: Use unsigned int bit instead of bool as a struct member (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Don't make internal use of errno to denote missing neigh (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Cleanup attach encap function (Alaa Hleihel) [1691236 1663236]
- [netdrv] net/mlx5e: Remove 'parse_attr' argument in mlx5e_tc_add_fdb_flow() (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Introduce mlx5e_flow_esw_attr_init() helper (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Return the allocated flow directly from __mlx5e_add_fdb_flow (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix GRE key by controlling port tunnel entropy calculation (Alaa Hleihel) [1691236 1663240]
- [include] net/mlx5: Introduce tunnel entropy control in PCMR register (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5: Use read-modify-write when changing PCMR register values (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Remove wrong and superfluous tc pedit header type check (Alaa Hleihel) [1691236]
- [netdrv] drivers: net: use flow action infrastructure (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: support for two independent packet edit actions (Alaa Hleihel) [1691236]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, fix redirect resources availability check (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Fix a compilation warning in events.c (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: No command allowed when command interface is not ready (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix NULL pointer derefernce in set channels error flow (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Don't overwrite pedit action when multiple pedit used (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Update hw flows when encap source mac changed (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Use the inner headers to determine tc/pedit offload limitation on decap flows (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Properly set steering match levels for offloaded TC decap rules (Alaa Hleihel) [1691236 1663207]
- [netdrv] net/mlx5e: Unblock setting vid 0 for VFs through the uplink rep (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Move to use common phys port names for vport representors (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Allow MAC invalidation while spoofchk is ON (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Take lock with IRQs disabled to avoid deadlock (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix wrong private flag usage causing checksum disable (Alaa Hleihel) [1691236]
- [netdrv] Revert "net/mlx5e: E-Switch, Initialize eswitch only if eswitch manager" (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Fix flow creation on representors (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Fix how advise_mr() launches async work (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Fix check for supported user flags when creating a QP (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix cb_ident duplicate in indirect block register (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix wrong (zero) TX drop counter indication for representor (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Fix wrong error code return on FEC query failure (Alaa Hleihel) [1691236]
- [infiniband] Revert "IB/mlx5: Fix long EEH recover time with NVMe offloads" (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Allow XRC INI usage via verbs in DEVX context (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: drop useless LIST_HEAD (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: fix semicolon.cocci warnings (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Signedness bug in UVERBS_HANDLER() (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Allocate the per-port Q counter shared when DEVX is supported (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Add user control for XDP TX MPWQE feature (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Support Enhanced Multi-Packet TX WQE (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Add array for WQE info descriptors (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Maintain a FIFO structure for xdp_info instances (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Replace boolean doorbell indication with segment pointer (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Warn upon polling an error CQE (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Change the XDP SQ redirect indication (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: XDP, Precede XDP-related operations in RQ poll by a loaded program check (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: TX, Print opcode in error CQE warning (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Fix wrong error unwind (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Fix long EEH recover time with NVMe offloads (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Simplify netdev unbinding (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use the correct commands for UMEM and UCTX allocation (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use uid as part of alloc/dealloc transport domain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Fix LAG requirement when CONFIG_MLX5_ESWITCH is off (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Fix query_nic_sys_image_guid() error during init (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Support tunnel encap over tagged Ethernet (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Support VLAN encap ETH header generation (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Re-order route and encap header memory allocation (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Tunnel encap ETH header helper function (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Fail attempt to offload e-switch TC encap flows with vlan on underlay (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Tunnel routing output devs helper function (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Fail attempt to offload e-switch TC flows with egress upper devices (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Allow vlans on e-switch uplink reps (Alaa Hleihel) [1691236 1663255]
- [netdrv] net/mlx5e: Increase VF representors' SQ size to 128 (Alaa Hleihel) [1691236]
- [netdrv] mlx5: extend PTP gettime function to read system clock (Alaa Hleihel) [1691236]
- [netdrv] mlx5: update timecounter at least twice per counter overflow (Alaa Hleihel) [1691236]
- [include] IB/mlx5: Introduce uid as part of alloc/dealloc transport domain (Alaa Hleihel) [1691236]
- [netdrv] drivers: net: ethernet: mellanox: use skb_sec_path helper (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Fix compile issue when ODP disabled (Alaa Hleihel) [1691236]
- [include] net/mlx5: Add shared Q counter bits (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Add advise_mr() support (Alaa Hleihel) [1691236 1663248]
- [infiniband] IB/uverbs: Add helper to get array size from ptr attribute (Alaa Hleihel) [1691236 1663248]
- [infiniband] RDMA/mlx5: Fix function name typo 'fileds' -> 'fields' (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Delete unreachable handle_atomic code by simplifying SW completion (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Continue driver initialization despite debugfs failure (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Add some ethtool port control entries to the uplink rep netdev (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Expose ethtool pause and link functions to mlx5e callers (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Add sriov and udp tunnel ndo support for the uplink rep (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Handle port mtu/link, dcb and lag for uplink reps (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Uninstantiate esw manager vport netdev on switchdev mode (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Remove leftover code from the PF netdev being uplink rep (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Use dedicated uplink vport netdev representor (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5e: Use single argument for the esw representor build params helper (Alaa Hleihel) [1691236 1663256]
- [netdrv] net/mlx5: E-Switch, Remove redundant reloading of the IB interface (Alaa Hleihel) [1691236 1663256 1663207]
- [netdrv] net/mlx5: Handle LAG FW commands failure gracefully (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Make RoCE and SR-IOV LAG modes explicit (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Rename mlx5_lag_is_bonded() to __mlx5_lag_is_active() (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Allow co-enablement of uplink LAG and SRIOV (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Allow/disallow LAG according to pre-req only (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Adjustments for the activate LAG logic to run under sriov (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5e: Duplicate offloaded TC eswitch rules under uplink LAG (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5e: Offload TC e-switch rules with egress LAG device (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5e: In case of LAG, one switch parent id is used for all representors (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5e: Enhance flow counter scheme for offloaded TC eswitch rules (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5e: Infrastructure for duplicated offloading of TC flows (Alaa Hleihel) [1691236 1663230 1663207]
- [netdrv] net/mlx5e: E-Switch, Add peer miss rules (Alaa Hleihel) [1691236 1663230 1663207]
- [netdrv] net/mlx5: Introduce inter-device communication mechanism (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Fold the modify lag code into function (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Add lag affinity info to log (Alaa Hleihel) [1691236 1663230]
- [netdrv] net/mlx5: Split the activate lag function into two routines (Alaa Hleihel) [1691236 1663230]
- [include] net/mlx5: E-Switch, Introduce flow counter affinity (Alaa Hleihel) [1691236 1663230]
- [infiniband] IB/mlx5: Unify e-switch representors load approach between uplink and VFs (Alaa Hleihel) [1691236]
- [include] net/mlx5: Use lowercase 'X' for hex values (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Remove set but not used variable 'upriv' (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove duplicated include from eswitch.c (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Use monitor counters for update stats (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Monitor counters commands support (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Avoid query PPCNT register if not supported by the device (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Use CQE padding for Ethernet CQs (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Support multiple encapsulations for a TC flow (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5e: Allow association of a flow to multiple encaps (Alaa Hleihel) [1691236 1663239]
- [netdrv] net/mlx5e: Change parse attr struct to accommodate multiple tunnel infos (Alaa Hleihel) [1691236 1663239]
- [netdrv] net/mlx5e: Support header rewrite actions with remote port mirroring (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5e: Replace the split logic with extended destination (Alaa Hleihel) [1691236 1663239]
- [netdrv] net/mlx5e: Annul encap action ordering requirement (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5e: Move flow attr reformat action bit to per dest flags (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5e: Refactor eswitch flow attr for destination specific properties (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5: E-Switch, Rename esw attr mirror count field (Alaa Hleihel) [1691236 1663239 1663207]
- [netdrv] net/mlx5: Consider encapsulation properties when comparing destinations (Alaa Hleihel) [1691236 1663239]
- [infiniband] RDMA/mlx5: Fail early if user tries to create flows on IB representors (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Remove duplicated include from mlx5_ib.h (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Add 2X width support to query_port (Alaa Hleihel) [1691236 1683102]
- [infiniband] IB/mlx5: Add HDR speed support to query port (Alaa Hleihel) [1691236 1683102]
- [infiniband] IB/mlx5: Report CapabilityMask2 in ib_query_port (Alaa Hleihel) [1691236 1683102]
- [netdrv] net/mlx5e: Add GRE protocol offloading (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Move TC tunnel offloading code to separate source file (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Branch according to classified tunnel type (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Refactor VXLAN tunnel decap offloading code (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Refactor VXLAN tunnel encap offloading code (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Replace egdev with indirect block notifications (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Propagate the filter's net device to mlx5e structures (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Provide the TC filter netdev as parameter to flower callbacks (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Support TC indirect block notifications for eswitch uplink reprs (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5e: Store eswitch uplink representor state on a dedicated struct (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5: Remove the get protocol device interface entry (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Support extended destination format in flow steering command (Alaa Hleihel) [1691236 1663239]
- [netdrv] net/mlx5: E-Switch, Change vhca id valid bool field to bit flag (Alaa Hleihel) [1691236 1663239 1663207]
- [include] net/mlx5: Introduce extended destination fields (Alaa Hleihel) [1691236 1663239]
- [infiniband] net/mlx5: Revise gre and nvgre key formats (Alaa Hleihel) [1691236 1663240]
- [netdrv] net/mlx5: Add monitor commands layout and event data (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Add support for plugged-disabled cable status in PME (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Add support for PCIe power slot exceeded error in PME (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Rework handling of port module events (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Move flow counters data structures from flow steering header (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use helper to get CQE opcode (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Use helper to get CQE opcode (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: When fetching CQEs return CQE instead of void pointer (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Report packet based credit mode device capability (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Add packet based credit mode support (Alaa Hleihel) [1691236]
- [include] net/mlx5: Expose packet based credit mode (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Enable TX on a DEVX flow table (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Improve ethtool private-flags code structure (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: ethtool, Support user configuration for RX hash fields (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Move RSS params to a dedicated struct (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Refactor TIR configuration function (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Move modify tirs hash functionality (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Cleanup unused defines (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Remove trailing space of tx_pause ethtool counter name (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Allow XRC usage via verbs in DEVX context (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Update the supported DEVX commands (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Enforce DEVX privilege by firmware (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Enable modify and query verbs objects via DEVX (Alaa Hleihel) [1691236]
- [include] net/mlx5: Update mlx5_ifc with DEVX UCTX capabilities bits (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Unfold modify RMP function (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Unfold create RMP function (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Initialize SRQ tables on mlx5_ib (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Update SRQ functions signatures to mlx5_ib format (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Use stages for callback to setup and release DEVX (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Remove SRQ signature global flag (Alaa Hleihel) [1691236]
- [infiniband] net/mlx5: Move SRQ functions to RDMA part (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove references to local mlx5_core functions (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove not-used lib/eq.h header file (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove dead transobj code (Alaa Hleihel) [1691236]
- [infiniband] net/mlx5: Align SRQ licenses and copyright information (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Debug print for forwarded async events (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Forward SRQ resource events (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Forward QP/WorkQueues resource events (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove all deprecated software versions of FW events (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Handle raw delay drop general event (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Allow forwarding event type general event as is (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Handle raw port change event rather than the software version (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Remove unused events callback and logic (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use the new mlx5 core notifier API (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Forward all mlx5 events to mlx5 notifiers chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Use the new mlx5 core notifier API (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Allow port change event to be forwarded to driver notifiers chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Driver events notifier API (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use fragmented QP's buffer for in-kernel users (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Use fragmented SRQ's buffer for in-kernel users (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Attach a DEVX counter via raw flow creation (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Improve core device events handling (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Device events, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: CQ ERR, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Resource tables, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: CmdIF, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: FWPage, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: E-Switch, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: Clock, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: FPGA, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: FWTrace, Use async events chain (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Introduce atomic notifier chain subscription API (Alaa Hleihel) [1691236]
- [infiniband] RDMA/mlx5: Use the uapi disablement APIs instead of code (Alaa Hleihel) [1691236]
- [infiniband] RDMA/uverbs: Use a linear list to describe the compiled-in uapi (Alaa Hleihel) [1691236]
- [netdrv] mlx5: use skb_vlan_tag_get_prio() (Alaa Hleihel) [1691236]
- [infiniband] IB/mlx5: Allow modify AV in DCI QP to RTR (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Make EQE access methods inline (Alaa Hleihel) [1691236]
- [netdrv] {net, IB}/mlx5: Move Page fault EQ and ODP logic to RDMA (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Generic EQ (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Different EQ types (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Privatize eq_table and friends (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, irq_info and rmap belong to eq_table (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Create all EQs in one place (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Move all EQ logic to eq.c (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Remove redundant completion EQ list lock (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, No need to store eq index as a field (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Remove unused fields and structures (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5: EQ, Use the right place to store/read IRQ affinity hint (Alaa Hleihel) [1691236]
- [include] net/mlx5: Fix offsets of ifc reserved fields (Alaa Hleihel) [1691236]
- [netdrv] net/mlx5e: Remove the false indication of software timestamping support (Alaa Hleihel) [1691234 1647734]
- [netdrv] net/mlx5: Typo fix in del_sw_hw_rule (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: RX, Fix wrong early return in receive queue poll (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Cancel DIM work on close SQ (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Remove unused UDP GSO remaining counter (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Avoid encap flows deletion attempt the 1st time a neigh is resolved (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Properly initialize flow attributes for slow path eswitch rule deletion (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Avoid overriding the user provided priority for offloaded tc rules (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Err if asked to mirror a goto chain tc eswitch rule (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Fix default amount of channels for VF representors (Alaa Hleihel) [1691234]
- [include] net/mlx5: E-Switch, Fix fdb cap bits swap (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Block DEVX umem from the non applicable cases (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Fix XRC QP support after introducing extended atomic (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Fix failing ethtool query on FEC query error (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Fix wrong field name in FEC related functions (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Fix a bug in turning off FEC policy in unsupported speeds (Alaa Hleihel) [1691234]
- [include] net/mlx5: Fix XRC SRQ umem valid bits (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Allocate enough space for the FDB sub-namespaces (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Added 'raw_errors_laneX' fields to ethtool statistics (Alaa Hleihel) [1691234]
- [include] net/mlx5: Added "per_lane_error_counters" cap bit to PCAM (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Ethtool driver callback for query/set FEC policy (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Add port FEC get/set functions (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Add FEC fields to Port Phy Link Mode (PPLM) reg (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Remove counter from idr after removing it from list (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Take fs_counters dellist before addlist (Alaa Hleihel) [1691234]
- [infiniband] net/mlx5: Refactor fragmented buffer struct fields and init flow (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Support offloading tc priorities and chains for eswitch flows (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Use a slow path rule instead if vxlan neighbour isn't available (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: E-Switch, Enable setting goto slow path chain action (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Avoid duplicated code for tc offloads add/del fdb rule (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: For TC offloads, always add new flow instead of appending the actions (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Add a no-append flow insertion mode (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: E-Switch, Add chains and priorities (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: E-Switch, Have explicit API to delete fwd rules (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Split FDB fast path prio to multiple namespaces (Alaa Hleihel) [1691234]
- [include] net/mlx5: Add cap bits for multi fdb encap (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Split TC add rule path for nic vs e-switch (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Change return type of tc add flow functions (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Use flow counter IDs and not the wrapping cache object (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: E-Switch, Get counters for offloaded flows from callers (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Add support for extended atomic operations (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Allow scatter to CQE without global signaled WRs (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Verify that driver supports user flags (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Support scatter to CQE for DC transport type (Alaa Hleihel) [1691234]
- [include] net/mlx5: Expose DC scatter to CQE capability bit (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Add support for flow tag to raw create flow (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Verify DEVX object type (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Add new counter for aRFS rule insertion failures (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Add extack messages for TC offload failures (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: E-Switch, Add extack messages to devlink callbacks (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Allow reporting of checksum unnecessary (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Enable reporting checksum unnecessary also for L3 packets (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Add ethtool control of ring params to VF representors (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Enable multi-queue and RSS for VF representors (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Expose ethtool rss key size / indirection table functions (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Expose function for building RSS params (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Provide explicit directive if to create inner indirect tirs (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: E-Switch, Provide flow dest when creating vport rx rule (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Extract creation of rep's default flow rule (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Enable stateless offloads for VF representor netdevs (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Change VF representors' RQ type (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Ethtool steering, Support masks for l3/l4 filters (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Enable DEVX on IB (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Enable DEVX white list commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Manage device uid for DEVX white list commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Expose RAW QP device handles to user space (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set valid umem bit on DEVX (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of TD commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of XRCD commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of CQ creation (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid upon PD allocation (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of RQT commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of TIS commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of TIR commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of MCG commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of DCT commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of SRQ commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of SQ commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of RQ commands (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Set uid as part of QP creation (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Use uid as part of PD commands (Alaa Hleihel) [1691234]
- [include] net/mlx5: Update mlx5_ifc with DEVX UID bits (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of DCT commands (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of SRQ commands (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of SQ commands (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of RQ commands (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of QP commands (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Set uid as part of CQ commands (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Enable vport loopback when user context or QP mandate (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Allow creating RAW ethernet QP with loopback support (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Refactor transport domain bookkeeping logic (Alaa Hleihel) [1691234]
- [infiniband] net/mlx5: Rename incorrect naming in IFC file (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Use rdma_user_mmap_io (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Allow creating a matcher for a NIC TX flow table (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Add NIC TX namespace when getting a flow table (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Add flow actions support to raw create flow (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Refactor raw flow creation (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Don't overwrite action if already set (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Refactor flow action parsing to be more generic (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Enable attaching packet reformat action to steering flows (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Enable reformat on NIC RX if supported (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Enable attaching DECAP action to steering flows (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Enable decap and packet reformat on flow tables (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Enable attaching modify header to steering flows (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Add NIC TX steering support (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5e: Replace PTP clock lock from RW lock to seq lock (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5e: Move Q counters allocation and drop RQ to init_rx (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Add flow counters idr (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Store flow counters in a list (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Add new list to store deleted flow counters (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Change flow counters addlist type to single linked list (Alaa Hleihel) [1691234]
- [infiniband] RDMA/mlx5: Extend packet reformat verbs (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Add new flow action verb - packet reformat (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/uverbs: Add generic function to fill in flow action object (Alaa Hleihel) [1691234 1663215]
- [infiniband] RDMA/mlx5: Add a new flow action verb - modify header (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Export packet reformat alloc/dealloc functions (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Pass a namespace for packet reformat ID allocation (Alaa Hleihel) [1691234 1663215]
- [include] net/mlx5: Expose new packet reformat capabilities (Alaa Hleihel) [1691234 1663215]
- [netdrv] {net, RDMA}/mlx5: Rename encap to reformat packet (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Move header encap type to IFC header file (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Break encap/decap into two separated flow table creation flags (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Add support for more namespaces when allocating modify header (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Export modify header alloc/dealloc functions (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Add proper NIC TX steering flow tables support (Alaa Hleihel) [1691234 1663215]
- [netdrv] net/mlx5: Cleanup flow namespace getter switch logic (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Change TX affinity assignment in RoCE LAG mode (Alaa Hleihel) [1691234]
- [netdrv] net/mlx5: Add memic command opcode to command checker (Alaa Hleihel) [1691234]
- [infiniband] IB/mlx5: Destroy the DEVX object upon error flow (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, Read capabilities only when it is safe (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Ethtool steering, fix udp source port value (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Improve argument name for add flow API (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Ethtool steering, l4 proto support (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Ethtool steering, ip6 support (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Ethtool steering flow parsing refactoring (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Ethtool steering flow validation refactoring (Alaa Hleihel) [1691231]
- [infiniband] IB/uverbs: Use uverbs_alloc for allocations (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Unexport functions that need not be exported (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Remove unused mlx5_query_vport_admin_state (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: E-Switch, Remove unused argument when creating legacy FDB (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Rename modify/query_vport state related enums (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Mark expected switch fall-throughs (Alaa Hleihel) [1691231]
- [netdrv] mellanox: fix the dport endianness in call of __inet6_lookup_established() (Alaa Hleihel) [1691231]
- [netdrv] mlx5: handle DMA mapping error case for XDP redirect (Alaa Hleihel) [1691231]
- [infiniband] IB/uverbs: Add UVERBS_ATTR_FLAGS_IN to the specs language (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Issue direct lookup on vxlan ports by vport representors (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TX, Use function to access sq_dma object in fifo (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TX, Move DB fields in TXQ-SQ struct (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Add support for XDP_REDIRECT in device-out side (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Re-order fields of struct mlx5e_xdpsq (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Refactor XDP counters (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Make XDP xmit functions more generic (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Add counter for XDP redirect in RX (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Enable driver uapi commands for flow steering (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Add support for a flow table destination for driver flow steering (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Support adding flow steering rule by raw description (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Introduce driver create and destroy flow methods (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Introduce flow steering matcher uapi object (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Add support for flow table destination number (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Add forward compatible support for the FTE match data (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: Support offloading double vlan push/pop tc actions (Alaa Hleihel) [1691231 1615127]
- [netdrv] net/mlx5e: Refactor tc vlan push/pop actions offloading (Alaa Hleihel) [1691231 1615127]
- [netdrv] net/mlx5e: Support offloading tc double vlan headers match (Alaa Hleihel) [1691231 1615127]
- [netdrv] net/mlx5: FW tracer, Add debug prints (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, Enable tracing (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, parse traces and kernel tracing support (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, events handling (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, register log buffer memory key (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, create trace buffer and copy strings database (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, implement tracer logic (Alaa Hleihel) [1691231]
- [infiniband] RDMA/mlx5: Remove set but not used variables (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Add XRQ commands definitions (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Add core support for double vlan push/pop steering action (Alaa Hleihel) [1691231 1615127]
- [netdrv] net/mlx5: Expose MPEGC (Management PCIe General Configuration) structures (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: FW tracer, add hardware structures (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: fix an unused-function warning (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: IPsec, fix byte count in CQE (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Accel, add common metadata functions (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, build TLS netdev from capabilities (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, add software statistics (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, add Innova TLS rx data path (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, add innova rx support (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Accel, add TLS rx offload routines (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5e: TLS, refactor variable names (Alaa Hleihel) [1691231]
- [infiniband] RDMA/mlx5: Check that supplied blue flame index doesn't overflow (Alaa Hleihel) [1691231]
- [infiniband] RDMA/mlx5: Melt consecutive calls to alloc_bfreg() in one call (Alaa Hleihel) [1691231]
- [netdrv] net/mlx5: Use 2-factor allocator calls (Alaa Hleihel) [1691231]
- [infiniband] RDMA/mlx5: Remove unused port number parameter (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Expose dump and fill memory key (Alaa Hleihel) [1691231]
- [include] net/mlx5: Add hardware definitions for dump_fill_mkey (Alaa Hleihel) [1691231]
- [infiniband] net/mlx5: Limit scope of dump_fill_mkey function (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Add support for drain SQ & RQ (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Support RoCE ICRC encapsulated error counter (Alaa Hleihel) [1691231 1663195]
- [include] net/mlx5: Add RoCE RX ICRC encapsulated counter (Alaa Hleihel) [1691231 1663195]
- [infiniband] RDMA/mlx5: Refactor transport domain checks (Alaa Hleihel) [1691231]
- [infiniband] IB/mlx5: Expose DEVX tree (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add DEVX query EQN support (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add DEVX support for memory registration (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add support for DEVX query UAR (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add DEVX support for modify and query commands (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add obj create and destroy functionality (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Add support for DEVX general command (Alaa Hleihel) [1691231 1663190]
- [infiniband] IB/mlx5: Introduce DEVX (Alaa Hleihel) [1691231 1663190]
- [netdrv] net/mlx5: Expose DEVX specification (Alaa Hleihel) [1691231]

* Wed Jun 12 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-104.rt20.45.el8]
- [rt] kernel-rt-4.18.0-104.rt20.44.el8 (Juri Lelli) [1678887]
- [virt] kvm: arm/arm64: Don't emulate virtual timers on userspace ioctls (Andrew Jones) [1716066]
- [virt] kvm: arm/arm64: Remove unused timer variable (Andrew Jones) [1716066]
- [virt] kvm: arm/arm64: Rework the timer code to use a timer_map (Andrew Jones) [1716066]
- [powerpc] powernv: Fix compile without CONFIG_TRACEPOINTS (David Gibson) [1524674]
- [virt] kvm: ppc: book3s: Remove useless checks in 'release' method of KVM device (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Clear escalation interrupt pointers on device close (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Prevent races when releasing device (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Replace the 'destroy' method by a 'release' method (David Gibson) [1524674]
- [virt] kvm: Introduce a 'release' method for KVM devices (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Activate XIVE exploitation mode (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add passthrough support (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a mapping for the source ESB pages (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a TIMA mapping (David Gibson) [1524674]
- [virt] kvm: Introduce a 'mmap' method for KVM devices (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add get/set accessors for the VP XIVE state (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a control to dirty the XIVE EQ pages (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a control to sync the sources (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a global reset control (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add controls for the EQ configuration (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Add a control to configure a source (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: add a control to initialize a source (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: xive: Introduce a new capability KVM_CAP_PPC_IRQ_XIVE (David Gibson) [1524674]
- [powerpc] kvm: ppc: book3s hv: Add a new KVM device for the XIVE native exploitation mode (David Gibson) [1524674]
- [powerpc] xive: add OPAL extensions for the XIVE native exploitation support (David Gibson) [1524674]
- [powerpc] powernv: move OPAL call wrapper tracing and interrupt handling to C (David Gibson) [1524674]
- [thermal] thermal/intel_powerclamp: fix truncated kthread name (Lihong Yang) [1716810]
- [kernel] kernel/signal.c: trace_signal_deliver when signal_group_exit (Waiman Long) [1548279]
- [kernel] signal: unconditionally leave the frozen state in ptrace_stop() (Waiman Long) [1548279]
- [kernel] cgroup: never call do_group_exit() with task->frozen bit set (Waiman Long) [1548279]
- [kernel] kernel: cgroup: fix misuse of x (Waiman Long) [1548279]
- [kernel] cgroup: get rid of cgroup_freezer_frozen_exit() (Waiman Long) [1548279]
- [kernel] cgroup: prevent spurious transition into non-frozen state (Waiman Long) [1548279]
- [kernel] cgroup: Remove unused cgrp variable (Waiman Long) [1548279]
- [documentation] cgroup: document cgroup v2 freezer interface (Waiman Long) [1548279]
- [kernel] cgroup: add tracing points for cgroup v2 freezer (Waiman Long) [1548279]
- [kernel] cgroup: make TRACE_CGROUP_PATH irq-safe (Waiman Long) [1548279]
- [tools] kselftests: cgroup: don't fail on cg_kill_all() error in cg_destroy() (Waiman Long) [1548279]
- [kernel] cgroup: cgroup v2 freezer (Waiman Long) [1548279]
- [kernel] cgroup: protect cgroup->nr_(dying_)descendants by css_set_lock (Waiman Long) [1548279]
- [kernel] cgroup: implement __cgroup_task_count() helper (Waiman Long) [1548279]
- [kernel] cgroup: rename freezer.c into legacy_freezer.c (Waiman Long) [1548279]
- [kernel] cgroup: remove extra cgroup_migrate_finish() call (Waiman Long) [1548279]
- [kernel] cgroup/cpuset: Update stale generate_sched_domains() comments (Waiman Long) [1548279]
- [kernel] cgroup: saner refcounting for cgroup_root (Waiman Long) [1548279]
- [fs] fix cgroup_do_mount() handling of failure exits (Waiman Long) [1548279]
- [kernel] cgroup: Add named hierarchy disabling to cgroup_no_v1 boot param (Waiman Long) [1548279]
- [kernel] cgroup: fix parsing empty mount option string (Waiman Long) [1548279]
- [kernel] cgroup: fix CSS_TASK_ITER_PROCS (Waiman Long) [1548279]
- [kernel] cgroup: Fix dom_cgrp propagation when enabling threaded mode (Waiman Long) [1548279]
- [lib] lib: objagg: fix handling of object with 0 users when assembling hints (Ivan Vecera) [1704850]
- [lib] test_objagg: Uninitialized variable in error handling (Ivan Vecera) [1704850]
- [lib] test_objagg: Test the correct variable (Ivan Vecera) [1704850]
- [lib] lib: objagg: Fix an error code in objagg_hints_get() (Ivan Vecera) [1704850]
- [lib] lib: objagg: add root count to stats (Ivan Vecera) [1704850]
- [lib] lib: objagg: implement optimization hints assembly and use hints for object creation (Ivan Vecera) [1704850]
- [lib] lib: objagg: fix typo in objagg_stats_put() docstring (Ivan Vecera) [1704850]
- [lib] lib: introduce initial implementation of object aggregation manager (Ivan Vecera) [1704850]
- [netdrv] ibmvnic: Fix unchecked return codes of memory allocations (Steve Best) [1718919]
- [netdrv] ibmvnic: Refresh device multicast list after reset (Steve Best) [1718919]
- [netdrv] ibmvnic: Do not close unopened driver during reset (Steve Best) [1718919]
- [target] scsi: target: tcmu: Switch to bitmap_zalloc() (Maurizio Lombardi) [1712917]
- [target] scsi: target: tcmu: wait for nl reply only if there are listeners or during an add (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Simplify iscsit_handle_text_cmd() (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Simplify iscsit_dump_data_payload() (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Avoid iscsit_release_commands_from_conn() deadlock (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Rename a function and a function pointer (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Fix spelling of "unsolicited" (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Convert comments about locking into runtime checks (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Remove an incorrect comment (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Add target_send_busy() (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Inline transport_lun_remove_cmd() (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Simplify the LUN RESET implementation (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Remove several state tests from the TMF code (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Remove the write_pending_status() callback function (Maurizio Lombardi) [1712917]
- [target] scsi: target: make the pi_prot_format ConfigFS path readable (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: fix use after free (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: avoid cmd/qfull timers updated whenever a new cmd comes (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: fix error msg typo when create lio_qr_cache failed (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Use kmem_cache_free() instead of kfree() (Maurizio Lombardi) [1712917]
- [target] scsi: target: perform t10_wwn ID initialisation in target_alloc_device() (Maurizio Lombardi) [1712917]
- [target] scsi: target: remove hardcoded T10 Vendor ID in INQUIRY response (Maurizio Lombardi) [1712917]
- [target] scsi: target: add device vendor_id configfs attribute (Maurizio Lombardi) [1712917]
- [target] scsi: target: consistently null-terminate t10_wwn strings (Maurizio Lombardi) [1712917]
- [target] scsi: target: use consistent left-aligned ASCII INQUIRY data (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Reduce the amount of code executed with a spinlock held (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Make ABORT and LUN RESET handling synchronous (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Fix TAS handling for aborted commands (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Simplify the code for aborting SCSI commands (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Make it possible to wait from more than one context for command completion (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Use system workqueues for TMF (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Make sure that target_wait_for_sess_cmds() waits long enough (Maurizio Lombardi) [1712917]
- [target] scsi: target: Fix target_wait_for_sess_cmds breakage with active signals (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Simplify transport_clear_lun_ref() (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Use kvcalloc() instead of open-coding it (Maurizio Lombardi) [1712917]
- [target] scsi: target/tcmu: Fix queue_cmd_ring() declaration (Maurizio Lombardi) [1712917]
- [target] scsi: target: replace fabric_ops.name with fabric_alias (Maurizio Lombardi) [1712917]
- [target] scsi: target: drop unnecessary get_fabric_name() accessor from fabric_ops (Maurizio Lombardi) [1712917]
- [target] scsi: target: drop unused pi_prot_format attribute storage (Maurizio Lombardi) [1712917]
- [target] scsi: target: add emulate_pr backstore attr to toggle PR support (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Avoid that a kernel oops is triggered when COMPARE AND WRITE fails (Maurizio Lombardi) [1712917]
- [target] scsi: target: Don't request modules that aren't even built (Maurizio Lombardi) [1712917]
- [target] scsi: target: Set response length for REPORT TARGET PORT GROUPS (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Always call transport_complete_callback() upon failure (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Use sg_alloc_table() instead of open-coding it (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Use the SECTOR_SHIFT constant (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Remove the SCF_COMPARE_AND_WRITE_POST flag (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Remove an unused data member from struct xcopy_pt_cmd (Maurizio Lombardi) [1712917]
- [target] scsi: target/core: Fix spelling in two source code comments (Maurizio Lombardi) [1712917]
- [target] scsi: target: stash sess_err_stats on Data-Out timeout (Maurizio Lombardi) [1712917]
- [target] scsi: target: split out helper for cxn timeout error stashing (Maurizio Lombardi) [1712917]
- [target] scsi: target: log NOP ping timeouts as errors (Maurizio Lombardi) [1712917]
- [target] scsi: target: log Data-Out timeouts as errors (Maurizio Lombardi) [1712917]
- [include] scsi: target: use ISCSI_IQN_LEN in iscsi_target_stat (Maurizio Lombardi) [1712917]
- [target] scsi: target: iblock: split T10 PI SGL across command bios (Maurizio Lombardi) [1712917]
- [target] scsi: iscsi: target: fix spelling mistake "entires" -> "entries" (Maurizio Lombardi) [1712917]
- [target] scsi: iscsi: target: Fix conn_ops double free (Maurizio Lombardi) [1712917]
- [target] scsi: iscsi: target: Set conn->sess to NULL when iscsi_login_set_conn_values fails (Maurizio Lombardi) [1712917]
- [target] scsi: target: loop, usb, vhost, xen: use target_remove_session (Maurizio Lombardi) [1712917]
- [target] scsi: tcm_fc: use target_remove_session (Maurizio Lombardi) [1712917]
- [target] scsi: target: make transport_init_session_tags static (Maurizio Lombardi) [1712917]
- [target] scsi: iscsi target: have iscsit_start_nopin_timer call __iscsit_start_nopin_timer (Maurizio Lombardi) [1712917]
- [target] scsi: target: fix __transport_register_session locking (Maurizio Lombardi) [1712917]
- [target] Revert "scsi: target/iscsi: Reduce number of __iscsit_free_cmd() callers" (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: use u64 for dev_size (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: use match_int for dev params (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: do not set max_blocks if data_bitmap has been setup (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: unmap if dev is configured (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: check if dev is configured before block/reset (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: use lio core se_device configuration helper (Maurizio Lombardi) [1712917]
- [target] scsi: target: add helper to check if dev is configured (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: initialize list head (Maurizio Lombardi) [1712917]
- [target] scsi: target_core_user: fix double unlock (Maurizio Lombardi) [1712917]
- [target] scsi: target: Remove se_dev_entry.ua_count (Maurizio Lombardi) [1712917]
- [target] scsi: target: Fix handling of removed LUNs (Maurizio Lombardi) [1712917]
- [target] scsi: target: Send unit attention condition even if the sense buffer is too small (Maurizio Lombardi) [1712917]
- [target] scsi: target: Do not duplicate the code that marks that a command has sense data (Maurizio Lombardi) [1712917]
- [target] scsi: target/tcm_loop: Avoid that static checkers warn about dead code (Maurizio Lombardi) [1712917]
- [target] scsi: target/iscsi: Reduce number of __iscsit_free_cmd() callers (Maurizio Lombardi) [1712917]
- [target] scsi: target: Simplify the code for waiting for command completion (Maurizio Lombardi) [1712917]
- [target] scsi: target: Simplify transport_generic_free_cmd() (2/2) (Maurizio Lombardi) [1712917]
- [target] scsi: target: Simplify transport_generic_free_cmd() (1/2) (Maurizio Lombardi) [1712917]
- [target] scsi: target: Fold core_tmr_handle_tas_abort() into transport_cmd_finish_abort() (Maurizio Lombardi) [1712917]
- [target] scsi: target: Simplify core_tmr_handle_tas_abort() (Maurizio Lombardi) [1712917]
- [target] scsi: target: Document when CMD_T_STOP and CMD_T_COMPLETE are set (Maurizio Lombardi) [1712917]
- [target] scsi: target: Make the session shutdown code also wait for commands that are being aborted (Maurizio Lombardi) [1712917]
- [target] scsi: target: Introduce transport_init_session() (Maurizio Lombardi) [1712917]
- [target] scsi: target: Rename transport_init_session() into transport_alloc_session() (Maurizio Lombardi) [1712917]
- [target] scsi: target: Move a list_del_init() statement (Maurizio Lombardi) [1712917]
- [target] scsi: target: Avoid that EXTENDED COPY commands trigger lock inversion (Maurizio Lombardi) [1712917]
- [target] scsi: target: Use config_item_name() instead of open-coding it (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: Don't pass KERN_ERR to pr_err (Maurizio Lombardi) [1712917]
- [target] scsi: target: remove target_find_device (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: add module wide block/reset_netlink support (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: misc nl code cleanup (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: simplify nl interface (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: track nl commands (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: delete unused __wait (Maurizio Lombardi) [1712917]
- [target] scsi: tcmu: remove useless code and clean up the code style (Maurizio Lombardi) [1712917]

* Mon Jun 10 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-103.rt20.44.el8]
- [rt] kernel-rt-4.18.0-103.rt20.43.el8 (Juri Lelli) [1678887]
- [rt] Update locaversion-rt to rt20 (Juri Lelli) [https://bugzilla.redhat.com/show_bug.cgi?id=1680161]
- [rt] sched/completion: Fix a lockup in wait_for_completion() (Corey Minyard) [https://bugzilla.redhat.com/show_bug.cgi?id=1680161]
- [rt] drm/i915: Don't disable interrupts independently of the lock (Sebastian Andrzej Siewior) [https://bugzilla.redhat.com/show_bug.cgi?id=1680161]
- [rt] tty/sysrq: Convert show_lock to raw_spinlock_t (Julien Grall) [https://bugzilla.redhat.com/show_bug.cgi?id=1680161]
- [rt] powerpc: reshuffle TIF bits (Sebastian Andrzej Siewior) [https://bugzilla.redhat.com/show_bug.cgi?id=1680161]
- [rt] powerpc/pseries/iommu: Use a locallock instead local_irq_save() (Sebastian Andrzej Siewior) [https://bugzilla.redhat.com/show_bug.cgi?id=1680161]

* Mon Jun 10 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-103.rt16.43.el8]
- [rt] kernel-rt-4.18.0-103.rt16.42.el8 (Juri Lelli) [1678887]
- [ipc] ipc: do cyclic id allocation for the ipc object. (Waiman Long) [1710480]
- [ipc] ipc: conserve sequence numbers in ipcmni_extend mode (Waiman Long) [1710480]
- [ipc] ipc: allow boot time extension of IPCMNI from 32k to 16M (Waiman Long) [1710480]
- [ipc] ipc/mqueue: optimize msg_get() (Waiman Long) [1710480]
- [ipc] ipc/mqueue: remove redundant wq task assignment (Waiman Long) [1710480]
- [ipc] ipc: prevent lockup on alloc_msg and free_msg (Waiman Long) [1710480]
- [ipc] ipc: IPCMNI limit check for semmni (Waiman Long) [1710480]
- [ipc] ipc: IPCMNI limit check for msgmni and shmmni (Waiman Long) [1710480]
- [ipc] ipc/shm.c: use ERR_CAST() for shm_lock() error return (Waiman Long) [1710480]
- [ipc] ipc/shm: properly return EIDRM in shm_lock() (Waiman Long) [1710480]
- [ipc] ipc/util.c: update return value of ipc_getref from int to bool (Waiman Long) [1710480]
- [ipc] ipc/util.c: further variable name cleanups (Waiman Long) [1710480]
- [ipc] ipc: simplify ipc initialization (Waiman Long) [1710480]
- [ipc] ipc: get rid of ids->tables_initialized hack (Waiman Long) [1710480]
- [lib] lib/rhashtable: guarantee initial hashtable allocation (Waiman Long) [1710480]
- [lib] lib/rhashtable: simplify bucket_table_alloc() (Waiman Long) [1710480]
- [ipc] ipc: drop ipc_lock() (Waiman Long) [1710480]
- [ipc] ipc/util.c: correct comment in ipc_obtain_object_check (Waiman Long) [1710480]
- [ipc] ipc: rename ipcctl_pre_down_nolock() (Waiman Long) [1710480]
- [ipc] ipc/util.c: use ipc_rcu_putref() for failues in ipc_addid() (Waiman Long) [1710480]
- [ipc] ipc: reorganize initialization of kern_ipc_perm.seq (Waiman Long) [1710480]
- [ipc] ipc: compute kern_ipc_perm.id under the ipc lock (Waiman Long) [1710480]
- [x86] x86/speculation/mds: Improve CPU buffer clear documentation (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Revert CPU buffer clear on double fault exit (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add 'mitigations=' support for MDS (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [s390] s390/speculation: Support 'mitigations=' cmdline option (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [powerpc] powerpc/speculation: Support 'mitigations=' cmdline option (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [mm] x86/speculation: Support 'mitigations=' cmdline option (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [kernel] cpu/speculation: Add 'mitigations=' cmdline option (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] x86/speculation/mds: Fix documentation typo (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] Documentation: Correct the possible MDS sysfs values (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] x86/mds: Add MDSUM variant to the MDS documentation (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Print SMT vulnerable on MSBDS with mitigations off (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Fix comment (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add SMT warning message (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation: Move arch_smt_update() call to after mitigation decisions (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] x86/speculation/mds: Add mds=full,nosmt cmdline option (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] Documentation: Add MDS vulnerability documentation (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] documentation: Move L1TF to separate directory (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add mitigation mode VMWERV (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [base] x86/speculation/mds: Add sysfs reporting for MDS (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add mitigation control for MDS (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Conditionally clear CPU buffers on idle entry (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [kvm] x86/kvm/vmx: Add MDS protection when L1D Flush is not active (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Clear CPU buffers on exit to user (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] x86/speculation/mds: Add mds_clear_cpu_buffers() (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [kvm] x86/kvm: Expose X86_FEATURE_MD_CLEAR to guests (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add BUG_MSBDS_ONLY (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation/mds: Add basic bug infrastructure for MDS (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation: Consolidate CPU whitelists (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [tools] x86/msr-index: Cleanup bit defines (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [documentation] x86/speculation/l1tf: Drop the swap storage limit restriction when l1tf=off (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [x86] x86/speculation: Cast ~SPEC_CTRL_STIBP atomic value to int (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [tools] tools power x86_energy_perf_policy: Override CFLAGS assignments and add LDFLAGS to build command (Waiman Long) [1713695 1690360 1690351 1690338] {CVE-2018-12126 CVE-2018-12127 CVE-2018-12130 CVE-2019-11091}
- [scsi] scsi: qla2xxx: Fix read offset in qla24xx_load_risc_flash() (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Simplify conditional check again (Himanshu Madhani) [1665555]
- [scsi] qla2xxx: Update driver version to 10.01.00.15.08.1-k (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Secure flash update support for ISP28XX (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Add 28xx flash primary/secondary status/image mechanism (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Simplification of register address used in qla_tmpl.c (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Correction and improvement to fwdt processing (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Update flash read/write routine (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Add support for multiple fwdump templates/segments (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Cleanups for NVRAM/Flash read/write path (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Correctly report max/min supported speeds (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Add Serdes support for ISP28XX (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Add Device ID for ISP28XX (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Fix routine qla27xx_dump_{mpi|ram}() (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Remove FW default template (Himanshu Madhani) [1665555]
- [scsi] scsi: qla2xxx: Add fw_attr and port_no SysFS node (Himanshu Madhani) [1665555]
- [netdrv] e1000e: Disable runtime PM on CNP+ (David Arcari) [1659179]
- [netdrv] intel: correct return from set features callback (David Arcari) [1659179]
- [netdrv] e1000e: Fix -Wformat-truncation warnings (David Arcari) [1659179]
- [netdrv] e1000e: fix cyclic resets at link up with active tx (David Arcari) [1659179]
- [netdrv] e1000e: fix a missing check for return value (David Arcari) [1659179]
- [netdrv] e1000e: Exclude device from suspend direct complete optimization (David Arcari) [1659179]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (David Arcari) [1659179]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (David Arcari) [1659179]
- [netdrv] e1000e: extend PTP gettime function to read system clock (David Arcari) [1659179]
- [netdrv] e1000e: allow non-monotonic SYSTIM readings (David Arcari) [1659179]
- [netdrv] intel-ethernet: use correct module license (David Arcari) [1659179]
- [kernel] sched/cpufreq: Fix kobject memleak (Phil Auld) [1714719]
- [kernel] sched/core: Check quota and period overflow at usec to nsec conversion (Phil Auld) [1714719]
- [kernel] sched/core: Handle overflow in cpu_shares_write_u64 (Phil Auld) [1714719]
- [kernel] sched/rt: Check integer overflow at usec to nsec conversion (Phil Auld) [1714719]
- [base] arch_topology: Make cpu_capacity sysfs node as read-only (Phil Auld) [1714719]
- [x86] sched/x86: Save [ER]FLAGS on context switch (Phil Auld) [1714719]
- [kernel] sched/fair: Remove setting task's se->runnable_weight during PELT update (Phil Auld) [1714719]
- [kernel] sched/fair: Disable LB_BIAS by default (Phil Auld) [1714719]
- [arm64] sched/topology, arch/arm64: Rebuild the sched_domain hierarchy when the CPU capacity changes (Phil Auld) [1714719]
- [base] sched/topology, drivers/base/arch_topology: Rebuild the sched_domain hierarchy when capacities change (Phil Auld) [1714719]
- [kernel] sched/topology: Add SD_ASYM_CPUCAPACITY flag detection (Phil Auld) [1714719]
- [kernel] sched/fair: Fix load_balance redo for !imbalance (Phil Auld) [1714719]
- [tools] cpupower : frequency-set -r option misses the last cpu in related cpu list (Steve Best) [1717841]
- [kernel] Uprobes: Fix kernel oops with delayed_uprobe_remove() (Gustavo Duarte) [1608798]
- [kernel] trace_uprobe/sdt: Prevent multiple reference counter for same uprobe (Gustavo Duarte) [1608798]
- [kernel] uprobes/sdt: Prevent multiple reference counter for same uprobe (Gustavo Duarte) [1608798]
- [kernel] uprobes: Support SDT markers having reference count (semaphore) (Gustavo Duarte) [1608798]
- [kernel] Uprobe: Additional argument arch_uprobe to uprobe_write_opcode() (Gustavo Duarte) [1608798]
- [kernel] Uprobes: Simplify uprobe_register() body (Gustavo Duarte) [1608798]
- [pci] PCI: Rework pcie_retrain_link() wait loop (Myron Stowe) [1707902]
- [pci] PCI: Work around Pericom PCIe-to-PCI bridge Retrain Link erratum (Myron Stowe) [1707902]
- [pci] PCI: Factor out pcie_retrain_link() function (Myron Stowe) [1707902]
- [tools] selftests/powerpc: Fix strncpy usage (Diego Domingos) [1662372]
- [tools] selftests: Fix test errors related to lib.mk khdr target (Diego Domingos) [1662372]
- [nvme] nvme-fc: use separate work queue to avoid warning (Ewan Milne) [1715135]
- [scsi] scsi: scsi_transport_fc: nvme: display FC-NVMe port roles (Ewan Milne) [1715135]
- [nvme] nvme-fc: correct csn initialization and increments on error (Ewan Milne) [1715135]
- [nvme] nvme-multipath: avoid crash on invalid subsystem cntlid enumeration (Ewan Milne) [1715135]
- [nvme] nvme-multipath: don't print ANA group state by default (Ewan Milne) [1715135]
- [nvme] nvme-multipath: split bios with the ns_head bio_set before submitting (Ewan Milne) [1715135]
- [nvme] nvme-multipath: relax ANA state check (Ewan Milne) [1715135]
- [drm] drm/i915: Bump gen7+ fb size limits to 16kx16k (Lyude Paul) [1664969]
- [drm] drm/i915: Bump fb stride limit to 128KiB for gen4+ and 256KiB for gen7+ (Lyude Paul) [1664969]
- [drm] drm/i915: Align dumb buffer stride to 4k to allow for gtt remapping (Lyude Paul) [1664969]
- [drm] drm/i915: Overcome display engine stride limits via GTT remapping (Lyude Paul) [1664969]
- [drm] drm/i915: Shuffle stride checking code around (Lyude Paul) [1664969]
- [drm] drm/i915/selftests: Add live vma selftest (Lyude Paul) [1664969]
- [drm] drm/i915/selftests: Add mock selftest for remapped vmas (Lyude Paul) [1664969]
- [drm] drm/i915: Add a new "remapped" gtt_view (Lyude Paul) [1664969]
- [md] dax: Arrange for dax_supported check to span multiple devices (Jeff Moyer) [1665364]
- [mm] mm/memory_hotplug.c: drop memory device reference after find_memory_block() (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: Retain security state after overwrite (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] libnvdimm/pmem: fix a possible OOB access when read and write pmem (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] libnvdimm/security, acpi/nfit: unify zero-key for all security commands (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] libnvdimm/security: provide fix for secure-erase to use zero-key (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [mm] mm/memory.c: fix modifying of page protection by insert_pfn() (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/btt: Fix a kmemdup failure check (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/namespace: Fix a potential NULL pointer dereference (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Always dump _DSM output payload (Jeff Moyer) [1665367 1665364 1665362]
- [fs] fs/dax: Deposit pagetable even when installing zero page (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/namespace: Clean up holder_class_store() (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/of_pmem: Fix platform_no_drv_owner.cocci warnings (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Update NFIT flags error message (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/btt: Fix LBA masking during 'free list' population (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/btt: Remove unnecessary code in btt_freelist_init (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/pfn: Remove dax_label_reserve (Jeff Moyer) [1665367 1665364 1665362]
- [drivers] dax: Check the end of the block-device capacity with dax_direct_access() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit/ars: Avoid stale ARS results (Jeff Moyer) [1697175 1665367 1665364 1665362]
- [acpi] nfit/ars: Allow root to busy-poll the ARS state machine (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit/ars: Introduce scrub_flags (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit/ars: Remove ars_start_flags (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit/ars: Attempt short-ARS even in the no_init_ars case (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit/ars: Attempt a short-ARS whenever the ARS state is idle at boot (Jeff Moyer) [1697194 1665367 1665364 1665362]
- [fs] fs/dax: NIT fix comment regarding start/end vs range (Jeff Moyer) [1665367 1665364 1665362]
- [fs] fs/dax: Convert to use vmf_error() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Require opt-in for read-only label configurations (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/pmem: Honor force_raw for legacy pmem regions (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/pfn: Account for PAGE_SIZE > info-block-size in nd_pfn_init() (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm: Fix altmap reservation size calculation (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, pfn: Fix over-trim in trim_pfn_device() (Jeff Moyer) [1665367 1665364 1665362 1662227]
- [nvdimm] libnvdimm/dimm: Add a no-BLK quirk based on NVDIMM family (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit: Add Hyper-V NVDIMM DSM command set to white list (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit: acpi_nfit_ctl(): Check out_obj->type in the right place (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] nfit: Fix nfit_intel_shutdown_status() command submission (Jeff Moyer) [1665367 1665364 1665362 1662217]
- [nvdimm] libnvdimm/security: Require nvdimm_security_setup_events() to succeed (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [tools] nfit_test: fix security state pull for nvdimm security nfit_test (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] libnvdimm/security: Fix nvdimm_security_state() state request selection (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] libnvdimm/label: Clear 'updating' flag after label-set update (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Remove duplicate set nd_set in acpi_nfit_init_interleave_set() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Fix race accessing memdev in nfit_get_smbios_id() (Jeff Moyer) [1665367 1665364 1665362]
- [include] libnvdimm/dimm: Fix security capability detection for non-Intel NVDIMMs (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [acpi] nfit: Mark some functions as __maybe_unused (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [acpi] ACPI/nfit: delete the function to_acpi_nfit_desc (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] ACPI/nfit: delete the redundant header file (Jeff Moyer) [1665367 1665364 1665362]
- [kernel] mm, devm_memremap_pages: add MEMORY_DEVICE_PRIVATE support (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] mm, devm_memremap_pages: fix shutdown handling (Jeff Moyer) [1665367 1665364 1665362]
- [kernel] mm, devm_memremap_pages: kill mapping "System RAM" support (Jeff Moyer) [1665367 1665364 1665362]
- [kernel] mm, devm_memremap_pages: mark devm_memremap_pages() EXPORT_SYMBOL_GPL (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm/security: Quiet security operations (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [documentation] libnvdimm/security: Add documentation for nvdimm security support (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [tools] tools/testing/nvdimm: add Intel DSM 1.8 support for nfit_test (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [tools] tools/testing/nvdimm: Add overwrite support for nfit_test (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [tools] tools/testing/nvdimm: Add test support for Intel nvdimm security DSMs (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm/security: add Intel DSM 1.8 master passphrase support (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm/security: Add security DSM overwrite support (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm: Add support for issue secure erase DSM to Intel nvdimm (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm: Add enable/update passphrase support for Intel nvdimms (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm: Add disable passphrase support to Intel nvdimm. (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm: Add unlock of nvdimm support for Intel DIMMs (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] acpi/nfit, libnvdimm: Add freeze security support to Intel nvdimm (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [acpi] acpi/nfit, libnvdimm: Introduce nvdimm_security_ops (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [security] keys-encrypted: add nvdimm key format type to encrypted keys (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [security] keys: Export lookup_user_key to external users (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [acpi] acpi/nfit, libnvdimm: Store dimm id as a member to struct nvdimm (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [nvdimm] libnvdimm, namespace: Replace kmemdup() with kstrndup() (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, label: Switch to bitmap_zalloc() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] ACPI/nfit: Adjust annotation for why return 0 if fail to find NFIT at start (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, bus: Check id immediately following ida_simple_get (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: Fix user-initiated ARS to be "ARS-long" rather than "ARS-short" (Jeff Moyer) [1665367 1665364 1665362 1662224 1641487]
- [nvdimm] libnvdimm, pfn: Pad pfn namespaces relative to other regions (Jeff Moyer) [1665367 1665364 1665362 1662227]
- [tools] tools/testing/nvdimm: Align test resources to 128M (Jeff Moyer) [1665367 1665364 1665362 1662227]
- [acpi] acpi/nfit: Add support for Intel DSM 1.8 commands (Jeff Moyer) [1665367 1665364 1665362 1584976]
- [acpi] Revert "acpi, nfit: Further restrict userspace ARS start requests" (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi, nfit: Fix ARS overflow continuation (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: Fix the array size for dimm devices. (Jeff Moyer) [1665367 1665364 1665362 1658918]
- [mm] mm: Fix warning in insert_pfn() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi, nfit: Further restrict userspace ARS start requests (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi, nfit: Fix Address Range Scrub completion tracking (Jeff Moyer) [1665367 1665364 1665362 1662224 1641487]
- [tools] tools/testing/nvdimm: Populate dirty shutdown data (Jeff Moyer) [1665367 1665364 1665362 1662217]
- [acpi] acpi, nfit: Collect shutdown status (Jeff Moyer) [1665367 1665364 1665362 1662217]
- [acpi] acpi, nfit: Introduce nfit_mem flags (Jeff Moyer) [1665367 1665364 1665362 1662217]
- [nvdimm] libnvdimm, label: Fix sparse warning (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, namespace: Drop the repeat assignment for variable dev->parent (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, region: Fail badblocks listing for inactive regions (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, pfn: during init, clear errors in the metadata area (Jeff Moyer) [1665367 1665364 1665362 1641565]
- [nvdimm] libnvdimm: Set device node in nd_device_register (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm: Hold reference on parent while scheduling async init (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm: remove duplicate include (Jeff Moyer) [1665367 1665364 1665362]
- [fs] filesystem-dax: Fix use of zero page (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, pmem: Restore page attributes when clearing errors (Jeff Moyer) [1665367 1665364 1665362]
- [drivers] device-dax: avoid hang on error before devm_memremap_pages() (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: improve emulation of smart injection (Jeff Moyer) [1685043 1665367 1665364 1665362]
- [fs] filesystem-dax: Do not request kaddr and pfn when not required (Jeff Moyer) [1665367 1665364 1665362]
- [drivers] dax/super: Do not request a pointer kaddr when not required (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: kaddr and pfn can be NULL to ->direct_access() (Jeff Moyer) [1665367 1665364 1665362]
- [nvdimm] libnvdimm, pmem: kaddr and pfn can be NULL to ->direct_access() (Jeff Moyer) [1665367 1665364 1665362]
- [acpi] acpi/nfit: queue issuing of ars when an uc error notification comes in (Jeff Moyer) [1665367 1665364 1665362 1641487]
- [kernel] mm, dev_pagemap: Do not clear ->mapping on final put (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: Fix support for emulating controller temperature (Jeff Moyer) [1665367 1665364 1665362]
- [tools] tools/testing/nvdimm: Make DSM failure code injection an override (Jeff Moyer) [1665367 1665364 1665362 1658918]
- [acpi] acpi, nfit: Prefer _DSM over _LSR for namespace label reads (Jeff Moyer) [1665367 1665364 1665362 1658918]
- [nvdimm] libnvdimm: Introduce locked DIMM capacity support (Jeff Moyer) [1665367 1665364 1665362 1658918]
- [drm] drm/nouveau: fix duplication of nv50_head_atom struct (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/disp/dp: respect sink limits when selecting failsafe link configuration (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/core: initial support for boards with TU117 chipset (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/core: allow detected chipset to be overridden (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/kms/gf119-gp10x: push HeadSetControlOutputResource() mthd when encoders change (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/kms/nv50-: fix bug preventing non-vsync'd page flips (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/kms/gv100-: fix spurious window immediate interlocks (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/nouveau: forward error generated while resuming objects tree (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/nouveau/i2c: Disable i2c bus access after ->fini() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Add WaDisableBankHangMode (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/fbc: disable framebuffer compression on GeminiLake (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Fix setting 10 bit deep color mode (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Add missing combo PHY lane power setup (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Factor out combo PHY lane power setup helper (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Corrupt DSI picture fix for GeminiLake (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Fix clockgating issue when using scalers (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Suppress spurious combo PHY B warning (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Disable read only ppgtt support for gen11 (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Use Engine1 instance for gen11 pm interrupts (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Disable video turbo mode for rp control (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Enable media sampler powergate (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: introduce REG_BIT() and REG_GENMASK() to define register contents (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1664615 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Apply a recommended rc6 threshold (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Use dedicated rc6 enabling sequence for gen11 (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Don't warn on spurious interrupts (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Handle rps interrupts without irq lock (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Make sure we have enough memory bandwidth on ICL (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Make sandybridge_pcode_read() deal with the second data register (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Fix ONLY icl+ max plane width (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Fix MG_DP_MODE() register programming (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Really calculate the cursor ddb based on the highest enabled wm level (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Inline skl_update_pipe_wm() into its only caller (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Don't pass pipe_wm around so much (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Move some variables to tighter scope (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Keep plane watermarks enabled more aggressively (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Make sure cursor has enough ddb for the selected wm level (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Allocate enough DDB for the cursor (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Extract skl_compute_wm_params() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Don't pass plane state to skl_compute_plane_wm() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Accept alloc_size == blocks (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/cml: Introduce Comet Lake PCH (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/cml: Add CML PCI IDS (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Fix PSR2 selective update corruption after PSR1 setup (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Turn off the CUS when turning off a HDR plane (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Fix legacy gamma mode for ICL (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Refactor icl_is_hdr_plane (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] drm/i915: Add new ICL PCI ID (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Fix CRC mismatch error for DP link layer compliance (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Prevent incorrect DBuf enabling (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Read out memory type (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Extract DIMM info on cnl+ (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Clean up intel_get_dram_info() a bit (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i914: s/l_info/dimm_l/ etc. (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Generalize intel_is_dram_symmetric() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Use dram_dimm_info more (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Extract DIMM info on GLK too (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Fix DRAM size reporting for BXT (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Extract BXT DIMM helpers (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Polish skl_is_16gb_dimm() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Extract functions to derive SKL+ DIMM info (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Store DIMM rank information as a number (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Default to Thread Group preemption for compute workloads (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Fix the state checker for ICL Y planes (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: move MG pll hw_state readout (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Finalize Wa_1408961008:icl (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Call MG_DP_MODE() macro with the right parameters order (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Drop redundant gamma mode mask (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Implement new w/a for underruns with wm1+ disabled (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Include "ignore lines" in skl+ wm state (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] Revert "drm/i915: W/A for underruns with WM1+ disabled on icl" (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Make MG PHY macros semantically consistent (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Make combo PHY DDI macro definitions consistent for ICL and CNL (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Add degamma and gamma lut size to gen11 caps (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Enable pipe output csc (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Enable ICL Pipe CSC block (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/icl: Add icl pipe degamma and gamma support (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/glk: Fix degamma lut programming (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Dump skl+ watermark changes (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Update DSPCNTR gamma/csc bits during crtc_enable() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Disable pipe gamma when C8 pixel format is used (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Turn off pipe CSC when it's not needed (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Turn off pipe gamma when it's not needed (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Track pipe csc enable in crtc state (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Track pipe gamma enable/disable in crtc state (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915: Populate gamma_mode for all platforms (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm: Main backport to rebase from 4.18 to 5.1 (Lyude Paul) [1713573 1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286] {CVE-2019-11085}
- [include] list: Backport list_is_first() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] lib/scatterlist: Provide a DMA page iterator (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [acpi] ACPI / PMIC: Add support for executing PMIC MIPI sequence elements (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] vfio: add edid api for display (vgpu) devices. (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [mm] mm: don't miss the last page because of round-off error (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [base] PM-runtime: Add new interface to get accounted time (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm: move i915_kick_out_vgacon to vgaarb (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [scripts] tracing: Avoid calling cc-option -mrecord-mcount for every Makefile (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/fb_helper: Allow leaking fbdev smem_start (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/fb: Stop leaking physical address (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [video] fbdev: Add FBINFO_HIDE_SMEM_START flag (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] vt: Remove vc_panic_force_write (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] fbdev: Drop FBINFO_CAN_FORCE_OUTPUT flag (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [video] fbdev: fix kerneldoc (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] fbdev: add remove_conflicting_pci_framebuffers() (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [media] media: cec-notifier: Get notifier by device and connector name (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [base] driver core: Add device_link_remove function (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] include: Move ascii85 functions from i915 to linux/ascii85.h (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [mm] mm, drm/i915: mark pinned shmemfs pages as unevictable (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] list: introduce list_bulk_move_tail helper (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [fs] sysfs: constify sysfs create/remove files harder (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm/i915/selftests: Remove unused dmabuf->kmap routines, fix the build (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] dma-buf: remove kmap_atomic interface (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [include] include/linux/bitops.h: introduce BITS_PER_TYPE (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] dma_buf: remove device parameter from attach callback v2 (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [pci] PCI: Export pcie_get_speed_cap and pcie_get_width_cap (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [drm] drm: Add support for pps and compression mode command packet (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [kernel] locking/mutex: Fix mutex debug call and ww_mutex documentation (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [kernel] locking: Implement an algorithm choice for Wound-Wait mutexes (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]
- [kernel] locking: WW mutex cleanup (Lyude Paul) [1707312 1688524 1685552 1685427 1665631 1665088 1664615 1664609 1664189 1664177 1664175 1664104 1662017 1660302 1643842 1640840 1639990 1639436 1637606 1633845 1633843 1633842 1504286]

* Mon Jun 10 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-102.rt16.42.el8]
- [rt] kernel-rt-4.18.0-102.rt16.41.el8 (Juri Lelli) [1678887]
- [netdrv] igb: Fix WARN_ONCE on runtime suspend (Corinna Vinschen) [1659168]
- [netdrv] igb: use struct_size() helper (Corinna Vinschen) [1659168]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Corinna Vinschen) [1659168]
- [netdrv] igb: Bump version number (Corinna Vinschen) [1659168]
- [netdrv] Revert "igb: reduce CPU0 latency when updating statistics" (Corinna Vinschen) [1659168]
- [netdrv] igb: Fix an issue that PME is not enabled during runtime suspend (Corinna Vinschen) [1659168]
- [netdrv] igb: Change RXPBSIZE size when setting Qav mode (Corinna Vinschen) [1659168]
- [netdrv] igb: reduce CPU0 latency when updating statistics (Corinna Vinschen) [1659168]
- [netdrv] igb: fix uninitialized variables (Corinna Vinschen) [1659168]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Corinna Vinschen) [1659168]
- [netdrv] igb: Fix format with line continuation whitespace (Corinna Vinschen) [1659168]
- [netdrv] igb: extend PTP gettime function to read system clock (Corinna Vinschen) [1659168]
- [netdrv] i40e/ixgbe/igb: fail on new WoL flag setting WAKE_MAGICSECURE (Corinna Vinschen) [1659168]
- [netdrv] intel-ethernet: software timestamp skbs as late as possible (Corinna Vinschen) [1659168]
- [netdrv] igb: remove ndo_poll_controller (Corinna Vinschen) [1659168]
- [netdrv] intel-ethernet: use correct module license (Corinna Vinschen) [1659168]
- [netdrv] igb: Replace mdelay() with msleep() in igb_integrated_phy_loopback() (Corinna Vinschen) [1659168]
- [netdrv] igb: Replace GFP_ATOMIC with GFP_KERNEL in igb_sw_init() (Corinna Vinschen) [1659168]
- [netdrv] igb: Use an advanced ctx descriptor for launchtime (Corinna Vinschen) [1659168]
- [netdrv] igb: e1000_phy: Mark expected switch fall-through (Corinna Vinschen) [1659168]
- [netdrv] igb: e1000_82575: Mark expected switch fall-through (Corinna Vinschen) [1659168]
- [netdrv] igb_main: Mark expected switch fall-throughs (Corinna Vinschen) [1659168]
- [netdrv] igb: Use dma_wmb() instead of wmb() before doorbell writes (Corinna Vinschen) [1659168]
- [netdrv] igb: Add support for ETF offload (Corinna Vinschen) [1659168]
- [netdrv] igb: Only call skb_tx_timestamp after descriptors are ready (Corinna Vinschen) [1659168]
- [netdrv] igb: Refactor igb_offload_cbs() (Corinna Vinschen) [1659168]
- [netdrv] igb: Only change Tx arbitration when CBS is on (Corinna Vinschen) [1659168]
- [netdrv] igb: Refactor igb_configure_cbs() (Corinna Vinschen) [1659168]
- [fs] Revert "[fs] ext4: protect journal inode's blocks using block_validity" (Lukas Czerner) [1716549]
- [fs] xfs: don't trip over uninitialized buffer on extent read of corrupted inode (Bill O'Donnell) [1715942]
- [fs] xfs: always init bma in xfs_bmapi_write (Bill O'Donnell) [1715942]
- [lib] rhashtable: Still do rehash when we get EEXIST (Vladis Dronov) [1712457]
- [fs] vmcore: Add a kernel parameter novmcoredd (Kairui Song) [1705864]
- [powerpc] powerpc/eeh: Correct retries in eeh_pe_reset_full() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Improve recovery of passed-through devices (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Add include_passed to eeh_clear_pe_frozen_state() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Add include_passed to eeh_pe_state_clear() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: remove sw_state from eeh_unfreeze_pe() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup eeh_pe_clear_frozen_state() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup control flow in eeh_handle_normal_event() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup eeh_ops.wait_state() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup eeh_pe_state_mark() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup unnecessary eeh_pe_state_mark_with_cfg() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup eeh_enabled() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup logic in eeh_rmv_from_parent_pe() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup field names in eeh_rmv_data (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup list_head field names (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup eeh_add_virt_device() (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup unused field in eeh_dev (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Cleanup EEH_POSTPONED_PROBE (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Avoid misleading message "EEH: no capable adapters found" (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Fix use of EEH_PE_KEEP on wrong field (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Fix null deref for devices removed during EEH (Sam Bobroff) [1352405]
- [powerpc] powerpc/eeh: Fix possible null deref in eeh_dump_dev_log() (Sam Bobroff) [1352405]
- [edac] x86/MCE/AMD, EDAC/mce_amd: Add new error descriptions for some SMCA bank types (Janakarajan Natarajan) [1688469]
- [x86] x86/MCE/AMD, EDAC/mce_amd: Add new McaTypes for CS, PSP, and SMU units (Janakarajan Natarajan) [1688469]
- [x86] x86/MCE/AMD, EDAC/mce_amd: Add new MP5, NBIO, and PCIE SMCA bank types (Janakarajan Natarajan) [1688469]
- [scsi] megaraid_sas: remove tech preview from Aero series (Tomas Henzl) [1668409]
- [scsi] megaraid_sas: sync with mainline (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: fix spelling mistake "oustanding" -> "outstanding" (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Make megasas_host_device_list_query() static (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: reduce module load time (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Remove a bunch of set but not used variables (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: return error when create DMA pool failed (Tomas Henzl) [1668409] {CVE-2019-11810}
- [scsi] scsi: megaraid_sas: driver version update (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Update structures for HOST_DEVICE_LIST DCMD (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Add support for DEVICE_LIST DCMD in driver (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Rework device add code in AEN path (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Rework code to get PD and LD list (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: correct an info message (Tomas Henzl) [1668409]
- [scsi] cross-tree: phase out dma_zalloc_coherent() (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid: fix out-of-bound array accesses (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: changes to function prototypes (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: NULL check before some freeing functions is not needed (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas_fusion: Mark expected switch fall-through (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid: megaraid_sas_base: Mark expected switch fall-through (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: modify max supported lds related print (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: remove unused macro (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: increase timeout for IOC INIT to 180seconds (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Remove double endian conversion (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Re-use max_mfi_cmds to calculate queue sizes (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Rename scratch_pad registers (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Remove spin lock for dpc operation (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: optimize raid context access in IO path (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Fail init if heartbeat timer fails (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: For SRIOV, do not set STOP_ADP bit (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Fix combined reply queue mode detection (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Fix module parameter description (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Fix goto labels in error handling (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Update copyright information (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Add check for reset adapter bit (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Fix msleep granularity (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Add support for FW snap dump (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: Add watchdog thread to detect Firmware fault (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: switch to generic DMA API (Tomas Henzl) [1668409]
- [scsi] scsi: megaraid_sas: fix a missing-check bug (Tomas Henzl) [1668409]
- [kernel] get_maintainer.pl: Add default .get_maintainer.conf file for RHEL (Prarit Bhargava) [1714630]
- [scripts] get_maintainer: allow option --mpath <directory> to read all files in <directory> (Prarit Bhargava) [1714630]
- [scripts] get_maintainer.pl: add -mpath=<path or file> for MAINTAINERS file location (Prarit Bhargava) [1714630]
- [scripts] get_maintainer: allow usage outside of kernel tree (Prarit Bhargava) [1714630]
- [scripts] Revert "[scripts] get_maintainer.pl: Add optional .get_maintainer.MAINTAINERS override" (Prarit Bhargava) [1714630]
- [include] signal: Make siginmask safe when passed a signal of 0 (Waiman Long) [1714351]
- [fs] signal: Don't send signals to tasks that don't exist (Waiman Long) [1714351]
- [kernel] signal: Restore the stop PTRACE_EVENT_EXIT (Waiman Long) [1714351]
- [kernel] signal: Better detection of synchronous signals (Waiman Long) [1714351]
- [kernel] signal: Always notice exiting tasks (Waiman Long) [1714351]
- [kernel] signal: Always attempt to allocate siginfo for SIGSTOP (Waiman Long) [1714351]
- [kernel] signal: Guard against negative signal numbers in copy_siginfo_from_user32 (Waiman Long) [1714351]
- [kernel] signal: Guard against negative signal numbers in copy_siginfo_from_user (Waiman Long) [1714351]
- [kernel] signal: In sigqueueinfo prefer sig not si_signo (Waiman Long) [1714351]
- [include] signal: Use a smaller struct siginfo in the kernel (Waiman Long) [1714351]
- [include] signal: Distinguish between kernel_siginfo and siginfo (Waiman Long) [1714351]
- [kernel] signal: Introduce copy_siginfo_from_user and use it's return value (Waiman Long) [1714351]
- [arm64] signal: Remove the need for __ARCH_SI_PREABLE_SIZE and SI_PAD_SIZE (Waiman Long) [1714351]
- [kernel] signal: Fail sigqueueinfo if si_signo != sig (Waiman Long) [1714351]
- [kernel] signal/sparc: Move EMT_TAGOVF into the generic siginfo.h (Waiman Long) [1714351]
- [mm] signal/arm: Use force_sig_fault where appropriate (Waiman Long) [1714351]
- [arm64] signal/arm64: Use send_sig_fault where appropriate (Waiman Long) [1714351]
- [arm64] signal/arm64: Add and use arm64_force_sig_ptrace_errno_trap (Waiman Long) [1714351]
- [arm64] signal/arm64: In ptrace_hbptriggered name the signal description string (Waiman Long) [1714351]
- [arm64] signal/arm64: Remove arm64_force_sig_info (Waiman Long) [1714351]
- [arm64] signal/arm64: Add and use arm64_force_sig_mceerr as appropriate (Waiman Long) [1714351]
- [arm64] signal/arm64: Add and use arm64_force_sig_fault where appropriate (Waiman Long) [1714351]
- [mm] signal/arm64: Only call set_thread_esr once in do_page_fault (Waiman Long) [1714351]
- [mm] signal/arm64: Only perform one esr_to_fault_info call in do_page_fault (Waiman Long) [1714351]
- [mm] signal/arm64: Expand __do_user_fault and remove it (Waiman Long) [1714351]
- [mm] signal/arm64: For clarity separate the 3 signal sending cases in do_page_fault (Waiman Long) [1714351]
- [mm] signal/arm64: Consolidate the two hwpoison cases in do_page_fault (Waiman Long) [1714351]
- [mm] signal/arm64: Factor set_thread_esr out of __do_user_fault (Waiman Long) [1714351]
- [arm64] signal/arm64: Factor out arm64_show_signal from arm64_force_sig_info (Waiman Long) [1714351]
- [arm64] signal/arm64: Remove unneeded tsk parameter from arm64_force_sig_info (Waiman Long) [1714351]
- [arm64] signal/arm64: Push siginfo generation into arm64_notify_die (Waiman Long) [1714351]
- [powerpc] signal/powerpc: Use force_sig_fault where appropriate (Waiman Long) [1714351]
- [powerpc] signal/powerpc: Simplify _exception_pkey by using force_sig_pkuerr (Waiman Long) [1714351]
- [powerpc] signal/powerpc: Specialize _exception_pkey for handling pkey exceptions (Waiman Long) [1714351]
- [powerpc] signal/powerpc: Call force_sig_fault from _exception (Waiman Long) [1714351]
- [powerpc] signal/powerpc: Factor the common exception code into exception_common (Waiman Long) [1714351]
- [powerpc] powerpc/traps: Print unhandled signals in a separate function (Waiman Long) [1714351]
- [mm] signal/powerpc: Remove pkey parameter from __bad_area_nosemaphore (Waiman Long) [1714351]
- [mm] signal/powerpc: Call _exception_pkey directly from bad_key_fault_exception (Waiman Long) [1714351]
- [mm] signal/powerpc: Remove pkey parameter from __bad_area (Waiman Long) [1714351]
- [mm] signal/powerpc: Use force_sig_mceerr as appropriate (Waiman Long) [1714351]
- [x86] signal/x86: Use force_sig_fault where appropriate (Waiman Long) [1714351]
- [mm] signal/x86: Pass pkey by value (Waiman Long) [1714351]
- [mm] signal/x86: Replace force_sig_info_fault with force_sig_fault (Waiman Long) [1714351]
- [mm] signal/x86: Call force_sig_pkuerr from __bad_area_nosemaphore (Waiman Long) [1714351]
- [mm] signal/x86: Pass pkey not vma into __bad_area (Waiman Long) [1714351]
- [mm] signal/x86: Don't compute pkey in __do_page_fault (Waiman Long) [1714351]
- [mm] signal/x86: Remove pkey parameter from mm_fault_error (Waiman Long) [1714351]
- [mm] signal/x86: Remove the pkey parameter from do_sigbus (Waiman Long) [1714351]
- [mm] signal/x86: Remove pkey parameter from bad_area_nosemaphore (Waiman Long) [1714351]
- [x86] signal/x86/traps: Simplify trap generation (Waiman Long) [1714351]
- [x86] signal/x86/traps: Use force_sig instead of open coding it. (Waiman Long) [1714351]
- [x86] signal/x86/traps: Use force_sig_bnderr (Waiman Long) [1714351]
- [x86] signal/x86/traps: Move more code into do_trap_no_signal so it can be reused (Waiman Long) [1714351]
- [x86] signal/x86/traps: Factor out show_signal (Waiman Long) [1714351]
- [x86] signal/x86: Move mpx siginfo generation into do_bounds (Waiman Long) [1714351]
- [x86] signal/x86: In trace_mpx_bounds_register_exception add __user annotations (Waiman Long) [1714351]
- [mm] signal/x86: Move MCE error reporting out of force_sig_info_fault (Waiman Long) [1714351]
- [x86] signal/x86: Inline fill_sigtrap_info in it's only caller send_sigtrap (Waiman Long) [1714351]
- [powerpc] signal: Simplify tracehook_report_syscall_exit (Waiman Long) [1714351]
- [kernel] signal: Pair exports with their functions (Waiman Long) [1714351]
- [kernel] signal: Remove specific_send_sig_info (Waiman Long) [1714351]
- [kernel] signal: Use group_send_sig_info to kill all processes in a pid namespace (Waiman Long) [1714351]
- [tty] tty_io: Use group_send_sig_info in __do_SACK to note it is a session being killed (Waiman Long) [1714351]
- [misc] signal/GenWQE: Fix sending of SIGKILL (Waiman Long) [1714351]
- [include] signal: Remove SEND_SIG_FORCED (Waiman Long) [1714351]
- [kernel] signal: Use SEND_SIG_PRIV not SEND_SIG_FORCED with SIGKILL and SIGSTOP (Waiman Long) [1714351]
- [kernel] signal: Never allocate siginfo for SIGKILL or SIGSTOP (Waiman Long) [1714351]
- [usb] signal: Don't send siginfo to kthreads. (Waiman Long) [1714351]
- [usb] signal: Remove the siginfo paramater from kernel_dqueue_signal (Waiman Long) [1714351]
- [tty] signal: send_sig_all no longer needs SEND_SIG_FORCED (Waiman Long) [1714351]
- [kernel] signal: Always deliver the kernel's SIGKILL and SIGSTOP to a pid namespace init (Waiman Long) [1714351]
- [x86] signal: Properly deliver SIGSEGV from x86 uprobes (Waiman Long) [1714351]
- [kernel] signal: Properly deliver SIGILL from uprobes (Waiman Long) [1714351]
- [kernel] signal: Always ignore SIGKILL and SIGSTOP sent to the global init (Waiman Long) [1714351]
- [iommu] mm: convert return type of handle_mm_fault() caller to vm_fault_t (Waiman Long) [1714351]
- [kernel] signal: make get_signal() return bool (Waiman Long) [1714351]
- [kernel] signal: make sigkill_pending() return bool (Waiman Long) [1714351]
- [kernel] signal: make legacy_queue() return bool (Waiman Long) [1714351]
- [kernel] signal: make wants_signal() return bool (Waiman Long) [1714351]
- [kernel] signal: make flush_sigqueue_mask() void (Waiman Long) [1714351]
- [kernel] signal: make unhandled_signal() return bool (Waiman Long) [1714351]
- [kernel] signal: make recalc_sigpending_tsk() return bool (Waiman Long) [1714351]
- [kernel] signal: make has_pending_signals() return bool (Waiman Long) [1714351]
- [kernel] signal: make sig_ignored() return bool (Waiman Long) [1714351]
- [kernel] signal: make sig_task_ignored() return bool (Waiman Long) [1714351]
- [kernel] signal: make sig_handler_ignored() return bool (Waiman Long) [1714351]
- [kernel] signal: make kill_ok_by_cred() return bool (Waiman Long) [1714351]
- [kernel] signal: simplify rt_sigaction() (Waiman Long) [1714351]
- [kernel] signal: make do_sigpending() void (Waiman Long) [1714351]
- [kernel] signal: make may_ptrace_stop() return bool (Waiman Long) [1714351]
- [kernel] signal: make kill_as_cred_perm() return bool (Waiman Long) [1714351]
- [kernel] signal: make force_sigsegv() void (Waiman Long) [1714351]
- [kernel] signal: Don't restart fork when signals come in. (Waiman Long) [1714351]
- [kernel] fork: Have new threads join on-going signal group stops (Waiman Long) [1714351]
- [include] fork: Skip setting TIF_SIGPENDING in ptrace_init_task (Waiman Long) [1714351]
- [kernel] signal: Add calculate_sigpending() (Waiman Long) [1714351]
- [kernel] fork: Unconditionally exit if a fatal signal is pending (Waiman Long) [1714351]
- [kernel] fork: Move and describe why the code examines PIDNS_ADDING (Waiman Long) [1714351]
- [kernel] signal: Push pid type down into complete_signal. (Waiman Long) [1714351]
- [kernel] signal: Push pid type down into __send_signal (Waiman Long) [1714351]
- [kernel] signal: Push pid type down into send_signal (Waiman Long) [1714351]
- [tty] signal: Pass pid type into do_send_sig_info (Waiman Long) [1714351]
- [fs] signal: Pass pid type into send_sigio_to_task & send_sigurg_to_task (Waiman Long) [1714351]
- [kernel] signal: Pass pid type into group_send_sig_info (Waiman Long) [1714351]
- [kernel] signal: Pass pid and pid type into send_sigqueue (Waiman Long) [1714351]
- [kernel] posix-timers: Noralize good_sigevent (Waiman Long) [1714351]
- [fs] signal: Use PIDTYPE_TGID to clearly store where file signals will be sent (Waiman Long) [1714351]
- [kernel] pid: Implement PIDTYPE_TGID (Waiman Long) [1714351]
- [include] pids: Move the pgrp and session pid pointers from task_struct to signal_struct (Waiman Long) [1714351]
- [fs] pids: Compute task_tgid using signal->leader_pid (Waiman Long) [1714351]
- [kernel] pids: Move task_pid_type into sched/signal.h (Waiman Long) [1714351]
- [init] pids: Initialize leader_pid in init_task (Waiman Long) [1714351]

* Thu Jun 06 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-101.rt16.41.el8]
- [rt] kernel-rt-4.18.0-101.rt16.40.el8 (Juri Lelli) [1678887]
- [s390] s390: enable processes for mio instructions (Philipp Rudo) [1651734]
- [s390] s390/pci: add parameter to disable usage of MIO instructions (Philipp Rudo) [1651734]
- [s390] s390/pci: provide support for MIO instructions (Philipp Rudo) [1651734]
- [s390] s390/pci: improve bar check (Philipp Rudo) [1651734]
- [s390] s390/ism: move oddities of device IO to wrapper function (Philipp Rudo) [1651734]
- [s390] s390/pci: move io address mapping code to pci_insn.c (Philipp Rudo) [1651734]
- [s390] s390/pci: add parameter to force floating irqs (Philipp Rudo) [1651735]
- [s390] s390/pci: gather statistics for floating vs directed irqs (Philipp Rudo) [1651735]
- [s390] s390: show statistics for MSI IRQs (Philipp Rudo) [1651735]
- [s390] s390/pci: provide support for CPU directed interrupts (Philipp Rudo) [1651735]
- [s390] s390/airq: provide cacheline aligned ivs (Philipp Rudo) [1651735]
- [s390] s390/pci: clarify interrupt vector usage (Philipp Rudo) [1651735]
- [s390] s390/airq: recognize directed interrupts (Philipp Rudo) [1651735]
- [s390] s390/sclp: detect DIRQ facility (Philipp Rudo) [1651735]
- [s390] s390/pci: move everything irq related to pci_irq.c (Philipp Rudo) [1651735]
- [s390] s390/pci: remove stale rc (Philipp Rudo) [1651735]
- [s390] s390/pci: remove unused define (Philipp Rudo) [1651735]
- [s390] s390/pci: mark command line parser data __initdata (Philipp Rudo) [1651735]
- [cpufreq] cpufreq: intel_pstate: Ignore turbo active ratio in HWP (David Arcari) [1711970]
- [scsi] mpt3sas: remove tech preview from Aero series (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: fix indentation issue (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Update mpt3sas driver version to 28.100.00.00 (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Improve the threshold value and introduce module param (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Load balance to improve performance and avoid soft lockups (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Irq poll to avoid CPU hard lockups (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: simplify interrupt handler (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Fix typo in request_desript_type (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Add missing breaks in switch statements (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Update driver version to 27.102.00.00 (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Add support for ATLAS PCIe switch (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Add support for NVMe Switch Adapter (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Rename mpi endpoint device ID macro. (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: mpt3sas_scsih: Mark expected switch fall-through (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: fix memory ordering on 64bit writes (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: fix spelling mistake "manufaucturing" -> "manufacturing" (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Fix driver modifying persistent data in Manufacturing page11 (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Don't modify EEDPTagMode field setting on SAS3.5 HBA devices (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Fix Sync cache command failure during driver unload (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Call sas_remove_host before removing the target devices (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Refactor mpt3sas_wait_for_ioc function (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Separate out mpt3sas_wait_for_ioc (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: Added new #define variable IOC_OPERATIONAL_WAIT_COUNT (Tomas Henzl) [1684444]
- [scsi] scsi: mpt3sas: switch to generic DMA API (Tomas Henzl) [1684444]
- [tools] perf tools beauty ioctl: Support new ISO7816 commands (Michael Petlan) [1709243]
- [tools] perf tools: Restore proper cwd on return from mnt namespace (Michael Petlan) [1709243]
- [tools] perf tools: Fix crash on synthesizing the unit (Michael Petlan) [1709243]
- [tools] perf tools: Do not zero sample_id_all for group members (Michael Petlan) [1709243]
- [tools] perf beauty: Use SRCARCH, ARCH=x86_64 must map to "x86" to find the headers (Michael Petlan) [1709243]
- [tools] perf intel-pt: Add MTC and CYC timestamps to debug log (Michael Petlan) [1709243]
- [tools] perf intel-pt: Add more event information to debug log (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Fix table find when table re-ordered (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add help window (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add Selected branches report (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Fall back to /usr/local/lib/libxed.so (Michael Petlan) [1709243]
- [tools] perf top: Display the LBR stats in callchain entry (Michael Petlan) [1709243]
- [tools] perf stat: Handle different PMU names with common prefix (Michael Petlan) [1709243]
- [tools] perf record: Support weak groups (Michael Petlan) [1709243]
- [tools] perf evlist: Move perf_evsel__reset_weak_group into evlist (Michael Petlan) [1709243]
- [tools] perf augmented_syscalls: Start collecting pathnames in the BPF program (Michael Petlan) [1709243]
- [tools] perf trace: Fix setting of augmented payload when using eBPF + raw_syscalls (Michael Petlan) [1709243]
- [tools] perf trace: When augmenting raw_syscalls plug raw_syscalls:sys_exit too (Michael Petlan) [1709243]
- [tools] perf examples bpf: Start augmenting raw_syscalls:sys_{start,exit} (Michael Petlan) [1709243]
- [tools] perf intel-pt/bts: Calculate cpumode for synthesized samples (Michael Petlan) [1709243]
- [tools] perf intel-pt: Insert callchain context into synthesized callchains (Michael Petlan) [1709243]
- [tools] perf top: Start display thread earlier (Michael Petlan) [1709243]
- [tools] perf trace beauty: Use the mmap flags table generated from headers (Michael Petlan) [1709243]
- [tools] perf beauty: Wire up the mmap flags table generator to the Makefile (Michael Petlan) [1709243]
- [tools] perf beauty: Add a generator for MAP_ mmap's flag constants (Michael Petlan) [1709243]
- [tools] perf callchain: Honour the ordering of PERF_CONTEXT_{USER,KERNEL,etc} (Michael Petlan) [1709243]
- [tools] perf cs-etm: Correct CPU mode for samples (Michael Petlan) [1709243]
- [tools] perf unwind: Take pgoff into account when reporting elf to libdwfl (Michael Petlan) [1709243]
- [tools] perf top: Do not use overwrite mode by default (Michael Petlan) [1709243]
- [tools] perf trace: Beautify mount's first pathname arg (Michael Petlan) [1709243]
- [tools] perf trace: Beautify the umount's 'name' argument (Michael Petlan) [1709243]
- [tools] perf trace: Consider syscall aliases too (Michael Petlan) [1709243]
- [tools] perf trace beauty: Beautify mount/umount's 'flags' argument (Michael Petlan) [1709243]
- [tools] perf trace beauty: Allow syscalls to mask an argument before considering it (Michael Petlan) [1709243]
- [tools] perf beauty: Introduce strarray__scnprintf_flags() (Michael Petlan) [1709243]
- [tools] perf beauty: Switch from GPL v2.0 to LGPL v2.1 (Michael Petlan) [1709243]
- [tools] perf beauty: Add a generator for MS_ mount/umount's flag constants (Michael Petlan) [1709243]
- [tools] tools include uapi: Grab a copy of linux/fs.h (Michael Petlan) [1709243]
- [tools] perf script: Support total cycles count (Michael Petlan) [1709243]
- [tools] perf script: Make itrace script default to all calls (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add All branches report (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add ability to display all the database tables (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add ability to shrink / enlarge font (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add ability to find symbols in the call-graph (Michael Petlan) [1709243]
- [tools] perf scripts python: exported-sql-viewer.py: Add support for multiple sub-windows (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Rename to exported-sql-viewer.py (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Refactor TreeItem class (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Add data helper functions (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Factor out CallGraphModel from TreeModel (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Remove use of setObjectName() (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Add a class for global data (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Separate the database details into a class (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Make a "Main" function (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Change icon (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Set a minimum window size (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Provide better default column sizes (Michael Petlan) [1709243]
- [tools] perf scripts python: call-graph-from-sql.py: Use SPDX license identifier (Michael Petlan) [1709243]
- [tools] perf trace: Introduce per-event maximum number of events property (Michael Petlan) [1709243]
- [tools] perf script: Flush output stream after events in verbose mode (Michael Petlan) [1709243]
- [tools] perf script: Allow extended console debug output (Michael Petlan) [1709243]
- [tools] perf stat: Poll for monitored tasks being alive (Michael Petlan) [1709243]
- [tools] perf trace: Drop thread refcount in trace__event_handler() (Michael Petlan) [1709243]
- [tools] perf trace: Drop addr_location refcounts (Michael Petlan) [1709243]
- [tools] perf evsel: Mark a evsel as disabled when asking the kernel do disable it (Michael Petlan) [1709243]
- [tools] perf evsel: Introduce per event max_events property (Michael Petlan) [1709243]
- [tools] tools lib subcmd: Introduce OPTION_ULONG (Michael Petlan) [1709243]
- [tools] perf arm64: Fix generate system call table failed with /tmp mounted with noexec (Michael Petlan) [1709243]
- [tools] perf symbols: Set PLT entry/header sizes properly on Sparc (Michael Petlan) [1709243]
- [tools] perf jitdump: Add Sparc support. (Michael Petlan) [1709243]
- [tools] perf annotate: Add Sparc support (Michael Petlan) [1709243]
- [tools] perf record: Encode -k clockid frequency into Perf trace (Michael Petlan) [1709243]
- [tools] perf probe: Support SDT markers having reference counter (semaphore) (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Move struct tep_handler definition in a local header file (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Separate out tep_strerror() for strerror_r() issues (Michael Petlan) [1709243]
- [tools] perf python: More portable way to make CFLAGS work with clang (Michael Petlan) [1709243]
- [tools] perf python: Make clang_has_option() work on Python 3 (Michael Petlan) [1709243]
- [tools] perf tools: Free temporary 'sys' string in read_event_files() (Michael Petlan) [1709243]
- [tools] perf tools: Avoid double free in read_event_file() (Michael Petlan) [1709243]
- [tools] perf tools: Free 'printk' string in parse_ftrace_printk() (Michael Petlan) [1709243]
- [tools] perf tools: Cleanup trace-event-info 'tdata' leak (Michael Petlan) [1709243]
- [tools] perf strbuf: Match va_{add,copy} with va_end (Michael Petlan) [1709243]
- [tools] perf test: S390 does not support watchpoints in test 22 (Michael Petlan) [1709243]
- [tools] perf auxtrace: Include missing asm/bitsperlong.h to get BITS_PER_LONG (Michael Petlan) [1709243]
- [tools] tools include: Adopt linux/bits.h (Michael Petlan) [1709243]
- [tools] perf intel-pt: Implement decoder flags for trace begin / end (Michael Petlan) [1709243]
- [tools] perf intel-pt: Add decoder flags for trace begin / end (Michael Petlan) [1709243]
- [tools] perf tools: Improve thread_stack__process() for trace begin / end (Michael Petlan) [1709243]
- [tools] perf tools: Improve thread_stack__event() for trace begin / end (Michael Petlan) [1709243]
- [tools] perf db-export: Add trace begin / end branch type variants (Michael Petlan) [1709243]
- [tools] perf script: Enhance sample flags for trace begin / end (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to enum filter_trivial_type (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Rename data2host*() APIs (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Rename struct plugin_list to struct tep_plugin_list (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to structs filter_type and event_filter (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to various structs filter_arg_*. (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to struct filter_{arg,value_type} (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to enums filter_{exp,arg}_type (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix tep_ to enums filter_{boolean,op,cmp}_type (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Rename enum print_arg_type to enum tep_print_arg_type (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Add prefix tep_ to all print_* structures (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Add prefix TEP_ to all EVENT_FL_* flags (Michael Petlan) [1709243]
- [tools] tools lib traceevent: Rename enum event_{sort_}type to enum tep_event_{sort_}type (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Rename enum format_flags to enum tep_format_flags (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Rename struct format{_field} to struct tep_format{_field} (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Rename struct event_format to struct tep_event_format (Michael Petlan) [1709243]
- [tools] perf script: Print DSO for callindent (Michael Petlan) [1709243]
- [tools] perf script: Allow sym and dso without ip, addr (Michael Petlan) [1709243]
- [tools] tools lib subcmd: Support overwriting the pager (Michael Petlan) [1709243]
- [tools] perf tools: Report itrace options in help (Michael Petlan) [1709243]
- [tools] perf help: Add missing subcommand `version` (Michael Petlan) [1709243]
- [tools] perf tools: Initialize perf_data_file fd field (Michael Petlan) [1709243]
- [tools] perf util: Make copyfile_offset() global (Michael Petlan) [1709243]
- [tools] perf tools: Add 'struct perf_mmap' arg to record__write() (Michael Petlan) [1709243]
- [tools] perf auxtrace: Pass struct perf_mmap into mmap__read* functions (Michael Petlan) [1709243]
- [tools] perf tools: Remove perf_tool from event_op3 (Michael Petlan) [1709243]
- [tools] perf tools: Remove perf_tool from event_op2 (Michael Petlan) [1709243]
- [tools] perf bpf-loader: use PTR_ERR_OR_ZERO inetead of return code (Michael Petlan) [1709243]
- [tools] tools include: Adopt PTR_ERR_OR_ZERO from the kernel err.h header (Michael Petlan) [1709243]
- [tools] perf ordered_events: Prevent crossing max_alloc_size (Michael Petlan) [1709243]
- [tools] perf ordered_events: Add 'struct ordered_events_buffer' layer (Michael Petlan) [1709243]
- [tools] perf test: Add watchpoint test (Michael Petlan) [1709243]
- [tools] perf tests: Fix record+probe_libc_inet_pton.sh without ping's debuginfo (Michael Petlan) [1709243]
- [tools] perf map: Turn some pr_warning() to pr_debug() (Michael Petlan) [1709243]
- [tools] perf trace: Use the raw_syscalls:sys_enter for the augmented syscalls (Michael Petlan) [1709243]
- [tools] perf trace: Setup augmented_args in the raw_syscalls:sys_enter handler (Michael Petlan) [1709243]
- [tools] perf trace: Introduce syscall__augmented_args() method (Michael Petlan) [1709243]
- [tools] perf augmented_syscalls: Avoid optimization to pass older BPF validators (Michael Petlan) [1709243]
- [tools] perf augmented_syscalls: Check probe_read_str() return separately (Michael Petlan) [1709243]
- [tools] perf annotate: Handle arm64 move instructions (Michael Petlan) [1709243]
- [tools] perf trace beauty: Alias 'umount' to 'umount2' (Michael Petlan) [1709243]
- [tools] perf stat: Move the display functions to stat-display.c (Michael Petlan) [1709243]
- [tools] perf stat: Move 'metric_events' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'walltime_*' data to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Propagate 'struct target' arg to sort_aggr_thread() (Michael Petlan) [1709243]
- [tools] perf stat: Move 'no_merge' data to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'big_num' data to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Do not use the global 'evsel_list' in print functions (Michael Petlan) [1709243]
- [tools] perf stat: Move *_aggr_* data to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move ru_* data to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'print_mixed_hw_group_error' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'print_free_counters_hint' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'null_run' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Add 'walltime_nsecs_stats' pointer to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Pass 'evlist' to aggr_update_shadow() (Michael Petlan) [1709243]
- [tools] perf stat: Pass 'struct perf_stat_config' to first_shadow_cpu() (Michael Petlan) [1709243]
- [tools] perf stat: Move 'metric_only_len' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'run_count' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Use 'evsel->evlist' instead of 'evsel_list' in collect_all_aliases() (Michael Petlan) [1709243]
- [tools] perf stat: Pass 'evlist' argument to print functions (Michael Petlan) [1709243]
- [tools] perf stat: Add 'target' argument to perf_evlist__print_counters() (Michael Petlan) [1709243]
- [tools] perf stat: Move 'unit_width' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'metric_only' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'interval_clear' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move csv_* to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Pass a 'struct perf_stat_config' argument to global print functions (Michael Petlan) [1709243]
- [tools] perf stat: Pass 'struct perf_stat_config' argument to local print functions (Michael Petlan) [1709243]
- [tools] perf stat: Add 'struct perf_stat_config' argument to perf_evlist__print_counters() (Michael Petlan) [1709243]
- [tools] perf stat: Move STAT_RECORD out of perf_evlist__print_counters() (Michael Petlan) [1709243]
- [tools] perf stat: Introduce perf_evlist__print_counters() (Michael Petlan) [1709243]
- [tools] perf stat: Move perf_stat_synthesize_config() to stat.c (Michael Petlan) [1709243]
- [tools] perf stat: Add 'perf_event__handler_t' argument to perf_stat_synthesize_config() (Michael Petlan) [1709243]
- [tools] perf stat: Add 'struct perf_evlist' argument to perf_stat_synthesize_config() (Michael Petlan) [1709243]
- [tools] perf stat: Add 'struct perf_tool' argument to perf_stat_synthesize_config() (Michael Petlan) [1709243]
- [tools] perf stat: Add 'struct perf_stat_config' argument to perf_stat_synthesize_config() (Michael Petlan) [1709243]
- [tools] perf stat: Rename 'is_pipe' argument to 'attrs' in perf_stat_synthesize_config() (Michael Petlan) [1709243]
- [tools] perf stat: Move create_perf_stat_counter() to stat.c (Michael Petlan) [1709243]
- [tools] perf evsel: Introduce perf_evsel__store_ids() (Michael Petlan) [1709243]
- [tools] perf tools: Switch 'session' argument to 'evlist' in perf_event__synthesize_attrs() (Michael Petlan) [1709243]
- [tools] perf stat: Add 'identifier' flag to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Use local config arg for scale in create_perf_stat_counter() (Michael Petlan) [1709243]
- [tools] perf stat: Move 'no_inherit' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Move 'initial_delay' to 'struct perf_stat_config' (Michael Petlan) [1709243]
- [tools] perf stat: Use evsel->threads in create_perf_stat_counter() (Michael Petlan) [1709243]
- [tools] perf trace: Show comm and tid for tracepoint events (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Hook into syscalls:sys_exit_SYSCALL too (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Rename augmented_*_syscall__enter to just *_syscall (Michael Petlan) [1709243]
- [tools] perf augmented_syscalls: Update the header comments (Michael Petlan) [1709243]
- [tools] perf bpf: Add syscall_exit() helper (Michael Petlan) [1709243]
- [tools] tools lib traceevent, perf tools: Split trace-seq related APIs in a separate header file (Michael Petlan) [1709243]
- [tools] perf report: Create auxiliary trace data files for s390 (Michael Petlan) [1709243]
- [tools] perf trace beauty: Reorganize 'struct sockaddr *' beautifier (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Augment sendto's 'addr' arg (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Augment bind's 'myaddr' sockaddr arg (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Add augmented_sockaddr_syscall_enter() (Michael Petlan) [1709243]
- [tools] perf trace augmented_syscalls: Augment connect's 'sockaddr' arg (Michael Petlan) [1709243]
- [tools] perf bpf: Add linux/socket.h to the headers accessible to bpf proggies (Michael Petlan) [1709243]
- [tools] perf bpf: Give precedence to bpf header dir (Michael Petlan) [1709243]
- [tools] perf trace: Add a etcsnoop.c augmented syscalls eBPF utility (Michael Petlan) [1709243]
- [tools] perf trace: Augment 'newstat' (aka 'stat') filename ptr (Michael Petlan) [1709243]
- [tools] perf trace: Introduce augmented_filename_syscall_enter() declarator (Michael Petlan) [1709243]
- [tools] perf trace: Augment inotify_add_watch pathname syscall arg (Michael Petlan) [1709243]
- [tools] perf trace: Augment the 'open' syscall 'filename' arg (Michael Petlan) [1709243]
- [tools] perf trace: Use the augmented filename, expanding syscall enter pointers (Michael Petlan) [1709243]
- [tools] perf trace: Show comm/tid for augmented_syscalls (Michael Petlan) [1709243]
- [tools] perf trace: Extract the comm/tid printing for syscall enter (Michael Petlan) [1709243]
- [tools] perf trace: Print the syscall name for augmented_syscalls (Michael Petlan) [1709243]
- [tools] perf trace: Make the augmented_syscalls filter out the tracepoint event (Michael Petlan) [1709243]
- [tools] perf trace: Pass augmented args to the arg formatters when available (Michael Petlan) [1709243]
- [x86] perf/x86/intel: Disallow precise_ip on BTS events (Michael Petlan) [1709243]
- [x86] perf/x86/intel: Add generic branch tracing check to intel_pmu_has_bts() (Michael Petlan) [1709243]
- [x86] perf/x86/intel: Move branch tracing setup to the Intel-specific source file (Michael Petlan) [1709243]
- [x86] perf/x86/intel: Fix regression by default disabling perfmon v4 interrupt handling (Michael Petlan) [1709243]
- [x86] perf/x86/intel/uncore: Support CoffeeLake 8th CBOX (Michael Petlan) [1709243]
- [x86] perf/x86/intel/uncore: Add more IMC PCI IDs for KabyLake and CoffeeLake CPUs (Michael Petlan) [1709243]
- [tools] perf tools: Don't clone maps from parent when synthesizing forks (Michael Petlan) [1709243]
- [tools] perf top: Allow disabling the overwrite mode (Michael Petlan) [1709243]
- [kernel] perf/core: Clean up inconsisent indentation (Michael Petlan) [1709243]
- [tools] perf script: Implement --graph-function (Michael Petlan) [1709243]
- [tools] tools script: Add --call-trace and --call-ret-trace (Michael Petlan) [1709243]
- [tools] perf script: Add --insn-trace for instruction decoding (Michael Petlan) [1709243]
- [tools] perf trace: Introduce --max-events (Michael Petlan) [1709243]
- [x86] perf/x86/intel: Add quirk for Goldmont Plus (Michael Petlan) [1709243]
- [kernel] perf: Suppress AUX/OVERWRITE records (Michael Petlan) [1709243]
- [x86] perf/x86/intel/pt: Annotate 'pt_cap_group' with __ro_after_init (Michael Petlan) [1709243]
- [x86] perf/x86: Add __ro_after_init annotations (Michael Petlan) [1709243]
- [x86] x86/mm/mem_encrypt: Disable all instrumentation for early SME setup (Janakarajan Natarajan) [1679265]
- [fs] cifs: fix copy_file_range to allow write on the same file (Leif Sahlberg) [1689100]
- [infiniband] Revert "[infiniband] IB/usnic: Remove stub functions" (Jonathan Toppins) [1713753]
- [x86] Update stepping values for Whiskey Lake U/Y (David Arcari) [1704801]
- [powerpc] powerpc/perf: Trace imc PMU functions (Jiri Olsa) [1608796]
- [powerpc] powerpc/perf: Trace imc events detection and cpuhotplug (Jiri Olsa) [1608796]
- [powerpc] powerpc/perf: Declare static identifier a such (Jiri Olsa) [1608796]
- [powerpc] powerpc/perf: Add privileged access check for thread_imc (Jiri Olsa) [1608796]
- [powerpc] powerpc/perf: Rearrange setting of ldbar for thread-imc (Jiri Olsa) [1608796]
- [powerpc] powerpc/include: Add data structures and macros for IMC trace mode (Jiri Olsa) [1608796]
- [scsi] hpsa: correct-static-checker-issue-in-reset-handler (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: update driver version (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: correct device resets (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: do-not-complete-cmds-for-deleted-devices (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: wait longer for ptraid commands (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: check for tag collision (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: use local workqueues instead of system workqueues (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: correct simple mode (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: bump driver version (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: correct device id issues (Joseph Szczypek) [1713772]
- [scsi] scsi: hpsa: check for lv removal (Joseph Szczypek) [1713772]
- [mm] mm, slub: restore the original intention of prefetch_freepointer() (Rafael Aquini) [1714671]
- [fs] Revert "add KABI padding to dentry structure" (Waiman Long) [1714253]
- [crypto] crypto: drbg - add FIPS 140-2 CTRNG for noise source (Herbert Xu) [1687905]
- [infiniband] RDMA/qedr: Fix incorrect device rate. (Manish Chopra) [1713580]
- [scsi] scsi: bnx2fc: remove unneeded variable (Nilesh Javali) [1665308]
- [scsi] scsi: fcoe: make use of fip_mode enum complete (Nilesh Javali) [1665308]
- [char] ipmi:ssif: compare block number correctly for multi-part return messages (Tony Camuso) [1712159]
- [kernel] kernel/sysctl.c: define minmax conv functions in terms of non-minmax versions (Alex Gladkov) [1683922]
- [kernel] kernel/sysctl.c: add missing range check in do_proc_dointvec_minmax_conv (Alex Gladkov) [1683922]
- [tools] tools/testing/selftests/sysctl/sysctl.sh: add tests for >32-bit values written to 32-bit integers (Alex Gladkov) [1683922]
- [kernel] sched/nohz: Run NOHZ idle load balancer on HK_FLAG_MISC CPUs (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] nohz_full: Allow the boot CPU to be nohz_full (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] sched/isolation: Require a present CPU in housekeeping mask (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] kernel/cpu: Allow non-zero CPU to be primary for suspend / kexec freeze (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] power/suspend: Add function to disable secondaries for suspend (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] sched/core: Allow the remote scheduler tick to be started on CPU0 (Desnes Augusto Nunes do Rosario) [1666614]
- [kernel] sched/fair: Use non-atomic cpumask_{set,clear}_cpu() (Desnes Augusto Nunes do Rosario) [1666614]
- [lib] lib: reciprocal_div: implement the improved algorithm on the paper mentioned (Petr Oros) [1706982]
- [kernel] kernel/sysctl.c: fix proc_do_large_bitmap for large input buffers (Eric Sandeen) [1667092]
- [kernel] tools/testing/selftests/sysctl/sysctl.sh: add proc_do_large_bitmap() test case (Eric Sandeen) [1667092]
- [tools] tools/testing/selftests/sysctl/sysctl.sh: allow graceful use on older kernels (Eric Sandeen) [1667092]
- [tools] tools/testing/selftests/sysctl/sysctl.sh: ignore diff output on verify_diff_w() (Eric Sandeen) [1667092]
- [tools] tools/testing/selftests/sysctl/sysctl.sh: load module before testing for it (Eric Sandeen) [1667092]
- [tools] tools/testing/selftests/sysctl/sysctl.sh: remove superfluous test_reqs() (Eric Sandeen) [1667092]
- [kernel] kernel/sysctl.c: fix out-of-bounds access when setting file-max (Eric Sandeen) [1694160]
- [kernel] sysctl: handle overflow for file-max (Eric Sandeen) [1694160]
- [kernel] sysctl: handle overflow in proc_get_long (Eric Sandeen) [1694160]
- [s390] kvm: s390: Fix potential spectre warnings (Thomas Huth) [1702344]
- [powerpc] mm: move warning from resize_hpt_for_hotplug() (Laurent Vivier) [1660737]
- [powerpc] pseries: Use pr_xxx() in lpar.c (Laurent Vivier) [1660737]
- [infiniband] RDMA/iw_cxgb4: Always disconnect when QP is transitioning to TERMINATE state (Arjun Vynipadath) [1664673]
- [infiniband] cxgb4: kfree mhp after the debug print (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/cxbg: Use correct sizing on buffers holding page DMA addresses (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: Make function read_tcb() static (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/cxgb4: Remove kref accounting for sync operation (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: cq/qp mask depends on bar2 pages in a host page (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: fix srqidx leak during connection abort (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: complete the cached SRQ buffers (Arjun Vynipadath) [1664673]
- [infiniband] rdma/cxgb4: Remove a set-but-not-used variable (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: use tos when finding ipv6 routes (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: use tos when importing the endpoint (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: use listening ep tos when accepting new connections (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb*: kzalloc the iwcm verbs struct (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/iw_cxgb4: Drop __GFP_NOFAIL (Arjun Vynipadath) [1664673]
- [infiniband] infiniband: cxgb4: no need to check return value of debugfs_create functions (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/iw_cxgb4: Fix the unchecked ep dereference (Arjun Vynipadath) [1664673]
- [infiniband] RDMA: Introduce and use rdma_device_to_ibdev() (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: Check for send WR also while posting write with completion WR (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: only reconnect with MPAv1 if the peer aborts (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: Use proper enumerated type in c4iw_bar2_addrs (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/cxgb4: remove redundant null pointer check before kfree_skb (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: Remove pci_unmap_addr() wrappers for DMA API (Arjun Vynipadath) [1664673]
- [infiniband] iw_cxgb4: Declare ib_post_send() and ib_post_recv() arguments const (Arjun Vynipadath) [1664673]
- [infiniband] rdma/cxgb4: Simplify a structure initialization (Arjun Vynipadath) [1664673]
- [infiniband] rdma/cxgb4: Fix SRQ endianness annotations (Arjun Vynipadath) [1664673]
- [infiniband] rdma/cxgb4: Add support for kernel mode SRQ's (Arjun Vynipadath) [1664673]
- [infiniband] rdma/cxgb4: Add support for srq functions & structs (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/cxgb4: Restore the dropped uninitialized_var (Arjun Vynipadath) [1664673]
- [infiniband] RDMA/cxgb4: Make c4iw_poll_cq_one() easier to analyze (Arjun Vynipadath) [1664673]
- [fs] gfs2: clean_journal improperly set sd_log_flush_head (Robert S Peterson) [1693660]

* Sat Jun 01 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-100.rt16.40.el8]
- [rt] kernel-rt-4.18.0-100.rt16.39.el8 (Juri Lelli) [1678887]
- [netdrv] bonding/802.3ad: fix slave link initialization transition states (Jarod Wilson) [1714387]
- [iommu] iommu/vt-d: Disable ATS support on untrusted devices (Jerry Snitselaar) [1649210 1692246]
- [documentation] thunderbolt: Export IOMMU based DMA protection support to userspace (Jerry Snitselaar) [1649210 1692246]
- [iommu] iommu/vt-d: Do not enable ATS for untrusted devices (Jerry Snitselaar) [1649210 1692246]
- [iommu] iommu/vt-d: Force IOMMU on for platform opt in hint (Jerry Snitselaar) [1649210 1692246]
- [arm64] arm64: makefile fix build of .i file in external module case (Jerome Marchand) [1713052]
- [s390] s390/protvirt: block kernel command line alteration (Philipp Rudo) [1651711]
- [s390] s390/protvirt: add memory sharing for diag 308 set/store (Philipp Rudo) [1651711]
- [s390] s390/uv: introduce guest side ultravisor code (Philipp Rudo) [1651711]
- [netdrv] net: aquantia: fix undefined devm_hwmon_device_register_with_info reference (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: Make aq_ndev_driver_name static (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: remove outdated device ids (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fixups on 64bit dma counters (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: get total counters from DMA block (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fetch up to date statistics on ethtool request (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: extract timer cb into work job (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: introduce fwreq mutex (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: user correct MSI irq type (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: use macros for better visibility (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: improve ifup link detection (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: link status irq handling (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: create global service workqueue (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: link interrupt handling function (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add link interrupt fields (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: implement hwmon api for chip temperature (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add infrastructure to readout chip temperature (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: enable driver build for arm64 or compile_test (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: improve LRO configuration (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: Increase rx ring default size from 1K to 2K (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: Make RX default frame size 2K (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: Introduce rx refill threshold value (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: optimize rx performance by page reuse strategy (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: optimize rx path using larger preallocated skb len (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix rx checksum offload for UDP/TCP over IPv6 (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: use better wrappers for state registers (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: replace AQ_HW_WAIT_FOR with readx_poll_timeout_atomic (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fixed instack structure overflow (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fixed buffer overflow (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: added newline at end of file (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fixed memcpy size (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: regression on cpus with high cores: set mode with 8 queues (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add support of RSS configuration (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix initialization of RSS table (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: increase max number of hw queues (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix RSS table and key sizes (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix rx checksum offload bits (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: return 'err' if set MPI_DEINIT state fails (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix spelling mistake "specfield" -> "specified" (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: cleanup err handing in hw_atl_utils_fw_rpc_wait (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add support of rx-vlan-filter offload (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add ethertype and PCP to rx flow filters (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add vlan id to rx flow filters (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add support of L3/L4 ntuple filters (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add infrastructure for ntuple rules (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: add rx-flow filter definitions (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: allow rx checksum offload configuration (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: invalid checksumm offload implementation (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fixed enable unicast on 32 macvlan (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: fix potential IOMMU fault after driver unbind (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: synchronized flow control between mac/phy (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: make function aq_fw2x_update_stats static (Igor Russkikh) [1706905]
- [netdrv] net: aquantia: remove some redundant variable initializations (Igor Russkikh) [1706905]
- [netdrv] bnxt_en: Add device IDs 0x1806 and 0x1752 for 57500 devices. (Selvin Xavier) [1672208]
- [scsi] scsi: fnic: Remove set but not used variable 'vdev' (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: no need to check return value of debugfs_create functions (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Update fnic driver version to 1.6.0.47 (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Enable fnic devcmd2 interface (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Adding devcmd2 init and posting interfaces (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Add devcmd2 initialization helpers (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: fnic devcmd2 controller definitions (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: fnic devcmd2 interface definitions (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Impose upper limit on max. # of CQs processed per intr (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: RQ enable and then post descriptors (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: delaying vnic dev enable till after req intr (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Warn when calling done for IO not issued to fw (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: fnic stats for max CQs processed and ISR time (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Add port speed stat to fnic debug stats (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: use fnic_lock to guard fnic->state_flags (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: vnic_rq_clean change BUG_ON to WARN_ON (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: change fnic queue depth to 256 (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: support to display 20G port speed (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: Use vzalloc (Govindarajulu Varadarajan) [1656236]
- [scsi] scsi: fnic: switch to generic DMA API (Govindarajulu Varadarajan) [1656236]
- [pci] PCI/PME: Fix possible use-after-free on remove (Myron Stowe) [1701834]
- [pci] PCI/PME: Fix hotplug/sysfs remove deadlock in pcie_pme_remove() (Myron Stowe) [1701834]
- [pci] PCI: Blacklist power management of Gigabyte X299 DESIGNARE EX PCIe ports (Myron Stowe) [1701834]
- [tools] perf arm64: Fix mksyscalltbl when system kernel headers are ahead of the kernel (Michael Petlan) [1709242]
- [rpmspec] perf: remove bpf examples (Michael Petlan) [1709242]
- [tools] perf tools: Stop fallbacking to kallsyms for vdso symbols lookup (Michael Petlan) [1709242]
- [tools] perf report: Don't crash on invalid inline debug information (Michael Petlan) [1709242]
- [tools] perf cpu_map: Align cpu map synthesized events properly. (Michael Petlan) [1709242]
- [tools] perf tools: Fix tracing_path_mount proper path (Michael Petlan) [1709242]
- [tools] perf evsel: Store ids for events with their own cpus perf_event__synthesize_event_update_cpus (Michael Petlan) [1709242]
- [tools] perf vendor events intel: Fix wrong filter_band* values for uncore events (Michael Petlan) [1709242]
- [tools] Revert "perf tools: Fix PMU term format max value calculation" (Michael Petlan) [1709242]
- [tools] tools headers uapi: Sync kvm.h copy (Michael Petlan) [1709242]
- [tools] perf record: Use unmapped IP for inline callchain cursors (Michael Petlan) [1709242]
- [tools] perf python: Use -Wno-redundant-decls to build with PYTHON=python3 (Michael Petlan) [1709242]
- [tools] perf report: Don't try to map ip to invalid map (Michael Petlan) [1709242]
- [tools] perf script python: Fix export-to-sqlite.py sample columns (Michael Petlan) [1709242]
- [tools] perf script python: Fix export-to-postgresql.py occasional failure (Michael Petlan) [1709242]
- [tools] perf Documentation: Fix out-of-tree asciidoctor man page generation (Michael Petlan) [1709242]
- [tools] perf tools: Fix maps__find_symbol_by_name() (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copy of linux/if_link.h (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copy of linux/vhost.h (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copies of kvm headers (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copy of drm/drm.h (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copy of asm-generic/unistd.h (Michael Petlan) [1709242]
- [tools] tools headers uapi: Update tools's copy of linux/perf_event.h (Michael Petlan) [1709242]
- [tools] perf annotate: Fix parsing aarch64 branch instructions after objdump update (Michael Petlan) [1709242]
- [tools] perf probe powerpc: Ignore SyS symbols irrespective of endianness (Michael Petlan) [1709242]
- [tools] perf event-parse: Use fixed size string for comms (Michael Petlan) [1709242]
- [tools] perf util: Fix bad memory access in trace info. (Michael Petlan) [1709242]
- [tools] perf tools: Streamline bpf examples and headers installation (Michael Petlan) [1709242]
- [tools] perf evsel: Fix potential null pointer dereference in perf_evsel__new_idx() (Michael Petlan) [1709242]
- [tools] perf arm64: Fix include path for asm-generic/unistd.h (Michael Petlan) [1709242]
- [tools] perf tests: Add breakpoint modify tests (Michael Petlan) [1709242]
- [tools] perf annotate: Properly interpret indirect call (Michael Petlan) [1709242]
- [tools] tools/lib/lockdep: Add dummy task_struct state member (Michael Petlan) [1709242]
- [tools] tools/lib/lockdep: Add empty nmi.h (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Change to SPDX License format (Michael Petlan) [1709242]
- [tools] perf llvm: Allow passing options to llc in addition to clang (Michael Petlan) [1709242]
- [tools] perf parser: Improve error message for PMU address filters (Michael Petlan) [1709242]
- [tools] perf tools: Disable parallelism for 'make clean' (Michael Petlan) [1709242]
- [tools] perf auxtrace: Fix queue resize (Michael Petlan) [1709242]
- [tools] perf python: Remove -mcet and -fcf-protection when building with clang (Michael Petlan) [1709242]
- [tools] perf arm spe: Fix uninitialized record error variable (Michael Petlan) [1709242]
- [tools] perf tools: Move syscall_64.tbl check into check-headers.sh (Michael Petlan) [1709242]
- [tools] perf tools: Make check-headers.sh check based on kernel dir (Michael Petlan) [1709242]
- [tools] perf tools: Fix check-headers.sh AND list path of execution (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename static variables and functions in event-parse.c (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename various pevent APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename internal parser related APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename various pevent get/set/is APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent_find_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent field APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent_data_ APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent_register / unregister APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent_filter* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent,  perf tools: Rename traceevent_plugin_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent: Rename pevent_function* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, tools lib lockdep: Rename 'enum pevent_errno' to 'enum tep_errno' (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename 'enum pevent_flag' to 'enum tep_flag' (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename traceevent_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent_set_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent_register_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent_read_number_* APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent print APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent parse APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent find APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent alloc / free APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename pevent plugin related APIs (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename 'struct pevent_record' to 'struct tep_record' (Michael Petlan) [1709242]
- [tools] tools lib traceevent, perf tools: Rename struct pevent to struct tep_handle (Michael Petlan) [1709242]
- [tools] perf probe powerpc: Fix trace event post-processing (Michael Petlan) [1709242]
- [tools] perf map: Optimize maps__fixup_overlappings() (Michael Petlan) [1709242]
- [tools] perf map: Synthesize maps only for thread group leader (Michael Petlan) [1709242]
- [tools] perf trace: Wire up the augmented syscalls with the syscalls:sys_enter_FOO beautifier (Michael Petlan) [1709242]
- [tools] perf trace: Setup the augmented syscalls bpf-output event fields (Michael Petlan) [1709242]
- [tools] perf bpf: Make bpf__setup_output_event() return the bpf-output event (Michael Petlan) [1709242]
- [tools] perf trace: Handle "bpf-output" events associated with "__augmented_syscalls__" BPF map (Michael Petlan) [1709242]
- [tools] perf bpf: Add wrappers to BPF_FUNC_probe_read(_str) functions (Michael Petlan) [1709242]
- [tools] perf bpf: Add bpf__setup_output_event() strerror() counterpart (Michael Petlan) [1709242]
- [tools] perf bpf: Generalize bpf__setup_stdout() (Michael Petlan) [1709242]
- [tools] perf bpf: Make bpf__for_each_stdout_map() generic (Michael Petlan) [1709242]
- [tools] perf bpf: Add bpf/stdio.h wrapper to bpf_perf_event_output function (Michael Petlan) [1709242]
- [tools] perf bpf: Add struct bpf_map struct (Michael Petlan) [1709242]
- [tools] perf report: Add --percent-type option (Michael Petlan) [1709242]
- [tools] perf annotate: Add --percent-type option (Michael Petlan) [1709242]
- [tools] perf annotate: Display percent type in stdio output (Michael Petlan) [1709242]
- [tools] perf annotate: Make local period the default percent type (Michael Petlan) [1709242]
- [tools] perf annotate: Add support to toggle percent type (Michael Petlan) [1709242]
- [tools] perf annotate: Pass browser percent_type in annotate_browser__calc_percent() (Michael Petlan) [1709242]
- [tools] perf annotate: Pass 'struct annotation_options' to map_symbol__annotation_dump() (Michael Petlan) [1709242]
- [tools] perf annotate: Pass struct annotation_options to symbol__calc_lines() (Michael Petlan) [1709242]
- [tools] perf annotate: Add percent_type to struct annotation_options (Michael Petlan) [1709242]
- [tools] perf annotate: Add PERCENT_PERIOD_GLOBAL percent value (Michael Petlan) [1709242]
- [tools] perf annotate: Add PERCENT_PERIOD_LOCAL percent value (Michael Petlan) [1709242]
- [tools] perf annotate: Add PERCENT_HITS_GLOBAL percent value (Michael Petlan) [1709242]
- [tools] perf annotate: Switch struct annotation_data::percent to array (Michael Petlan) [1709242]
- [tools] perf annotate: Loop group events directly in annotation__calc_percent() (Michael Petlan) [1709242]
- [tools] perf annotate: Rename hist to sym_hist in annotation__calc_percent (Michael Petlan) [1709242]
- [tools] perf annotate: Rename local sample variables to data (Michael Petlan) [1709242]
- [tools] perf annotate: Rename struct annotation_line::samples* to data* (Michael Petlan) [1709242]
- [tools] perf annotate: Get rid of annotation__scnprintf_samples_period() (Michael Petlan) [1709242]
- [tools] perf annotate: Make annotation_line__max_percent static (Michael Petlan) [1709242]
- [tools] perf annotate: Make symbol__annotate_fprintf2() local (Michael Petlan) [1709242]
- [tools] perf bpf: Add 'syscall_enter' probe helper for syscall enter tracepoints (Michael Petlan) [1709242]
- [tools] perf tools: Drop unneeded bitmap_zero() calls (Michael Petlan) [1709242]
- [tools] perf vendor events arm64: Enable JSON events for eMAG (Michael Petlan) [1709242]
- [tools] perf report: Add GUI report support for s390 auxiliary trace (Michael Petlan) [1709242]
- [tools] perf report: Add raw report support for s390 auxiliary trace (Michael Petlan) [1709242]
- [tools] perf auxtrace: Support for perf report -D for s390 (Michael Petlan) [1709242]
- [tools] perf trace: Use perf_evsel__sc_tp_{uint,ptr} for "id"/"args" handling syscalls:* events (Michael Petlan) [1709242]
- [tools] perf trace: Setup struct syscall_tp for syscalls:sys_{enter,exit}_NAME events (Michael Petlan) [1709242]
- [tools] perf trace: Allow setting up a syscall_tp struct without a format_field (Michael Petlan) [1709242]
- [tools] perf trace: Rename some syscall_tp methods to raw_syscall (Michael Petlan) [1709242]
- [tools] perf trace: Use beautifiers on syscalls:sys_enter_ handlers (Michael Petlan) [1709242]
- [tools] perf trace: Associate vfs_getname()'ed pathname with fd returned from 'openat' (Michael Petlan) [1709242]
- [tools] perf trace: Do not require --no-syscalls to suppress strace like output (Michael Petlan) [1709242]
- [tools] perf bpf: Include uapi/linux/bpf.h from the 'perf trace' script's bpf.h (Michael Petlan) [1709242]
- [tools] perf tools: Allow overriding MAX_NR_CPUS at compile time (Michael Petlan) [1709242]
- [tools] perf bpf: Show better message when failing to load an object (Michael Petlan) [1709242]
- [tools] perf list: Unify metric group description format with PMU event description (Michael Petlan) [1709242]
- [tools] perf cs-etm: Generate branch sample for CS_ETM_TRACE_ON packet (Michael Petlan) [1709242]
- [tools] perf cs-etm: Generate branch sample when receiving a CS_ETM_TRACE_ON packet (Michael Petlan) [1709242]
- [tools] perf cs-etm: Support dummy address value for CS_ETM_TRACE_ON packet (Michael Petlan) [1709242]
- [tools] perf cs-etm: Fix start tracing packet handling (Michael Petlan) [1709242]
- [tools] perf build: Fix installation directory for eBPF (Michael Petlan) [1709242]
- [tools] perf c2c report: Fix crash for empty browser (Michael Petlan) [1709242]
- [tools] perf tests: Fix indexing when invoking subtests (Michael Petlan) [1709242]
- [tools] perf trace: Beautify the AF_INET & AF_INET6 'socket' syscall 'protocol' args (Michael Petlan) [1709242]
- [tools] perf trace beauty: Add beautifiers for 'socket''s 'protocol' arg (Michael Petlan) [1709242]
- [tools] perf trace beauty: Do not print NULL strarray entries (Michael Petlan) [1709242]
- [tools] perf beauty: Add a generator for IPPROTO_ socket's protocol constants (Michael Petlan) [1709242]
- [tools] tools include uapi: Grab a copy of linux/in.h (Michael Petlan) [1709242]
- [tools] perf tests: Fix complex event name parsing (Michael Petlan) [1709242]
- [tools] perf evlist: Fix error out while applying initial delay and LBR (Michael Petlan) [1709242]
- [tools] perf trace beauty: Default header_dir to cwd to work without parms (Michael Petlan) [1709242]
- [tools] perf test: Fix subtest number when showing results (Michael Petlan) [1709242]
- [tools] perf stat: Get rid of extra clock display function (Michael Petlan) [1709242]
- [tools] perf tools: Use perf_evsel__match instead of open coded equivalent (Michael Petlan) [1709242]
- [tools] perf tools: Fix struct comm_str removal crash (Michael Petlan) [1709242]
- [tools] perf machine: Use last_match threads cache only in single thread mode (Michael Petlan) [1709242]
- [tools] perf machine: Add threads__set_last_match function (Michael Petlan) [1709242]
- [tools] perf machine: Add threads__get_last_match function (Michael Petlan) [1709242]
- [tools] perf tools: Synthesize GROUP_DESC feature in pipe mode (Michael Petlan) [1709242]
- [tools] perf script: Show correct offsets for DWARF-based unwinding (Michael Petlan) [1709242]
- [tools] perf trace arm64: Use generated syscall table (Michael Petlan) [1709242]
- [tools] perf arm64: Generate system call table from asm/unistd.h (Michael Petlan) [1709242]
- [tools] tools include: Grab copies of arm64 dependent unistd.h files (Michael Petlan) [1709242]
- [tools] perf tests: Fix record+probe_libc_inet_pton.sh when event exists (Michael Petlan) [1709242]
- [tools] perf tests: Fix record+probe_libc_inet_pton.sh to ensure cleanups (Michael Petlan) [1709242]
- [tools] perf tests: Fix record+probe_libc_inet_pton.sh for powerpc64 (Michael Petlan) [1709242]
- [tools] perf powerpc: Fix callchain ip filtering when return address is in a register (Michael Petlan) [1709242]
- [tools] perf powerpc: Fix callchain ip filtering (Michael Petlan) [1709242]
- [tools] perf list: Add missing documentation for --desc and --debug options (Michael Petlan) [1709242]
- [tools] perf stat: Add transaction flag (-T) support for s390 (Michael Petlan) [1709242]
- [tools] perf json: Add s390 transaction counter definition (Michael Petlan) [1709242]
- [tools] perf list: Add s390 support for detailed PMU event description (Michael Petlan) [1709242]
- [tools] Revert "perf list: Add s390 support for detailed/verbose PMU event description" (Michael Petlan) [1709242]
- [tools] perf cs-etm: Bail out immediately for instruction sample failure (Michael Petlan) [1709242]
- [tools] perf cs-etm: Introduce invalid address macro (Michael Petlan) [1709242]
- [tools] perf hists: Clarify callchain disabling when available (Michael Petlan) [1709242]
- [tools] perf tests: Check that complex event name is parsed correctly (Michael Petlan) [1709242]
- [arm64] arm64: perf: Reject stand-alone CHAIN events for PMUv3 (Michael Petlan) [1709242]
- [x86] perf/x86/amd/uncore: Set ThreadMask and SliceMask for L3 Cache perf events (Michael Petlan) [1709242]
- [x86] perf/x86/intel/uncore: Fix PCI BDF address of M3UPI on SKX (Michael Petlan) [1709242]
- [kernel] perf/ring_buffer: Prevent concurent ring buffer access (Michael Petlan) [1709242]
- [x86] perf/x86/intel/uncore: Use boot_cpu_data.phys_proc_id instead of hardcorded physical package ID 0 (Michael Petlan) [1709242]
- [kernel] perf/core: Fix perf_pmu_unregister() locking (Michael Petlan) [1709242]
- [kernel] perf/core: Add sanity check to deal with pinned event failure (Michael Petlan) [1709242]
- [kernel] perf/core: Force USER_DS when recording user stack data (Michael Petlan) [1709242]
- [include] perf/UAPI: Clearly mark __PERF_SAMPLE_CALLCHAIN_EARLY as internal use (Michael Petlan) [1709242]
- [x86] perf/x86/intel: Add support/quirk for the MISPREDICT bit on Knights Landing CPUs (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Simplify breakpoint enable in perf_event_modify_breakpoint (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Enable breakpoint in modify_user_hw_breakpoint (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Remove superfluous bp->attr.disabled = 0 (Michael Petlan) [1709242]
- [kernel] arm64: perf: Add cap_user_time aarch64 (Michael Petlan) [1709242]
- [include] arm_pmu: Add support for 64bit event counters (Michael Petlan) [1709242]
- [x86] perf/x86/intel: Support Extended PEBS for Goldmont Plus (Michael Petlan) [1709242]
- [x86] perf/x86/intel/ds: Handle PEBS overflow for fixed counters (Michael Petlan) [1709242]
- [x86] perf/x86/intel: Support PEBS on fixed counters (Michael Petlan) [1709242]
- [kernel] perf, tools: Use correct articles in comments (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Clean up and consolidate modify_user_hw_breakpoint_check() (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Pass new breakpoint type to modify_breakpoint_slot() (Michael Petlan) [1709242]
- [kernel] perf/hw_breakpoint: Remove default hw_breakpoint_arch_parse() (Michael Petlan) [1709242]
- [arm64] perf/arch/arm64: Implement hw_breakpoint_arch_parse() (Michael Petlan) [1709242]
- [powerpc] perf/arch/powerpc: Implement hw_breakpoint_arch_parse() (Michael Petlan) [1709242]
- [x86] perf/arch/x86: Implement hw_breakpoint_arch_parse() (Michael Petlan) [1709242]
- [arm64] perf/hw_breakpoint: Pass arch breakpoint struct to arch_check_bp_in_kernelspace() (Michael Petlan) [1709242]
- [kernel] perf/core: Change perf_mmap_fault() return type to 'vm_fault_t' (Michael Petlan) [1709242]
- [x86] perf/x86/intel/lbr: Optimize context switches for the LBR call stack (Michael Petlan) [1709242]
- [netdrv] cnic: Refactor code and mark expected switch fall-through (Nilesh Javali) [1665302]
- [netdrv] cnic: remove use of VLAN_TAG_PRESENT (Nilesh Javali) [1665302]
- [netdrv] cnic: use kvzalloc to allocate memory for csk_tbl (Nilesh Javali) [1665302]
- [netdrv] cnic: remove redundant pointer req and variable func (Nilesh Javali) [1665302]
- [scsi] drivers: Remove useless trailing comments from mmiowb() invocations (Nilesh Javali) [1665307]
- [scsi] scsi: qedf: remove set but not used variables (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Update the driver version to 8.37.25.20 (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add return value to log message if scsi_add_host fails (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Print fcport information on wait for upload timeout (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Check the return value of start_xmit (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Log message if scsi_add_host fails (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Check for fcoe_libfc_config failure (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add comment to display logging levels (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add port_id for fcport into initiate_cleanup debug message (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add LBA to underrun debug messages (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Print scsi_cmd backpointer in good completion path if the command is still being used (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add driver state to 'driver_stats' debugfs node (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Change MSI-X load error message (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: remove memset/memcpy to nfunc and use func instead (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Remove set but not used variable 'fr_len' (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Update the driver version to 8.37.25.19 (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Fix lport may be used uninitialized warning (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Correctly handle refcounting of rdata (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Cleanup rrq_work after QEDF_CMD_OUTSTANDING is cleared (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Check for tm_flags instead of cmd_type during cleanup (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add a flag to help debugging io_req which could not be cleaned (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Don't send ABTS for under run scenario (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Don't queue anything if upload is in progress (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Check both the FCF and fabric ID before servicing clear virtual link (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: fc_rport_priv reference counting fixes (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add missing return in qedf_scsi_done() (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Wait for upload and link down processing during soft ctx reset (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add additional checks for io_req->sc_cmd validity (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: fixup bit operations (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: fixup locking in qedf_restart_rport() (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: missing kref_put in qedf_xmit() (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Check for link state before processing LL2 packets and send fipvlan retries (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add missing fc_disc_init call after allocating lport (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Correct the memory barriers in qedf_ring_doorbell (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Use a separate completion for cleanup commands (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Modify abort and tmf handler to handle edge condition and flush (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Modify flush routine to handle all I/Os and TMF (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Simplify s/g list mapping (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Add missing return in qedf_post_io_req() in the fcport offload check (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Correct xid range overlap between offloaded requests and libfc requests (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: Do not retry ELS request if qedf_alloc_cmd fails (Nilesh Javali) [1665301]
- [scsi] scsi: fcoe: make use of fip_mode enum complete (Nilesh Javali) [1665301]
- [scsi] scsi: stop setting up request->special (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: no need to check return value of debugfs_create functions (Nilesh Javali) [1665301]
- [scsi] cross-tree: phase out dma_zalloc_coherent() (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: NULL check before some freeing functions is not needed (Nilesh Javali) [1665301]
- [scsi] scsi: qedf: fully convert to the generic DMA API (Nilesh Javali) [1665301]
- [scsi] scsi: qedi: Adjust termination and offload ramrod timers (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Abort ep termination if offload not scheduled (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: fix spelling mistake "oflload" -> "offload" (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: remove declaration of nvm_image from stack (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Remove set but not used variable 'cls_sess' (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Add ep_state for login completion on un-reachable targets (Nilesh Javali) [1665300]
- [scsi] cross-tree: phase out dma_zalloc_coherent() (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Update driver version to 8.33.0.21 (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Move LL2 producer index processing in BH. (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: add module param to set ping packet size (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Add packet filter in light L2 Rx path. (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Check for session online before getting iSCSI TLV data. (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Replace PAGE_SIZE with QEDI_PAGE_SIZE (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Fix spelling mistake "OUSTANDING" -> "OUTSTANDING" (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: Cleanup redundant QEDI_PAGE_SIZE macro definition (Nilesh Javali) [1665300]
- [scsi] scsi: qedi: fully convert to the generic DMA API (Nilesh Javali) [1665300]
- [x86] x86/kdump: Fall back to reserve high crashkernel memory (Pingfan Liu) [1682984]
- [x86] x86/kdump: Have crashkernel=X reserve under 4G by default (Pingfan Liu) [1682984]
- [x86] Revert "[x86] x86/kdump: make the behavior of crashkernel=X consistent with kaslr" (Pingfan Liu) [1682984]
- [scsi] scsi: core: avoid pre-allocating big SGL for data (Ewan Milne) [1698297]
- [scsi] scsi: core: avoid pre-allocating big SGL for protection information (Ewan Milne) [1698297]
- [nvme] scsi: lib/sg_pool.c: improve APIs for allocating sg pool (Ewan Milne) [1698297]
- [kvm] KVM: PPC: Book3S HV: Save/restore vrsave register in kvmhv_p9_guest_entry() (Suraj Jitindar Singh) [1700272]
- [fs] ext4: avoid kernel warning when writing the superblock to a dead device (Lukas Czerner) [1695021]
- [fs] ext4: cond_resched in work-heavy group loops (Lukas Czerner) [1698815]
- [fs] ext4: ignore e_value_offs for xattrs with value-in-ea-inode (Lukas Czerner) [1698815]
- [fs] ext4: protect journal inode's blocks using block_validity (Lukas Czerner) [1698815]
- [fs] ext4: use BUG() instead of BUG_ON(1) (Lukas Czerner) [1698815]
- [fs] jbd2: check superblock mapped prior to committing (Lukas Czerner) [1698815]
- [fs] ext4: remove incorrect comment for NEXT_ORPHAN() (Lukas Czerner) [1698815]
- [fs] ext4: make sanity check in mballoc more strict (Lukas Czerner) [1698815]
- [fs] ext4: fix use-after-free race with debug_want_extra_isize (Lukas Czerner) [1698815]
- [fs] ext4: fix ext4_show_options for file systems w/o journal (Lukas Czerner) [1698815]
- [fs] ext4: actually request zeroing of inode table after grow (Lukas Czerner) [1698815]
- [fs] Revert "ext4: use ext4_write_inode() when fsyncing w/o a journal" (Lukas Czerner) [1698815]
- [fs] ext4: fix some error pointer dereferences (Lukas Czerner) [1698815]
- [fs] ext4: fix special inode number checks in __ext4_iget() (Lukas Czerner) [1698815]
- [fs] ext4: prohibit fstrim in norecovery mode (Lukas Czerner) [1698815]
- [fs] ext4: cleanup bh release code in ext4_ind_remove_space() (Lukas Czerner) [1698815]
- [fs] ext4: brelse all indirect buffer in ext4_ind_remove_space() (Lukas Czerner) [1698815]
- [fs] ext4: report real fs size after failed resize (Lukas Czerner) [1698815]
- [fs] ext4: add missing brelse() in add_new_gdb_meta_bg() (Lukas Czerner) [1698815]
- [fs] ext4: remove useless ext4_pin_inode() (Lukas Czerner) [1698815]
- [fs] ext4: avoid panic during forced reboot (Lukas Czerner) [1698815]
- [fs] ext4: fix data corruption caused by unaligned direct AIO (Lukas Czerner) [1698815]
- [fs] ext4: fix NULL pointer dereference while journal is aborted (Lukas Czerner) [1698815]
- [fs] jbd2: jbd2_get_transaction does not need to return a value (Lukas Czerner) [1698815]
- [fs] jbd2: fix invalid descriptor block checksum (Lukas Czerner) [1698815]
- [fs] ext4: fix bigalloc cluster freeing when hole punching under load (Lukas Czerner) [1698815]
- [fs] ext4: add sysfs attr /sys/fs/ext4/<disk>/journal_task (Lukas Czerner) [1698815]
- [fs] ext4: Change debugging support help prefix from EXT4 to Ext4 (Lukas Czerner) [1698815]
- [fs] ext4: fix compile error when using BUFFER_TRACE (Lukas Czerner) [1698815]
- [fs] jbd2: fix compile warning when using JBUFFER_TRACE (Lukas Czerner) [1698815]
- [fs] ext4: annotate more implicit fall throughs (Lukas Czerner) [1698815]
- [fs] ext4: annotate implicit fall throughs (Lukas Czerner) [1698815]
- [fs] ext4: don't update s_rev_level if not required (Lukas Czerner) [1698815]
- [fs] jbd2: fold jbd2_superblock_csum_{verify,set} into their callers (Lukas Czerner) [1698815]
- [fs] jbd2: fix race when writing superblock (Lukas Czerner) [1698815]
- [fs] ext4: fix crash during online resizing (Lukas Czerner) [1698815]
- [fs] ext4: disallow files with EXT4_JOURNAL_DATA_FL from EXT4_IOC_SWAP_BOOT (Lukas Czerner) [1698815]
- [fs] ext4: add mask of ext4 flags to swap (Lukas Czerner) [1698815]
- [fs] ext4: update quota information while swapping boot loader inode (Lukas Czerner) [1698815]
- [fs] ext4: cleanup pagecache before swap i_data (Lukas Czerner) [1698815]
- [fs] ext4: fix check of inode in swap_inode_boot_loader (Lukas Czerner) [1698815]
- [fs] ext4: unlock unused_pages timely when doing writeback (Lukas Czerner) [1698815]
- [fs] ext4: cleanup clean_bdev_aliases() calls (Lukas Czerner) [1698815]
- [fs] jbd2: discard dirty data when forgetting an un-journalled buffer (Lukas Czerner) [1698815]
- [fs] jbd2: clear dirty flag when revoking a buffer from an older transaction (Lukas Czerner) [1698815]
- [fs] ext4: replace opencoded i_writecount usage with inode_is_open_for_write() (Lukas Czerner) [1698815]
- [fs] jbd2: fix deadlock while checkpoint thread waits commit thread to finish (Lukas Czerner) [1698815]
- [fs] ext4: use IS_ENCRYPTED() to check encryption status (Lukas Czerner) [1698815]
- [fs] ext4: track writeback errors using the generic tracking infrastructure (Lukas Czerner) [1698815]
- [fs] ext4: use ext4_write_inode() when fsyncing w/o a journal (Lukas Czerner) [1698815]
- [fs] ext4: fix a potential fiemap/page fault deadlock w/ inline_data (Lukas Czerner) [1698815]
- [fs] ext4: make sure enough credits are reserved for dioread_nolock writes (Lukas Czerner) [1698815]
- [fs] ext4: check for shutdown and r/o file system in ext4_write_inode() (Lukas Czerner) [1698815]
- [fs] ext4: force inode writes when nfsd calls commit_metadata() (Lukas Czerner) [1698815]
- [fs] ext4: avoid declaring fs inconsistent due to invalid file handles (Lukas Czerner) [1698815]
- [fs] ext4: include terminating u32 in size of xattr entries when expanding inodes (Lukas Czerner) [1698815]
- [fs] ext4: compare old and new mode before setting update_mode flag (Lukas Czerner) [1698815]
- [fs] ext4: fix EXT4_IOC_GROUP_ADD ioctl (Lukas Czerner) [1698815]
- [fs] ext4: hard fail dax mount on unsupported devices (Lukas Czerner) [1698815]
- [fs] ext4: remove redundant condition check (Lukas Czerner) [1698815]
- [fs] jbd2: clean up indentation issue, replace spaces with tab (Lukas Czerner) [1698815]
- [fs] ext4: clean up indentation issues, remove extraneous tabs (Lukas Czerner) [1698815]
- [fs] ext4: missing unlock/put_page() in ext4_try_to_write_inline_data() (Lukas Czerner) [1698815]
- [fs] ext4: fix possible use after free in ext4_quota_enable (Lukas Czerner) [1698815]
- [fs] jbd2: avoid long hold times of j_state_lock while committing a transaction (Lukas Czerner) [1698815]
- [fs] ext4: add ext4_sb_bread() to disambiguate ENOMEM cases (Lukas Czerner) [1698815]
- [fs] ext4: remove unneeded brelse call in ext4_xattr_inode_update_ref() (Lukas Czerner) [1698815]
- [fs] ext4: fix use-after-free race in ext4_remount()'s error path (Lukas Czerner) [1698815]
- [fs] ext4: don't open-code ERR_CAST (Lukas Czerner) [1698815]
- [fs] ext4: cache NULL when both default_acl and acl are NULL (Lukas Czerner) [1698815]
- [fs] ext4: propagate error from dquot_initialize() in EXT4_IOC_FSSETXATTR (Lukas Czerner) [1698815]
- [fs] ext4: fix setattr project check in fssetxattr ioctl (Lukas Czerner) [1698815]
- [fs] ext4: convert fault handler to use vm_fault_t type (Lukas Czerner) [1698815]
- [fs] ext4: fix EXT4_IOC_SWAP_BOOT (Lukas Czerner) [1698815]
- [fs] ext4: fix argument checking in EXT4_IOC_MOVE_EXT (Lukas Czerner) [1698815]
- [fs] ext4: fix reserved cluster accounting at page invalidation time (Lukas Czerner) [1698815]
- [fs] ext4: adjust reserved cluster count when removing extents (Lukas Czerner) [1698815]
- [fs] ext4: reduce reserved cluster count by number of allocated clusters (Lukas Czerner) [1698815]
- [fs] ext4: fix reserved cluster accounting at delayed write time (Lukas Czerner) [1698815]
- [fs] ext4: add new pending reservation mechanism (Lukas Czerner) [1698815]
- [fs] ext4: generalize extents status tree search functions (Lukas Czerner) [1698815]
- [fs] ext4: readpages() should submit IO as read-ahead (Lukas Czerner) [1698815]
- [fs] ext4: improve code readability in ext4_iget() (Lukas Czerner) [1698815]
- [fs] ext4: use swap macro in mext_page_double_lock (Lukas Czerner) [1698815]
- [fs] ext4: fix warning message in ext4_enable_quotas() (Lukas Czerner) [1698815]
- [fs] ext4: super: extend timestamps to 40 bits (Lukas Czerner) [1698815]
- [fs] jbd2: replace current_kernel_time64 with ktime equivalent (Lukas Czerner) [1698815]
- [fs] ext4: use timespec64 for all inode times (Lukas Czerner) [1698815]
- [fs] ext4: use ktime_get_real_seconds for i_dtime (Lukas Czerner) [1698815]
- [fs] ext4: use 64-bit timestamps for mmp_time (Lukas Czerner) [1698815]
- [scsi] scsi: smartpqi: Use HCTX_TYPE_DEFAULT for blk_mq_tag_set->map (Don Brace) [1665565]
- [scsi] scsi: smartpqi: bump driver version (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add spdx (Don Brace) [1665565]
- [scsi] scsi: smartpqi: update copyright (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add H3C controller IDs (Don Brace) [1665565]
- [scsi] scsi: smartpqi: increase LUN reset timeout (Don Brace) [1665565]
- [scsi] scsi: smartpqi: Reporting 'logical unit failure' (Don Brace) [1665565]
- [scsi] scsi: smartpqi_init: fix boolean expression in pqi_device_remove_start (Don Brace) [1665565]
- [scsi] scsi: smartpqi: call pqi_free_interrupts() in pqi_shutdown() (Don Brace) [1665565]
- [scsi] scsi: smartpqi: fix build warnings (Don Brace) [1665565]
- [scsi] scsi: smartpqi: update driver version (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add ofa support (Don Brace) [1665565]
- [scsi] scsi: smartpqi: increase fw status register read timeout (Don Brace) [1665565]
- [scsi] scsi: smartpqi: bump driver version (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add smp_utils support (Don Brace) [1665565]
- [scsi] scsi: smartpqi: correct lun reset issues (Don Brace) [1665565]
- [scsi] scsi: smartpqi: correct volume status (Don Brace) [1665565]
- [scsi] scsi: smartpqi: do not offline disks for transient did no connect conditions (Don Brace) [1665565]
- [scsi] scsi: smartpqi: allow for larger raid maps (Don Brace) [1665565]
- [scsi] scsi: smartpqi: check for null device pointers (Don Brace) [1665565]
- [scsi] scsi: smartpqi: enhance numa node detection (Don Brace) [1665565]
- [scsi] scsi: smartpqi: wake up drives after os resumes from suspend (Don Brace) [1665565]
- [scsi] scsi: smartpqi: fix disk name mount point (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add h3c ssid (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add sysfs attributes (Don Brace) [1665565]
- [scsi] scsi: smartpqi: refactor sending controller raid requests (Don Brace) [1665565]
- [scsi] scsi: smartpqi: turn off lun data caching for ptraid (Don Brace) [1665565]
- [scsi] scsi: smartpqi: correct host serial num for ssa (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add no_write_same for logical volumes (Don Brace) [1665565]
- [scsi] scsi: smartpqi: Add retries for device reset (Don Brace) [1665565]
- [scsi] scsi: smartpqi: add support for PQI Config Table handshake (Don Brace) [1665565]
- [scsi] scsi: smartpqi: fully convert to the generic DMA API (Don Brace) [1665565]
- [net] rtnetlink: always put IFLA_LINK for links with a link-netnsid (Sabrina Dubroca) [1711933]
- [net] ipv6: add inet6_fill_args (Ivan Vecera) [1711956]
- [net] ipv4: add inet_fill_args (Ivan Vecera) [1711956]
- [net] rtnetlink: s/IFLA_IF_NETNSID/IFLA_TARGET_NETNSID/g (Ivan Vecera) [1711956]
- [include] if_link: add IFLA_TARGET_NETNSID alias (Ivan Vecera) [1711956]
- [net] rtnetlink: move type calculation out of loop (Ivan Vecera) [1711956]
- [net] ipv6: enable IFA_TARGET_NETNSID for RTM_GETADDR (Ivan Vecera) [1711956]
- [net] ipv4: enable IFA_TARGET_NETNSID for RTM_GETADDR (Ivan Vecera) [1711956]
- [include] if_addr: add IFA_TARGET_NETNSID (Ivan Vecera) [1711956]
- [net] rtnetlink: add rtnl_get_net_ns_capable() (Ivan Vecera) [1711956]
- [tools] selftests: forwarding: mirror_gre_vlan_bridge_1q: Fix untagged test (Hangbin Liu) [1710283]
- [tools] selftests: forwarding: Tweak tc filters for mirror-to-gretap tests (Hangbin Liu) [1710283]
- [tools] selftests: forwarding: lib: Avoid trapping soft devices (Hangbin Liu) [1710283]
- [tools] selftests: pmtu: maximum MTU for vti4 is 2^16-1-20 (Hangbin Liu) [1704659]
- [net] sched: red: inform offloads about harddrop setting (Ivan Vecera) [1710999]
- [net] tls: fix copy to fragments in reencrypt (Ivan Vecera) [1710366]
- [net] tls: don't copy negative amounts of data in reencrypt (Ivan Vecera) [1710366]
- [net] tls: don't leak IV and record seq when offload fails (Ivan Vecera) [1710366]
- [net] tls: avoid potential deadlock in tls_set_device_offload_rx() (Ivan Vecera) [1710366]
- [net] tls: prevent bad memory access in tls_is_sk_tx_device_offloaded() (Ivan Vecera) [1710366]
- [net] tls: Combined memory allocation for decryption request (Ivan Vecera) [1710366]
- [net] tls: Skip zerocopy path for ITER_KVEC (Ivan Vecera) [1710366]
- [net] tls: Fix copy-paste error in tls_device_reencrypt (Ivan Vecera) [1710366]
- [net] tls: Add rx inline crypto offload (Ivan Vecera) [1710366]
- [net] tls: Fill software context without allocation (Ivan Vecera) [1710366]
- [net] tls: Split tls_sw_release_resources_rx (Ivan Vecera) [1710366]
- [net] tls: Split decrypt_skb to two functions (Ivan Vecera) [1710366]
- [net] tcp: Don't coalesce decrypted and encrypted SKBs (Ivan Vecera) [1710366]
- [include] Add TLS rx resync NDO (Ivan Vecera) [1710366]
- [net] Add TLS RX offload feature (Ivan Vecera) [1710366]
- [net] Add decrypted field to skb (Ivan Vecera) [1710366]
- [net] tls: Use aead_request_alloc/free for request alloc/free (Ivan Vecera) [1710366]
- [net] tls: Refactor tls_offload variable names (Ivan Vecera) [1703389]

* Fri May 31 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-99.rt16.39.el8]
- [rt] kernel-rt-4.18.0-99.rt16.38.el8 (Juri Lelli) [1678887]
- [netdrv] qede: use ethtool_rx_flow_rule() to remove duplicated parser code (Manish Chopra) [1663274]
- [netdrv] qede: place ethtool_rx_flow_spec after code after TC flower codebase (Manish Chopra) [1663274]
- [netdrv] drivers: net: use flow action infrastructure (Manish Chopra) [1663274]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Manish Chopra) [1663274]
- [infiniband] RDMA: Cleanup undesired pd->uobject usage (Manish Chopra) [1663274]
- [netdrv] qede: Populate mbi version in ethtool driver query data. (Manish Chopra) [1663274]
- [netdrv] qed: Define new MF bit for no_vlan config (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "faspath" -> "fastpath" (Manish Chopra) [1663274]
- [netdrv] qed: Fix the DORQ's attentions handling (Manish Chopra) [1663274]
- [netdrv] qed: Fix missing DORQ attentions (Manish Chopra) [1663274]
- [netdrv] qed: Fix the doorbell address sanity check (Manish Chopra) [1663274]
- [netdrv] qed: Delete redundant doorbell recovery types (Manish Chopra) [1663274]
- [netdrv] qede: fix write to free'd pointer error and double free of ptp (Manish Chopra) [1663274]
- [netdrv] qede: Fix internal loopback failure with jumbo mtu configuration (Manish Chopra) [1663274]
- [netdrv] qed: Read device port count from the shmem (Manish Chopra) [1663274]
- [netdrv] qed: Fix iWARP syn packet mac address validation. (Manish Chopra) [1663274]
- [netdrv] qed: Fix iWARP buffer size provided for syn packet processing. (Manish Chopra) [1663274]
- [netdrv] qed: fix indentation issue with statements in an if-block (Manish Chopra) [1663274]
- [netdrv] qede: Add ethtool interface for SmartAN query. (Manish Chopra) [1663274]
- [netdrv] qed: Add API for SmartAN query. (Manish Chopra) [1663274]
- [netdrv] qed*: Advance drivers version to 8.37.0.20 (Manish Chopra) [1663274]
- [netdrv] qed: Change verbosity for coalescing message. (Manish Chopra) [1663274]
- [netdrv] qede: Fix system crash on configuring channels. (Manish Chopra) [1663274]
- [netdrv] qed: Consider TX tcs while deriving the max num_queues for PF. (Manish Chopra) [1663274]
- [netdrv] qed: Assign UFP TC value to vlan priority in UFP mode. (Manish Chopra) [1663274]
- [netdrv] qed: Fix EQ full firmware assert. (Manish Chopra) [1663274]
- [netdrv] qed: Fix stack out of bounds bug (Manish Chopra) [1663274]
- [netdrv] qed: Fix system crash in ll2 xmit (Manish Chopra) [1663274]
- [netdrv] qed: Fix VF probe failure while FLR (Manish Chopra) [1663274]
- [netdrv] qed: Fix LACP pdu drops for VFs (Manish Chopra) [1663274]
- [netdrv] qed: Fix bug in tx promiscuous mode settings (Manish Chopra) [1663274]
- [netdrv] qede: Error recovery process (Manish Chopra) [1663274]
- [netdrv] qed: Add infrastructure for error detection and recovery (Manish Chopra) [1663274]
- [netdrv] qed: Revise load sequence to avoid PCI errors (Manish Chopra) [1663274]
- [netdrv] qed: Mark expected switch fall-through (Manish Chopra) [1663274]
- [include] qed: remove duplicated include from qed_if.h (Manish Chopra) [1663274]
- [infiniband] RDMA/qedr: Fix out of bounds index check in query pkey (Manish Chopra) [1663274]
- [netdrv] qed: Fix qed_ll2_post_rx_buffer_notify_fw() by adding a write memory barrier (Manish Chopra) [1663274]
- [include] qed: Fix qed_chain_set_prod() for PBL chains with non power of 2 page count (Manish Chopra) [1663274]
- [infiniband] infiniband/qedr: Potential null ptr dereference of qp (Manish Chopra) [1663274]
- [netdrv] qed: Fix an error code qed_ll2_start_xmit() (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "Dispalying" -> "Displaying" (Manish Chopra) [1663274]
- [netdrv] qede: Register l2 queues with doorbell overflow recovery mechanism (Manish Chopra) [1663274]
- [netdrv] qed: Expose the doorbell overflow recovery mechanism to the protocol drivers (Manish Chopra) [1663274]
- [netdrv] qed: Register light L2 queues with doorbell overflow recovery mechanism (Manish Chopra) [1663274]
- [netdrv] qed: Register slowpath queue doorbell with doorbell overflow recovery mechanism (Manish Chopra) [1663274]
- [netdrv] qed: Use the doorbell overflow recovery mechanism in case of doorbell overflow (Manish Chopra) [1663274]
- [netdrv] qed: Add doorbell overflow recovery mechanism (Manish Chopra) [1663274]
- [netdrv] qede - Add a statistic for a case where driver drops tx packet due to memory allocation failure. (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "attnetion" -> "attention" (Manish Chopra) [1663274]
- [netdrv] qed: Add support for MBI upgrade over MFW. (Manish Chopra) [1663274]
- [netdrv] qede: Update link status only when interface is ready. (Manish Chopra) [1663274]
- [netdrv] qede: Simplify the usage of qede-flags. (Manish Chopra) [1663274]
- [netdrv] qed: Display port_id in the UFP debug messages. (Manish Chopra) [1663274]
- [netdrv] qed: Fix QM getters to always return a valid pq (Manish Chopra) [1663274]
- [netdrv] qed: Fix bitmap_weight() check (Manish Chopra) [1663274]
- [netdrv] drivers/net/ethernet/qlogic/qed/qed_rdma.h: fix typo (Manish Chopra) [1663274]
- [netdrv] qed: Fix reading wrong value in loop condition (Manish Chopra) [1663274]
- [netdrv] qed: Fix rdma_info structure allocation (Manish Chopra) [1663274]
- [netdrv] qed: Fix overriding offload_tc by protocols without APP TLV (Manish Chopra) [1663274]
- [netdrv] qed: Fix PTT leak in qed_drain() (Manish Chopra) [1663274]
- [netdrv] qed: Fix potential memory corruption (Manish Chopra) [1663274]
- [netdrv] qed: Fix SPQ entries not returned to pool in error flows (Manish Chopra) [1663274]
- [netdrv] qed: Fix blocking/unlimited SPQ entries leak (Manish Chopra) [1663274]
- [netdrv] qed: Fix memory/entry leak in qed_init_sp_request() (Manish Chopra) [1663274]
- [netdrv] qed: fix link config error handling (Manish Chopra) [1663274]
- [netdrv] qed: Fix static checker warning (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "transcevier" -> "transceiver" (Manish Chopra) [1663274]
- [netdrv] qed: Prevent link getting down in case of autoneg-off. (Manish Chopra) [1663274]
- [netdrv] qede: Check available link modes before link set from ethtool. (Manish Chopra) [1663274]
- [netdrv] qed: Add supported link and advertise link to display in ethtool. (Manish Chopra) [1663274]
- [netdrv] qed: Added supported transceiver modes, speed capability and board config to HSI. (Manish Chopra) [1663274]
- [netdrv] qed: Align local and global PTT to propagate through the APIs. (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "Ireelevant" -> "Irrelevant" (Manish Chopra) [1663274]
- [netdrv] qed: Avoid implicit enum conversion in qed_ooo_submit_tx_buffers (Manish Chopra) [1663274]
- [infiniband] RDMA/qedr: Remove enumerated type qed_roce_ll2_tx_dest (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "b_cb_registred" -> "b_cb_registered" (Manish Chopra) [1663274]
- [netdrv] qed: Remove set but not used variable 'p_archipelago' (Manish Chopra) [1663274]
- [netdrv] qed: Avoid implicit enum conversion in qed_iwarp_parse_rx_pkt (Manish Chopra) [1663274]
- [netdrv] qed: Avoid constant logical operation warning in qed_vf_pf_acquire (Manish Chopra) [1663274]
- [netdrv] qed: Avoid implicit enum conversion in qed_roce_mode_to_flavor (Manish Chopra) [1663274]
- [netdrv] qed: Fix mask parameter in qed_vf_prep_tunn_req_tlv (Manish Chopra) [1663274]
- [netdrv] qed: Avoid implicit enum conversion in qed_set_tunn_cls_info (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "toogle" -> "toggle" (Manish Chopra) [1663274]
- [netdrv] net: qed: list usage cleanup (Manish Chopra) [1663274]
- [netdrv] net: qede: Use FIELD_SIZEOF directly instead of reimplementing its function (Manish Chopra) [1663274]
- [netdrv] qed: remove duplicated include from qed_cxt.c (Manish Chopra) [1663274]
- [netdrv] qed*: Utilize FW 8.37.7.0 (Manish Chopra) [1663274]
- [infiniband] RDMA/qedr: remove set but not used variable 'ctx' (Manish Chopra) [1663274]
- [netdrv] qed: Lower the severity of a dcbx log message. (Manish Chopra) [1663274]
- [netdrv] qed: fix spelling mistake "comparsion" -> "comparison" (Manish Chopra) [1663274]
- [netdrv] net_sched: remove list_head from tc_action (Manish Chopra) [1663274]
- [infiniband] qedr: Add user space support for SRQ (Manish Chopra) [1663274]
- [infiniband] qedr: Add support for kernel mode SRQ's (Manish Chopra) [1663274]
- [infiniband] qedr: Add wrapping generic structure for qpidr and adjust idr routines. (Manish Chopra) [1663274]
- [netdrv] qed/qede: qede_setup_tc() can be static (Manish Chopra) [1663274]
- [netdrv] qede: Ingress tc flower offload (drop action) support. (Manish Chopra) [1663274]
- [netdrv] qede: Add destination ip based flow profile. (Manish Chopra) [1663274]
- [netdrv] qed/qede: Multi CoS support. (Manish Chopra) [1663274]
- [netdrv] qede: qede_fp: Mark expected switch fall-through (Manish Chopra) [1663274]
- [netdrv] qed: qed_dev: Mark expected switch fall-throughs (Manish Chopra) [1663274]
- [netdrv] qed: Add Multi-TC RoCE support (Manish Chopra) [1663274]
- [netdrv] qed: Add DCBX API - qed_dcbx_get_priority_tc() (Manish Chopra) [1663274]
- [netdrv] qed: Make some functions static (Manish Chopra) [1663274]
- [netdrv] qed: remove redundant functions qed_get_cm_pq_idx_rl (Manish Chopra) [1663274]
- [netdrv] qed: remove redundant functions qed_set_gft_event_id_cm_hdr (Manish Chopra) [1663274]
- [netdrv] qede: Add driver callbacks for eeprom module query. (Manish Chopra) [1663274]
- [netdrv] qed: Add qed APIs for PHY module query. (Manish Chopra) [1663274]
- [netdrv] qed: remove redundant pointer 'name' (Manish Chopra) [1663274]
- [iommu] iommu: Don't print warning when IOMMU driver only supports unmanaged domains (Jerry Snitselaar) [1707616 1694210 1689183]
- [iommu] iommu/vt-d: Check capability before disabling protected memory (Jerry Snitselaar) [1694210]
- [iommu] iommu/amd: fix sg->dma_address for sg->offset bigger than PAGE_SIZE (Jerry Snitselaar) [1694210 1694029]
- [iommu] iommu/amd: Fix NULL dereference bug in match_hid_uid (Jerry Snitselaar) [1677737 1694210]
- [iommu] iommu/vt-d: Fix NULL pointer reference in intel_svm_bind_mm() (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Remove unnecessary WARN_ON() (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Check identity map for hot-added devices (Jerry Snitselaar) [1694210]
- [iommu] iommu/dmar: Fix buffer overflow during PCI bus notification (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Fix memory leak in intel_iommu_put_resv_regions() (Jerry Snitselaar) [1694210]
- [iommu] iommu/amd: Fix amd_iommu=force_isolation (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Handle domain agaw being less than iommu agaw (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Use memunmap to free memremap (Jerry Snitselaar) [1694210]
- [iommu] amd/iommu: Fix Guest Virtual APIC Log Tail Address Register (Jerry Snitselaar) [1694210]
- [iommu] iommu/vt-d: Fix NULL pointer dereference in prq_event_thread() (Jerry Snitselaar) [1694210]
- [iommu] iommu/amd: Return devid as alias for ACPI HID devices (Jerry Snitselaar) [1694210]
- [iommu] iommu/rockchip: Free irqs in shutdown handler (Jerry Snitselaar) [1694210]
- [iommu] iommu/rockchip: Move irq request past pm_runtime_enable (Jerry Snitselaar) [1694210]
- [iommu] iommu/rockchip: Handle errors returned from PM framework (Jerry Snitselaar) [1694210]
- [iommu] iommu/amd: make sure TLB to be flushed before IOVA freed (Jerry Snitselaar) [1694210]
- [idle] intel_idle: Get rid of custom ICPU() macro (Alexander Beregalov) [1710976]
- [security] selinux: do not report error on connect(AF_UNSPEC) (Ondrej Mosnacek) [1707828]
- [security] selinux: Check address length before reading address family (Ondrej Mosnacek) [1707828]
- [scsi] scsi: core: add new RDAC LENOVO/DE_Series device (Maurizio Lombardi) [1700912]
- [infiniband] i40iw: Avoid panic when handling the inetdev event (Stefan Assmann) [1659180]
- [infiniband] cross-tree: phase out dma_zalloc_coherent() (Stefan Assmann) [1659180]
- [infiniband] infiniband: prefix header search paths with $(srctree)/ (Stefan Assmann) [1659180]
- [infiniband] i40iw: remove use of VLAN_TAG_PRESENT (Stefan Assmann) [1659180]
- [infiniband] RDMA/i40iw: Fix incorrect iterator type (Stefan Assmann) [1659180]
- [infiniband] infiniband: i40iw, nes: don't use wall time for TCP sequence numbers (Stefan Assmann) [1659180]
- [infiniband] i40iw: Reorganize acquire/release of locks in i40iw_manage_apbvt (Stefan Assmann) [1659180]
- [netdrv] i40e: Changed maximum supported FW API version to 1.8 (Stefan Assmann) [1659174]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Stefan Assmann) [1659174]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Stefan Assmann) [1659174]
- [netdrv] intel-ethernet: software timestamp skbs as late as possible (Stefan Assmann) [1659174]
- [netdrv] drivers: net: remove <net/busy_poll.h> inclusion when not needed (Stefan Assmann) [1659174]
- [netdrv] i40e: Memory leak in i40e_config_iwarp_qvlist (Stefan Assmann) [1659162]
- [netdrv] i40e: Fix of memory leak and integer truncation in i40e_virtchnl.c (Stefan Assmann) [1659162]
- [netdrv] i40e: Use struct_size() in kzalloc() (Stefan Assmann) [1659162]
- [netdrv] i40e: Revert ShadowRAM checksum calculation change (Stefan Assmann) [1659162]
- [netdrv] i40e: missing input validation on VF message handling by the PF (Stefan Assmann) [1659162]
- [netdrv] i40e: Add support for X710 B/P & SFP+ cards (Stefan Assmann) [1659162]
- [netdrv] i40e: Wrong truncation from u16 to u8 (Stefan Assmann) [1659162]
- [netdrv] i40e: add num_vectors checker in iwarp handler (Stefan Assmann) [1659162]
- [netdrv] i40e: Fix the typo in adding 40GE KR4 mode (Stefan Assmann) [1659162]
- [netdrv] i40e: Setting VF to VLAN 0 requires restart (Stefan Assmann) [1659162]
- [netdrv] i40e: add new pci id for X710/XXV710 N3000 cards (Stefan Assmann) [1659162]
- [netdrv] i40e: VF's promiscuous attribute is not kept (Stefan Assmann) [1659162]
- [netdrv] i40e: Introduce recovery mode support (Stefan Assmann) [1659162]
- [netdrv] i40e: print PCI vendor and device ID during probe (Stefan Assmann) [1659162]
- [netdrv] i40e: fix misleading message about promisc setting on un-trusted VF (Stefan Assmann) [1659162]
- [netdrv] i40e: update version number (Stefan Assmann) [1659162]
- [netdrv] i40e: remove out-of-range comparisons in i40e_validate_cloud_filter (Stefan Assmann) [1659162]
- [netdrv] i40e: Further implementation of LLDP (Stefan Assmann) [1659162]
- [netdrv] i40e: Report advertised link modes on 40GBase_LR4, CR4 and fibre (Stefan Assmann) [1659162]
- [netdrv] i40e: ShadowRAM checksum calculation change (Stefan Assmann) [1659162]
- [netdrv] i40e: remove error msg when vf with port vlan tries to remove vlan 0 (Stefan Assmann) [1659162]
- [netdrv] i40e: change behavior on PF in response to MDD event (Stefan Assmann) [1659162]
- [netdrv] i40e: Fix for allowing too many MDD events on VF (Stefan Assmann) [1659162]
- [netdrv] i40e: Fix misleading error message (Stefan Assmann) [1659162]
- [netdrv] i40e: Able to add up to 16 MAC filters on an untrusted VF (Stefan Assmann) [1659162]
- [netdrv] i40e: Report advertised link modes on 40GBASE_SR4 (Stefan Assmann) [1659162]
- [netdrv] i40e: The driver now prints the API version in error message (Stefan Assmann) [1659162]
- [netdrv] i40e: Changed maximum supported FW API version to 1.8 (Stefan Assmann) [1659162]
- [netdrv] i40e: Remove misleading messages for untrusted VF (Stefan Assmann) [1659162]
- [netdrv] i40e: Update i40e_init_dcb to return correct error (Stefan Assmann) [1659162]
- [netdrv] i40e: Fix for 10G ports LED not blinking (Stefan Assmann) [1659162]
- [netdrv] i40e: save PTP time before a device reset (Stefan Assmann) [1659162]
- [netdrv] i40e: don't allow changes to HW VLAN stripping on active port VLANs (Stefan Assmann) [1659162]
- [netdrv] i40e: Implement DDP support in i40e driver (Stefan Assmann) [1659162]
- [netdrv] i40e: Queues are reserved despite "Invalid argument" error (Stefan Assmann) [1659162]
- [netdrv] i40e: add tracking of AF_XDP ZC state for each queue pair (Stefan Assmann) [1659162]
- [netdrv] i40e: move i40e_xsk_umem function (Stefan Assmann) [1659162]
- [netdrv] i40e: fix WoL support check (Stefan Assmann) [1659162]
- [netdrv] i40e: fix i40e_ptp_adjtime when given a negative delta (Stefan Assmann) [1659162]
- [netdrv] i40e: fix XDP_REDIRECT/XDP xmit ring cleanup race (Stefan Assmann) [1659162]
- [netdrv] i40e: fix potential RX buffer starvation for AF_XDP (Stefan Assmann) [1659162]
- [netdrv] net: bpf: remove XDP_QUERY_XSK_UMEM enumerator (Stefan Assmann) [1659162]
- [netdrv] flow_offload: add flow_rule and flow_match structures and use them (Stefan Assmann) [1659162]
- [netdrv] i40e: clean up several indentation issues (Stefan Assmann) [1659162]
- [netdrv] i40e: increase indentation (Stefan Assmann) [1659162]
- [netdrv] i40e: update version number (Stefan Assmann) [1659162]
- [netdrv] i40e: remove debugfs tx_timeout support (Stefan Assmann) [1659162]
- [netdrv] i40e: check queue pairs num in config queues handler (Stefan Assmann) [1659162]
- [netdrv] i40e: Change unmatched function types (Stefan Assmann) [1659162]
- [netdrv] i40e: Add support FEC configuration for Fortville 25G (Stefan Assmann) [1659162]
- [netdrv] i40e: Limiting RSS queues to CPUs (Stefan Assmann) [1659162]
- [netdrv] i40e: Remove umem from VSI (Stefan Assmann) [1659162]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (Stefan Assmann) [1659162]
- [netdrv] i40e: extend PTP gettime function to read system clock (Stefan Assmann) [1659162]
- [netdrv] i40e: DRY rx_ptype handling code (Stefan Assmann) [1659162]
- [netdrv] i40e: fix kerneldoc for xsk methods (Stefan Assmann) [1659162]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Stefan Assmann) [1659162]
- [netdrv] i40e: suppress bogus error message (Stefan Assmann) [1659162]
- [netdrv] i40e: Allow disabling FW LLDP on X722 devices (Stefan Assmann) [1659162]
- [netdrv] i40e: update driver version (Stefan Assmann) [1659162]
- [netdrv] i40e: Protect access to VF control methods (Stefan Assmann) [1659162]
- [netdrv] i40e: Replace strncpy with strlcpy to ensure null termination (Stefan Assmann) [1659162]
- [netdrv] i40e: Add capability flag for stopping FW LLDP (Stefan Assmann) [1659162]
- [netdrv] i40e: Use a local variable for readability (Stefan Assmann) [1659162]
- [netdrv] i40e: Replace spin_is_locked() with lockdep (Stefan Assmann) [1659162]
- [netdrv] i40e/ixgbe/igb: fail on new WoL flag setting WAKE_MAGICSECURE (Stefan Assmann) [1659162]
- [netdrv] intel-ethernet: software timestamp skbs as late as possible (Stefan Assmann) [1659162]
- [netdrv] drivers: net: remove <net/busy_poll.h> inclusion when not needed (Stefan Assmann) [1659162]
- [netdrv] i40e: Remove unnecessary print statement (Stefan Assmann) [1659162]
- [netdrv] i40e: Use proper enum in i40e_ndo_set_vf_link_state (Stefan Assmann) [1659162]
- [nvme] nvmet: ignore EOPNOTSUPP for discard (Ewan Milne) [1696369]
- [tools] tools: bpftool: fix potential NULL pointer dereference in do_load (Ivan Vecera) [1708560]
- [tools] tools lib bpf: Provide wrapper for strerror_r to build in !_GNU_SOURCE systems (Ivan Vecera) [1708560]
- [tools] libbpf: Remove the duplicate checking of function storage (Ivan Vecera) [1708560]
- [tools] bpf: fix build error in libbpf with EXTRA_CFLAGS="-Wp, -D_FORTIFY_SOURCE=2 -O2" (Ivan Vecera) [1708560]
- [tools] tools: include reallocarray feature test in FEATURE_TESTS_BASIC (Ivan Vecera) [1708560]
- [tools] tools: bpftool: allow reuse of maps with bpftool prog load (Ivan Vecera) [1708560]
- [tools] tools: libbpf: allow map reuse (Ivan Vecera) [1708560]
- [tools] tools: bpf: make use of reallocarray (Ivan Vecera) [1708560]
- [tools] tools: libbpf: move library error code into a separate file (Ivan Vecera) [1708560]
- [tools] tools: bpftool: reimplement bpf_prog_load() for prog load (Ivan Vecera) [1708560]
- [tools] tools: libbpf: add extended attributes version of bpf_object__open() (Ivan Vecera) [1708560]
- [tools] tools: libbpf: recognize offload neutral maps (Ivan Vecera) [1708560]
- [tools] tools: bpftool: allow users to specify program type for prog load (Ivan Vecera) [1708560]
- [tools] tools: libbpf: expose the prog type guessing from section name logic (Ivan Vecera) [1708560]
- [tools] tools: bpftool: add support for loading programs for offload (Ivan Vecera) [1708560]
- [tools] tools: bpftool: refactor argument parsing for prog load (Ivan Vecera) [1708560]
- [tools] selftests/bpf: add Error: prefix in check_extack helper (Ivan Vecera) [1708560]
- [tools] selftests/bpf: remove duplicated word from test offloads (Ivan Vecera) [1708560]
- [tools] tools: bpftool: deal with options upfront (Ivan Vecera) [1708560]
- [tools] tools: bpftool: add missing --bpffs to completions (Ivan Vecera) [1708560]
- [tools] tools: bpftool: drop unnecessary Author comments (Ivan Vecera) [1708560]
- [tools] tools: libbpf: don't return '.text' as a program for multi-function programs (Ivan Vecera) [1708560]
- [tools] tools: libbpf: restore the ability to load programs from .text section (Ivan Vecera) [1708560]
- [tools] tools: libbpf: allow setting ifindex for programs and maps (Ivan Vecera) [1708560]
- [tools] tools: libbpf: add section names for missing program types (Ivan Vecera) [1708560]
- [tools] tools: bpftool: use correct make variable type to improve compilation time (Ivan Vecera) [1708560]
- [scsi] scsi: lpfc: nvme: avoid hang / use-after-free when destroying localport (Dick Kennedy) [1588024]

* Thu May 30 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-98.rt16.38.el8]
- [rt] kernel-rt-4.18.0-98.rt16.37.el8 (Juri Lelli) [1678887]
- [xen] ALSA: xen: Introduce shared buffer helpers for page directory... (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Initialize completion for defer messages (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: intel: constify snd_soc_dai_ops structures (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: intel: Remove duplicate assignment (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: intel: Fix uninitialized adev deref (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: intel: Add pre/post bank switch ops (Jaroslav Kysela) [1683051]
- [include] ALSA: soundwire: keep track of Masters in a stream (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Add support for multi link bank switch (Jaroslav Kysela) [1683051]
- [include] ALSA: soundwire: Handle multiple master instances in a stream (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Add support to lock across bus instances (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Fix acquiring bus lock twice during master release (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Fix incorrect exit after configuring stream (Jaroslav Kysela) [1683051]
- [drivers] ALSA: soundwire: Fix duplicate stream state assignment (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix for Lenovo B50-70 inverted internal microphone bug (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix race between creating and refreshing sysfs entries (Jaroslav Kysela) [1683051]
- [include] ALSA: ASoC: uapi: fix sound/skl-tplg-interface.h userspace compilation errors (Jaroslav Kysela) [1683051]
- [include] ALSA: uapi: #include <time.h> in asound.h (Jaroslav Kysela) [1683051]
- [include] ALSA: timer: fix wrong comment to refer to 'SNDRV_TIMER_PSFLG_*' (Jaroslav Kysela) [1683051]
- [sound] ALSA: x86/cpu: Sanitize FAM6_ATOM naming (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: don't select DPCM via simple-audio-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: don't select DPCM via audio-graph-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Corrected fixup for System76 Gazelle (gaze14) (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Avoid superfluous COEF EAPD setups (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fixup headphone noise via runtime suspend (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Fix unused variable warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: line6: toneport: Fix broken usage of timer for delayed execution (Jaroslav Kysela) [1683051]
- [sound] ALSA: aica: Fix a long-time build breakage (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Support low power consumption for ALC256 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: update pcm hardware constraints (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codec: hdac_hdmi: no checking monitor in hw_params (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt6358: save PGA for mixer control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt6358: save output volume for mixer controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt6358: initialize setting when ramping volume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: core: fix undefined nocodec reference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: xtensa: fix undefined references (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Propagate sof_get_ctrl_copy_params() error properly (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdea/realtek - Headset fixup for System76 Gazelle (gaze14) (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/intel: add CometLake PCI IDs (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Support low power consumption for ALC295 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: Fix an uninitialized variable compile warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Fix a compile warning with CONFIG_PCI=n (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Fix a compile warning at CONFIG_COMMON_CLK=n (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sound/soc/sof/: fix kconfig dependency warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: spdifrx: change trace level on iec control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: spdifrx: update pcm hardware constraints (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98090: Fix restore of DAPM Muxes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: RT5677-SPI: Disable 16Bit SPI Transfers (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi - Consider eld_valid when reporting jack event (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi - Read the pin sense from register when repolling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Add reserved DMA memory support (Jaroslav Kysela) [1683051]
- [sound] ALSA: synth: emux: soundfont.c: divide by zero in calc_gus_envelope_time() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98357a: Map BTN_0 to KEY_PLAYPAUSE (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: add sof-rt5682 machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: skl_hda_dsp_generic:refine code style (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: skl_hda_dsp_generic: add DMIC support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: CNL: add ipc dump function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: APL: add ipc dump function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: IPC: add ipc dump function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: intel: hda: add hw_params_upon_resume flag for hda stream (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda-stream: handle real stream interrupts only (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda-stream: store stream capabilities (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda-ipc: simplify handling of IPC IRQ (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: ipc: use snd_sof_pcm_period_elapsed (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: use snd_sof_pcm_period_elapsed (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: PCM: add period_elapsed work to fix race condition in interrupt context (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda-pcm: remove useless dependency on hdac_ext (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda: set bus->idx as 0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda: set I2S slave before enabling DSP (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda: add SSP info to the chip info struct (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: hda: add the SSP Host Device memory space (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: cnl: add pointer ops to use DPIB position (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: topology: add support for stricter ABI checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASOC: SOF: ipc: add support for stricter ABI checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: add Kconfig option for strict ABI checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: avoid Oops if DMA setup fails (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: stream is already locked in hw_params (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: remove redundant null checks of dai (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: skip hw_free on codec dai for which the stream is invalid (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fix valid stream condition (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: unlock the device on startup errors (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Update the support rate list (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Use clk_round_rate to handle enabled bclk/wclk case (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5645: Headphone Jack sense inverts on the LattePanda board (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_esai: Fix missing break in switch statement (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Correct region base typo in wm_halo_setup_algs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: fix spelling mistake "incompatble" -> "incompatible" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Use DSP ops pointers to stop watchdog in error handlers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Fix to use list_for_each_entry_safe() when delete items (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Fix return value check in sprd_mcdt_probe() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7213: fix DAI_CLK_EN register bit overwrite (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: fix kcontrols for effect widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_audmix: cache pdev->dev pointer (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Fix potential uninitialized variable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: add I2S2 control path from UL2 and UL3 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: change supported formats of DL2 and UL1 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_audmix: remove "model" attribute (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-audmix: fix object reference leaks in probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs43130: fix a NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5645: fix a NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add Geminilake Realtek+Maxim machine driver entry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Make boards more available for compile test (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc5200_dma: Fix invalid license ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc5200_psc_i2s: Fix invalid license ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atmel: tse850: Make some functions static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx: fix fiq dependencies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: acp3x: Make acp3x_dai_i2s_ops static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Remove set but not used variable 'mclk_rate' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_micfil: Remove set but not used variable 'osr' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: Enable TDM support for DSP_A/B modes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Configure wclk and bclk of master codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Fix build err while CONFIG_I2C set to module (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: fix spelling mistake "plalform" -> "platform" (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Apply the fixup for ASUS Q325UAR (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Register irq handler after the chip initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: usx2y: fix a double free bug (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hda: overwrite hdev type to HDA_DEV_ASOC (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: fix unregister device twice on ASoC driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: line6: use dynamic buffers (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix a memory leak bug (Jaroslav Kysela) [1683051]
- [sound] ALSA: gus: fix misuse of x (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - EAPD turn on later (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fixed Dell AIO speaker noise (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: select relevant machine drivers for SOF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Make sure BDW based machine drivers build for SOF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add Build support for SOF core and Intel drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Kconfig: expose common option between SST and SOF drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add platform differentiation for APL and CNL (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: add SKL+ platform DAIs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add support for HDAudio codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA trace operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA stream operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add hda-bus support and initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA PCM operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA firmware loader (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add PCI device support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add ACPI device support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA IPC mechanisms. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add Intel specific HDA DSP HW operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add HDA controller for Intel DSP (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add APL/CNL HW DSP support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add legacy IPC support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add BDW HW DSP support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Intel: Add BYT, CHT and BSW DSP HW support. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add utils (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add xtensa support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add Nocodec machine driver support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add PM support (Jaroslav Kysela) [1683051]
- [include] ALSA: ASoC: SOF: Add userspace ABI support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add firmware loader support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add DSP HW abstraction operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add DSP firmware logger support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add support for loading topologies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add PCM operations support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add support for IPC IO between DSP and Host (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add driver debug support. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add Sound Open Firmware KControl support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: SOF: Add Sound Open Firmware driver core (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: simplify dai driver initialisation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: Read pin switches conf from devicetree (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_sai: Add missing return 0 in remove() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: add asoc_simple_parse_pin_switches() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: btcvsd fix irq mask (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: align quirk override handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: align quirk override handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: fix compilation warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_sai: Add support for runtime pm (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_sai: Update is_slave_mode with correct value (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Add Spreadtrum multi-channel data transfer support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: rt5682: initialize mutex before using (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: return the get_irq error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup 6ch settings to 8ch (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Handle the error from snd_usb_mixer_apply_create_quirk() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add new Dell platform for headset mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codec: hdac_hdmi add device_link to card device (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Haswell: Remove set but not used variable 'stage_type' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm: save fixed-up hw_params of BE (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: tobermory: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: tm2_wm5110: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: speyside: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: spdif: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: snow: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: smdk_wm8994*: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: smdk_wm8580: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: smdk_spdif: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: smartq_wm8987: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: s3c24xx_uda134x: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: s3c24xx_simtec*: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: s3c2412-i2s: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: rx1950_uda1380: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: s3c24xx-i2s: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: s3c-i2s-v2: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: pcm: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: neo1973_wm8753: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: lowland: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: littlemill: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: jive_wm8750: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: idma: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: h1940_uda1380: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: dmaengine: Convert to SPDX License Indentifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: bells: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: arndale: Convert to SPDX License Identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ps3: Remove set but not used variables 'start_vaddr' and 'pcm_index' (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - add two more pin configuration sets to quirk table (Jaroslav Kysela) [1683051]
- [sound] ALSA: core: Don't refer to snd_cards array directly (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: Drop superfluous id-uniquification behavior (Jaroslav Kysela) [1683051]
- [sound] ALSA: core: Fix card races between register and disconnect (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Fix racy addition/deletion of nodes (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Correct unlock sequence at snd_seq_client_ioctl_unlock() (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add quirk for Focusrite Scarlett Solo (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Initialize ext-bus-specific fields in snd_hdac_bus_init(), too (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Initialize power_state field properly (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Protect racy pool manipulation from OSS sequencer (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Simplify snd_seq_kernel_client_enqueue() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Cover unsubscribe_port() in list_mutex (Jaroslav Kysela) [1683051]
- [sound] ALSA: Revert "ALSA: seq: Protect in-kernel ioctl calls with mutex" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: Fix missing regmap requirement (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix racy display power access (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm: fix error handling when try_module_get() fails. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix master clock management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl: fix wrong number of channels (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Coding style fixes (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Simplify error path in snd_timer_open() (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Fix race of get-subscription call vs port-delete ioctls (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Protect in-kernel ioctl calls with mutex (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Remove superfluous irqsave flags (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Align temporary re-locking with irqsave version (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Use kvmalloc() for cell pools (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Revert active callback sync check at close (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add two more machines to the power_save_blacklist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Fix spacing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98927: remove headset (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm: update module refcount if module_get_upon_open is set (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: conditionally increase module refcount on component open (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add quirk for the Teclast X98+ II (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add quirk for inverted jack detect (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm1133-ev1: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: phycore-ac97: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm030-audio-fabric: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: p1022_rdk: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: p1022_ds: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mx27vis-aic32x4: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc8610_hpcd: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc5200_psc_i2s: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc5200_psc_ac97: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mpc5200_dma: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-ssi: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-spdif: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-pcm-fiq: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-mc13783: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-es8328: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-audmux: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl-dma: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: eukrea-tlv320: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-pcm: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: fix sai driver name initialisation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Use the correct dobj to free enum control values and texts (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Fix OOB-reads from strlcpy (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: change mic bias DAPM (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_esai: Support synchronous mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: fix big-endian check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: fix endianness issues (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-tdmout: add g12a support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-tdm-formatter: rework quirks settings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-frddr: add g12a support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-toddr: add g12a support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-fifo: add g12a support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: remove link components before cleaning up card resources (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: skylake: add remove() callback for component driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs35l35: Disable regulators on driver removal (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add adc volume control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add support of master mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add reset management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add regulator management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Avoid calling snd_compr_stop_error from WDT expiry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98357a: add missing supported rates (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Add Playback PowerTune Controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Add Switch for Setting Common Mode Voltage (Jaroslav Kysela) [1683051]
- [sound] ALSA: xen-front: Do not use stream buffer size before it is set (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: Mark RXFIFO_DATA as volatile and precious (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Fix spelling mistake "faied" -> "failed" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: Correct PDM_CTRL0 reg value (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: adjust waterlevel in frame unit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: add compatible for rk1808 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: fixup pdm fractional div (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: optimize clear logic (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: add default regs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: using left justified store mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: change dma burst to 8 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: pdm: fix regmap_ops hang issue (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Update copyright and use SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Fix the smatch warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Fix platform_no_drv_owner.cocci warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Fix platform_no_drv_owner.cocci warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Change author's name (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add quirk for Tuxedo XC 1509 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Move to ACT_INIT state (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Fix modular build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_max98090_ti: Enable codec clock once and keep it enabled (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Fix build error in mt8183_da7219_max98357_dev_probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: TS3A227: fix build error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Make use of local variables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Remove redundant NULL check in wm_adsp_buffer_free (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: aic31xx_set_jack() can be static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Check for buffer in trigger stop (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset MIC of Acer TravelMate B114-21 with ALC233 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: eukrea-tlv320: fix a leaked reference by adding missing of_node_put (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_utils: fix a leaked reference by adding missing of_node_put (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: fix a leaked reference by adding missing of_node_put (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Align tplg pointer increment across all kcontrols (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: support driver alias names for FE topology overrides (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Add Spreadtrum audio compress offload support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fix SND_SOC_LOCHNAGAR_SC kconfig warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: set power_check callback for widgets that shouldnt be always on (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: Add button press detection (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: Add headphone/headset detection (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: skip missing substream while applying symmetry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5672: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5645: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_da7213: Convert to use acpi_dev_get_first_match_dev() (Jaroslav Kysela) [1683051]
- [acpi] ALSA: ACPI / utils: Introduce acpi_dev_get_first_match_dev() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: remove set but not used variable 'dai_name' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es8316: Add support for inverted jack detect (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Fix typo in comment (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: fix spelling mistake: "missign" -> "missing" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Add machine driver with DA7219 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Mediatek: MT8183: Add machine driver with TS3A227 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5677-spi: Add ACPI ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add multi endpoint support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Fix Common Pins (Jaroslav Kysela) [1683051]
- [sound] ALSA: us122l: Use alloc_pages_exact() (Jaroslav Kysela) [1683051]
- [sound] ALSA: Replace snd_malloc_pages() and snd_free_pages() with standard helpers, take#2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Make snd_timer_close() really kill pending actions (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Check ack_list emptiness instead of bit flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Make sure to clear pending ack list (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: Unify timer callback process code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_audmix: Fix kbuild failure (Jaroslav Kysela) [1683051]
- [sound] ALSA: emux: Add support of loading GUS-patch (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix speakers on Acer Predator Helios 500 Ryzen laptops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: Add Audio Mixer machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: Add Audio Mixer CPU DAI driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: enable S24_LE format support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Only enable with common clock (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Allow 192000 Sample Rate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Remove mclk references (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Restructure set_dai_sysclk (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Dynamically Determine Clocking (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Move aosr and dosr setting to separate functions (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Control clock gating with CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Model BDIV divider in CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Model DAC/ADC dividers in CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Model CODEC_CLKIN in CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Model PLL in CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Initialize private_value in snd_soc_dapm_new_dai (Jaroslav Kysela) [1683051]
- [sound] ALSA: aloop: Support S24 sample formats (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Don't suspend stream in unrecoverable PCM state (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Fix NULL pointer dereference in snd_soc_dapm_free_kcontrol (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sirf-audio: Remove redundant of_match_node call (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: add power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Fix incorrect extern (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8810: fix the issue of 64 bits division (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: Fix crash at suspend/resume after failed codec registration (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Simplify alt firmware loading code (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix possible OOB access in PCM oss plugins (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset MIC of ASUS X430UN and X512DK with ALC256 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset mic of ASUS P5440FF with ALC256 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable ASUS X441MB and X705FD headset MIC with ALC256 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: test memory allocation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: lochnagar: Add driver to support Lochnagar 2 sound card (Jaroslav Kysela) [1683051]
- [mfd] ALSA: mfd: lochnagar: Add support for the Cirrus Logic Lochnagar (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Properly Set Processing Blocks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mchp-i2s-mcc: add driver for I2SC Multi-Channel Controller (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: rename asoc_simple_card_xxx() to asoc_simple_() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: separate asoc_simple_card_parse_dai() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_card_init_priv() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_be_hw_params_fixup() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_dai_init() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_hw_param() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_shutdown() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: share asoc_simple_startup() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple_card_utils: share common priv for simple-card/audio-graph (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: add asoc_simple_debug_info() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Update DA7219 DAI clock name to align with codec updates (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Expose BCLK and WCLK control through CCF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_esai: fix channel swap issue when stream starts (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_asrc: add constraint for the asrc of older version (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4270: Set auto-increment bit for register writes (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add support for Acer Aspire E5-523G/ES1-432 headset mic (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset MIC of Acer Aspire Z24-890 with ALC286 (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: oss: Fix Spectre v1 vulnerability (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Fix potential Spectre v1 vulnerability (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset MIC of Acer AIO with ALC286 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: dfsdm: add mmap support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: dfsdm: fix debugfs warnings on entry creation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: dfsdm: manage multiple prepare (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Correct some minor issues (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Don't use register read to determine slave/master mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Break out clock setting into separate function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: jz4740: Depend on MIPS instead of MACH_JZ4740 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Add WDT expiry IRQ handling support for Halo core (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Add HALO MPU fault logging (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Add support for new Halo core DSPs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: Reduce repititive code on mtk_regmap_update_bits. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: Fix UBSAN warning. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Factor out DSP specific operations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Factor out parsing of firmware ID header (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Refactor firmware status reading (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Move wm_adsp2_set_dspclk to CODEC drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Don't export wm_adsp2_lock (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Shutdown any compressed streams on DSP watchdog timeout (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Add locking to wm_adsp2_bus_error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Correct handling of compressed streams that restart (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: free link string in error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: free stream_name of dai_drv (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Enforces runtime_resume after S3 and S4 for each codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Don't trigger jackpoll_work in azx_resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph: add graph_parse_mclk_fs() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph: rename graph_get_conversion() to graph_parse_convert() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: add simple_parse_mclk_fs() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: rename simple_get_conversion() to simple_parse_convert() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: recording has no sound after booting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: fix jack type detection issue (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Check JD status when system resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt8183: skip for i2s5 in mck_disable (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: use 8 byte header for IR context to get isochronous cycle (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: add support MOTU 8pre FireWire (Jaroslav Kysela) [1683051]
- [sound] ALSA: opl3: fix mismatch between snd_opl3_drum_switch definition and declaration (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - add Lenovo IdeaCentre B550 to the power_save_blacklist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add BYT_RT5651_JD_NOT_INV quirk (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Add support for active-high jack detect (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: spdifrx: add power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-amplifier: Make gpio property optional (Jaroslav Kysela) [1683051]
- [documentation] ALSA: ASoC: dt-bindings: add regulator property to simple amplifier (Jaroslav Kysela) [1683051]
- [documentation] ALSA: ASoC: simple-amplifier: remame dio2125 documentation (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: use 'version' field of unit directory to identify model (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb8: add a check for request_region (Jaroslav Kysela) [1683051]
- [sound] ALSA: echoaudio: add a check for ioremap_nocache (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: create tlv before soc_tplg_init_kcontrol (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add support headset mode for New DELL WYSE NB (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add support headset mode for DELL WYSE AIO (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: merge alc_fixup_headset_jack to alc295_fixup_chromebook (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: hdmi - add Icelake support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8810: automatic selecting BCLK in I2S master mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8810: fix the typo of function name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8810: use 64-bit arithmetic instead of 32-bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Fix clock configuration for 44100 sample rate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8810: fix the issue of widget with prefixed name (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - add more quirks for HP Z2 G4 and HP Z240 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fixed Headset Mic JD not stable (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable headset MIC of Acer TravelMate X514-51T with ALC255 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: avoid build error without CONFIG_PM (Jaroslav Kysela) [1683051]
- [sound] ALSA: usx2y: Fix potential NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Avoid NULL pointer dereference at snd_hdac_stream_start() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: axi-i2s: let both capture and playback be optional (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: src: Avoid a potential deadlock (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix registers declaration in regmap (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8824: fix the issue of the widget with prefix name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: prevent snd_soc_dpcm use after free (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC:intel:skl:fix a simultaneous playback & capture issue on hda platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC:hdac_hda:use correct format to setup hda codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC:soc-pcm:fix a codec fixup issue in TDM case (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: fix davinci_mcasp_probe dependencies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ams-delta: remove duplicate 'const' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: remove compat dma probing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: use default dai name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: improve channel capabilities handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: change trigger traces (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: add i2c dependency for SND_SOC_SDM845 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-mcasp: Fix clang warning without CONFIG_PM (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: src: fix compiler warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Fix DAPM routes for capture stream (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: Fix probe deferral following prelink failure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: avoid limiting params->msbits in hw_params() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix set_sync service (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix oversampling mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix race condition in irq handler (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix exposed capabilities in spdif mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix iec958 controls indexation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ab8500: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: fix S/PDIF DAI (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add quirk for MOTU MicroBook II (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: btcvsd add loopback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic3x: fix reset gpio reference counting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: skip useless write in slave mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix race condition in irq handler (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: remove useless callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix dma configuration (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix stream count management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix 16 bit format support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: fix IRQ clearing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Kconfig: fix dependency for sdm845 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Boards: Add Maxim98373 support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: gen: fix SSI9 4/5/6/7 busif related register address (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: fix construction of PCM frame for capture direction (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob: use more identical mod_alias for Saffire Pro 10 I/O against Liquid Saffire 56 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Extend i915 component bind timeout (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Improve logging messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Add support for multiple compressed buffers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Refactor compress stream initialisation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Reorder some functions for improved clarity (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Factor out stripping padding from ADSP data (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs35l36: Fix an IS_ERR() vs NULL checking bug (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: sound card name from device tree (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable audio jacks of ASUS UX362FA with ALC294 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Prevent uninitialized variable use (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Fix of-node refcount unbalance in qcom_snd_parse_of() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Fix of-node refcount unbalance in apq8016_sbc_parse_of() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Fix of_node refcount unbalance (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Reduce click noise on Dell Precision 5820 headphone (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: Fix of-node refcount unbalance in DAI-link parser (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: Fix of-node refcount unbalance in fsl_ssi_probe_from_dt() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Allow compressed buffers in any memory region (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Update cached error state on trigger (Jaroslav Kysela) [1683051]
- [sound] ALSA: ppc: Fix of-node refcount unbalance (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Fix of-node refcount unbalance (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: Fix of-node refcount unbalance (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: pcm186x: Fix energysense SLEEP bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: pcm186x: fix wrong usage of DECLARE_TLV_DB_SCALE() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Fix multiple "IIS multi" devices initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Fix secondary platform device unregistration (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: glk: Add DAI links for Multi-Playback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Add Geminilake Dialog Maxim machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Headset button support in broxton machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sunxi: sun50i-codec-analog: Rename hpvcc regulator supply to cpvdd (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adau1977: Add support for setting MICBIAS via DT (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Potential small memory leak in dapm_cnew_widget() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Add missing DAPM routes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8741: Make function 'wm8741_mute' static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_esai: fix register setting issue in RIGHT_J mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: SoC: imx-sgtl5000: add missing put_device() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: Fix missing of_node_put() at simple_dai_link_of() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: Fix refcount underflow (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Ensure proper sample rate on pri/sec PCM (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: remove set but not used variables 'mask, cr1' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: free created components in tplg load error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs35l36: Make some symbols static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Kconfig: select dmic for sdm845 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_spdif: fix sysclk_df type (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_spdif: fix TXCLK_DF mask (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ad193x: Add support to disable on-chip PLL (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ad193x: Add runtime support for DSP_A and I2S modes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ad193x: Fix frame polarity for DSP_A format (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ad193x: Set constraint to always have 32 sample bits (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ad193x: Remove capture support for codecs without ADC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsi: fix spelling mistake "doens't" -> "doesn't" (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Expose sample resolution through proc interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Prevent potential NULL platform data dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Remove unused SND_DMAENGINE_PCM_FLAG_CUSTOM_CHANNEL_NAME flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Update TDM usage to be more flexible (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Add support for master mode BCLK rate adjustment (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Convert to SPDX License Indentifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Comments clean up (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Change indentation in SAMSUNG_I2S_FMTS definition (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Simplify pri_dai, sec_dai pointers usage (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: add missing put_device() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: Specify DMA channel names through custom DMA config (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: odroid: Add support for secondary CPU DAI (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Get rid of a static spinlock (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move quirks data to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move IP variant data to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Drop spinlock pointer from i2s_dai data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move SFR pointer to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: es1688: Remove set but not used variable 'hw' (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Disable PC beep in passthrough on alc285 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Headset microphone and internal speaker support for System76 oryp5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cros_ec_codec: Make symbol 'cros_ec_dai' static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt8183: make some functions static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs35l36: Remove unused including <linux/version.h> (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move registers cache to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move opclk data to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move core clk to the driver common data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Add widgets and routes for DPCM support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Move clk supplier data to common driver data structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Restore support for the secondary PCM (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Comment why read blocks when PCM is not running (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-acpi: remove new_mach_data field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-acpi: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: cnl-match.c: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: icl-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: hsw-bdw-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: glk-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: cht-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: byt-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: soc-acpi: bxt-match: remove asoc_plat_name field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: icl-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: hsw-bdw-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: hda-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: glk-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cnl-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: byt-match.c: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bxt-match: remove prefix for SOF files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Convert to single component with multiple DAIs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: dmaengine: Allow to specify custom DMA device (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Extend use of chan_names provided in custom DMA config (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Improve of_node test in dmaengine_pcm_request_chan_of() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Fix prescaler setting for the secondary DAI (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Use __printf markup to silence compiler (Jaroslav Kysela) [1683051]
- [sound] ALSA: tlv320aic32x4: delay i2c access by 1 ms after hardware reset (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: btcvsd fix rx stream assign (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8741: Set OSR mode in hw_params() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8741: Add digital mute callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: PCM: check if ops are defined before suspending PCM (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hdmi: use devm_kzalloc for all structures (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: use pOFn instead of device_node.name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Add clock select (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Add soft reset on probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: set .ignore_module_refcount field in component (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: don't increase component module refcount unconditionally (Jaroslav Kysela) [1683051]
- [sound] ALSA: gpiolib: acpi: Introduce ACPI_GPIO_QUIRK_ONLY_GPIOIO (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: msm8916-wcd-digital: convert license header to SPDX (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: msm8916-wcd-analog: add missing license information (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: regulator notifier registration should be managed (Jaroslav Kysela) [1683051]
- [sound] ALSA: i915/snd_hdac: I915 subcomponent for the snd_hdac (Jaroslav Kysela) [1683051]
- [base] ALSA: components: multiple components for a device (Jaroslav Kysela) [1683051]
- [documentation] ALSA: component: Add documentation (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Revert capture stream behavior change in blocking mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix function name in kernel-doc comment (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Define snd_pcm_lib_preallocate_*() as returning void (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: fix up for snd_pcm_lib_preallocate_pages_for_all() API change (Jaroslav Kysela) [1683051]
- [sound] ALSA: SoC: stm32: i2s: manage clock power (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: i2s: add power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: jz4725b: Remove unnecessary const qualifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs35l36: Add support for Cirrus CS35L36 Amplifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix implicit fb endpoint setup by quirk (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add quirk for HP EliteBook 840 G5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: jz4725b: Use C++ style comments in header (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: Kconfig: Show knob, and depend on MIPS || COMPILE_TEST (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: jz4740: Add support for devicetree (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: jz4740: Use SPDX license notifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: Prevent clk_get_rate() calls in atomic context (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add Line Playback Volume, Line Boost Volume, Line Right, Line Left, Line Playback Switch (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add FM Playback Volume, FM Left, FM Right, FM Playback Switch (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add Mic1 Playback Switch, Mic2 Playback Switch (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Merge sun4i_codec_left_mixer_controls and sun4i_codec_right_mixer_controls into sun4i_codec_mixer_controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add Mic1 Boost Volume, Mic2 Boost Volume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add sun7i_codec_controls, sun7i_codec_codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add Mic Playback Volume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-codec: Add MIC2 Pre-Amplifier, Mic2 input (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: jz4725b: fix spelling mistake "Deemphatize" -> "Deemphasize" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: fix semicolon.cocci warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: ssiu: correct shift bit for ssiu9 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: Add jz4725b-codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup rsnd_ssi_master_clk_start() user count check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: harden use of lookup tables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xtensa: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: uniphier: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: txx9: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sh: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dwc: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: fix out-of-bounds accesses to DAPM lookup tables (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs46xx: Clean up proc file creations (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Move card id proc creation into info.c (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Minor optimization (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Drop unused snd_info_entry.card field (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: sparc: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcmcia: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: pci: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: i2c: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: isa: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: drivers: Clean up with new procfs helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Add standard helpers for card proc file entries (Jaroslav Kysela) [1683051]
- [sound] ALSA: pci: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: compress: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: emux: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: opl4: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire: Remove superfluous snd_info_register() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ssm2602: switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: compress: Add helper functions for component trigger/set_params (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: compress: Clarify the intent of current compressed ops handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: remove some unnecessary NULL checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ssm2602: Fix ADC powerup sequencing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Check for NULL widget in dapm_update_dai_unlocked (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: spi: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: sparc: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: sh: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ppc: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: pci: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: parisc: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: atmel: Drop superfluous PCM preallocation error checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Fix build error without CONFIG_PCI (Jaroslav Kysela) [1683051]
- [sound] ALSA: compress: Fix stop handling on compressed capture streams (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add support for new T+A USB DAC (Jaroslav Kysela) [1683051]
- [sound] ALSA: info: Always register entries recursively (Jaroslav Kysela) [1683051]
- [sound] ALSA: core: Don't allow NULL device for memory allocation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sh: Avoid passing NULL to memory allocators (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Avoid passing NULL to memory allocators (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4118: fix missing header (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: btcvsd: fix spelling mistake "offest" -> "offset" (Jaroslav Kysela) [1683051]
- [sound] ALSA: arm: Avoid passing NULL to memory allocators (Jaroslav Kysela) [1683051]
- [sound] ALSA: x86: Avoid passing NULL to memory allocators (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: unload physical dai link in remove (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: add SND_SOC_DOBJ_GRAPH type for dapm routes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: clear platform pointers on error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl-asoc-card: fix object reference leaks in fsl_asoc_card_probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Add warnings for widget overwrite when adding route (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Only power up active channels from a DAI (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: fix oops/use-after-free case with dai driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: fix use-after-free issue with dailink sname (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: add btcvsd driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: arizona: Add channel numbers to AIFs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup TDM Split mode check for CTU (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: synchronize connection check for simple-card/audio-graph (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup MIX kctrl registration (Jaroslav Kysela) [1683051]
- [sound] ALSA: isa: Avoid passing NULL to memory allocators (Jaroslav Kysela) [1683051]
- [sound] ALSA: mips: pass struct device to DMA API functions (Jaroslav Kysela) [1683051]
- [sound] ALSA: hal2: pass struct device to DMA API functions (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Serialize codec registrations (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Use a common helper for hp pin reference (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix lose hp_pins for disable auto mute (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Headset microphone support for System76 darp5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: remove a superfluous function declaration (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sprd: Add Spreadtrum audio DMA platfrom driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: modify dapm route loading routine and add dapm route unloading (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: fix memory leak in soc_tplg_dapm_widget_create (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Fix memory leak from soc_tplg_denum_create_texts (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Remove widgets from dobj list (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Reduce number of dereferences when accessing dobj (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Use standard device registration for beep (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Apply ALC294 hp init also for S4 resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Record the current power state before suspend/resume calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5672: remove useless test (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fixed hp_pin no value (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cros_ec_codec: Add codec driver for Cros EC (Jaroslav Kysela) [1683051]
- [documentation] ALSA: ASoC: Documentation: Add google, cros-ec-codec (Jaroslav Kysela) [1683051]
- [maintainers] ALSA: MAINTAINERS: add maintainers for ChromeOS EC sub-drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: Fix missing slimbus dependency (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Cleanup DSD whitelist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: apq8096: add slim support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add audio routings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add capture dapm widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add playback dapm widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add basic controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add CLASS-H Controller support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add support to wcd9335 codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: glk_rt5682_max98357a: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bxt_rt298: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bxt_da7219_max98357a: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5672: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_rt5645: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_nau8824: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht_bsw_max98090_ti: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_da7213: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bdw-rt5677: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: broadwell: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: haswell: platform name fixup support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add helper to change platform name for all dailinks (Jaroslav Kysela) [1683051]
- [sound] ALSA: dice: add support for Solid State Logic Duende Classic/Mini (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Variable "ret" in function rt5651_i2c_probe() could be uninitialized (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-acpi: add static inline fallbacks when CONFIG_ACPI=n (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm512x: Fix clocking calculations when not using the PLL (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm512x: Implement the set_bclk_ratio interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: use for_each_link_codecs() for dai_link codecs V2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Fixup build error for mt6358 (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix tight loop of OSS capture stream (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add Opus #3 to quirks for native DSD support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt6358: add codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: mt8183: add platform driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Allow soc_find_component lookups to match parent of_node (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Use the common error path in __snd_pcm_lib_xfer() (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: Off by one in latter_handle_midi_msg() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: make const arrays static, reduces object code size (Jaroslav Kysela) [1683051]
- [sound] ALSA: proc: Avoid possible leaks of snd_info_entry objects (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Simplify proc file destruction (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Drop unused snd_pcm_substream.file field (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: comment cleanup about destination address of async transactions for MIDI messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Cleanup snd_pcm_stream_lock() & co (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Remove down_write() hack for snd_pcm_link_rwsem (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: More fine-grained PCM link locking (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Fix multi-CODEC setups (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: support rx MIDI functionality for Fireface UCX (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add protocol-specific operation to fill transaction buffer with MIDI messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add model-dependent parameter for address to receive async transaction for MIDI messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: support tx MIDI functionality of Fireface UCX (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add model-dependent parameter for address range to receive async transaction (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: change prototype of handler for async transaction with MIDI messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Correct the setting while select ASRC clk for AD/DA filter (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: add driver flag for runtime PM (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: implement runtime suspend/resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: remove redundant clock enable API (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: add runtime PM callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: get clock handles early in probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: runtime power management support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: rename to asoc_simple_card_canonicalize_platform() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: use for_each_link_codecs() for dai_link codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: add soc_cleanup_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: reduce if/else nest on soc_probe_link_dais (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: merge card resources cleanup method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: add new snd_soc_flush_all_delayed_work() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: add .num_platform for dai_link (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Avoid confusing loop in snd_pcm_unlink() (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Make PCM linked list consistent while re-grouping (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Unify snd_pcm_group initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Call snd_card_unref() inside in_pcm_file() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add mute LED support for HP ProBook 470 G5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add support for Fireface UCX (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: code refactoring to parse of clock configuration (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: code refactoring for dump of sync status (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add protocol-dependent operation to get clock status (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add protocol-dependent operation to switch mode to fetch PCM frame (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add protocol-dependent operation to dump status (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: obsolete proc node to leave one node (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: unify protocol layer for FF400/FF800 (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: rename protocol layer for former models (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Fix unused variable warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc.h: add explanation of legacy/modern style of dai_link (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_sai: Remove expensive print in irq handler (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: remove error due to probe deferral (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-spdif: don't print EPROBE_DEFER as error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_spdif: don't print EPROBE_DEFER as error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-sgtl5000: don't print EPROBE_DEFER as error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-sgtl5000: lower log level for potential probe deferral cases (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-sgtl5000: put of nodes if finding codec fails (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: fix oops on re-probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: add default pdata for i2s mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: Set DAI format for dmic codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Kconfig: select max98927 for sdm845 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Fix potential NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-audmux: change snprintf to scnprintf for possible overflow (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5514-spi: Fix potential NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: change snprintf to scnprintf for possible overflow (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Fix PLL source register definitions (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Don't defer probe on optional, NULL components (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Make snd_pcm_suspend() local static (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcmcia: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: arm: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ppc: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: x86: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: pci: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: drivers: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: isa: Remove superfluous snd_pcm_suspend*() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: atiixp: Move PCM suspend/resume code into trigger callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Suspend streams globally via device type PM ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Make snd_soc_find_component() more robust (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: fix init platform memory handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: parse AES audio parameters (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: msm8916-wcd-digital: Select REGMAP_MMIO to fix build error (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: msm8916-wcd-digital: remove few unused variables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4341: fix waring unused-function (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: program stripe control for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: program stripe bits for controller (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: add verbs for stripe control (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: add register offset for stripe control (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Add api to program stripe control bits (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: skl: Fix display power regression (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix typo for ALC225 model (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: Hold client_mutex around soc_init_dai_link() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: use correct drvdata in snd_byt_cht_es8316_mc_remove() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Boards: move the codec PLL configuration to _init (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: SND_SOC_DAPM_MICBIAS is deprecated (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Add recalc_rate function to return DAI clock rate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: MCLK should be enabled before DAI clocks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: defer card probe until all component is added to list (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Remove set but not used variable 'first_ch_bits' (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix a mask wrong issue in snd_hdac_stream_start() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix mismatches for register mask and value in hdac controller (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Disable headset Mic VREF for headset mode of ALC225 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add unplug function into unplug state of Headset Mode for ALC225 (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: fix CM6206 register definitions (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt274: Variable "buf" in function rt274_jack_detect() could be uninitialized (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ADAU7002: Add optional delay before start of capture (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs46xx: Potential NULL dereference in probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add quirk for PoV TAB-P1006W-232 (v1.0) tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add support for jack-detect using an external GPIO (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add quirks module parameter (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Revert "Fix DMIC map headsetmic mapping" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Add support for jack detect using an external GPIO (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Add ACPI ID 10EC5640 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: Add quirk for PoV P1006W tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: update BSDSR/BSDISR handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sgtl5000: Allow SCLK pad drive strength to be changed (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atom: fix a missing check of snd_pcm_lib_malloc_pages (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: enable SPDIF driver build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: add SPDIF audio driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic32x4: Kernel OOPS while entering DAPM standby mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Add MICFIL SoC Digital Audio Interface driver. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: eliminate left-over from Raumfeld machine driver removal (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt298: fix boolean tests (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rl6437a: use __be32 for a __be32 buf (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5645: store eq kcontrol byte in __be (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: use logical AND (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: fix endianness issues (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mt6351: remove unneeded variable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tscs42xx.c: fix boolean test (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8824: fix boolean assignment (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: fix boolean assignments (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98927: fix boolean assignments (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5640: fix boolean assignments (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoc: rt286: fix boolean tests (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt274: fix boolean tests (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4271: fix boolean assignments (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98383: fix boolean assignments to true/false (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5670: remove unused mux/mixer define (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5645: remove unused mux define (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: fix kernel doc descriptions (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es8316: remove unused constant variables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98090: remove unused constant variables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmic: declare trigger function as static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4458: Add support for AK4497 (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb: fix a missing check of snd_ctl_add (Jaroslav Kysela) [1683051]
- [sound] ALSA: line6: fix check on snd_card_register (Jaroslav Kysela) [1683051]
- [sound] ALSA: ice1712: fix a missing check of snd_i2c_sendbytes (Jaroslav Kysela) [1683051]
- [sound] ALSA: gus: add a check of the status of snd_ctl_add (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxygen: initialize spdif_playback_enable to 0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: virtuoso: add de-emphasis control (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Support Dell headset mode for New AIO platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix an out-of-bound read in create_composite_quirks (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Always check descriptor sizes in parser code (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Check mixer unit descriptors more strictly (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Avoid access before bLength check in build_audio_procunit() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Add support for GPIO mode of the pins (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: davinci-mcasp: Move context save/restore to runtime_pm callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: davinci-mcasp: No need for IS_MODULE/BUILTIN check for pcm driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirks for ASUS MeMO Pad 7 (ME176C) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: sst: Fallback to BYT-CR if IRQ 5 is missing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: sst: Simplify is_byt_cr() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Add ACPI match table entry for ES8316 codec on BYTCR platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Set card long_name based on quirks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add input-map support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add external speaker mux support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add jack-detect support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Add support for SSP0 (BYTCR) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Minor refactoring (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcht_es8316: Sort includes alphabetically (Jaroslav Kysela) [1683051]
- [regulator] ALSA: regulator: fixed: Let core handle GPIO descriptor (Jaroslav Kysela) [1683051]
- [regulator] ALSA: regulator/gpio: Allow nonexclusive GPIO access (Jaroslav Kysela) [1683051]
- [regulator] ALSA: regulator: fixed: Default enable high on DT regulators (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es8316: Add DAC mono mix switch mixer control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es8316: Add jack-detect support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Variable "val" in function rt274_i2c_probe() could be uninitialized (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: fix platform_no_drv_owner.cocci warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: fix error handling in xlnx_formatter_pcm_probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: add workaround for silence of rk3288 ACODEC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: support ACODEC for rk3328 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: reduce naming prefix (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: cleanup DAI link loop method - step2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: cleanup DAI link loop method - step1 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: add link_info (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: add 1 CPU : 1 Codec support again (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: add asoc_simple_card_get_conversion() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: reduce naming prefix (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: cleanup DAI link loop method - step2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: cleanup DAI link loop method - step1 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: add link_info (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: add 1 CPU : 1 Codec support again (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: enable audio formatter driver build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: add pcm formatter platform driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: remove simple-scu-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: remove audio-graph-scu-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: add asoc_graph_card_get_conversion() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: check "reg" property on asoc_simple_card_get_dai_id() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: boards: use snd_mask_set_format in all machine drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Atom: simplify boolean tests (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Baytrail: simplify boolean test (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Baytrail: remove unneeded variable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Haswell: assign booleans to true/false (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Haswell: remove unneeded semicolon (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: simplify boolean tests (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: remove useless cast (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8904: enable MCLK in STANDBY (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8904: save model id directly in of_device_id.data (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8904: make the driver visible in Kconfig (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4341: Add driver for CS4341 DAC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Fix recording no sound issue (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: atom: Make PCI dependency explicit (Jaroslav Kysela) [1683051]
- [sound] ALSA: compress: prevent potential divide by zero bugs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: Fix a small memory leak (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: Fix a NULL vs IS_ERR() bug (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: Off by one in of_q6asm_parse_dai_data() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm512x: Fix a double unlock in pcm512x_digital_mute() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: change license header format style (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Haswell/Broadwell: fix setting for .dynamic field (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: Grammar s/the the/the/ (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dma-sh7760: cleanup a debug printk (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: set jack only for a specific backend (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Revert DSP detection on legacy HD-audio driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: clear pending irq handlers (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable the headset mic auto detection for ASUS laptops (Jaroslav Kysela) [1683051]
- [sound] ALSA: HD-Audio: SKL+: force HDaudio legacy or SKL+ driver selection (Jaroslav Kysela) [1683051]
- [sound] ALSA: HD-Audio: SKL+: abort probe if DSP is present and Skylake driver selected (Jaroslav Kysela) [1683051]
- [sound] ALSA: HDA: export process_unsol_events() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable audio jacks of ASUS UX391UA with ALC294 (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob: fix model-id of unit for Apogee Ensemble (Jaroslav Kysela) [1683051]
- [sound] ALSA: xen-front: Use Xen common shared buffer implementation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: Kconfig: Remove the deprecated options (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ti: Merge davinci and omap directories (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: add mute LED support for HP EliteBook 840 G4 (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: code refactoring to handle model-specific registers (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add support for packet streaming on Fireface 800 (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: allocate isochronous resources in mode-specific implementation (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: code refactoring to handle multiplier mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: share helper function to switch fetching mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: fix for state to fetch PCM frames (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: use the same print format for 'without_header' tracepoints (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: fix wrong assignment for 'out_packet_without_header' tracepoint (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: fix wrong handling payload_length as payload_quadlet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: add display_port_rx port routing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: add support to Display port RX dais (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: qdafe: add support for display_port_rx (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: Add support to compress offload (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm: add support to MP3 format (Jaroslav Kysela) [1683051]
- [sound] ALSA: soc-compress: add support to snd_compr_set_runtime_buffer() (Jaroslav Kysela) [1683051]
- [sound] ALSA: compress: make use of runtime buffer for copy (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Add more platform granularity (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: tidyup prefix for snd_soc_codec_conf (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: tidyup convert_rate/channel method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: tidyup mclk-fs method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: merge simple-scu-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: tidyup prefix for snd_soc_codec_conf (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: tidyup convert_rate/channel method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: tidyup mclk-fs method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: merge audio-graph-scu-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: fixup asoc_simple_card_get_dai_id() ID method (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Invoke pcm_new() for all DAI-link (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm512x: Implement the digital_mute interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: fix do_div warning in spdifin (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: add error logs on probe, remove dependency on NHLT (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: remove useless tests on HDaudio capabilities (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: stop probe if HDaudio capabilities don't exist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Harden DSP detection with PCI class/subclass info (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Add CFL-S support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Add powersaving widgets for DAC and ADC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: enable i2s driver build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: xlnx: Add i2s driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_rt5660: Add a new machine driver for kbl with rt5660 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg spdif input (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-toddr: add support for spdifin backend (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: Dereference pointer for memcpy sizeof in asoc_simple_card_probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: Fix SND_SOC_EUKREA_TLV320 build error on i.MX8M (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: add support for Huawei WMI micmute LED (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: fix front speakers on Huawei MBXP (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: remove RSND_REG_ from rsnd_reg (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add support for Fireface 800 with MIDI functionality only (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: localize a handler for MIDI messages on tx transaction (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add driver data for register for MIDI high address (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: share register for async transaction of MIDI messages (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: add support for second optical interface for ADAT stream (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: share helper function to get current sampling rate and clock source (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: share status and configuration dump (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: share some registers for status of clock synchronization (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: care multi DPCM codec_conf (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: use cpu/codec pointer on graph_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: tidyup "convert-rate/channels" parsing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: care link / dai count (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: add dai-link support (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - make pci_iounmap() call conditional (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi: Always set display_power_control for Intel HSW+ codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hdmi: Add missing display power-off at driver removal (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Make snd_hdac_display_power() void function (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/intel: Properly free the display power at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/intel: Drop superfluous AZX_DCAPS_I915_POWERWELL checks (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Refactor display power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: tidyup asoc_simple_card_parse_daifmt() timing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: use cpu/codec pointer on simple_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: fix build warning without CONFIG_OF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: add rt5663 codec select (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98927: fix the audio jack button remapping (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the Point of View Mobii TAB-P1005W-232 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the Prowise PT301 tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable audio jacks of ASUS UX433FN/UX333FA with ALC294 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Enable audio jacks of ASUS UX533FD with ALC294 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: ALC294 mic and headset-mode fixups for ASUS X542UN (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/intel: Refactoring PM code (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: fix reference to wrong register for clock configuration (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix the mute LED regresion on Lenovo X1 Carbon (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Add copyright and module author (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: Add configuration for headset codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: Add TDM configuration for speaker (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Fix signal paths (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Calculate LRCLK divider (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Fix power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Remove useless assignment (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Enable headset button support for new codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add jack button support (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add jack pointer and unsolicited event bits to callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fixed headphone issue for ALC700 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5660: Add a new ACPI match ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: ak4104: move to GPIO consumer API (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: cs4270: move to GPIO consumer API (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Use of_node_name_eq for node name comparisons (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: use dma_ops of parent device for acp_audio_dma (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: use DMA addr rather than CPU pa for acp_audio_dma (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: cht_bsw_max98090_ti: Add pmc_plt_clk_0 quirk for Chromebook Gnawty (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Use of_node_name_eq for node name comparisons (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Remove direct OF name and type accesses (Jaroslav Kysela) [1683051]
- [sound] ALSA: sparc: Use of_node_name_eq for node name comparisons (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Fix mic issue on Acer AIO Veriton Z4860G/Z6860G (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: Fix mic issue on Acer AIO Veriton Z4660G (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add support for Acer Aspire C24-860 headset mic (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek: ALC286 mic and headset-mode fixups for Acer Aspire U27-880 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Added max98373_reset for stable amp reset (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: use cpu/codec pointer on graph_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: care multi DPCM codec_conf (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: use cpu/codec pointer on graph_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: care link / dai count (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: fixup asoc_simple_card_get_dai_id() counting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add missing TDM Split mode support for simple-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup mod ID for CTU regmap read/write (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: indicates Channel and Mode for debug (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi - Add Tegra186 and Tegra194 support (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra - Probe up to 8 codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: cht_bsw_max98090_ti: Add pmc_plt_clk_0 quirk for Chromebook Clapper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: remove raumfeld machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix UAF decrement if card has no live interfaces in card.c (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add ACPI matching tables for ICL (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix speaker output regression on Thinkpad T570 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: au8540: use 64-bit arithmetic instead of 32-bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Add support for AMD Stoney Ridge (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add SMSL D1 to quirks for native DSD support (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix starvation on down_write_nonblock() (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Call snd_pcm_unlink() conditionally at closing (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/tegra: compatible string as shortname (Jaroslav Kysela) [1683051]
- [platform] ALSA: platform/x86: thinkpad_acpi: Add audio mute LED classdev support (Jaroslav Kysela) [1683051]
- [platform] ALSA: platform/x86: dell-laptop: Add micmute LED trigger support (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Support led audio trigger (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: Don't disable pcm3168a when CONFIG_PM defined (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmic: introduce module_param wakeup_delay (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmic: introduce mode switch delay (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: sdm845: Create and setup jack in init callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: sdm845: Add board specific dapm widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-mcasp: Implement configurable dismod handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-mcasp: Update PDIR (pin direction) register handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-mcasp: Clear TXSTAT register before activating serializers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Add FW reply for MCLK/SCLK IPC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Make DSP replies more human readable (Jaroslav Kysela) [1683051]
- [drivers] ALSA: leds: trigger: Introduce audio mute LED trigger (Jaroslav Kysela) [1683051]
- [drivers] ALSA: leds: core: Introduce LED pattern trigger (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: tidyup registering method for rsnd_kctrl_new() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Support ALC300 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add auto-mute quirk for HP Spectre x360 laptop (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9867: Fix whitespace (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc.h: makes snd_soc_of_parse_audio_prefix() inline (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Fix a NULL vs IS_ERR() check in probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - fix the pop noise on headphone for lenovo laptops (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: fix spelling mistake "Frequence" -> "Frequency" (Jaroslav Kysela) [1683051]
- [sound] ALSA: Revert "ALSA: Replace snd_malloc_pages() and snd_free_pages() with standard helpers" (Jaroslav Kysela) [1683051]
- [sound] ALSA: Replace snd_malloc_pages() and snd_free_pages() with standard helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: control: Consolidate helpers for adding and replacing ctl elements (Jaroslav Kysela) [1683051]
- [sound] ALSA: control: Fix race between adding and removing a user element (Jaroslav Kysela) [1683051]
- [sound] ALSA: sparc: Fix invalid snd_free_pages() at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: wss: Fix invalid snd_free_pages() at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - fix headset mic detection for MSI MS-B171 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Add ASRock N68C-S UCC the power_save blacklist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: Fix incorrect bit shift at AC97-SPSA control write (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: notify events of change of state for userspace applications (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: apply small refactoring to handle several type of event for hwdep interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: queue events for change of control surface (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: add new hwdep ioctl command to get state image (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: pick up data of state from tx isochronous pakcets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-dmic: Add pm_qos handling to avoid overruns with CPU_IDLE (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcpdm: Add pm_qos handling to avoid under/overruns with CPU_IDLE (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Fix latency value calculation for pm_qos (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: tidyup define position (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: tidyup typo SND_AUDIO_GRAPH_CARD (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: tidyup asoc_simple_card_parse_daifmt() timing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: tidyup "convert-rate/channels" parsing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: tidyup "prefix" parsing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: tidyup "prefix" parsing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: add snd_soc_of_parse_node_prefix() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-amplifier: add VCC regulator widget (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sunxi: sun50i-codec-analog: Add support for cpvdd regulator supply (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple_card_utils: remove "option" from asoc_simple_card_of_parse_routing() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: tidyup asoc_simple_card_parse_convert() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: accept NULL parameter on asoc_simple_card_xxx() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: remove asoc_simple_card_clk_register() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: makes rsnd_ssi_is_dma_mode() static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: tidyup rsnd_parse_connect_ssiu_compatible() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: Add support for Secondary MI2S interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: Update slot_width for Quaternary TDM port (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: use platform_data for machine drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: fix interface for Chromebook machine drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: acpi: define common interface for machine driver configuration (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: acpi: fix: continue searching when machine is ignored (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: fix Kconfigs, make HDaudio codec optional (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic3x: Add support for CBM_CFS and CBS_CFM clocking modes (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Use device_type helpers to access the node type (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - fix AE-5 pincfg (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add new ZxR quirk (Jaroslav Kysela) [1683051]
- [sound] ALSA: asihpi: clean up indentation, replace spaces with tab (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5663: Fix error handling of regulator_set_load (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: fix spelling mistake "Inavlid" -> "Invalid" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: clean up indentation, remove extraneous tab (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: arizona: fix indentation issue with return statement (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320dac33: clean up indentation, remove extraneous tab (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: asihpi: clean up indentation, remove extraneous tab (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Convert a few more users to using pOFn instead of device_node.name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5663: Add regulator support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4118: Add support for AK4118 S/PDIF transceiver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm186x: Fix device reset-registers trigger value (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: remove set but not used variable 'dma_buffer' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Fixed build errors (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8822: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8822: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Recalculate audio map forcely when card instantiated (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-abe-twl6040: Fix missing audio card caused by deferred probing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: fix memory leak of i2s_data on error return (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Add DT property for single-ended output (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Rename output widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Set dai_link id to each dai_link (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun8i-codec: add missing route for ADC (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: enable acp3x drivers build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add acp3x system resume pm op (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add acp3x runtime pm ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add acp3x tdm mode support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add acp3x i2s ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add acp3x pcm driver dma ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: Interrupt handler changes for ACP3x DMA driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: add ACP3x PCM platform driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: amd: create ACP3x PCM platform device (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: add ACP3.0 PCI driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: add ACP 3.x IP register header (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Power down links before turning off display audio power (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: hdac_hdmi: add Icelake support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Factor out common init code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Fix dma-unsafe read of scratch registers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: add missing slave_config setting for I2S (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: No need to initialize max_xx_thres when it is not used (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Remove redundant check for mcbsp->pdata (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Re-arrange files for core McBSP and Sidetone function split (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Move out the FIFO check from set_threshold and get_delay (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Simplify the mcbsp_start/_stop function parameters (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Clean up the interrupt handlers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Skip dma_data.maxburst initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: Clean up dma_data addr initialization code (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: add support for APOGEE duet FireWire (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Call pci_iounmap() instead of iounmap() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add quirk entry for HP Pavilion 15 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Optimize for non-PCI configuration (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: use ring buffer for rsnd_mod_name() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun8i-codec: fix crash on module removal (Jaroslav Kysela) [1683051]
- [sound] ALSA: oss: Use kvzalloc() for local buffer allocations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_ssi: Change to use DEFINE_SHOW_ATTRIBUTE macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add TDM Split mode support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add SSIU BUSIF support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: handle DPCM converted rate/chan under core (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: move HDMI information from ssi.c to core.c (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: use defined io_playback/io_capture (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: rename rsnd_runtime_is_ssi_xxx() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: remove endpoint bidirectional check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: remove error check which never happen (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: remove endpoint bidirectional check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: remove endpoint bidirectional check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add quirk for APL RVP boards (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add SOF information for APL RVP (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: remove GFP_ATOMIC, use GFP_KERNEL (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: boards: fix Skylake typo (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: use standard interface for Atom machine drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: use standard interface for Hdaudio machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: change ac97 dependencies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap: Remove unused machine driver for AM3517-evm (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: remove read-only status register from snd_kcontrol_new (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak5558: Remove redundant snd_soc_component_read32 calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: Fix the dai widgets (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: Only add routing once. (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Define registers for CM6206 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Fix incorrect clearance of thinkpad_acpi hooks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe: Fix wrong MI2S SD line mask (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: cht_bsw_max98090_ti: Add quirk for boards using pmc_plt_clk_0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: rsnd_mod_name() handles both name and ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add .get_id/.get_id_sub (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: move .get_status under rsnd_mod_ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: cleanup hw_constraint for LEFT_J/I2S (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcbsp: On OMAP1 and OMAP2420 only 16bit format is supported (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: constify regulator_desc structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: constify snd_soc_dai_ops structures (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: constify snd_soc_dai_ops structures (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8825: remove unnecessary unlikely() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: mrfld: fix uninitialized variable access (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm97xx: fix uninitialized regmap pointer problem (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: smd845: constify snd_soc_ops structure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix less than zero comparison on unsigned int (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sunxi: rename SND_SUNXI_ADDA_PR_REGMAP to SND_SUN8I_ADDA_PR_REGMAP (Jaroslav Kysela) [1683051]
- [sound] ALSA: x86: Rip out the lpe audio runtime suspend/resume hooks (Jaroslav Kysela) [1683051]
- [sound] ALSA: x86: Fix runtime PM for hdmi-lpe-audio (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup clock start checker (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fix oops w/ for_each_rtd_codec_dai_rollback() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: fix insufficient PCM rule for period/buffer size (Jaroslav Kysela) [1683051]
- [sound] ALSA: ca0106: Disable IZD on SB0570 DAC to fix audio pops (Jaroslav Kysela) [1683051]
- [sound] ALSA: dice: fix to wait for releases of all ALSA character devices (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix noderef.cocci warnings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: fix master clock naming (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: add clock dependency for sai (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Actually fix microphone issue (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-i2s: move code from startup/shutdown hooks into pm_runtime hooks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm2000: Remove wm2000_read helper function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: fix mclk support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Log addresses as 8 digits in wm_adsp_buffer_populate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Rename memory fields in wm_adsp_buffer (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs42l51: add mclk support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: set sai as mclk clock provider (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: fix trivial checkpatch issues (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Add support for hw_free on CODEC to CODEC links (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98927: minor white space clean up (Jaroslav Kysela) [1683051]
- [sound] ALSA: i2c/cs8427: Fix int to char conversion (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: tidyup SSICR::SWSP for TDM (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: enable TDM settings for SSI parent (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: add hw constraint for capture channel (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sta32x: Add support for XTI clock (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8822: new codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tegra_sgtl5000: fix device_node refcounting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sunxi: allow the sun8i-codec driver to be built on ARM64 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sunxi: Add new driver for Allwinner A64 codec's analog path controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun8i-codec-analog: split regmap code into separate driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun8i-codec: Don't hardcode BCLK / LRCK ratio (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sun4i-i2s: Add compatibility with A64 codec I2S (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: don't pass GFP_DMA32 to dma_alloc_coherent (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Add 2 more models to the power_save blacklist (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: Add Kabylake Dialog+Maxim machine driver entry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Boards: Add KBL Dialog Maxim I2S machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Add SND_JACK_LINEOUT jack type (Jaroslav Kysela) [1683051]
- [sound] ALSA: asihpi: don't pass GFP_DMA32 to dma_alloc_coherent (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: add I2S/Left_J TDM support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: add hw constraint for channel (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3168a: add HW constraint for non RIGHT_J (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sta32x: set ->component pointer in private struct (Jaroslav Kysela) [1683051]
- [sound] ALSA: au88xx: Add fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: opti92xx-ad1848: Use the standard fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: oss: Use the standard fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: caiaq: Add fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Add fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: add missing entries to Kconfig (Jaroslav Kysela) [1683051]
- [sound] ALSA: isight: fix leak of reference to firewire unit in error path of .probe callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add mic quirk for the Lenovo G50-30 (17aa:3905) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Sort DHT Rot Pnt Volume in reverse order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Sort max98373_bde_gain_tlv in reverse order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Sort BDE Limiter Thresh Volume in reverse order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Sort Digital Volume in reverse order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: enable mclk-fs on codec node (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: use 32bit TDM width as default (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98988: add I2C dependency (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire: simplify cleanup process when failing to register sound card (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob/fireworks: simplify handling of local device entry table (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire: release reference count of firewire unit in .remove callback of bus driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire: block .remove callback of bus driver till all of ALSA character devices are released (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix the problem of the front MIC on the Lenovo M715 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Fix headphone pin config for ASUS G751 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Fix input effect controls for desktop cards (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add error checking in ca0132_build_controls() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Clean up patch_ca0132() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Fix microphone inconsistency issues (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98988: make it selectable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98088: Add master clock handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8782: add support for regulators (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add ASUS G751 quirk model entry (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Add quirk for ASUS G751 laptop (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Use the standard fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: skylake: Add fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt274: Add fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm186x: Use the standard fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adau1761: Use the standard fall-through annotation (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add custom mixer status quirks for RME CC devices (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: update quirk for B&W PX to remove microphone (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/sigmatel - Disable automute for Elo VuPoint (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: A lightweight function to discard pending bytes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add fault detect recovery property to DT bindings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa-ssp: enable and disable extclk if given (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: checking NULL vs IS_ERR() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: skylake: Add missing break in skl_tplg_get_token() (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: use managed-resource to maintain cache of stream formats (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: use managed-resource to maintain model-specific data (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireworks: use managed-resource to maintain response buffer (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob: use managed-resource to maintain data specific to M-Audio FW-1814/ProjectMix I/O (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire: use managed-resource of fw unit device for private data (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Cannot adjust speaker's volume on Dell XPS 27 7760 (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel8x0: Fix fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb8: Fix fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-lib: add PCM rules to obsolete PCM constraints based on LCM of SYT_INTERVAL (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR exit commands (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR 600 ohm gain control (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Remove input select enum for ZxR (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR input/output select commands (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR DSP post-download commands (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR init commands (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add DBpro hda_codec_ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR pincfg (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add ZxR quirks + new quirk check function (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Fix surround sound with output effects (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Fix AE-5 control type (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix mismatch for register mask and value in ext controller. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: qdsp6: remove duplicated include (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm9712: fix unused variable warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atmel: add SND_SOC_I2C_AND_SPI dependency (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: avoid AC97_BUS build warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-utils: Rename dummy_dma_ops to snd_dummy_dma_ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98088: add OF support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4265: Add a MIC pre. route (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_component_dais() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_component() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup SSI clock during suspend/resume modes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: qdsp6: remove duplicated include from q6adm.c (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tidyup for_each_card_prelinks() dai_link (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5663: Remove the boost volume in the beginning of playback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_dpcm_be() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_dpcm_fe() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_comp_order() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_card_components() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_card_rtds() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_card_links() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_card_prelinks() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rename for_each_rtd_codec_dai_reverse to rollback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: convert for_each_rtd_codec_dai() for missing part (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add AE-5 exit function (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add AE-5 specific controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add input selection commands for AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add output set commands for AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Clean up ca0132_alt_out_select (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add DSP setup functions for AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Merge post-dsp functions + cleanup (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Change firmware name and usage (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add AE-5 regular init setup (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add AE-5 pre-init and ca0113 functions (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Change ca0132_mmio_init for AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Set AE-5 bools and select mixer (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add pincfg for AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add quirk for Sound BlasterX AE-5 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Define new verbs and control params (Jaroslav Kysela) [1683051]
- [sound] ALSA: xen-front: Refine indentations and constify snd_pcm_ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix the audio-component completion timeout (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5677-spi: Drop unused GPIO include (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Minor code modification (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Fix capture unstable in beginning for some runs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Fix the boost volume at the begining of playback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Update calibration function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Remove HP volume control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Improve HP performance (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: remove redundant include (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5514-spi: Get the period_bytes in the copy work to make sure the value correctly (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: add snd_soc_is_matching_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: manage platform name under snd_soc_init_platform() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: remove duplicated include from q6asm-dai.c (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hisilicon: fix fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es8328: Fix fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireworks: fix memory leak of response buffer at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: fix memory leak of discovered stream formats at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: fix memory leak for model-dependent data at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob: fix memory leak for M-Audio FW1814 and ProjectMix I/O at error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: atiixp: fix fall-through annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Enable runtime PM only for discrete GPU (Jaroslav Kysela) [1683051]
- [sound] ALSA: oxfw: fix memory leak of private data (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-tascam: fix memory leak of private data (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-digi00x: fix memory leak of private data (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel8x0m: Register irq handler after register initializations (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix implicit definition of pci_iomap() on SH (Jaroslav Kysela) [1683051]
- [sound] ALSA: don't call skl_init_chip() to reset intel skl soc (Jaroslav Kysela) [1683051]
- [sound] ALSA: enable interrupt after dma buffer initialization (Jaroslav Kysela) [1683051]
- [sound] ALSA: Revert "ASoC: Intel: Skylake: Acquire irq after RIRB allocation" (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: remove dai->driver NULL check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: add support to card rebind (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: remove unneeded static set .owner field in platform_driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: add missing INTERLEAVED PCM attribute (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: remove unused num_dai_links (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: avoid nested code on soc_remove_dai() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5668: remove empty rt5668_i2c_remove() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: fix unused variable warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Fix UBSAN warning at snd_soc_get/put_volsw_sx() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: switch to new ac97 bus support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Fix simultaneous playback and capture on different channel (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: fix possible info leak to userspace on SNDRV_EMU10K1_IOCTL_INFO (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Add missing return value check for snd_soc_dapm_new_dai (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: skl-topology: Use kmemdup to replace kzalloc + memcpy (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: q6core: Use kmemdup to replace kzalloc + memcpy (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: txx9: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sh: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nuc900: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tscs454: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5668: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hda: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: bcm: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atmel_ssc_dai: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Ensure reset bit is cleared before configuring (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: clean up a return (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Fix a couple uninitialized ret variables (Jaroslav Kysela) [1683051]
- [sound] ALSA: fireface: fix memory leak in ff400_switch_fetching_mode() (Jaroslav Kysela) [1683051]
- [sound] ALSA: bebob: use address returned by kmalloc() instead of kernel stack for streaming DMA mapping (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Update hardware pointer before start capture (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: usleep_range() needs include/delay.h (Jaroslav Kysela) [1683051]
- [sound] ALSA: regmap: split up regmap_config.use_single_rw (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: hdac_hdmi: Limit sampling rates at dai creation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Avoid uninitialised variable warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sgtl5000: avoid division by zero if lo_vag is zero (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: don't use p for dev_dbg() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: don't fallback to PIO mode when -EPROBE_DEFER (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: adg: care clock-frequency size (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: gen: use tab instead of white-space (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hdmi: remove redundant check for !port condition (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Move CODEC to CODEC params from the widget to the runtime (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Add support for multi-CODEC CODEC to CODEC links (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Move connection of CODEC to CODEC DAIs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Cosmetic tidy up of snd_soc_dapm_new_control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Move error handling to snd_soc_dapm_new_control_unlocked (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_rtd_codec_dai() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: add for_each_link_codecs() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: Add overflow detection support (Jaroslav Kysela) [1683051]
- [sound] ALSA: mips: Cleanup indirect PCM helper usages (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs46xx: Use SNDRV_PCM_INFO_SYNC_APPLPTR info flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: Use SNDRV_PCM_INFO_SYNC_APPLPTR info flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: mips: Use SNDRV_PCM_INFO_SYNC_APPLPTR info flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: rme32: Use SNDRV_PCM_INFO_SYNC_APPLPTR info flag (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix several mismatch for register mask and value (Jaroslav Kysela) [1683051]
- [sound] ALSA: aoa: Convert to using pOFn instead of device_node.name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Don't schedule DAPM work if already in target state (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Add driver for PROTO Audio CODEC (with a WM8731) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: merge .nolock_start and .prepare (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: ssiu: Support to init different BUSIF instance (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: ssiu: Support BUSIF other than BUSIF0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoc: rsnd: dma: Calculate PDMACHCRE with consider of BUSIF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoc: rsnd: dma: Calculate dma address with consider of BUSIF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: ssi: Check runtime channel number rather than hw_params (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: ssi: Fix issue in dma data address assignment (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: remove is_play parameter from hw_rule function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add support for 8 bit S8 format (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add support for the DSP_A/DSP_B formats (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add support for 16/24 bit slot widths (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add warning message to rsnd_kctrl_accept_runtime() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: fixup not to call clk_get/set under non-atomic (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Initialize allocated buffers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tlv320aic31xx: Add short circuit detection support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fix soc-core.c kernel-doc warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: q6routing: initialize data correctly (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tas6424: Add channel fault reporting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tas6424: Save last fault register even when clear (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tas6424: Print full register name in error message (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-util: remove dai_link compatible code for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: support snd_soc_dai_link_component style for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: support snd_soc_dai_link_component style for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: support snd_soc_dai_link_component style for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: support snd_soc_dai_link_component style for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-util: support snd_soc_dai_link_component style for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: use snd_soc_dai_link_component for platform (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-util: remove dai_link compatible code for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: support snd_soc_dai_link_component style for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card: use simple_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: support snd_soc_dai_link_component style for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: support snd_soc_dai_link_component style for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card: use simple_dai_props (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: support snd_soc_dai_link_component style for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple_card_utils: support snd_soc_dai_link_component style for codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4265: Add a S/PDIF enable switch (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4265: Add native 32bit I2S transport (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4265: SOC_SINGLE register value error fix (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: tas5720: add TAS5722 TDM slot width setting support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: tas5720: add TAS5722 specific volume control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-mcasp: Add support for FIFO usage caused delay reporting (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Fix cancel_work_sync() stall from jackpoll work (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Clean up jackpoll_ms option handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg pdm input (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmic: add DT module alias (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmic: add Kconfig prompt for the generic dmic codec. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adau17x1: Unused exported functions changed to internal (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Improve legibility of if-statements (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Improve stylistics of file comments (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atmel: tse850: switch to SPDX license identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Change MCLK to 48Mhz (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Set constraints for DMIC and MAX98357a codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm3060: Add codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: cht-bsw-rt5672: Add key-mappings for the headset buttons (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: Add quirk for Thinkpad 8 tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5670: Add quirk for Thinkpad 8 tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adau17x1: Implemented safeload support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sigmadsp: safeload should not have lower byte limit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hda: add asoc extension for legacy HDA codec drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: use hda_bus instead of hdac_bus (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: add HDA BE DAIs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: use HDAudio if ACPI enumeration fails (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Boards: Machine driver for SKL+ w/ HDAudio codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add table for HDA-based platforms (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: move hda_codec.h to include/sound (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8804: Add ACPI support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Update calibration function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: Change DAC/ADC volume scale (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Added 10ms sleep after amp software reset (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-tdm: restrict formats depending on slot width (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-fifo: report interrupt request failure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: imply clock and reset controllers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: Properly initialise hw->rate_max (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Don't fail creating new DAPM control on NULL pinctrl (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Remove clock framework ifdefs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Convert to using pOFn instead of device_node.name (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel_hdmi: Use the new non-cached allocation (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel8x0: Use the new non-cached allocation for 440MX workaround (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Remove substream allocation/free ops (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Use new non-cached allocation for non-snoop mode (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Check the non-cached stream buffers more explicitly (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Add non-cached buffer type (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Simplify snd_malloc_dev_pages() calls (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Don't align the size to power-of-two (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Do error checks at creating system ports (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: add error check in snd_seq_system_client_init() (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: signedness bug in snd_pcm_plug_alloc() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdspm: fix spelling mistake "Initializeing" -> "Initializing" (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Return 0 when size < start_threshold in capture (Jaroslav Kysela) [1683051]
- [kvm] ALSA: treewide: correct "differenciate" and "instanciate" typos (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Fix HP Headset Mic can't record (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: fix unbalanced pm_runtime_enable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: fix check of pm_runtime_get_sync failure (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: fix device initialization in the compat layer (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5514: Fix the issue of the delay volume applied again (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Added speaker FS gain cotnrol register to volatile. (Jaroslav Kysela) [1683051]
- [sound] ALSA: update dell-wmi mic-mute registration to new world order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Fix NULL pointer deference on CODEC to CODEC DAIs (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: virmidi: Fix discarding the unsubscribed output (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: Acquire irq after RIRB allocation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm9712: fix replace codec to component (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirks for 2 more devices (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adav80x: mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: Add delays to capture path to remove DC offset noise (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: mixart: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: opl3: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add exit commands for Recon3D (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Change mixer controls for Recon3D (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add Recon3D input and output select commands (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add DSP setup defaults for Recon3D (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add Recon3D startup functions and setup (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add bool variable to enable/disable pci region2 mmio (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add Recon3D pincfg (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add quirk ID and enum for Recon3D (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Add alt_functions unsolicited response (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Clean up ca0132_init function. (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Create mmio gpio function to make code clearer (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Make DSP name configurable by codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Declare firmware controls from codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max98373: Added software reset register to readable registers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Correct DSP pointer for preloader control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5677: Fix initialization of rt5677_of_match.data (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: compress: make BE and FE order inline with dpcm (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel_hdmi: remove redundant variable cfg_val (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Set delay value for the capture case (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Modified DMA pointer for capture (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Make ACP->SYSMEM DMA non circular (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8994: Fix missing break in switch (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: add SLIM tx AIF_IN dapm (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: remove unused header files from common.h (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sdm845: remove unused header files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: apq8096: remove unused header files (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: make common.c as proper module (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8903: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da9055: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm5100-tables: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7213: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: twl6040: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7219: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8996: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cs4270: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8990: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tda7419: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5631: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: max9850: use true and false for boolean values (Jaroslav Kysela) [1683051]
- [sound] ALSA: dice: fix wrong copy to rx parameters for Alesis iO26 (Jaroslav Kysela) [1683051]
- [sound] ALSA: echoaudio: Mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: Mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: mixart: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add mute LED quirk for HP Spectre x360 (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq_oss: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: samsung: i2s: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-dmic: Mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_esai: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: omap-mcpdm: Mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci-i2s: mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: smd845: fix memory leak (Jaroslav Kysela) [1683051]
- [sound] ALSA: synth: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: pci: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: i2c: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: isa: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: drivers: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: compress: Remove empty init and exit (Jaroslav Kysela) [1683051]
- [sound] ALSA: gus: fix spelling mistake "acumulator" -> "accumulator" (Jaroslav Kysela) [1683051]
- [sound] ALSA: es18xx: mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: opti9xx: mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: opti92x: mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: galaxy: Mark expected switch fall-throughs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bxt: Use refcap device for mono recording (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: remove support for card rebind using component framework (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: smd845: remove auto rebinding (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: apq8096: remove auto rebinding (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Correct Asrock B85M-ITX power_save blacklist entry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Fix unmet dependency warning for SND_SOC_SDM845 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8994: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm9081: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8995: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8962: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8996: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8904: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8960: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8955: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5677: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5640: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8961: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsi: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb: Fix a typo (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix invalid use of sizeof in parse_uac_endpoint_attributes() (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Drop unused 64bit division macros (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Use no intrruptible mutex_lock (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Fix leftovers at probe error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Remove dead codes (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Minor cleanup of MIDI event parser helpers (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-pcm: Use delay set in component pointer function (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: Fix build (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: Fix build due to CLASS-H Controller support (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: remove redundant pointer 'urb' (Jaroslav Kysela) [1683051]
- [sound] ALSA: sonicvibes: remove redundant pointer 'dir' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ens137x: remove redundant array pcm_devs (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: remove redundant variable attn (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs5535audio: remove redundant pointer 'dma' (Jaroslav Kysela) [1683051]
- [sound] ALSA: asihpi: remove redundant variable max_streams (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: remove redundant pointers 'priv' and 'rtd' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8540: remove redundant variable osrate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: add sdm845 sound card support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Add support to parse common audio device nodes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add CLASS-H Controller support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wcd9335: add support to wcd9335 codec (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Operate UAC3 Power Domains in PCM callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add UAC3 Power Domains to suspend/resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: AudioStreaming Power Domain parsing (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Initial Power Domain support (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: virmidi: Use READ_ONCE/WRITE_ONCE() macros (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: virmidi: Offload the output event processing (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: uniphier: change functions to static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: uniphier: add support for multichannel output (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sirf: Fix potential NULL pointer dereference (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tegra_alc5632: fix device_node refcounting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sh: Kconfig: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4613: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: da7210: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4554: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4642: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm8988: fix typo in rate constraints (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tegra: i2s: Fix typo/broken macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi: Use single mutex unlock in error paths (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Sleep for 10ms after entering D3 on Conexant codecs (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Turn CX8200 into D3 as well upon reboot (Jaroslav Kysela) [1683051]
- [sound] ALSA: ctxfi: cthw20k2: Replace mdelay() with msleep() and usleep_range() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ALSA:: ctxfi: cthw20k1: Replace mdelay() with msleep() (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: quirks: Replace mdelay() with msleep() and usleep_range() (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: atiixp_modem: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: atiixp: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: bt87x: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: echoaudio: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: maestro3: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel8x0m: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: intel8x0: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: lola: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: mixart: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: riptide: Properly endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Proper endian notations for BDL pointers (Jaroslav Kysela) [1683051]
- [sound] ALSA: trident: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: ymfpci: Proper endian notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: xen: Use standard pcm_format_to_bits() for ALSA format bits (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb: Fix sparse warning wrt PCM format type (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb: Fix PCM format bit calculation (Jaroslav Kysela) [1683051]
- [sound] ALSA: wss: Fix sparse warning wrt PCM format type (Jaroslav Kysela) [1683051]
- [sound] ALSA: asihpi: Fix PCM format notations (Jaroslav Kysela) [1683051]
- [sound] ALSA: au88x0: Fix sparse warning wrt PCM format type (Jaroslav Kysela) [1683051]
- [sound] ALSA: ad1816a: Fix sparse warning wrt PCM format type (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix sparse warning wrt PCM format type (Jaroslav Kysela) [1683051]
- [sound] ALSA: riptide: Fix PCM format type conversion (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Fix implicit PCM format type conversion (Jaroslav Kysela) [1683051]
- [sound] ALSA: virmidi: Fix too long output trigger loop (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Use standard pcm_format_to_bits() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm186x: Declare PCM format with snd_pcm_format_t (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl: Use snd_mask_set_format() (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix interval evaluation with openmin/max (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Add snd_mask_set_format() helper for standard usages (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: intel: Fix snd_pcm_format_t handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Use int for format bit position (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dmaengine: Fix missing __user prefix in copy_user callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: zte: Fix incorrect PCM format bit usages (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: align axg card driver with DT bindings documentation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: use IRQ_RETVAL in the fifo irq handler (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Fix build warning (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Add a fix voltage regulator for DA7219 and ADAU7002 (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Fix missing PAGE_SIZE definition (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: declare snd_sgbuf_aligned_pages() unconditionally (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1: Fix missing __force annotation for user/kernel pointer cast (Jaroslav Kysela) [1683051]
- [sound] ALSA: korg1212: Add __force annotation to cast in user-copy callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Use standard lower_32_bits() and upper_32_bits() (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Declare the common variable in header file (Jaroslav Kysela) [1683051]
- [sound] ALSA: opl3: Declare common variables properly (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Fix a sparse warning about snd_ctl_elem_iface_t (Jaroslav Kysela) [1683051]
- [sound] ALSA: msnd: Use NULL instead of 0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/ca0132 - Use NULL instead of 0 (Jaroslav Kysela) [1683051]
- [sound] ALSA: msnd: Fix the default sample sizes (Jaroslav Kysela) [1683051]
- [sound] ALSA: msnd: Add missing __iomem annotations (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Fix multiple definitions in AU0828_DEVICE() macro (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add support for Encore mDSD USB DAC (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs5535audio: Fix invalid endian conversion (Jaroslav Kysela) [1683051]
- [sound] ALSA: vxpocket: Fix invalid endian conversions (Jaroslav Kysela) [1683051]
- [sound] ALSA: vx222: Fix invalid endian conversions (Jaroslav Kysela) [1683051]
- [sound] ALSA: seq: Fix poll() error return (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: fix widget handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Atom: fix inversion between __iowrite32 and __ioread32 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Atom: simplify iomem address and casts (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: make sst_dma functions static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: BDL definitions should be __le32 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Haswell: fix endianness handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5631: add Volume to the name of volume control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: imx-sgtl5000: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_utils: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_asrc: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl-asoc-card: Switch to SPDX identifier (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: add support to snd_soc_dai_get_channel_map() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5514: Fix the issue of the delay volume applied (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: axg-spdifout: select SND_PCM_IEC958 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/i915: Allow delayed i915 audio component binding (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Generic DSD detection for Thesycon-based implementations (Jaroslav Kysela) [1683051]
- [sound] ALSA: memalloc: Don't exceed over the requested size (Jaroslav Kysela) [1683051]
- [sound] ALSA: timer: catch invalid timer object creation (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: remove clock divider and pll setup from zylonite and magician (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg sound card support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: export snd_soc_of_get_slot_mask (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add tdm input driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add tdm output driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add tdm interface driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add tdm formatter base driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tegra: improve goto error label (Jaroslav Kysela) [1683051]
- [usb] ALSA: powerpc/ps3: Set driver coherent_dma_mask (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the "Connect Tablet 9" tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add quirk table entries for various devices (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add mono speaker quirk (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add IN2 input mapping (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Set OVCD limit for VIOS LTH17 to 2000uA (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Fix using the wrong GPIO for the ext-amp on some boards (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Add IN3 Boost volume control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Parse HOST_BUFFER controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Allow up to 8 channels for voice control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Take prefix into account in control name length (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Correct algorithm list allocation size (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Ensure DSP boot work complete before preloader_put return (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Allow changing from a bad sample rate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg spdif output (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg toddr driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg frddr driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: meson: add axg fifo base driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdac_hdmi: Add documentation for power management (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: apq8096: remove component framework related code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: remove component framework related code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: remove component framework related code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: remove component fw related code (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: add support to card re-bind using component framework (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Add __force to cast in snd_pcm_lib_read/write() (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Nuke snd_pcm_lib_mmap_vmalloc() (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Use kvmalloc() for buffers (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Minor code refactoring (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Simplify error paths (Jaroslav Kysela) [1683051]
- [sound] ALSA: rawmidi: Tidy up coding styles (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Make audio component support more generic (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/i915: Associate audio component with devres (Jaroslav Kysela) [1683051]
- [sound] ALSA: drm/i915: Split audio component to a generic type (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu8000: Use swap macro in snd_emu8000_sample_new (Jaroslav Kysela) [1683051]
- [sound] ALSA: emu10k1_patch: Use swap macro in snd_emu10k1_sample_new (Jaroslav Kysela) [1683051]
- [gpu] ALSA: vga_switcheroo: set audio client id according to bound GPU id (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: use PCI_BASE_CLASS_DISPLAY to replace PCI_CLASS_DISPLAY_VGA (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Tidy up logic for Processing Unit min/max values (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Unify virtual type units type to UAC3 values (Jaroslav Kysela) [1683051]
- [include] ALSA: usb-audio: Add support for Processing Units in UAC3 (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Processing Unit controls parsing in UAC2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-audio: Add support for Selector Units in UAC3 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: For capture have interrupts on I2S->ACP channel (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Send correct channel for configuring DMA descriptors (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Boards: Add GLK Realtek Maxim I2S machine driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hdmi-codec: fix routing (Jaroslav Kysela) [1683051]
- [sound] ALSA: cs46xx: remove redundant pointer 'ins' (Jaroslav Kysela) [1683051]
- [sound] ALSA: ali5451: remove redundant pointer 'codec' (Jaroslav Kysela) [1683051]
- [sound] ALSA: sb8: remove redundant pointer runtime (Jaroslav Kysela) [1683051]
- [sound] ALSA: gus: remove redundant pointer private_data (Jaroslav Kysela) [1683051]
- [sound] ALSA: es1688: remove redundant pointer chip (Jaroslav Kysela) [1683051]
- [sound] ALSA: opl3: remove redundant pointer opl3 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: off by one in routing_hw_params() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: fix a range check in of_q6afe_parse_dai_data() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: allow soc-core to pick up name prefixes from component nodes (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: add rate merge to the BE stream merge (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: rework runtime stream merge (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Fix snd_interval_refine first/last with open min/max (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Reporting button presses (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Disable jack-detect over suspend/resume (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Add button press support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Allow disabling jack-detect by calling set_jack(NULL) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5651: Fix workqueue cancel vs irq free race on remove (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add support for externar amplifier enable GPIO (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Move getting of codec_dev into probe() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Remove is_valleyview helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the Lenovo Miix2 8 tablet (Jaroslav Kysela) [1683051]
- [dma] ALSA: dmaengine: add support for reporting pause and resume separately (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: adau171x1: Connect playback DAI to the DSP (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: make SND_PXA_SOC_SSP depend on PLAT_PXA (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: replace "p" with "pK" (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Allow drivers to set R/W wait time. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8824: use 64-bit arithmetic instead of 32-bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa-ssp: add support for an external clock in devicetree (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: cmd: Add missing newline to debug message (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsl_spdif: Use 64-bit arithmetic instead of 32-bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: Do not overwrite slim dai num_channels (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: add slim rx routings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: add support to slim tx dais (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe: Add missing slimbus capture ports (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: Use snd_pcm_stop_xrun() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sti: Use snd_pcm_stop_xrun() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: Use snd_pcm_stop_xrun() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: davinci: Use snd_pcm_stop_xrun() helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: nau8825: use 64-bit arithmetic instead of 32-bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: do not close port if its not opened (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: do not close port if its not opened (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: Use snd_pcm_stop_xrun() for xrun injection (Jaroslav Kysela) [1683051]
- [sound] ALSA: pcm: trace XRUN event at injection, too (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: core: Allow topology to override machine driver FE DAI link config. (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: atmel-i2s: Remove unnecessary audio PLL clock (aclk) (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7134: add support for the es7154 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7134: correct required power supplies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Simplify trigger handler (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Reset bytescount when starting transaction (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Do not generate interrups for every captured sample (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Fix Capture DMA channel names (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Always subtract bytescount (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Always stop ch2 first (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa-ssp: mark expected switch fall-through (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7241: add es7241 codec support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: add button detection mode control (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb-midi: use irqsave() in USB's complete callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: usb: caiaq: audio: use irqsave() in USB's complete callback (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7134: Add VDD and AVDD power supplies (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7134: check if mclk rate is valid (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: es7134: remove 64kHz rate from the supported rates (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa-ssp: remove .set_pll() and .set_clkdiv() callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: select SND_PXA2XX_LIB for drivers that depend on it (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ac97: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-generic-dmaengine-pcm: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-compress: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-topology: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-dapm: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-core: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-acpi: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-devres.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-utils.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-jack.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-dpcm.h: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-pcm.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-ops.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-dai.h: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-io.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-scu-card.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-scu-card.c: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: snd-aoa: add of_node_put() in error path (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mt6797: sub dai use list_head (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: mediatek: sub dai use list_head (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: make SND_PXA2XX_SOC_I2S selectable (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: remove bindings from pxa2xx-pcm (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: provide PCM ops for ssp, i2s and ac97 components (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa2xx-pcm-lib: fix indenting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: move some functions to pxa2xx-lib (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: clean up function names in pxa2xx-lib (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fold pxa2xx-pcm into its only user, pxa2xx-ac97 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: remove the dmaengine compat need (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/hdmi - Don't fall back to generic when i915 binding fails (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: don't merge format from invalid codec dai (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: extend channel merging to the backend cpu dai (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: qdafe: fix some off by one bugs (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dpcm: improve runtime update predictability (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: Add AZX_DCAPS_PM_RUNTIME for AMD Raven Ridge (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: add extended ops in the hdac_bus (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: remove memory allocation from snd_hdac_ext_bus_device_init (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda: split snd_hda_codec_new function (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: ext: add wait for codec to respond after link reset (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: Remove usage of struct hdac_ext_driver, use hdac_driver instead (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: Remove usage of struct hdac_ext_bus and use hdac_bus instead (Jaroslav Kysela) [1683051]
- [sound] ALSA: hdac: Remove usage of struct hdac_ext_device and use hdac_device instead (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Move in_pm accessors to HDA core (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tas517x: add tas5707 support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-amplifer: add simple-amplifier compatible (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-amplifier: rename dio2125 to simple-amplifer (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Sort DMI table entries alphabetically (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add BYT_RT5651_HP_LR_SWAPPED quirk (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Simplify card long-name (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Fix DMIC map headsetmic mapping (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Fix IN1 map headsetmic mapping (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Remove IN2 input mappings (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Fix IN1_IN2_MAP quirk not being logged (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Change default input map from in2 to in1 (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5651: Add BYT_RT5651_DEFAULT_QUIRKS define (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Kill snd_hda_codec_update_cache() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Comprehensive model list for ALC882 & co (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Comprehensive model list for ALC262 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Comprehensive model list for ALC268 (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Comprehensive model list for ALC259 & co (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Comprehensive model list for ALC662 & co (Jaroslav Kysela) [1683051]
- [sound] ALSA: Fix references to Documentation/.*/MultiSound (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm: remove unused struct q6asm member (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: add proper error check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: apq8096: remove redundant owner assignment (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6routing: support dt based module loading (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm-dai: support dt based module loading (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe-dai: support dt based module loading (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6afe: use of_platform_populate/depopulate() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6asm: use of_platform_populate/depopulate() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qdsp6: q6adm: use of_platform_populate/depopulate() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-utils: Fix unregistration order (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: cx20442: Don't ignore regulator_get() errors. (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Apply PRE_PROBE fixup after ALC269 codec variant setups (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/via - Use standard verb containers (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/via - Simplify control management (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/via - Rewrite with error goto (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/cirrus - Simplify creation of new controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/conexant - Clean up beep code (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Use common helper for creating beep controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Use common helper for creating ALC268 beep controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Use common GPIO mask for ALC660VD ASUS fixup (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Simplify Dell XPS13 GPIO handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Convert some manual GPIO setups (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Simplify mute LED GPIO handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Simplify alc885_fixup_macpro_gpio() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Consolidate gpio_data and gpio_led (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Add GPIO data update helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Manage GPIO bits commonly (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Allow skipping spec->init_amp detection (Jaroslav Kysela) [1683051]
- [sound] ALSA: ac97: add codecs devicetree binding (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: soc-pcm: DPCM cares BE channel constraint (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Configure channel 1 or channel 0 for capture (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Change codec to channel link as per hardware redesign (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: uniphier: remove redundant check of PLL ID (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt1305: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: use devm_snd_soc_register_component() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: fix missing rename from 'reef' to 'sof' (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Simplify alc269_fixup_hp_line1_mic1_led() (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Sanity check of unexpected cap_sync_hook override (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/sigmatel - Use common helper for mic mute LED (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Allow multiple ADCs for mic mute LED controls (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/conexant - Use the mic-mute LED helper (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda/realtek - Use the mic-mute LED helper for HP and others (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Use the common helper for thinkpad_acpi mic mute LED handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: hda - Move mic mute LED helper to the generic parser (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: rename 'reef' to 'sof' in ACPI matching table (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: arizona: Set compressed IRQ to a wake source (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: wm_adsp: Simplify handling of alg offset and length (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: add support for Motu Traveler (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: cancel chunk alignment for protocol version 2 (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: add a flag for AES/EBU on XLR interface (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: add a flag for chunks for main 1/2 out (Jaroslav Kysela) [1683051]
- [sound] ALSA: firewire-motu: suppless consumption for unused element of array in stack (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pcm: Tidy up open/hw_params handling (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: fix copy/paste issue with SOF/broadwell topology file (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add entries for SOF-based machine drivers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: add firmware/topology information for SOF (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: common: Add Geminilake Dialog+Maxim machine driver entry (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: move SKL+ codec ACPI tables to common directory (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: Skylake: cleanup before moving ACPI tables (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: broxton: reduce machine name for bxt_da7219_max98357a (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: kbl_da7219_max98357a: add fe_ops for kbl Audio Capture Port (Jaroslav Kysela) [1683051]
- [sound] ALSA: ARM: pxa: change SSP DMA channels allocation (Jaroslav Kysela) [1683051]
- [sound] ALSA: line6: stop using get_seconds() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ctxfi: use enum type CT_SUM_CTL where appropriate (Jaroslav Kysela) [1683051]
- [sound] ALSA: ice1724: remove unused array (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Fix Acer Iconia 8 over-current detect threshold (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the Nuvison/TMax TM800W560 tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: tegra: fix device_node refcounting (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: pxa: add devicetree support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: codecs: PCM1789: unconditionally flush work (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt5682: add rt5682 codec driver (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: TSCS42xx: Add headphone auto switching (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: TSCS42xx: Remove Playback/Capture in names (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: TSCS42xx: Add mic bias boost control (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak4458: make structure soc_codec_dev_ak4458 static const (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ak5558: make two structures static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: twl6040: make pointer dmic_codec_dev static (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: qcom: apq8096: set card as device drvdata (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: add rsnd_daidrv_get() (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: audio-graph-card: add hp and mic detect gpios same as simple-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card: move hp and mic detection to soc_card probe (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: simple-card-utils: move hp and mic detect gpios from simple-card (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: Intel: bytcr_rt5640: Add quirk for the Chuwi Vi10 tablet (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rt1305: Use ULL suffixes for 64-bit constants (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: add config for rockchip dmaengine pcm register (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rockchip: put device_node on remove (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: stm32: sai: add iec958 controls support (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: AMD: Add NULL pointer check (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: SSI parent cares SWSP bit (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: has .symmetric_rates if SSIs are sharing WS pin (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: sh7760-ac97: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dma-sh7760: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: migor: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: rsnd: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: siu: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: ssi: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: hac: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: fsi: convert to SPDX identifiers (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Add callback for DAPM route load/unload (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: topology: Give more data to clients via callbacks (Jaroslav Kysela) [1683051]
- [sound] ALSA: ASoC: dapm: Fix potential DAI widget pointer deref when linking DAIs (Jaroslav Kysela) [1683051]
- [fs] gfs2: Fix loop in gfs2_rbm_find (v2) (Andreas Grunbacher) [1690483]
- [fs] gfs2: Rename bitmap.bi_{len => bytes} (Andreas Grunbacher) [1690483]

* Wed May 29 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-97.rt16.37.el8]
- [rt] kernel-rt-4.18.0-97.rt16.36.el8 (Juri Lelli) [1678887]
- [vfio] vfio/pci: Mask buggy SR-IOV VF INTx support (Myron Stowe) [1678076]
- [netdrv] net/ibmvnic: Update carrier state after link state change (Steve Best) [1711282]
- [netdrv] net/ibmvnic: Update MAC address settings after adapter reset (Steve Best) [1711282]
- [scsi] scsi: storvsc: Reduce default ring buffer size to 128 Kbytes (Cathy Avery) [1691370]
- [scsi] scsi: storvsc: Fix calculation of sub-channel count (Cathy Avery) [1691370]
- [powercap] powercap: RAPL: Get rid of custom RAPL_CPU() macro (Alexander Beregalov) [1706827]
- [tools] tools/power turbostat: Increase default buffer size (Prarit Bhargava) [1711260]
- [char] virtio_console: initialize vtermno value for ports (Pankaj Gupta) [1460636]
- [rpmspec] redhat: exclude kvm_stat from pathfix.py's tenure (Vitaly Kuznetsov) [1692804]
- [virt] kvm: arm: Skip stage2 huge mappings for unaligned ipa backed by THP (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Ensure vcpu target is unset on reset failure (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic-v3: Retire pending interrupts on disabling LPIs (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: arch_timer: Fix CNTP_TVAL calculation (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move RSB stuffing to before the first RET after VM-Exit (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Fix size checks in vmx_set_nested_state (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: lapic: Check for in-kernel LAPIC before deferencing apic pointer (Vitaly Kuznetsov) [1692804]
- [virt] KVM: fix KVM_CLEAR_DIRTY_LOG for memory slots of unaligned size (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: reset MMU context when 32-bit guest switches PAE (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Whitelist port 0x7e for pre-incrementing rip (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: lapic: Convert guest TSC to host time domain if necessary (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: lapic: Allow user to disable adaptive tuning of timer advancement (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: lapic: Track lapic timer advance per vCPU (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: lapic: Disable timer advancement if adaptive tuning goes haywire (Vitaly Kuznetsov) [1692804]
- [kvm] x86: kvm: hyper-v: deal with buggy TLB flush requests from WS2012 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Consider LAPIC TSC-Deadline timer expired if deadline too short (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: avoid misreporting level-triggered irqs as edge-triggered in tracing (Vitaly Kuznetsov) [1692804]
- [virt] KVM: fix spectrev1 gadgets (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: fix warning Using plain integer as NULL pointer (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm: add a selftest for SMM (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm: fix for compilers that do not support -no-pie (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm/evmcs_test: complete I/O before migrating guest state (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Always use 32-bit SMRAM save state for 32-bit kernels (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Don't clear EFER during SMM transitions for 32-bit vCPU (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: clear SMM flags before loading state while leaving SMM (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Open code kvm_set_hflags (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Load SMRAM in a single shot when leaving SMM (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Expose RDPMC-exiting only when guest supports PMU (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm: move kvm_load/put_guest_xcr0 into atomic context (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: svm: make sure NMI is injected after nmi_singlestep (Vitaly Kuznetsov) [1692804]
- [kvm] svm/avic: Fix invalidate logical APIC id entry (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "svm: Fix AVIC incomplete IPI emulation" (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: mmu: Fix overflow on kvm mmu page limit calculation (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: always use early vmcs check when EPT is disabled (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: allow tests to use bad virtual-APIC page address (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Fix an inverted list_empty() check when zapping sptes (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: nVMX: fix x2APIC VTPR read intercept (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: nVMX: close leak of L0's x2APIC MSRs (CVE-2019-3887) (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: SVM: prevent DBG_DECRYPT and DBG_ENCRYPT overflow (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: svm: fix potential get_num_contig_pages overflow (Vitaly Kuznetsov) [1692804]
- [documentation] Documentation: kvm: clarify KVM_SET_USER_MEMORY_REGION (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: complete IO before migrating guest state (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: disable stack protector for all KVM tests (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: explicitly disable PIE for tests (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: assert on exit reason in CR4/cpuid sync test (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: update rip after emulating IO (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: avoid spurious pending stimer on vCPU init (Vitaly Kuznetsov) [1692804]
- [kvm] kvm/x86: Move MSR_IA32_ARCH_CAPABILITIES to array emulated_msrs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Emulate MSR_IA32_ARCH_CAPABILITIES on AMD hosts (Vitaly Kuznetsov) [1692804]
- [virt] kvm: don't redefine flags as something else (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: mmu: Used range based flushing in slot_handle_level_range (Vitaly Kuznetsov) [1692804]
- [x86] x86/hyper-v: Fix definition of HV_MAX_FLUSH_REP_COUNT (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: remove check on nr_mmu_pages in kvm_arch_commit_memory_region() (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: nVMX: Add a vmentry check for HOST_SYSENTER_ESP and HOST_SYSENTER_EIP fields (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: SVM: Workaround errata#1096 (insn_len maybe zero on SMAP violation) (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Reject device ioctls from processes other than the VM's creator (Vitaly Kuznetsov) [1692804]
- [documentation] KVM: doc: Fix incorrect word ordering regarding supported use of APIs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: fix handling of role.cr4_pae and rename it to 'gpte_size' (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Do not inherit quadrant and invalid for the root shadow EPT (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Comments cleanup in mmu.c (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic-its: Make attribute accessors static (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Fix handling of stage2 huge mappings (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Enforce PTE mappings at stage2 when needed (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic-its: Take the srcu lock when parsing the memslots (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic-its: Take the srcu lock when writing to guest memory (Vitaly Kuznetsov) [1692804]
- [virt] arm64: KVM: Always set ICH_HCR_EL2.EN if GICv4 is enabled (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm64: Reset the PMU in preemptible context (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: fix formatting of a comment (Vitaly Kuznetsov) [1692804]
- [documentation] KVM: doc: Document the life cycle of a VM and its resources (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM/MMU: Flush tlb directly in the kvm_zap_gfn_range()" (Vitaly Kuznetsov) [1692804]
- [documentation] virtio-ccw: diag 500 may return a negative cookie (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S: Add count cache flush parameters to kvmppc_get_cpu_char() (Vitaly Kuznetsov) [1692804]
- [virt] kvm: properly check debugfs dentry before using it (Vitaly Kuznetsov) [1692804]
- [powerpc] KVM: PPC: Fix compilation when KVM is not enabled (Vitaly Kuznetsov) [1692804]
- [powerpc] powerpc: Avoid circular header inclusion in mmu-hash.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: MMU: record maximum physical address width in kvm_mmu_extended_role (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Return LA57 feature based on hardware capability (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: fix switch between root and guest MMUs (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Minor cleanups for kvm_main.c (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Fix architecturally invalid reset value for FPEXC32_EL2 (Vitaly Kuznetsov) [1692804]
- [kvm] powerpc/kvm: Save and restore host AMR/IAMR/UAMOR (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S: Improve KVM reference counting (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Fix build failure without IOMMU support (Vitaly Kuznetsov) [1692804]
- [powerpc] powerpc/64s: Better printing of machine check info for guest MCEs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Simplify machine check handling (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Context switch AMR on Power9 (Vitaly Kuznetsov) [1692804]
- [virt] Revert "KVM: Eliminate extra function calls in kvm_get_dirty_log_protect()" (Vitaly Kuznetsov) [1692804]
- [x86] x86: kvmguest: use TSC clocksource if invariant TSC is exposed (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Never start grow vCPU halt_poll_ns from value below halt_poll_ns_grow_start (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Expose the initial start value in grow_halt_poll_ns() as a module parameter (Vitaly Kuznetsov) [1692804]
- [virt] KVM: grow_halt_poll_ns() should never shrink vCPU halt_poll_ns (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Consolidate kvm_mmu_zap_all() and kvm_mmu_zap_mmio_sptes() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: WARN if zapping a MMIO spte results in zapping children (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Differentiate between nr zapped and list unstable (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: fast invalidate all pages" (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Voluntarily reschedule as needed when zapping all sptes (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: skip over invalid root pages when zapping all sptes (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: x86: use the fast way to invalidate all pages" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: show mmu_valid_gen in shadow page related tracepoints" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: add tracepoint for kvm_mmu_invalidate_all_pages" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: zap pages in batch" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: collapse TLB flushes when zap all pages" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: reclaim the zapped-obsolete page first" (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Remove is_obsolete() call (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Voluntarily reschedule as needed when zapping MMIO sptes (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "KVM: MMU: drop kvm_mmu_zap_mmio_sptes" (Vitaly Kuznetsov) [1692804]
- [x86] Revert "KVM: MMU: document fast invalidate all pages" (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Zap only the relevant pages when removing a memslot (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Split remote_flush+zap case out of kvm_mmu_flush_or_zap() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Move slot_level_*() helper functions up a few lines (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Move the memslot update in-progress flag to bit 63 (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Remove the hack to trigger memslot generation wraparound (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Refactor the MMIO SPTE generation handling (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Use a u64 when passing the MMIO gen around (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Explicitly define the "memslot update in-progress" bit (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Do not cache MMIO accesses while memslots are in flux (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86/mmu: Detect MMIO generation wrap in any address space (Vitaly Kuznetsov) [1692804]
- [virt] KVM: Call kvm_arch_memslots_updated() before updating memslots (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Add memcg accounting to KVM allocations (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: svm: Add memcg accounting to KVM allocations (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Add memcg accounting to KVM allocations (Vitaly Kuznetsov) [1692804]
- [virt] kvm: Add memcg accounting to KVM allocations (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: do not start the preemption timer hrtimer unnecessarily (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Fix typos in vmentry/vmexit control setting (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: cleanup freeing of nested state (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Sync the pending Posted-Interrupts (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: expose MOVDIR64B CPU feature into VM. (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: expose MOVDIRI CPU feature into VM. (Vitaly Kuznetsov) [1692804]
- [kvm] kvm, x86, mmu: Use kernel generic dynamic physical address mask (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: remove useless is_protmode check (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Ignore limit checks on VMX instructions using flat segments (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Apply addr size mask to effective address for VMX instructions (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Sign extend displacements of VMX instr's mem operands (Vitaly Kuznetsov) [1692804]
- [kvm] svm: Fix improper check when deactivate AVIC (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: cull apicv code when userspace irqchip is requested (Vitaly Kuznetsov) [1692804]
- [kvm] svm: Fix AVIC DFR and LDR handling (Vitaly Kuznetsov) [1692804]
- [virt] kvm: Use struct_size() in kmalloc() (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: set offset for kvm unstable clock (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Reorder clearing of registers in the vCPU-run assembly flow (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Call vCPU-run asm sub-routine from C and remove clobbering (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Preserve callee-save registers in vCPU-run asm sub-routine (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Return VM-Fail from vCPU-run assembly via standard ABI reg (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Pass @launched to the vCPU-run asm via standard ABI regs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Use RAX as the scratch register during vCPU-run (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Rename ____vmx_vcpu_run() to __vmx_vcpu_run() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Fold __vmx_vcpu_run() back into vmx_vcpu_run() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move vCPU-run code to a proper assembly routine (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Create a stack frame in vCPU-run (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Use #defines in place of immediates in VM-Enter inline asm (Vitaly Kuznetsov) [1692804]
- [x86] KVM: x86: Explicitly #define the VCPU_REGS_* indices (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Remove unused gpa_end variable (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm64: Fix comment for KVM_PHYS_SHIFT (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: fix spelling mistake: "auxilary" -> "auxiliary" (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm/arm64: Prefix header search paths with $(srctree)/ (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm/arm64: Remove -I. header search paths (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Fix TRACE_INCLUDE_PATH (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: arch_timer: Mark physical interrupt active when a virtual interrupt is pending (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Describe data or unified caches as having 1 set and 1 way (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: KVM: Expose sanitised cache type register to guest (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Move kvm_is_write_fault to header file (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: arch_timer: Assign the phys timer on VHE systems (Vitaly Kuznetsov) [1692804]
- [include] clocksource/arm_arch_timer: Store physical timer IRQ number for KVM on VHE (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: timer: Rework data structures for multiple timers (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: consolidate arch timer trap handlers (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm64: Reuse sys_reg() macro when searching the trap table (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm64: Fix ICH_ELRSR_EL2 sysreg naming (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Simplify bg_timer programming (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm/arm64: Factor out VMID into struct kvm_vmid (Vitaly Kuznetsov) [1692804]
- [virt] arm/arm64: KVM: Statically configure the host's view of MPIDR (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Drop VHE-specific HYP call stub (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: KVM: Allow for direct call of HYP functions when using VHE (Vitaly Kuznetsov) [1692804]
- [virt] arm/arm64: KVM: Introduce kvm_call_hyp_ret() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Release all hardware TCE tables attached to a group (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Optimise mmio emulation for devices on FAST_MMIO_BUS (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S: Allow XICS emulation to work in nested hosts using XIVE (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Replace kmalloc_node+memset with kzalloc_node (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S PR: Add emulation for slbfee. instruction (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Fix entry number check for add_atomic_switch_msr() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Recompute PID.ON when clearing PID.SN (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Restore a preemption timer consistency check (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/nVMX: read from MSR_IA32_VMX_PROCBASED_CTLS2 only when it is available (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Use vcpu->arch.regs directly when saving/loading guest state (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Don't save guest registers after VM-Fail (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Invert the ordering of saving guest/host scratch reg at VM-Enter (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Pass "launched" directly to the vCPU-run asm blob (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Update VMCS.HOST_RSP via helper C function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Load/save guest CR2 via C code in __vmx_vcpu_run() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Cache host_rsp on a per-VMCS basis (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Let the compiler select the reg for holding HOST_RSP (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Reference vmx->loaded_vmcs->launched directly (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Capture VM-Fail via CC_{SET, OUT} in nested early checks (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Capture VM-Fail to a local var in nested_vmx_check_vmentry_hw() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Explicitly reference the scratch reg in nested early checks (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Drop STACK_FRAME_NON_STANDARD from nested_vmx_check_vmentry_hw() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Remove a rogue "rax" clobber from nested_vmx_check_vmentry_hw() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Let the compiler save/load RDX during vCPU-run (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Manually load RDX in vCPU-run asm blob (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Save RSI to an unused output in the vCPU-run asm blob (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Modify only RSP when creating a placeholder for guest's RCX (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Zero out *all* general purpose registers after VM-Exit (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Check a single byte for VMCS "launched" in nested early checks (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Compare only a single byte for VMCS' "launched" in vCPU-run (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm: add selftest for releasing VM file descriptor while in L2 (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm/arm64: Add kvm_ras.h to collect kvm specific RAS plumbing (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: work around leak of uninitialized stack contents (CVE-2019-7222) (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm64: Forbid kprobing of the VHE world-switch code (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm64: Relax the restriction on using stage2 PUD huge mapping (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic: Always initialize the group of private IRQs (Vitaly Kuznetsov) [1692804]
- [kvm] arm/arm64: KVM: Don't panic on failure to properly reset system registers (Vitaly Kuznetsov) [1692804]
- [virt] arm/arm64: KVM: Allow a VCPU to fully reset itself (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm/arm64: Reset the VCPU without preemption and vcpu state loaded (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: fix possible null pointer dereference in pending_irqs() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: start using the GIB (Vitaly Kuznetsov) [1692804]
- [s390] KVM: s390: add gib_alert_irq_handler() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: kvm_s390_gisa_clear() now clears the IPM only (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: add functions to (un)register GISC with GISA (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: add kvm reference to struct sie_page2 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: add the GIB and its related life-cyle functions (Vitaly Kuznetsov) [1692804]
- [s390] s390/cio: add function chsc_sgib() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: introduce struct kvm_s390_gisa_interrupt (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: remove kvm_s390_ from gisa static inline functions (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: use pending_irqs_no_gisa() where appropriate (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: coding style kvm_s390_gisa_init/clear() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: s390: move bitmap idle_mask into arch struct top level (Vitaly Kuznetsov) [1692804]
- [virt] virt/kvm: Replace spin_is_locked() with lockdep (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Mark expected switch fall-throughs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: fix TRACE_INCLUDE_PATH and remove -I. header search paths (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: check returned evmcs version range (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: nested_enable_evmcs() sets vmcs_version incorrectly (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move vmx_vcpu_run()'s VM-Enter asm blob to a helper function (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: Fix region overlap check in kvm_util (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: fix some -Wmissing-prototypes warnings (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nSVM: clear events pending from svm_complete_interrupts() when exiting to L1 (Vitaly Kuznetsov) [1692804]
- [kvm] svm: Fix AVIC incomplete IPI emulation (Vitaly Kuznetsov) [1692804]
- [kvm] svm: Add warning message for AVIC IPI invalid target (Vitaly Kuznetsov) [1692804]
- [x86] KVM: x86: WARN_ONCE if sending a PV IPI returns a fatal error (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Fix PV IPIs for 32-bit KVM host (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: recommend using eVMCS only when it is enabled (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: don't recommend doing reset via synthetic MSR (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86/vmx: Use kzalloc for cached_vmcs12 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Use the correct field var when clearing VM_ENTRY_LOAD_IA32_PERF_GLOBAL_CTRL (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Fix single-step debugging (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: don't announce GUEST IDLE MSR support (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Don't generate UNDEF when LORegion feature is present (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic: Make vgic_cpu->ap_list_lock a raw_spinlock (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic: Make vgic_dist->lpi_list_lock a raw_spinlock (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic: Make vgic_irq->irq_lock a raw_spinlock (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: powerpc: remove -I. header search paths (Vitaly Kuznetsov) [1692804]
- [documentation] Documentation/virtual/kvm: Update URL for AMD SEV API specification (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/VMX: Avoid return error when flush tlb successfully in the hv_remote_flush_tlb_with_range() (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: sev: Fail KVM_SEV_INIT if already initialized (Vitaly Kuznetsov) [1692804]
- [virt] KVM: validate userspace input in kvm_clear_dirty_log_protect() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Fix bit shifting in update_intel_pt_cfg (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: radix: Fix uninitialized var build error (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: ucall: fix exit mmio address guessing (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move VM-Enter + VM-Exit handling to non-inline sub-routines (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Explicitly reference RCX as the vmx_vcpu pointer in asm blobs (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/x86: Use SVM assembly instruction mnemonics instead of .byte streams (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/MMU: Flush tlb directly in the kvm_zap_gfn_range() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/MMU: Flush tlb directly in kvm_set_pte_rmapp() (Vitaly Kuznetsov) [1692804]
- [virt] KVM/MMU: Move tlb flush in kvm_set_pte_rmapp() to kvm_mmu_notifier_change_pte() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: Make kvm_set_spte_hva() return int (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: Replace old tlb flush function with new one to flush a specified range. (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/MMU: Add tlb flush with range helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/VMX: Add hv tlb range flush support (Vitaly Kuznetsov) [1692804]
- [x86] x86/hyper-v: Add HvFlushGuestAddressList hypercall support (Vitaly Kuznetsov) [1692804]
- [x86] KVM: Add tlb_remote_flush_with_range callback in kvm_x86_ops (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Disable Intel PT when VMXON in L1 guest (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Set intercept for Intel PT MSRs read/write (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Implement Intel PT MSRs read/write emulation (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Introduce a function to initialize the PT configuration (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Add Intel PT context switch for each vcpu (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Add Intel Processor Trace cpuid emulation (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Add Intel PT virtualization work mode (Vitaly Kuznetsov) [1692804]
- [x86] perf/x86/intel/pt: add new capability for Intel PT (Vitaly Kuznetsov) [1692804]
- [x86] perf/x86/intel/pt: Add new bit definitions for PT MSRs (Vitaly Kuznetsov) [1692804]
- [x86] perf/x86/intel/pt: Introduce intel_pt_validate_cap() (Vitaly Kuznetsov) [1692804]
- [x86] perf/x86/intel/pt: Export pt_cap_get() (Vitaly Kuznetsov) [1692804]
- [x86] perf/x86/intel/pt: Move Intel PT MSRs bit defines to global header (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: aarch64: dirty_log_test: support greater than 40-bit IPAs (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: add pa-48/va-48 VM modes (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: dirty_log_test: improve mode param management (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: dirty_log_test: reset guest test phys offset (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: dirty_log_test: always use -t (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: dirty_log_test: don't identity map the test mem (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: x86_64: dirty_log_test: fix -t (Vitaly Kuznetsov) [1692804]
- [virt] KVM: fix some typos (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: convert to SPDX identifiers (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Remove KF() macro placeholder (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Allow guest read access to IA32_TSC (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: nVMX: NMI-window and interrupt-window exiting should wake L2 from HLT (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nSVM: Fix nested guest support for PAUSE filtering. (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Remove duplicated include from vmx.c (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm: report failed stage when exit reason is unexpected (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: fix size of x86_fpu_cache objects (Vitaly Kuznetsov) [1692804]
- [kvm] powerpc/fsl: Flush branch predictor when entering KVM (Vitaly Kuznetsov) [1692804]
- [kvm] powerpc/fsl: Emulate SPRN_BUCSR register (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: nSVM: fix switch to guest mmu (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Add trapped system register access tracepoint (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm64: Make vcpu const in vcpu_read_sys_reg (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: arch_timer: Simplify kvm_timer_vcpu_terminate (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Remove arch timer workqueue (Vitaly Kuznetsov) [1692804]
- [virt] KVM: fix unregistering coalesced mmio zone from wrong bus (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm64: Add support for creating PUD hugepages at stage 2 (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm64: Update age handlers to support PUD hugepages (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm64: Support handling access faults for PUD hugepages (Vitaly Kuznetsov) [1692804]
- [arm64] KVM: arm64: Support PUD hugepage in stage2_is_exec() (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm64: Support dirty page tracking for PUD hugepages (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Introduce helpers to manipulate page table entries (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Re-factor setting the Stage 2 entry to exec on fault (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: Share common code in user_mem_abort() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: arm/arm64: Log PSTATE for unhandled sysregs (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Consistently advance singlestep when emulating instructions (Vitaly Kuznetsov) [1692804]
- [virt] arm64: KVM: Skip MMIO insn after emulation (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Allow passthrough of an emulated device to an L3 guest (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S: Introduce new hcall H_COPY_TOFROM_GUEST to access quadrants 1 & 2 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Allow passthrough of an emulated device to an L2 guest (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Update kvmppc_st and kvmppc_ld to use quadrants (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Add load_from_eaddr and store_to_eaddr to the kvmppc_ops struct (Vitaly Kuznetsov) [1692804]
- [powerpc] KVM: PPC: Book3S HV: Implement functions to access quadrants 1 & 2 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Add function kvmhv_vcpu_is_radix() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S: Only report KVM_CAP_SPAPR_TCE_VFIO on powernv machines (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: ucall: improve ucall placement in memory, fix unsigned comparison (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Dynamically allocate guest_fpu (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Use task structs fpu field for user (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move the checks for Guest Non-Register States to a separate helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move the checks for Host Control Registers and MSRs to a separate helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move the checks for VM-Entry Control Fields to a separate helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move the checks for VM-Exit Control Fields to a separate helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Remove param indirection from nested_vmx_check_msr_switch() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move the checks for VM-Execution Control Fields to a separate helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Prepend "nested_vmx_" to check_vmentry_{pre, post}reqs() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/VMX: Check ept_pointer before flushing ept tlb (Vitaly Kuznetsov) [1692804]
- [kvm] KVM nVMX: MSRs should not be stored if VM-entry fails during or after loading guest state (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Don't modify MSR_PLATFORM_INFO on vCPU reset (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: add cpu into VMX preemption timer bug list (Vitaly Kuznetsov) [1692804]
- [kvm] x86/hyper-v: Stop caring about EOI for direct stimers (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: avoid open-coding stimer_mark_pending() in kvm_hv_notify_acked_sint() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: direct mode for synthetic timers (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvm/hyper-v: use stimer config definition from hyperv-tlfs.h (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: Add hyperv_cpuid test (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: implement an unchecked version of vcpu_ioctl() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: Introduce KVM_GET_SUPPORTED_HV_CPUID (Vitaly Kuznetsov) [1692804]
- [kvm] x86/hyper-v: Do some housekeeping in hyperv-tlfs.h (Vitaly Kuznetsov) [1692804]
- [x86] x86/hyper-v: Mark TLFS structures packed (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyper-v: Introduce nested_get_evmcs_version() helper (Vitaly Kuznetsov) [1692804]
- [kvm] x86: kvm: hyperv: don't retry message delivery for periodic timers (Vitaly Kuznetsov) [1692804]
- [kvm] x86: kvm: hyperv: simplify SynIC message delivery (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: remove unnecessary recalculate_apic_map (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: svm: remove unused struct definition (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Skip all SYSCALL MSRs in setup_msrs() when !EFER.SCE (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Don't set hardware IA32_CSTAR MSR on VM-entry (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Document the need for MSR_STAR in i386 builds (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Set IA32_TSC_AUX for legacy mode guests (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move nested code to dedicated files (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Expose nested_vmx_allowed() to nested VMX as a non-inline (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Expose various getters and setters to nested VMX (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Expose misc variables needed for nested VMX (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move "vmcs12 to shadow/evmcs sync" to helper function (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Call nested_vmx_setup_ctls_msrs() iff @nested is true (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Set callbacks for nested functions during hardware setup (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move the hardware {un}setup functions to the bottom (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: nVMX: Allow nested_enable_evmcs to be NULL (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move nested hardware/vcpu {un}setup to helper functions (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move VMX instruction wrappers to a dedicated header file (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move eVMCS code to dedicated files (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Add vmx.h to hold VMX definitions (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Move vmcs12 code to dedicated files (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move VMCS definitions to dedicated file (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Expose various module param vars via capabilities.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move capabilities structs and helpers to dedicated file (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Pass vmx_capability struct to setup_vmcs_config() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Properly handle dynamic VM Entry/Exit controls (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move caching of MSR_IA32_XSS to hardware_setup() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Drop the "vmx" prefix from vmx_evmcs.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: rename vmx_shadow_fields.h to vmcs_shadow_fields.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Move VMX specific files to a "vmx" subdirectory (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Add requisite includes to hyperv.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Add requisite includes to kvm_cache_regs.h (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: Alphabetize the includes in vmx.c (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Allocate and configure VM{READ, WRITE} bitmaps iff enable_shadow_vmcs (Vitaly Kuznetsov) [1692804]
- [tools] kvm: introduce manual dirty log reprotect (Vitaly Kuznetsov) [1692804]
- [virt] kvm: rename last argument to kvm_get_dirty_log_protect (Vitaly Kuznetsov) [1692804]
- [virt] kvm: make KVM_CAP_ENABLE_CAP_VM architecture agnostic (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S PR: Set hflag to indicate that POWER9 supports 1T segments (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Change to use DEFINE_SHOW_ATTRIBUTE macro (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: Don't trap host pointer auth use to EL2 (Vitaly Kuznetsov) [1692804]
- [kvm] arm64/kvm: hide ptrauth from guests (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: add pointer authentication register bits (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: add comments about EC exception levels (Vitaly Kuznetsov) [1692804]
- [arm64] arm64/kvm: consistently handle host HCR_EL2 flags (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: Add configuration/documentation for Cortex-A76 erratum 1165522 (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Handle ARM erratum 1165522 in TLB invalidation (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Add synchronization on translation regime change for erratum 1165522 (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: KVM: Force VHE for systems affected by erratum 1165522 (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: Add TCR_EPD{0,1} definitions (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm64: Rework detection of SVE, !VHE systems (Vitaly Kuznetsov) [1692804]
- [kvm] nVMX x86: Check VMX-preemption timer controls on vmentry of L2 guests (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/nVMX: Remove unneeded forward jump in nested_vmx_check_vmentry_hw asm (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Unrestricted guest mode requires EPT (Vitaly Kuznetsov) [1692804]
- [tools] tools/kvm_stat: switch to python3 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: Trace changes to active TSC offset regardless if vCPU in guest-mode (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: vmcs12 revision_id is always VMCS12_REVISION even when copied from eVMCS (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Verify eVMCS revision id match supported eVMCS version on eVMCS VMPTRLD (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/vmx: fix old-style function declaration (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: fix empty-body warnings (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Fix kernel info-leak when enabling KVM_CAP_HYPERV_ENLIGHTENED_VMCS more than once (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm/arm64: vgic: Replace spin_is_locked() with lockdep (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Move and undef TRACE_INCLUDE_PATH/FILE (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Use exported tb_to_ns() function in decrementer emulation (Vitaly Kuznetsov) [1692804]
- [tools] selftests: kvm: Fix -Wformat warnings (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: fix spelling mistake "Insufficent" -> "Insufficient" (Vitaly Kuznetsov) [1692804]
- [kvm] Revert "kvm: x86: optimize dr6 restore" (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Optimize clearing TCEs for sparse tables (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/nVMX: tweak shadow fields (Vitaly Kuznetsov) [1692804]
- [tools] selftests/kvm: add missing executables to .gitignore (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Don't use streamlined entry path on early POWER9 chips (Vitaly Kuznetsov) [1692804]
- [virt] arm/arm64: KVM: Enable 32 bits kvm vcpu events support (Vitaly Kuznetsov) [1692804]
- [virt] arm/arm64: KVM: Rename function kvm_arch_dev_ioctl_check_extension() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: enable nested virtualization by default (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/x86: Use 32bit xor to clear registers in svm.c (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Introduce KVM_CAP_EXCEPTION_PAYLOAD (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: vmx: Defer setting of DR6 until #DB delivery (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Defer setting of CR2 until #PF delivery (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Add payload operands to kvm_multiple_exception (Vitaly Kuznetsov) [1692804]
- [x86] kvm: x86: Add exception payload fields to kvm_vcpu_events (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: Add has_payload and payload to kvm_queued_exception (Vitaly Kuznetsov) [1692804]
- [documentation] KVM: Documentation: Fix omission in struct kvm_vcpu_events (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: add Enlightened VMCS test (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/nVMX: nested state migration for Enlightened VMCS (Vitaly Kuznetsov) [1692804]
- [tools] KVM: selftests: state_test: test bare VMXON migration (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/hyperv: don't clear VP assist pages on init (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: optimize prepare_vmcs02{, _full} for Enlightened VMCS case (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: implement enlightened VMPTRLD and VMCLEAR (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: add enlightened VMCS state (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: add KVM_CAP_HYPERV_ENLIGHTENED_VMCS capability (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: refactor evmcs_sanitize_exec_ctrls() (Vitaly Kuznetsov) [1692804]
- [virt] KVM: refine the comment of function gfn_to_hva_memslot_prot() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: reintroduce pte_list_remove, but including mmu_spte_clear_track_bits (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: rename pte_list_remove to __pte_list_remove (Vitaly Kuznetsov) [1692804]
- [virt] kvm/x86 : add coalesced pio support (Vitaly Kuznetsov) [1692804]
- [documentation] kvm/x86 : add document for coalesced mmio (Vitaly Kuznetsov) [1692804]
- [kvm] kvm/x86 : fix some typo (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/VMX: Change hv flush logic when ept tables are mismatched. (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/x86: Use 32bit xor to clear register (Vitaly Kuznetsov) [1692804]
- [x86] KVM/x86: Use assembly instruction mnemonics instead of .byte streams (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/x86: Fix invvpid and invept register operand size in 64-bit mode (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: check if MMU reconfiguration is needed in init_kvm_nested_mmu() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: check if tdp/shadow MMU reconfiguration is needed (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/nVMX: introduce source data cache for kvm_init_shadow_ept_mmu() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: make space for source data caching in struct kvm_mmu (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: get rid of redundant kvm_mmu_setup() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: introduce guest_mmu (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu.c: add kvm_mmu parameter to kvm_mmu_free_roots() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu.c: set get_pdptr hook in kvm_init_shadow_ept_mmu() (Vitaly Kuznetsov) [1692804]
- [kvm] x86/kvm/mmu: make vcpu->mmu a pointer to the current MMU (Vitaly Kuznetsov) [1692804]
- [kvm] kvm: x86: optimize dr6 restore (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: optimize sparse VP set processing (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: fix 'tlb_lush' typo (Vitaly Kuznetsov) [1692804]
- [virt] vgic: Add support for 52bit guest physical address (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: WARN if nested run hits VMFail with early consistency checks enabled (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: add option to perform early consistency checks via H/W (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: vmx: write HOST_IA32_EFER in vmx_set_constant_host_state() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: call kvm_skip_emulated_instruction in nested_vmx_{fail, succeed} (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: do not call nested_vmx_succeed() for consistency check VMExit (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: do not skip VMEnter instruction that succeeds (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: do early preparation of vmcs02 before check_vmentry_postreqs() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: initialize vmcs02 constant exactly once (per VMCS) (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: split pieces of prepare_vmcs02() to prepare_vmcs02_early() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: VMX: remove ASSERT() on vmx->pml_pg validity (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: vVMX: rename label for post-enter_guest_mode consistency check (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: assimilate nested_vmx_entry_failure() into nested_vmx_enter_non_root_mode() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: rename enter_vmx_non_root_mode to nested_vmx_enter_non_root_mode (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: try to set EFER bits correctly when initializing controls (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: vmx: do not unconditionally clear EFER switching (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: reset cache/shadows when switching loaded VMCS (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: use vm_exit_controls_init() to write exit controls for vmcs02 (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: move vmcs12 EPTP consistency check to check_vmentry_prereqs() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: move host EFER consistency checks to VMFail path (Vitaly Kuznetsov) [1692804]
- [virt] KVM: leverage change to adjust slots->used_slots in update_memslots() (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: implement PV IPI send hypercalls (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: optimize kvm_hv_flush_tlb() for vp_index == vcpu_idx case (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: valid_bank_mask should be 'u64' (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: hyperv: keep track of mismatched VP indexes (Vitaly Kuznetsov) [1692804]
- [virt] KVM: x86: hyperv: optimize 'all cpus' case in kvm_hv_flush_tlb() (Vitaly Kuznetsov) [1692804]
- [kvm] kvm/x86: return meaningful value from KVM_SIGNAL_MSI (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: move definition PT_MAX_HUGEPAGE_LEVEL and KVM_NR_PAGE_SIZES together (Vitaly Kuznetsov) [1692804]
- [kvm] KVM/VMX: Remve unused function is_external_interrupt(). (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: x86: return 0 in case kvm_mmu_memory_cache has min number of objects (Vitaly Kuznetsov) [1692804]
- [kvm] nVMX x86: Make nested_vmx_check_pml_controls() concise (Vitaly Kuznetsov) [1692804]
- [x86] KVM: x86: adjust kvm_mmu_page member to save 8 bytes (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: support high GPAs in dirty_log_test (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: stop lying to aarch64 tests about PA-bits (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: dirty_log_test: also test 64K pages on aarch64 (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: port dirty_log_test to aarch64 (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: introduce new VM mode for 64K pages (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: add vcpu support for aarch64 (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: add virt mem support for aarch64 (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: add vm_phy_pages_alloc (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: tidy up kvm_util (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: add cscope make target (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: move arch-specific files to arch-specific locations (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: introduce ucall (Vitaly Kuznetsov) [1692804]
- [tools] kvm: selftests: vcpu_setup: set cr4.osfxsr (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: LAPIC: Tune lapic_timer_advance_ns automatically (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Do not flush TLB on L1<->L2 transitions if L1 uses VPID and EPT (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Flush linear and combined mappings on VPID02 related flushes (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Use correct VPID02 when emulating L1 INVVPID (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: nVMX: Flush TLB entries tagged by dest EPTP on L1<->L2 transitions (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: vmx: rename KVM_GUEST_CR0_MASK tp KVM_VM_CR0_ALWAYS_OFF (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Remove redundand permission bits removal (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Propagate errors to the guest when failed instead of ignoring (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S HV: Provide mode where all vCPUs on a core must be the same VM (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Book3S PR: Exiting split hack mode needs to fixup both PC and LR (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Remove some extra semicolon in kvm_target_cpu (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: PPC: Validate all tces before updating tables (Vitaly Kuznetsov) [1692804]
- [documentation] arm64: Add silicon-errata.txt entry for ARM erratum 1188873 (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: arch_timer: Add workaround for ARM erratum 1188873 (Vitaly Kuznetsov) [1692804]
- [virt] signal/arm/kvm: Use send_sig_mceerr (Vitaly Kuznetsov) [1692804]
- [arm64] arm64/cpufeatures: Introduce ESR_ELx_SYS64_ISS_RT() (Vitaly Kuznetsov) [1692804]
- [kvm] signal/x86: Use send_sig_mceerr as apropriate (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvm: Use __bss_decrypted attribute in shared variables (Vitaly Kuznetsov) [1692804]
- [x86] x86/mm: Add .bss..decrypted section to hold shared variables (Vitaly Kuznetsov) [1692804]
- [kvm] KVM: vmx: Inject #UD for SGX ENCLS instruction in guest (Vitaly Kuznetsov) [1692804]
- [x86] KVM: vmx: Add defines for SGX ENCLS exiting (Vitaly Kuznetsov) [1692804]
- [documentation] KVM: Documentation: rename the capability of KVM_CAP_ARM_SET_SERROR_ESR (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Mark kvm_get_preset_lpj() as __init (Vitaly Kuznetsov) [1692804]
- [virt] kvm: Don't open code task_pid in kvm_vcpu_ioctl (Vitaly Kuznetsov) [1692804]
- [virt] KVM: arm64: Share the parts of get/set events useful to 32bit (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: export the capability to set guest SError syndrome (Vitaly Kuznetsov) [1692804]
- [kvm] arm/arm64: KVM: Add KVM_GET/SET_VCPU_EVENTS (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Switch kvmclock data to a PER_CPU variable (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Move kvmclock vsyscall param and init to kvmclock (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Mark variables __initdata and __ro_after_init (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Cleanup the code (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Decrapify kvm_register_clock() (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Remove page size requirement from wall_clock (Vitaly Kuznetsov) [1692804]
- [x86] x86/kvmclock: Remove memblock dependency (Vitaly Kuznetsov) [1692804]
- [kvm] kvm/arm: use PSR_AA32 definitions (Vitaly Kuznetsov) [1692804]
- [kvm] arm64: KVM: Handle Set/Way CMOs as NOPs if FWB is present (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: KVM: Add support for Stage-2 control of memory types and cacheability (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: Handle mismatched cache type (Vitaly Kuznetsov) [1692804]
- [arm64] arm64: Fix mismatched cache line size detection (Vitaly Kuznetsov) [1692804]

* Mon May 27 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-96.rt16.36.el8]
- [rt] kernel-rt-4.18.0-96.rt16.35.el8 (Juri Lelli) [1678887]
- [lib] rhel-kabi: Add RH_KABI_FORCE_CHANGE() to radix-tree and idr functions (Don Dutile) [1692079]
- [lib] XArray: Fix xa_reserve for 2-byte aligned entries (Don Dutile) [1692079]
- [lib] XArray: Fix xa_erase of 2-byte aligned entries (Don Dutile) [1692079]
- [lib] XArray: Use xa_cmpxchg to implement xa_reserve (Don Dutile) [1692079]
- [lib] XArray: Fix xa_release in allocating arrays (Don Dutile) [1692079]
- [lib] XArray: Mark xa_insert and xa_reserve as must_check (Don Dutile) [1692079]
- [lib] XArray: Add cyclic allocation (Don Dutile) [1692079]
- [lib] XArray: Redesign xa_alloc API (Don Dutile) [1692079]
- [lib] XArray: Add support for 1s-based allocation (Don Dutile) [1692079]
- [lib] XArray: Change xa_insert to return -EBUSY (Don Dutile) [1692079]
- [lib] XArray: Update xa_erase family descriptions (Don Dutile) [1692079]
- [lib] XArray tests: RCU lock prohibits GFP_KERNEL (Don Dutile) [1692079]
- [include] XArray: Fix an arithmetic error in xa_is_err (Don Dutile) [1692079]
- [lib] XArray tests: Check mark 2 gets squashed (Don Dutile) [1692079]
- [include] XArray: Fix typo in comment (Don Dutile) [1692079]
- [lib] XArray: Honour reserved entries in xa_insert (Don Dutile) [1692079]
- [lib] XArray: Permit storing 2-byte-aligned pointers (Don Dutile) [1692079]
- [lib] XArray: Change xa_for_each iterator (Don Dutile) [1692079]
- [lib] XArray: Turn xa_init_flags into a static inline (Don Dutile) [1692079]
- [lib] XArray tests: Add RCU locking (Don Dutile) [1692079]
- [lib] XArray: Fix xa_alloc when id exceeds max (Don Dutile) [1692079]
- [lib] XArray tests: Check iterating over multiorder entries (Don Dutile) [1692079]
- [lib] XArray tests: Handle larger indices more elegantly (Don Dutile) [1692079]
- [include] XArray: Add xa_cmpxchg_irq and xa_cmpxchg_bh (Don Dutile) [1692079]
- [tools] radix tree: Don't return retry entries from lookup (Don Dutile) [1692079]
- [lib] XArray tests: Add missing locking (Don Dutile) [1692079]
- [lib] XArray tests: Correct some 64-bit assumptions (Don Dutile) [1692079]
- [lib] XArray: Correct xa_store_range (Don Dutile) [1692079]
- [lib] XArray: Fix Documentation (Don Dutile) [1692079]
- [lib] XArray: Handle NULL pointers differently for allocation (Don Dutile) [1692079]
- [lib] XArray: Unify xa_store and __xa_store (Don Dutile) [1692079]
- [include] XArray: Add xa_store_bh() and xa_store_irq() (Don Dutile) [1692079]
- [lib] XArray: Turn xa_erase into an exported function (Don Dutile) [1692079]
- [lib] XArray: Unify xa_cmpxchg and __xa_cmpxchg (Don Dutile) [1692079]
- [lib] XArray: Regularise xa_reserve (Don Dutile) [1692079]
- [lib] XArray: Export __xa_foo to non-GPL modules (Don Dutile) [1692079]
- [lib] XArray: Fix xa_for_each with a single element at 0 (Don Dutile) [1692079]
- [lib] xarray: Add range store functionality (Don Dutile) [1692079]
- [lib] xarray: Move multiorder_check to in-kernel tests (Don Dutile) [1692079]
- [lib] xarray: Move multiorder_shrink to kernel tests (Don Dutile) [1692079]
- [lib] xarray: Move multiorder account test in-kernel (Don Dutile) [1692079]
- [tools] radix tree test suite: Convert iteration test to XArray (Don Dutile) [1692079]
- [tools] radix tree test suite: Convert tag_tagged_items to XArray (Don Dutile) [1692079]
- [tools] radix tree test suite: Convert regression1 to XArray (Don Dutile) [1692079]
- [lib] ida: Convert to XArray (Don Dutile) [1692079]
- [lib] xarray: Track free entries in an XArray (Don Dutile) [1692079]
- [lib] xarray: Add xa_reserve and xa_release (Don Dutile) [1692079]
- [lib] xarray: Add xas_create_range (Don Dutile) [1692079]
- [lib] xarray: Add xas_for_each_conflict (Don Dutile) [1692079]
- [lib] xarray: Step through an XArray (Don Dutile) [1692079]
- [lib] xarray: Destroy an XArray (Don Dutile) [1692079]
- [lib] xarray: Extract entries from an XArray (Don Dutile) [1692079]
- [lib] xarray: Add XArray iterators (Don Dutile) [1692079]
- [lib] xarray: Add XArray conditional store operations (Don Dutile) [1692079]
- [tools] xarray: Add XArray unconditional store operations (Don Dutile) [1692079]
- [tools] xarray: Add XArray marks (Don Dutile) [1692079]
- [tools] xarray: Add XArray load operation (Don Dutile) [1692079]
- [documentation] xarray: Add documentation (Don Dutile) [1692079]
- [include] xarray: Define struct xa_node (Don Dutile) [1692079]
- [tools] xarray: Add definition of struct xarray (Don Dutile) [1692079]
- [lib] test_ida: Fix lockdep warning (Don Dutile) [1692079]
- [lib] xarray: Change definition of sibling entries (Don Dutile) [1692079]
- [mm] xarray: Replace exceptional entries (Don Dutile) [1692079]
- [lib] idr: Permit any valid kernel pointer to be stored (Don Dutile) [1692079]
- [pci] Update email address (Don Dutile) [1692079]
- [lib] ida: Change ida_get_new_above to return the id (Don Dutile) [1692079]
- [lib] ida: Remove old API (Don Dutile) [1692079]
- [target] target/iscsi: Allocate session IDs from an IDA (Don Dutile) [1692079]
- [target] iscsi target: fix session creation failure handling (Don Dutile) [1692079]
- [drm] drm/vmwgfx: Return 0 when gmrid::get_node runs out of ID's (Don Dutile) [1692079]
- [drm] drm/vmwgfx: Convert to new IDA API (Don Dutile) [1692079]
- [dma] dmaengine: Convert to new IDA API (Don Dutile) [1692079]
- [powerpc] ppc: Convert vas ID allocation to new IDA API (Don Dutile) [1692079]
- [media] media: Convert entity ID allocation to new IDA API (Don Dutile) [1692079]
- [mm] ppc: Convert mmu context allocation to new IDA API (Don Dutile) [1692079]
- [net] Convert net_namespace to new IDA API (Don Dutile) [1692079]
- [misc] cb710: Convert to new IDA API (Don Dutile) [1692079]
- [block] rsxx: Convert to new IDA API (Don Dutile) [1692079]
- [scsi] osd: Convert to new IDA API (Don Dutile) [1692079]
- [scsi] sd: Convert to new IDA API (Don Dutile) [1692079]
- [fs] devpts: Convert to new IDA API (Don Dutile) [1692079]
- [fs] fs: Convert namespace IDAs to new API (Don Dutile) [1692079]
- [fs] fs: Convert unnamed_dev_ida to new API (Don Dutile) [1692079]
- [lib] test_ida: check_ida_destroy and check_ida_alloc (Don Dutile) [1692079]
- [lib] test_ida: Convert check_ida_conv to new API (Don Dutile) [1692079]
- [lib] test_ida: Move ida_check_max (Don Dutile) [1692079]
- [lib] test_ida: Move ida_check_leaf (Don Dutile) [1692079]
- [tools] idr-test: Convert ida_check_nomem to new API (Don Dutile) [1692079]
- [tools] ida: Start new test_ida module (Don Dutile) [1692079]
- [lib] ida: Lock the IDA in ida_destroy (Don Dutile) [1692079]
- [lib] radix-tree: Fix UBSAN warning (Don Dutile) [1692079]
- [include] rh_kabi: Indirect EXTEND macros so nesting of other macros will resolve. (Don Dutile) [1692079]
- [s390] s390/pkey: add one more argument space for debug feature entry (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: fix possible deadlock situation on ap queue remove (Philipp Rudo) [1710033]
- [s390] zcrypt: handle AP Info notification from CHSC SEI command (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: revisit ap device remove procedure (Philipp Rudo) [1710033]
- [s390] pkey: Indicate old mkvp only if old and current mkvp are different (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: use new state UNBOUND during queue driver rebind (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: fix specification exception on z196 during ap probe (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: rework ap scan bus code (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: make sysfs reset attribute trigger queue reset (Philipp Rudo) [1710033]
- [s390] s390/zcrypt: improve special ap message cmd handling (Philipp Rudo) [1710033]
- [s390] s390: vfio-ap: include <asm/facility> for test_facility() (Philipp Rudo) [1710033]
- [fs] flexfiles: enforce per-mirror stateid only for v4 DSes (Scott Mayhew) [1709556]
- [fs] flexfiles: use per-mirror specified stateid for IO (Scott Mayhew) [1709556]
- [powerpc] powerpc/pseries: Fix build break due to pnv_npu2_init() (Sam Bobroff) [1704567]
- [powerpc] powerpc/powernv/sriov: Register IOMMU groups for VFs (Sam Bobroff) [1704567]
- [powerpc] powerpc/powernv/npu: Allocate enough memory in pnv_try_setup_npu_table_group() (Sam Bobroff) [1704567]
- [powerpc] powerpc/powernv/npu: Fix oops in pnv_try_setup_npu_table_group() (Sam Bobroff) [1704567]
- [mm] mm: defer ZONE_DEVICE page initialization to the point where we init pgmap (Waiman Long) [1666538 1634343]
- [mm] mm: create non-atomic version of SetPageReserved for init use (Waiman Long) [1666538 1634343]
- [mm] mm: provide kernel parameter to allow disabling page init poisoning (Waiman Long) [1666538 1634343]
- [x86] x86/resctrl: Initialize a new resource group with default MBA values (David Arcari) [1688127]
- [x86] x86/resctrl: Move per RDT domain initialization to a separate function (David Arcari) [1688127]
- [x86] x86/resctrl: Do not repeat rdtgroup mode initialization (David Arcari) [1688127]
- [x86] x86/resctrl: Fix rdt_find_domain() return value and checks (David Arcari) [1688127]
- [x86] x86/resctrl: Use rdt_last_cmd_puts() where possible (David Arcari) [1688127]

* Fri May 24 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-95.rt16.35.el8]
- [rt] kernel-rt-4.18.0-95.rt16.34.el8 (Juri Lelli) [1678887]
- [s390] s390/pci: map IOV resources (Philipp Rudo) [1659411]
- [powerpc] powerpc/book3s/64: check for NULL pointer in pgd_alloc() (Steve Best) [1710310]
- [md] dm thin metadata: do not write metadata if no changes occurred (Mike Snitzer) [1710030]
- [md] dm thin metadata: add wrappers for managing write locking of metadata (Mike Snitzer) [1710030]
- [md] dm thin metadata: check __commit_transaction()'s return (Mike Snitzer) [1710030]
- [md] dm space map common: zero entire ll_disk (Mike Snitzer) [1710030]
- [powerpc] powerpc/tm: Fix stack pointer corruption (Desnes Augusto Nunes do Rosario) [1707635]
- [pci] PCI/MSI: Remove obsolete sanity checks for multiple interrupt sets (Prarit Bhargava) [1686678]
- [kernel] genirq/affinity: Remove the leftovers of the original set support (Prarit Bhargava) [1686678]
- [nvme] nvme-pci: Simplify interrupt allocation (Prarit Bhargava) [1686678]
- [include] genirq/affinity: Add new callback for (re)calculating interrupt sets (Prarit Bhargava) [1686678]
- [nvme] genirq/affinity: Store interrupt sets size in struct irq_affinity (Prarit Bhargava) [1686678]
- [kernel] genirq/affinity: Code consolidation (Prarit Bhargava) [1686678]
- [kernel] genirq/affinity: Move allocation of 'node_to_cpumask' to irq_build_affinity_masks() (Prarit Bhargava) [1686678]
- [kernel] genirq/irqdesc: Fix double increment in alloc_descs() (Prarit Bhargava) [1686678]
- [include] genirq: Fix the kerneldoc comment for struct irq_affinity_desc (Prarit Bhargava) [1686678]
- [kernel] genirq/affinity: Add is_managed to struct irq_affinity_desc (Prarit Bhargava) [1686678]
- [kernel] genirq/core: Introduce struct irq_affinity_desc (Prarit Bhargava) [1686678]
- [kernel] genirq/affinity: Remove excess indentation (Prarit Bhargava) [1686678]

* Thu May 23 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-94.rt16.34.el8]
- [rt] kernel-rt-4.18.0-94.rt16.33.el8 (Juri Lelli) [1678887]
- [md] dm: make sure to obey max_io_len_target_boundary (Mike Snitzer) [1712607]

* Wed May 22 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-93.rt16.33.el8]
- [rt] kernel-rt-4.18.0-93.rt16.32.el8 (Juri Lelli) [1678887]
- [mm] x86/dump_pagetables: Fix LDT remap address marker (Baoquan He) [1639560]
- [x86] x86/mm: Fix guard hole handling (Baoquan He) [1639560]
- [x86] x86/mm: Move LDT remap out of KASLR region on 5-level paging (Baoquan He) [1639560]
- [x86] x86/ldt: Define LDT_END_ADDR (Baoquan He) [1639560]
- [mm] x86/ldt: Reserve address-space range on 32 bit for the LDT (Baoquan He) [1639560]
- [documentation] x86/mm/doc: Enhance the x86-64 virtual memory layout descriptions (Baoquan He) [1639560]
- [documentation] x86/mm/doc: Clean up the x86-64 virtual memory layout descriptions (Baoquan He) [1639560]
- [fs] cifs: fix page reference leak with readv/writev (Leif Sahlberg) [1708033]
- [fs] cifs: do not attempt cifs operation on smb2+ rename error (Leif Sahlberg) [1708033]
- [fs] cifs: fix memory leak in SMB2_read (Leif Sahlberg) [1708033]
- [fs] CIFS: keep FileInfo handle live during oplock break (Leif Sahlberg) [1708033]
- [fs] cifs: fix handle leak in smb2_query_symlink() (Leif Sahlberg) [1708033]
- [fs] cifs: Fix lease buffer length error (Leif Sahlberg) [1708033]
- [fs] cifs: Fix use-after-free in SMB2_read (Leif Sahlberg) [1708033]
- [fs] cifs: Fix use-after-free in SMB2_write (Leif Sahlberg) [1708033]
- [fs] cifs: a smb2_validate_and_copy_iov failure does not mean the handle is invalid. (Leif Sahlberg) [1708033]
- [fs] SMB3: Allow persistent handle timeout to be configurable on mount (Leif Sahlberg) [1708033]
- [fs] smb3: Fix enumerating snapshots to Azure (Leif Sahlberg) [1708033]
- [fs] cifs: fix kref underflow in close_shroot() (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1708033]
- [fs] SMB3: Fix SMB3.1.1 guest mounts to Samba (Leif Sahlberg) [1708033]
- [fs] cifs: Fix slab-out-of-bounds when tracing SMB tcon (Leif Sahlberg) [1708033]
- [fs] cifs: allow guest mounts to work for smb3.11 (Leif Sahlberg) [1708033]
- [fs] fix incorrect error code mapping for OBJECTID_NOT_FOUND (Leif Sahlberg) [1708033]
- [fs] cifs: fix that return -EINVAL when do dedupe operation (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix an issue with re-sending rdata when transport returning -EAGAIN (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix an issue with re-sending wdata when transport returning -EAGAIN (Leif Sahlberg) [1708033]
- [fs] CIFS: fix POSIX lock leak and invalid ptr deref (Leif Sahlberg) [1708033]
- [fs] SMB3: Allow SMB3 FSCTL queries to be sent to server from tools (Leif Sahlberg) [1708033]
- [fs] cifs: fix incorrect handling of smb2_set_sparse() return in smb3_simple_falloc (Leif Sahlberg) [1708033]
- [fs] smb2: fix typo in definition of a few error flags (Leif Sahlberg) [1708033]
- [fs] CIFS: make mknod() an smb_version_op (Leif Sahlberg) [1708033]
- [documentation] cifs: minor documentation updates (Leif Sahlberg) [1708033]
- [documentation] cifs: minor updates to documentation (Leif Sahlberg) [1708033]
- [fs] cifs: remove unused value pointed out by Coverity (Leif Sahlberg) [1708033]
- [fs] SMB3: passthru query info doesn't check for SMB3 FSCTL passthru (Leif Sahlberg) [1708033]
- [fs] smb3: add dynamic tracepoints for simple fallocate and zero range (Leif Sahlberg) [1708033]
- [fs] cifs: fix smb3_zero_range so it can expand the file-size when required (Leif Sahlberg) [1708033]
- [fs] cifs: add SMB2_ioctl_init/free helpers to be used with compounding (Leif Sahlberg) [1708033]
- [fs] smb3: Add dynamic trace points for various compounded smb3 ops (Leif Sahlberg) [1708033]
- [fs] cifs: cache FILE_ALL_INFO for the shared root handle (Leif Sahlberg) [1708033]
- [fs] smb3: display volume serial number for shares in /proc/fs/cifs/DebugData (Leif Sahlberg) [1708033]
- [fs] cifs: simplify how we handle credits in compound_send_recv() (Leif Sahlberg) [1708033]
- [fs] smb3: add dynamic tracepoint for timeout waiting for credits (Leif Sahlberg) [1708033]
- [fs] smb3: display security information in /proc/fs/cifs/DebugData more accurately (Leif Sahlberg) [1708033]
- [fs] cifs: add a timeout argument to wait_for_free_credits (Leif Sahlberg) [1708033]
- [fs] cifs: prevent starvation in wait_for_free_credits for multi-credit requests (Leif Sahlberg) [1708033]
- [fs] cifs: wait_for_free_credits() make it possible to wait for >=1 credits (Leif Sahlberg) [1708033]
- [fs] cifs: pass flags down into wait_for_free_credits() (Leif Sahlberg) [1708033]
- [fs] cifs: change wait_for_free_request() to take flags as argument (Leif Sahlberg) [1708033]
- [fs] fs: cifs: Kconfig: pedantic formatting (Leif Sahlberg) [1708033]
- [fs] smb3: request more credits on normal (non-large read/write) ops (Leif Sahlberg) [1708033]
- [fs] CIFS: Return -EAGAIN instead of -ENOTSOCK (Leif Sahlberg) [1708033]
- [fs] CIFS: Only send SMB2_NEGOTIATE command on new TCP connections (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix read after write for files with read caching (Leif Sahlberg) [1708033]
- [fs] smb3: for kerberos mounts display the credential uid used (Leif Sahlberg) [1708033]
- [fs] cifs: use correct format characters (Leif Sahlberg) [1708033]
- [fs] smb3: add dynamic trace point for query_info_enter/done (Leif Sahlberg) [1708033]
- [fs] smb3: add dynamic trace point for smb3_cmd_enter (Leif Sahlberg) [1708033]
- [fs] smb3: improve dynamic tracing of open and posix mkdir (Leif Sahlberg) [1708033]
- [fs] smb3: add missing read completion trace point (Leif Sahlberg) [1708033]
- [fs] smb3: Add tracepoints for read, write and query_dir enter (Leif Sahlberg) [1708033]
- [fs] smb3: add tracepoints for query dir (Leif Sahlberg) [1708033]
- [fs] smb3: Update POSIX negotiate context with POSIX ctxt GUID (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1708033]
- [fs] CIFS: Try to acquire credits at once for compound requests (Leif Sahlberg) [1708033]
- [fs] CIFS: Return error code when getting file handle for writeback (Leif Sahlberg) [1708033]
- [fs] CIFS: Move open file handling to writepages (Leif Sahlberg) [1708033]
- [fs] CIFS: Move unlocking pages from wdata_send_pages() (Leif Sahlberg) [1708033]
- [fs] CIFS: Find and reopen a file before get MTU credits in writepages (Leif Sahlberg) [1708033]
- [fs] CIFS: Reopen file before get SMB2 MTU credits for async IO (Leif Sahlberg) [1708033]
- [fs] CIFS: Remove custom credit adjustments for SMB2 async IO (Leif Sahlberg) [1708033]
- [fs] CIFS: Adjust MTU credits before reopening a file (Leif Sahlberg) [1708033]
- [fs] CIFS: Check for reconnects before sending compound requests (Leif Sahlberg) [1708033]
- [fs] CIFS: Check for reconnects before sending async requests (Leif Sahlberg) [1708033]
- [fs] CIFS: Respect reconnect in non-MTU credits calculations (Leif Sahlberg) [1708033]
- [fs] CIFS: Respect reconnect in MTU credits calculations (Leif Sahlberg) [1708033]
- [fs] CIFS: Set reconnect instance to one initially (Leif Sahlberg) [1708033]
- [fs] CIFS: Respect SMB2 hdr preamble size in read responses (Leif Sahlberg) [1708033]
- [fs] CIFS: Count SMB3 credits for malformed pending responses (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not log credits when unmounting a share (Leif Sahlberg) [1708033]
- [fs] CIFS: Always reset read error to -EIO if no response (Leif Sahlberg) [1708033]
- [fs] cifs: Accept validate negotiate if server return NT_STATUS_NOT_SUPPORTED (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not skip SMB2 message IDs on send failures (Leif Sahlberg) [1708033]
- [fs] smb3: request more credits on tree connect (Leif Sahlberg) [1708033]
- [fs] smb3: make default i/o size for smb3 mounts larger (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not reset lease state to NONE on lease break (Leif Sahlberg) [1708033]
- [fs] smb3: fix bytes_read statistics (Leif Sahlberg) [1708033]
- [fs] cifs: return -ENODATA when deleting an xattr that does not exist (Leif Sahlberg) [1708033]
- [fs] cifs: add credits from unmatched responses/messages (Leif Sahlberg) [1708033]
- [fs] cifs: replace snprintf with scnprintf (Leif Sahlberg) [1708033]
- [fs] cifs: Fix NULL pointer dereference of devname (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix leaking locked VFS cache pages in writeback retry (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1708033]
- [fs] CIFS: fix use-after-free of the lease keys (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not consider -ENODATA as stat failure for reads (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not count -ENODATA as failure for query directory (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix trace command logging for SMB2 reads and writes (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix possible oops and memory leaks in async IO (Leif Sahlberg) [1708033]
- [fs] cifs: limit amount of data we request for xattrs to CIFSMaxBufSize (Leif Sahlberg) [1708033]
- [fs] cifs: fix computation for MAX_SMB2_HDR_SIZE (Leif Sahlberg) [1708033]
- [fs] cifs: print CIFSMaxBufSize as part of /proc/fs/cifs/DebugData (Leif Sahlberg) [1708033]
- [fs] smb3: add credits we receive from oplock/break PDUs (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix mounts if the client is low on credits (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not assume one credit for async responses (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix credit calculations in compound mid callback (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix credit calculation for encrypted reads with errors (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix credits calculations for reads with errors (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not reconnect TCP session in add_credits() (Leif Sahlberg) [1708033]
- [fs] smb3: Cleanup license mess (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix possible hang during async MTU reads and writes (Leif Sahlberg) [1708033]
- [fs] cifs: fix memory leak of an allocated cifs_ntsd structure (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix error paths in writeback code (Leif Sahlberg) [1708033]
- [fs] CIFS: Move credit processing to mid callbacks for SMB3 (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix credits calculation for cancelled requests (Leif Sahlberg) [1708033]
- [fs] cifs: Fix potential OOB access of lock element array (Leif Sahlberg) [1708033]
- [fs] cifs: Limit memory used by lock request calls to a page (Leif Sahlberg) [1708033]
- [fs] cifs: move large array from stack to heap (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not hide EINTR after sending network packets (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix credit computation for compounded requests (Leif Sahlberg) [1708033]
- [fs] CIFS: Do not set credits to 1 if the server didn't grant anything (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix adjustment of credits for MTU requests (Leif Sahlberg) [1708033]
- [fs] cifs: Fix a tiny potential memory leak (Leif Sahlberg) [1708033]
- [fs] cifs: Fix a debug message (Leif Sahlberg) [1708033]
- [fs] smb3: add smb3.1.1 to default dialect list (Leif Sahlberg) [1708033]
- [fs] cifs: fix confusing warning message on reconnect (Leif Sahlberg) [1708033]
- [fs] smb3: fix large reads on encrypted connections (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number (Leif Sahlberg) [1708033]
- [fs] cifs: we can not use small padding iovs together with encryption (Leif Sahlberg) [1708033]
- [fs] cifs: Minor Kconfig clarification (Leif Sahlberg) [1708033]
- [fs] cifs: Always resolve hostname before reconnecting (Leif Sahlberg) [1708033]
- [fs] cifs: Add support for failover in cifs_reconnect_tcon() (Leif Sahlberg) [1708033]
- [fs] cifs: Add support for failover in smb2_reconnect() (Leif Sahlberg) [1708033]
- [fs] cifs: Only free DFS target list if we actually got one (Leif Sahlberg) [1708033]
- [fs] cifs: start DFS cache refresher in cifs_mount() (Leif Sahlberg) [1708033]
- [fs] cifs: Use GFP_ATOMIC when a lock is held in cifs_mount() (Leif Sahlberg) [1708033]
- [fs] cifs: Add support for failover in cifs_reconnect() (Leif Sahlberg) [1708033]
- [fs] cifs: Add support for failover in cifs_mount() (Leif Sahlberg) [1708033]
- [fs] cifs: remove set but not used variable 'sep' (Leif Sahlberg) [1708033]
- [fs] cifs: Make use of DFS cache to get new DFS referrals (Leif Sahlberg) [1708033]
- [fs] cifs: check kzalloc return (Leif Sahlberg) [1708033]
- [fs] cifs: remove set but not used variable 'server' (Leif Sahlberg) [1708033]
- [fs] cifs: Use kzfree() to free password (Leif Sahlberg) [1708033]
- [fs] cifs: Fix to use kmem_cache_free() instead of kfree() (Leif Sahlberg) [1708033]
- [fs] cifs: update for current_kernel_time64() removal (Leif Sahlberg) [1708033]
- [fs] cifs: Add DFS cache routines (Leif Sahlberg) [1708033]
- [fs] cifs: Save TTL value when parsing DFS referrals (Leif Sahlberg) [1708033]
- [fs] cifs: auto disable 'serverino' in dfs mounts (Leif Sahlberg) [1708033]
- [fs] cifs: Make devname param optional in cifs_compose_mount_options() (Leif Sahlberg) [1708033]
- [fs] cifs: Skip any trailing backslashes from UNC (Leif Sahlberg) [1708033]
- [fs] cifs: Refactor out cifs_mount() (Leif Sahlberg) [1708033]
- [fs] CIFS: Fix error mapping for SMB2_LOCK command which caused OFD lock problem (Leif Sahlberg) [1708033]
- [fs] CIFS: return correct errors when pinning memory failed for direct I/O (Leif Sahlberg) [1708033]
- [fs] CIFS: use the correct length when pinning memory for direct I/O for write (Leif Sahlberg) [1708033]
- [fs] cifs: check ntwrk_buf_start for NULL before dereferencing it (Leif Sahlberg) [1708033]
- [fs] cifs: remove coverity warning in calc_lanman_hash (Leif Sahlberg) [1708033]
- [fs] cifs: remove set but not used variable 'smb_buf' (Leif Sahlberg) [1708033]
- [fs] cifs: suppress some implicit-fallthrough warnings (Leif Sahlberg) [1708033]
- [fs] cifs: change smb2_query_eas to use the compound query-info helper (Leif Sahlberg) [1708033]
- [fs] Add vers=3.0.2 as a valid option for SMBv3.0.2 (Leif Sahlberg) [1708033]
- [fs] cifs: create a helper function for compound query_info (Leif Sahlberg) [1708033]
- [fs] cifs: address trivial coverity warning (Leif Sahlberg) [1708033]
- [fs] cifs: smb2 commands can not be negative, remove confusing check (Leif Sahlberg) [1708033]
- [fs] cifs: use a compound for setting an xattr (Leif Sahlberg) [1708033]
- [fs] cifs: clean up indentation, replace spaces with tab (Leif Sahlberg) [1708033]
- [fs] smb3: Fix rmdir compounding regression to strict servers (Leif Sahlberg) [1708033]
- [fs] CIFS: Avoid returning EBUSY to upper layer VFS (Leif Sahlberg) [1708033]
- [fs] cifs: Fix separator when building path from dentry (Leif Sahlberg) [1708033]
- [fs] cifs: In Kconfig CONFIG_CIFS_POSIX needs depends on legacy (insecure cifs) (Leif Sahlberg) [1708033]
- [fs] cifs: fix signed/unsigned mismatch on aio_read patch (Leif Sahlberg) [1708033]
- [fs] cifs: don't dereference smb_file_target before null check (Leif Sahlberg) [1708033]
- [fs] CIFS: Add direct I/O functions to file_operations (Leif Sahlberg) [1708033]
- [fs] CIFS: Add support for direct I/O write (Leif Sahlberg) [1708033]
- [fs] CIFS: Add support for direct I/O read (Leif Sahlberg) [1708033]
- [fs] smb3: missing defines and structs for reparse point handling (Leif Sahlberg) [1708033]
- [fs] smb3: allow more detailed protocol info on open files for debugging (Leif Sahlberg) [1708033]
- [fs] smb3: on kerberos mount if server doesn't specify auth type use krb5 (Leif Sahlberg) [1708033]
- [fs] smb3: add trace point for tree connection (Leif Sahlberg) [1708033]
- [fs] cifs: fix spelling mistake, EACCESS -> EACCES (Leif Sahlberg) [1708033]
- [fs] cifs: fix return value for cifs_listxattr (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number for cifs.ko to 2.14 (Leif Sahlberg) [1708033]
- [fs] smb3: add debug for unexpected mid cancellation (Leif Sahlberg) [1708033]
- [fs] cifs: allow calling SMB2_xxx_free(NULL) (Leif Sahlberg) [1708033]
- [fs] smb3 - clean up debug output displaying network interfaces (Leif Sahlberg) [1708033]
- [fs] smb3: show number of current open files in /proc/fs/cifs/Stats (Leif Sahlberg) [1708033]
- [fs] cifs: add support for ioctl on directories (Leif Sahlberg) [1708033]
- [fs] cifs: fallback to older infolevels on findfirst queryinfo retry (Leif Sahlberg) [1708033]
- [fs] smb3: do not attempt cifs operation in smb3 query info error path (Leif Sahlberg) [1708033]
- [fs] smb3: send backup intent on compounded query info (Leif Sahlberg) [1708033]
- [fs] cifs: track writepages in vfs operation counters (Leif Sahlberg) [1708033]
- [fs] smb2: fix uninitialized variable bug in smb2_ioctl_query_info (Leif Sahlberg) [1708033]
- [fs] cifs: add IOCTL for QUERY_INFO passthrough to userspace (Leif Sahlberg) [1708033]
- [fs] cifs: minor clarification in comments (Leif Sahlberg) [1708033]
- [fs] CIFS: Print message when attempting a mount (Leif Sahlberg) [1708033]
- [fs] CIFS: Adds information-level logging function (Leif Sahlberg) [1708033]
- [fs] cifs: OFD locks do not conflict with eachothers (Leif Sahlberg) [1708033]
- [fs] CIFS: SMBD: Do not call ib_dereg_mr on invalidated memory registration (Leif Sahlberg) [1708033]
- [fs] CIFS: pass page offsets on SMB1 read/write (Leif Sahlberg) [1708033]
- [fs] fs/cifs: fix uninitialised variable warnings (Leif Sahlberg) [1708033]
- [fs] smb3: add tracepoint for sending lease break responses to server (Leif Sahlberg) [1708033]
- [fs] cifs: do not return atime less than mtime (Leif Sahlberg) [1708033]
- [fs] smb3: update default requested iosize to 4MB from 1MB for recent dialects (Leif Sahlberg) [1708033]
- [fs] smb3: Add debug message later in smb2/smb3 reconnect path (Leif Sahlberg) [1708033]
- [fs] CIFS: make 'nodfs' mount opt a superblock flag (Leif Sahlberg) [1708033]
- [fs] smb3: track the instance of each session for debugging (Leif Sahlberg) [1708033]
- [fs] smb3: minor missing defines relating to reparse points (Leif Sahlberg) [1708033]
- [fs] smb3: add way to control slow response threshold for logging and stats (Leif Sahlberg) [1708033]
- [fs] cifs: minor updates to module description for cifs.ko (Leif Sahlberg) [1708033]
- [fs] cifs: protect against server returning invalid file system block size (Leif Sahlberg) [1708033]
- [fs] smb3: allow stats which track session and share reconnects to be reset (Leif Sahlberg) [1708033]
- [fs] SMB3: Backup intent flag missing from compounded ops (Leif Sahlberg) [1708033]
- [fs] cifs: create a define for the max number of iov we need for a SMB2 set_info (Leif Sahlberg) [1708033]
- [fs] cifs: change SMB2_OP_RENAME and SMB2_OP_HARDLINK to use compounding (Leif Sahlberg) [1708033]
- [fs] cifs: remove the is_falloc argument to SMB2_set_eof (Leif Sahlberg) [1708033]
- [fs] cifs: change SMB2_OP_SET_INFO to use compounding (Leif Sahlberg) [1708033]
- [fs] cifs: change SMB2_OP_SET_EOF to use compounding (Leif Sahlberg) [1708033]
- [fs] cifs: make rmdir() use compounding (Leif Sahlberg) [1708033]
- [fs] cifs: create helpers for SMB2_set_info_init/free() (Leif Sahlberg) [1708033]
- [fs] cifs: change unlink to use a compound (Leif Sahlberg) [1708033]
- [fs] cifs: change mkdir to use a compound (Leif Sahlberg) [1708033]
- [fs] cifs: add a smb2_compound_op and change QUERY_INFO to use it (Leif Sahlberg) [1708033]
- [fs] cifs: fix a credits leak for compund commands (Leif Sahlberg) [1708033]
- [fs] smb3: add tracepoint to catch cases where credit refund of failed op overlaps reconnect (Leif Sahlberg) [1708033]
- [fs] cifs: remove set but not used variable 'cifs_sb' (Leif Sahlberg) [1708033]
- [fs] cifs: Use kmemdup rather than duplicating its implementation in smb311_posix_mkdir() (Leif Sahlberg) [1708033]
- [fs] smb3: do not display confusing message on mount to Azure servers (Leif Sahlberg) [1708033]
- [fs] smb3: fix lease break problem introduced by compounding (Leif Sahlberg) [1708033]
- [fs] cifs: only wake the thread for the very last PDU in a compound (Leif Sahlberg) [1708033]
- [fs] cifs: add a warning if we try to to dequeue a deleted mid (Leif Sahlberg) [1708033]
- [fs] smb2: fix missing files in root share directory listing (Leif Sahlberg) [1708033]
- [fs] cifs: read overflow in is_valid_oplock_break() (Leif Sahlberg) [1708033]
- [fs] cifs: integer overflow in in SMB2_ioctl() (Leif Sahlberg) [1708033]
- [fs] CIFS: fix wrapping bugs in num_entries() (Leif Sahlberg) [1708033]
- [fs] cifs: prevent integer overflow in nxt_dir_entry() (Leif Sahlberg) [1708033]
- [fs] fs/cifs: suppress a string overflow warning (Leif Sahlberg) [1708033]
- [fs] cifs: connect to servername instead of IP for IPC$ share (Leif Sahlberg) [1708033]
- [fs] smb3: check for and properly advertise directory lease support (Leif Sahlberg) [1708033]
- [fs] smb3: minor debugging clarifications in rfc1001 len processing (Leif Sahlberg) [1708033]
- [fs] SMB3: Backup intent flag missing for directory opens with backupuid mounts (Leif Sahlberg) [1708033]
- [fs] fs/cifs: don't translate SFM_SLASH (U+F026) to backslash (Leif Sahlberg) [1708033]
- [fs] cifs: update internal module version number for cifs.ko to 2.12 (Leif Sahlberg) [1708033]
- [fs] cifs: check kmalloc before use (Leif Sahlberg) [1708033]
- [fs] cifs: check if SMB2 PDU size has been padded and suppress the warning (Leif Sahlberg) [1708033]
- [fs] cifs: create a define for how many iovs we need for an SMB2_open() (Leif Sahlberg) [1708033]
- [fs] smb3: create smb3 equivalent alias for cifs pseudo-xattrs (Leif Sahlberg) [1708033]
- [fs] smb3: allow previous versions to be mounted with snapshot= mount parm (Leif Sahlberg) [1708033]
- [fs] cifs: don't show domain= in mount output when domain is empty (Leif Sahlberg) [1708033]
- [fs] cifs: add missing support for ACLs in SMB 3.11 (Leif Sahlberg) [1708033]
- [fs] smb3: enumerating snapshots was leaving part of the data off end (Leif Sahlberg) [1708033]
- [fs] cifs: update smb2_queryfs() to use compounding (Leif Sahlberg) [1708033]
- [fs] cifs: update receive_encrypted_standard to handle compounded responses (Leif Sahlberg) [1708033]
- [fs] cifs: create SMB2_open_init()/SMB2_open_free() helpers. (Leif Sahlberg) [1708033]
- [fs] cifs: add SMB2_query_info_[init|free]() (Leif Sahlberg) [1708033]
- [fs] cifs: add SMB2_close_init()/SMB2_close_free() (Leif Sahlberg) [1708033]
- [fs] smb3: display stats counters for number of slow commands (Leif Sahlberg) [1708033]
- [fs] CIFS: fix uninitialized ptr deref in smb2 signing (Leif Sahlberg) [1708033]
- [fs] smb3: Do not send SMB3 SET_INFO if nothing changed (Leif Sahlberg) [1708033]
- [fs] smb3: fix minor debug output for CONFIG_CIFS_STATS (Leif Sahlberg) [1708033]
- [fs] smb3: add tracepoint for slow responses (Leif Sahlberg) [1708033]
- [fs] cifs: add compound_send_recv() (Leif Sahlberg) [1708033]
- [fs] cifs: make smb_send_rqst take an array of requests (Leif Sahlberg) [1708033]
- [fs] cifs: update init_sg, crypt_message to take an array of rqst (Leif Sahlberg) [1708033]
- [fs] smb3: fix reset of bytes read and written stats (Leif Sahlberg) [1708033]
- [fs] smb3: display bytes_read and bytes_written in smb3 stats (Leif Sahlberg) [1708033]
- [fs] cifs: simple stats should always be enabled (Leif Sahlberg) [1708033]
- [fs] cifs: use a refcount to protect open/closing the cached file handle (Leif Sahlberg) [1708033]
- [fs] smb3: add reconnect tracepoints (Leif Sahlberg) [1708033]
- [fs] smb3: add tracepoint for session expired or deleted (Leif Sahlberg) [1708033]
- [fs] cifs: remove unused stats (Leif Sahlberg) [1708033]
- [fs] smb3: don't request leases in symlink creation and query (Leif Sahlberg) [1708033]
- [fs] smb3: remove per-session operations from per-tree connection stats (Leif Sahlberg) [1708033]
- [fs] SMB3: Number of requests sent should be displayed for SMB3 not just CIFS (Leif Sahlberg) [1708033]
- [fs] smb3: snapshot mounts are read-only and make sure info is displayable about the mount (Leif Sahlberg) [1708033]
- [fs] smb3: remove noisy warning message on mount (Leif Sahlberg) [1708033]
- [fs] cifs: add missing debug entries for kconfig options (Leif Sahlberg) [1708033]
- [fs] smb3: fill in statfs fsid and correct namelen (Leif Sahlberg) [1708033]
- [fs] cifs: Make sure all data pages are signed correctly (Leif Sahlberg) [1708033]
- [fs] CIFS: fix memory leak and remove dead code (Leif Sahlberg) [1708033]
- [fs] cifs: use 64-bit timestamps for fscache (Leif Sahlberg) [1708033]
- [fs] cifs: use timespec64 internally (Leif Sahlberg) [1708033]
- [fs] cifs: Silence uninitialized variable warning (Leif Sahlberg) [1708033]
- [fs] fs/cifs: Simplify ib_post_(send|recv|srq_recv)() calls (Leif Sahlberg) [1708033]

* Tue May 21 2019 Clark Williams <williams@redhat.com> [4.18.0-92.rt16.32.el8]
- [rt] kernel-rt-4.18.0-92.rt16.31.el8 (Clark Williams) [1678887]
- [rt] move sctp_association structure rcu member on RT (Clark Williams)
- [edac] EDAC/amd64: Set maximum channel layer size depending on family (Gary Hook) [1690984]
- [edac] EDAC/amd64: Adjust printed chip select sizes when interleaved (Gary Hook) [1690984]
- [edac] EDAC/amd64: Recognize x16 symbol size (Gary Hook) [1690984]
- [edac] EDAC/amd64: Support more than two Unified Memory Controllers (Gary Hook) [1690984]
- [edac] EDAC/amd64: Use a macro for iterating over Unified Memory Controllers (Gary Hook) [1690984]
- [edac] EDAC, amd64: Add Family 17h, models 10h-2fh support (Gary Hook) [1670609 1690984]
- [md] dm mpath: fix missing call of path selector type->end_io (Mike Snitzer) [1686227]
- [rpmspec] redhat: do not generate debuginfo for self-tests and samples (Ivan Vecera) [1708375]
- [netdrv] broadcom: Mark expected switch fall-throughs (Kamal Heib) [1684380]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() (Kamal Heib) [1684380]
- [netdrv] broadcom: tg3: fix use of SPEED_UNKNOWN ethtool constant (Kamal Heib) [1684380]
- [netdrv] tg3: allow ethtool -p to work for NICs in down state (Kamal Heib) [1684380]
- [netdrv] tg3: optionally use eth_platform_get_mac_address() to get mac address (Kamal Heib) [1684380]
- [netdrv] tg3: extend PTP gettime function to read system clock (Kamal Heib) [1684380]
- [netdrv] tg3: Fix fall-through annotations (Kamal Heib) [1684380]
- [netdrv] tg3: Mark expected switch fall-throughs (Kamal Heib) [1684380]
- [mm] x86/mm/KASLR: Fix the size of the direct mapping section (Baoquan He) [1669075]
- [netdrv] net/mlx4_en: fix spelling mistake: "quiting" -> "quitting" (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_core: Fix error handling when initializing CQ bufs in the driver (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_core: Add masking for a few queries on HCA caps (Alaa Hleihel) [1691235 1691228]
- [infiniband] IB/mlx4: Fix using wrong function to destroy sqp AHs under SRIOV (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4: replace pci_{,un}map_sg with dma_{,un}map_sg (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4: Get rid of page operation after dma_alloc_coherent (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_core: drop useless LIST_HEAD (Alaa Hleihel) [1691235 1691228]
- [infiniband] IB/mlx4: Remove set but not used variable 'pd' (Alaa Hleihel) [1691235 1691228]
- [infiniband] IB/mlx4: Utilize macro to calculate SQ spare size (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_en: remove fallback after kzalloc_node() (Alaa Hleihel) [1691235 1691228]
- [infiniband] IB/mlx4: Remove unneeded NULL check (Alaa Hleihel) [1691235 1691228]
- [infiniband] mlx4: Use snprintf instead of complicated strcpy (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_core: Fix several coding style errors (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_core: Fix return codes of unsupported operations (Alaa Hleihel) [1691235 1691228]
- [netdrv] {net, IB}/mlx4: Initialize CQ buffers in the driver when possible (Alaa Hleihel) [1691235 1691228]
- [netdrv] mlx4: use __vlan_hwaccel helpers (Alaa Hleihel) [1691235 1691228]
- [netdrv] net/mlx4_en: Fix build break when CONFIG_INET is off (Alaa Hleihel) [1691233 1691228]
- [netdrv] net/mlx4_en: use __netdev_tx_sent_queue() (Alaa Hleihel) [1691233 1691228]
- [netdrv] net/mlx4_en: add a missing <net/ip.h> include (Alaa Hleihel) [1691233 1691228]
- [infiniband] IB/mlx4: Add port and TID to MAD debug print (Alaa Hleihel) [1691233 1691228]
- [infiniband] IB/mlx4: Enable debug print of SMPs (Alaa Hleihel) [1691233 1691228]
- [infiniband] RDMA: Fix dependencies for rdma_user_mmap_io (Alaa Hleihel) [1691233 1691228]
- [infiniband] IB/mlx4: Remove unnecessary parentheses (Alaa Hleihel) [1691233 1691228]
- [infiniband] RDMA/mlx4: Use rdma_user_mmap_io (Alaa Hleihel) [1691233 1691228]
- [netdrv] net/mlx4_core: Fix warnings during boot on driverinit param set failures (Alaa Hleihel) [1691228]
- [netdrv] net/mlx4_core: Use devlink region_snapshot parameter (Alaa Hleihel) [1691228]
- [netdrv] net/mlx4_core: Add Crdump FW snapshot support (Alaa Hleihel) [1691228]
- [netdrv] net/mlx4_core: Add health buffer address capability (Alaa Hleihel) [1691228]
- [netdrv] mlx4: Add support for devlink reload and load driverinit values (Alaa Hleihel) [1691228 1663198]
- [netdrv] mlx4: Add mlx4 initial parameters table and register it (Alaa Hleihel) [1691228 1663198]
- [infiniband] IB/mlx4: Create slave AH's directly (Alaa Hleihel) [1691228]
- [infiniband] IB/mlx4: Add support for drain SQ & RQ (Alaa Hleihel) [1691228]
- [net] openvswitch: return an error instead of doing BUG_ON() (Eelco Chaudron) [1700468]
- [include] net: add netif_is_geneve() (Petr Oros) [1707002]
- [netdrv] team: fix possible recursive locking when add slaves (Hangbin Liu) [1700679]
- [netdrv] phy: Fix ioctl handler when modifing MII_ADVERTISE (Petr Oros) [1691676]
- [netdrv] mii: Add mii_lpa_mod_linkmode_lpa_t (Petr Oros) [1691676]
- [netdrv] phy: marvell: Rename mii_lpa_to_linkmode_lpa_t (Petr Oros) [1691676]
- [netdrv] mii: Rename mii_stat1000_to_linkmode_lpa_t (Petr Oros) [1691676]
- [include] mii: Fix autoneg in mii_lpa_to_linkmode_lpa_t() (Petr Oros) [1691676]
- [netdrv] phy: remove unused code in phy_probe (Petr Oros) [1691676]
- [netdrv] phy: check if advertising is zero using linkmode_empty (Petr Oros) [1691676]
- [netdrv] phy: marvell: remove set but not used variable 'pause' (Petr Oros) [1691676]
- [netdrv] phy: Add support for resolving 5G and 2.5G autoneg (Petr Oros) [1691676]
- [netdrv] phy: Add more link modes to the settings table (Petr Oros) [1691676]
- [netdrv] phy: Fixup kerneldoc markup. (Petr Oros) [1691676]
- [netdrv] phy: Convert u32 phydev->lp_advertising to linkmode (Petr Oros) [1691676]
- [netdrv] ethernet: Convert phydev advertize and supported from u32 to link mode (Petr Oros) [1691676]
- [netdrv] bonding: Issue NETDEV_PRE_CHANGEADDR (Ivan Vecera) [1705509]
- [netdrv] bonding: Give bond_set_dev_addr() a return value (Ivan Vecera) [1705509]
- [netdrv] ipvlan: Issue NETDEV_PRE_CHANGEADDR (Ivan Vecera) [1705509]
- [net] bridge: Handle NETDEV_PRE_CHANGEADDR from ports (Ivan Vecera) [1705509]
- [net] bridge: Issue NETDEV_PRE_CHANGEADDR (Ivan Vecera) [1705509]
- [net] dev: Issue NETDEV_PRE_CHANGEADDR (Ivan Vecera) [1705509]
- [net] dev: Add NETDEV_PRE_CHANGEADDR (Ivan Vecera) [1705509]
- [net] dev: Add extack argument to dev_set_mac_address() (Ivan Vecera) [1705509]
- [netdrv] phy: phy driver features are mandatory (Petr Oros) [1691720]
- [netdrv] phy: add missing phy driver features (Petr Oros) [1691720]
- [netdrv] phy: Add missing features to PHY drivers (Petr Oros) [1691720]
- [netdrv] phy: genphy_10g_driver: Avoid NULL pointer dereference (Petr Oros) [1691720]
- [netdrv] phy: phy_support_sym_pause: Clear Asym Pause (Petr Oros) [1691720]
- [netdrv] phy: Replace phy driver features u32 with link_mode bitmap (Petr Oros) [1691720]
- [netdrv] ethernet: xgbe: expand PHY_GBIT_FEAUTRES (Petr Oros) [1691720]
- [net] net: phy: Add limkmode equivalents to some of the MII ethtool helpers (Petr Oros) [1691720]
- [netdrv] phy: Add helper for advertise to lcl value (Petr Oros) [1691720]
- [net] phy: Add helper to convert MII ADV register to a linkmode (Petr Oros) [1691720]
- [netdrv] phy: Add phydev_info() (Petr Oros) [1691720]
- [netdrv] phy: Add phydev_warn() (Petr Oros) [1691720]
- [netdrv] phy: Move linkmode helpers to somewhere public (Petr Oros) [1691720]
- [netdrv] ethernet: dpaa: remove unused variables (Petr Oros) [1691720]
- [netdrv] ravb: Disable Pause Advertisement (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper to determine if pause configuration is supported (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper for set_pauseparam for Pause (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper for set_pauseparam for Asym Pause (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper for MACs which support pause (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper for MACs which support asym pause (Petr Oros) [1691720]
- [netdrv] ethernet: Add helper to remove a supported link mode (Petr Oros) [1691720]
- [netdrv] ethernet: Fix up drivers masking pause support (Petr Oros) [1691720]
- [netdrv] bcmgenet: Fix speed selection for reverse MII (Petr Oros) [1691720]
- [netdrv] ethernet: Use phy_set_max_speed() to limit advertised speed (Petr Oros) [1691720]
- [netdrv] phy: bcm63xx: Allow to be built with COMPILE_TEST (Petr Oros) [1691720]
- [netdrv] phy: et1011c: Remove incorrect missing 1000 Half (Petr Oros) [1691720]
- [netdrv] phy: ste10Xp: Remove wrong SUPPORTED_Pause (Petr Oros) [1691720]
- [tools] selftests: net: ip_defrag: cover new IPv6 defrag behavior (Guillaume Nault) [1660282]
- [tools] selftests: net: fix/improve ip_defrag selftest (Guillaume Nault) [1660282]
- [tools] selftests: use posix-style redirection in ip_defrag.sh (Guillaume Nault) [1660282]
- [tools] selftests: net: Clean up an unused variable (Guillaume Nault) [1660282]
- [tools] selftests/net: add ipv6 tests to ip_defrag selftest (Guillaume Nault) [1660282]
- [tools] selftests/net: add ip_defrag selftest (Guillaume Nault) [1660282]
- [net] ip6: fix skb leak in ip6frag_expire_frag_queue() (Guillaume Nault) [1660282]
- [net] IP6 defrag: use rbtrees in nf_conntrack_reasm.c (Guillaume Nault) [1660282]
- [net] IP6 defrag: use rbtrees for IPv6 defrag (Guillaume Nault) [1660282]
- [net] IP defrag: encapsulate rbtree defrag code into callable functions (Guillaume Nault) [1660282]
- [net] ipv4: do not handle duplicate fragments as overlapping (Guillaume Nault) [1660282]
- [net] ipv4: ipv6: netfilter: Adjust the frag mem limit when truesize changes (Guillaume Nault) [1660282]
- [net] ipv6: remove dependency of nf_defrag_ipv6 on ipv6 module (Guillaume Nault) [1660282]
- [net] ipv6: fix typo in net/ipv6/reassembly.c (Guillaume Nault) [1660282]
- [net] core: dev: Attach extack to NETDEV_PRE_UP (Ivan Vecera) [1705501]
- [net] core: dev: Add call_netdevice_notifiers_extack() (Ivan Vecera) [1705501]
- [net] core: dev: Add extack argument to __dev_change_flags() (Ivan Vecera) [1705501]
- [net] core: dev: Add extack argument to dev_change_flags() (Ivan Vecera) [1705501]
- [netdrv] ipvlan: ipvlan_set_port_mode(): Add an extack argument (Ivan Vecera) [1705501]
- [netdrv] vrf: cycle_netdev(): Add an extack argument (Ivan Vecera) [1705501]
- [net] net: core: dev: Add extack argument to dev_open() (Ivan Vecera) [1705501]
- [net] vlan: conditional inclusion of FCoE hooks to match netdevice.h and bnx2x (Chris Leech) [1685894]
- [net] Do not route unicast IP packets twice (Ivan Vecera) [1704923]
- [net] skbuff: Rename 'offload_mr_fwd_mark' to 'offload_l3_fwd_mark' (Ivan Vecera) [1704923]
- [net] devlink: Add 'fw_load_policy' generic parameter (Ivan Vecera) [1704902]
- [net] bridge: Extend br_vlan_get_pvid() for bridge ports (Ivan Vecera) [1704863]
- [net] ipv4: Notify about changes to ip_forward_update_priority (Ivan Vecera) [1704697]
- [net] ipv4: Control SKB reprioritization after forwarding (Ivan Vecera) [1704697]
- [net] dcb: Add priority-to-DSCP map getters (Ivan Vecera) [1704639]
- [net] xsk: export xdp_get_umem_from_qid (Ivan Vecera) [1704606]
- [net] net: Add lag.h, net_lag_port_dev_txable() (Ivan Vecera) [1704297]
- [netdrv] team: Publish team_port_get_rcu() (Ivan Vecera) [1704297]
- [net] sched: sch_api: set an error msg when qdisc_alloc_handle() fails (Ivan Vecera) [1677094]
- [net] ethtool: Remove unnecessary null check in ethtool_rx_flow_rule_create (Ivan Vecera) [1691738]
- [net] flow_offload: fix block stats (Ivan Vecera) [1691738]
- [net] sched: flower: only return error from hw offload if skip_sw (Ivan Vecera) [1691738]
- [net] flow_offload: Fix flow action infrastructure (Ivan Vecera) [1691738]
- [net] ethtool: add ethtool_rx_flow_spec to flow_rule structure translator (Ivan Vecera) [1691738]
- [net] flow_offload: add wake-up-on-lan and queue to flow_action (Ivan Vecera) [1691738]
- [net] flow_offload: add statistics retrieval infrastructure and use it (Ivan Vecera) [1691738]
- [net] cls_api: add translator to flow_action representation (Ivan Vecera) [1691738]
- [net] flow_offload: add flow action infrastructure (Ivan Vecera) [1691738]
- [net] flow_offload: add flow_rule and flow_match structures and use them (Ivan Vecera) [1691738]
- [net] netfilter: ipv6: Don't preserve original oif for loopback address (Florian Westphal) [1702813]
- [net] netfilter: ipv6: Preserve link scope traffic original oif (Florian Westphal) [1702813]
- [net] sctp: implement memory accounting on rx path (Xin Long) [1665243] {CVE-2019-3874}
- [net] sctp: implement memory accounting on tx path (Xin Long) [1665243] {CVE-2019-3874}
- [net] openvswitch: fix flow actions reallocation (Eelco Chaudron) [1700468]
- [net] openvswitch: fix missing checks for nla_nest_start (Eelco Chaudron) [1700468]
- [net] openvswitch: fix a NULL pointer dereference (Eelco Chaudron) [1700468]
- [net] openvswitch: meter: Use struct_size() in kzalloc() (Eelco Chaudron) [1700468]
- [net] openvswitch: Fix IPv6 later frags parsing (Eelco Chaudron) [1700468]
- [net] openvswitch: fix spelling mistake "execeeds" -> "exceeds" (Eelco Chaudron) [1700468]
- [net] openvswitch: remove BUG_ON from get_dpdev (Eelco Chaudron) [1700468]
- [net] openvswitch: fix linking without CONFIG_NF_CONNTRACK_LABELS (Eelco Chaudron) [1700468]
- [net] revert "openvswitch: Fix template leak in error cases." (Eelco Chaudron) [1700468]
- [net] openvswitch: Use correct reply values in datapath and vport ops (Eelco Chaudron) [1700468]
- [net] ovs: fix return type of ndo_start_xmit function (Eelco Chaudron) [1700468]
- [net] openvswitch: Derive IP protocol number for IPv6 later frags (Eelco Chaudron) [1700468]
- [net] openvswitch: kernel datapath clone action (Eelco Chaudron) [1700468]
- [net] openvswitch: Avoid OOB read when parsing flow nlattrs (Eelco Chaudron) [1700468]
- [net] net/vlan: remove unused #define HAVE_VLAN_GET_TAG (Ivan Vecera) [1700369]
- [net] vlan: include the shift in skb_vlan_tag_get_prio() (Ivan Vecera) [1700369]
- [net] vlan: introduce __vlan_hwaccel_copy_tag() helper (Ivan Vecera) [1700369]
- [net] vlan: introduce __vlan_hwaccel_clear_tag() helper (Ivan Vecera) [1700369]
- [net] sctp: initialize _pad of sockaddr_in before copying to user memory (Xin Long) [1699076]
- [net] sctp: use memdup_user instead of vmemdup_user (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_STREAM_SCHEDULER sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_EVENT sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_ENABLE_STREAM_RESET sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_DEFAULT_PRINFO sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_AUTH_DEACTIVATE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_AUTH_DELETE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_AUTH_ACTIVE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_AUTH_KEY sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_MAX_BURST sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_CONTEXT sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_DEFAULT_SNDINFO sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_DELAYED_SACK sockopt (Xin Long) [1699076]
- [net] sctp: fix ignoring asoc_id for tcp-style sockets on SCTP_DEFAULT_SEND_PARAM sockopt (Xin Long) [1699076]
- [net] sctp: not copy sctp_sock pd_lobby in sctp_copy_descendant (Xin Long) [1699076]
- [net] sctp: get sctphdr by offset in sctp_compute_cksum (Xin Long) [1699076]
- [net] sctp: call sctp_auth_init_hmacs() in sctp_sock_migrate() (Xin Long) [1699076]
- [net] sctp: move up sctp_auth_init_hmacs() in sctp_endpoint_init() (Xin Long) [1699076]
- [net] sctp: sctp_sock_migrate() returns error if sctp_bind_addr_dup() fails (Xin Long) [1699076]
- [net] sctp: remove sched init from sctp_stream_init (Xin Long) [1699076]
- [net] sctp: call iov_iter_revert() after sending ABORT (Xin Long) [1699076]
- [net] ipvs: get sctphdr by sctphoff in sctp_csum_check (Xin Long) [1699076]
- [net] sctp: chunk.c: correct format string for size_t in printk (Xin Long) [1699076]
- [net] sctp: don't compare hb_timer expire date before starting it (Xin Long) [1699076]
- [net] doc: sctp: Merge and clean up rst files (Xin Long) [1699076]
- [net] sctp: set stream ext to NULL after freeing it in sctp_stream_outq_migrate (Xin Long) [1699076]
- [net] sctp: add SCTP_FUTURE_ASOC and SCTP_CURRENT_ASSOC for SCTP_STREAM_SCHEDULER sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_EVENT sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_ENABLE_STREAM_RESET sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_DEFAULT_PRINFO sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_AUTH_DEACTIVATE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_AUTH_DELETE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_AUTH_ACTIVE_KEY sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_AUTH_KEY sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_MAX_BURST sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_CONTEXT sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_DEFAULT_SNDINFO sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_DEFAULT_SEND_PARAM sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC and add SCTP_CURRENT_ASSOC for SCTP_DELAYED_SACK sockopt (Xin Long) [1699076]
- [net] sctp: add SCTP_CURRENT_ASSOC for SCTP_STREAM_SCHEDULER_VALUE sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_INTERLEAVING_SUPPORTED sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_RECONFIG_SUPPORTED sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_PR_SUPPORTED sockopt (Xin Long) [1699076]
- [net] sctp: add SCTP_FUTURE_ASSOC for SCTP_PEER_ADDR_THLDS sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_LOCAL_AUTH_CHUNKS sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_MAXSEG sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_ASSOCINFO sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_RTOINFO sockopt (Xin Long) [1699076]
- [net] sctp: use SCTP_FUTURE_ASSOC for SCTP_PEER_ADDR_PARAMS sockopt (Xin Long) [1699076]
- [net] sctp: introduce SCTP_FUTURE/CURRENT/ALL_ASSOC (Xin Long) [1699076]
- [net] sctp: set flow sport from saddr only when it's 0 (Xin Long) [1699076]
- [net] sctp: set chunk transport correctly when it's a new asoc (Xin Long) [1699076]
- [net] sctp: improve the events for sctp stream adding (Xin Long) [1699076]
- [net] sctp: improve the events for sctp stream reset (Xin Long) [1699076]
- [net] sctp: allocate sctp_sockaddr_entry with kzalloc (Xin Long) [1699076]
- [net] sctp: initialize sin6_flowinfo for ipv6 addrs in sctp_inet6addr_event (Xin Long) [1699076]
- [net] sctp: frag_point sanity check (Xin Long) [1699076]
- [net] sctp: kfree_rcu asoc (Xin Long) [1699076]
- [net] sctp: update frag_point when stream_interleave is set (Xin Long) [1699076]
- [net] sctp: add sockopt SCTP_EVENT (Xin Long) [1699076]
- [net] sctp: rename enum sctp_event to sctp_event_type (Xin Long) [1699076]
- [net] sctp: add subscribe per asoc (Xin Long) [1699076]
- [net] sctp: define subscribe in sctp_sock as __u16 (Xin Long) [1699076]
- [net] sctp: process sk_reuseport in sctp_get_port_local (Xin Long) [1699076]
- [net] sctp: add sock_reuseport for the sock in __sctp_hash_endpoint (Xin Long) [1699076]
- [net] sctp: do reuseport_select_sock in __sctp_rcv_lookup_endpoint (Xin Long) [1699076]
- [net] sctp: Fix SKB list traversal in sctp_intl_store_ordered(). (Xin Long) [1699076]
- [net] sctp: Fix SKB list traversal in sctp_intl_store_reasm(). (Xin Long) [1699076]
- [net] sctp: define SCTP_SS_DEFAULT for Stream schedulers (Xin Long) [1699076]
- [net] sctp: clear the transport of some out_chunk_list chunks in sctp_assoc_rm_peer (Xin Long) [1699076]
- [net] sctp: use sk_wmem_queued to check for writable space (Xin Long) [1699076]
- [net] sctp: count both sk and asoc sndbuf with skb truesize and sctp_chunk size (Xin Long) [1699076]
- [net] sctp: use the pmtu from the icmp packet to update transport pathmtu (Xin Long) [1699076]
- [net] sctp: fix fall-through annotation (Xin Long) [1699076]
- [net] sctp: Use skb_queue_is_first(). (Xin Long) [1699076]
- [net] sctp: not traverse asoc trans list if non-ipv6 trans exists for ipv6_flowlabel (Xin Long) [1699076]
- [net] sctp: fix invalid reference to the index variable of the iterator (Xin Long) [1699076]
- [net] sctp: remove useless start_fail from sctp_ht_iter in proc (Xin Long) [1699076]
- [net] sctp: Make wrappers for accessing in/out streams (Xin Long) [1699076]
- [net] sctp: whitespace fixes (Xin Long) [1699076]
- [net] sctp: check for ipv6_pinfo legal sndflow with flowlabel in sctp_v6_get_dst (Xin Long) [1699076]
- [net] sctp: add support for setting flowlabel when adding a transport (Xin Long) [1699076]
- [net] sctp: add spp_ipv6_flowlabel and spp_dscp for sctp_paddrparams (Xin Long) [1699076]
- [net] sctp: add support for dscp and flowlabel per transport (Xin Long) [1699076]
- [net] ipv4: add __ip_queue_xmit() that supports tos param (Xin Long) [1699076]
- [net] sctp: add support for SCTP_REUSE_PORT sockopt (Xin Long) [1699076]
- [netdrv] pptp: dst_release sk_dst_cache in pptp_sock_destruct (Xin Long) [1671606]
- [net] datagram: fix unbounded loop in __skb_try_recv_datagram() (Paolo Abeni) [1692379]
- [net] ipv6: route: purge exception on removal (Paolo Abeni) [1669049]
- [net] vsock: cope with memory allocation failure at socket creation time (Paolo Abeni) [1671619]
- [net] ptp: fix Spectre v1 vulnerability (Hangbin Liu) [1664624]

* Fri May 17 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-91.rt16.31.el8]
- [rt] kernel-rt-4.18.0-91.rt16.30.el8 (Juri Lelli) [1678887]
- [infiniband] RDMA/bnxt_re: fix or'ing of data into an uninitialized struct member (Selvin Xavier) [1664798]
- [netdrv] RDMA/bnxt_en: Enable RDMA driver support for 57500 chip (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Update kernel user abi to pass chip context (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Add extended psn structure for 57500 adapters (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Enable GSI QP support for 57500 series (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Skip backing store allocation for 57500 series (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Add 64bit doorbells for 57500 series (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Add chip context to identify 57500 series (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: fix a size calculation (Selvin Xavier) [1664798]
- [infiniband] infiniband: bnxt_re: qplib: Check the return value of send_message (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Increase depth of control path command queue (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Query HWRM Interface version from FW (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Make use of destroy AH sleepable flag (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Make use of create AH sleepable flag (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Avoid accessing the device structure after it is freed (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Fix system hang when registration with L2 driver fails (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Avoid resource leak in case the NQ registration fails (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Wait for delayed work to finish before device removal (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Limit max_pkey to 16 bit value (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Fix qp async event reporting (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Report out of sequence hw counters (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Expose rx discards and drop counters (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Prevent driver crash due to NULL pointer in error message print (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Drop L2 async events silently (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Avoid accessing nq->bar_reg_iomem in failure case (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Avoid NULL check after accessing the pointer (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Remove the unnecessary version macro definition (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Fix recursive lock warning in debug kernel (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Add missing spin lock initialization (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: QPLIB: Add and use #define dev_fmt(fmt) "QPLIB: " fmt (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Modify a fall-through annotation (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Fix a bunch of off by one bugs in qplib_fp.c (Selvin Xavier) [1664798]
- [infiniband] RDMA/bnxt_re: Fix a couple off by one bugs (Selvin Xavier) [1664798]
- [powerpc] powerpc/fadump: Do not allow hot-remove memory from fadump reserved area. (Gustavo Duarte) [1524686]
- [powerpc] powerpc/fadump: Throw proper error message on fadump registration failure (Gustavo Duarte) [1524686]
- [powerpc] powerpc/fadump: Reservationless firmware assisted dump (Gustavo Duarte) [1524686]
- [infiniband] IB/hfi1: Fix WQ_MEM_RECLAIM warning (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Implement CCA for TID RDMA protocol (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove WARN_ON when freeing expected receive groups (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Unify the software PSN check for TID RDMA READ/WRITE (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to read next expected psn from hardware flow (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Delay the release of destination mr for TID RDMA WRITE DATA (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Do not flush send queue in the TID RDMA second leg (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Fix the allocation of RSM table (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Eliminate opcode tests on mr deref (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Clear the IOWAIT pending bits when QP is put into error state (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Failed to drain send queue when QP is put into error state (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add missing break in switch statement (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Fix a build warning for TID RDMA READ (Alex Estrin) [1660618]
- [infiniband] RDMA/rdmavt: Adapt to handle non-uniform sizes on umem SGEs (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Prioritize the sending of ACK packets (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add static trace for TID RDMA WRITE protocol (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Enable TID RDMA WRITE protocol (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add interlock between TID RDMA WRITE and other requests (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add TID RDMA WRITE functionality into RDMA verbs (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add the dual leg code (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add the TID second leg ACK packet builder (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add the TID second leg send packet builder (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Resend the TID RDMA WRITE DATA packets (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to receive TID RDMA RESYNC packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to build TID RDMA RESYNC packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add TID RDMA retry timer (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to receive TID RDMA ACK packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to build TID RDMA ACK packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to receive TID RDMA WRITE DATA packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to build TID RDMA WRITE DATA packet (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to receive TID RDMA WRITE response (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add TID resource timer (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to build TID RDMA WRITE response (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add functions to receive TID RDMA WRITE request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add an s_acked_ack_queue pointer (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Allow for extra entries in QP's s_ack_queue (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Build TID RDMA WRITE request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add static trace for TID RDMA READ protocol (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Enable TID RDMA READ protocol (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add interlock between a TID RDMA request and other requests (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Integrate TID RDMA READ protocol into RC protocol (Alex Estrin) [1660618]
- [include] IB/hfi1: Increment the retry timeout value for TID RDMA READ request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add functions for restarting TID RDMA READ request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add TID RDMA handlers (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add functions to receive TID RDMA READ response (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add a function to build TID RDMA READ response (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add functions to receive TID RDMA READ request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Set PbcInsertHcrc for TID RDMA packets (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add functions to build TID RDMA READ request (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add static trace for flow and TID management functions (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add the counter n_tidwait (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: TID RDMA RcvArray programming and TID allocation (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: TID RDMA flow allocation (Alex Estrin) [1660618]
- [infiniband] IB/hfi: Move RC functions into a header file (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add static trace for OPFN (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Integrate OPFN into RC transactions (Alex Estrin) [1660618]
- [infiniband] IB/hfi1, IB/rdmavt: Allow for extending of QP's s_ack_queue (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: OPFN interface (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add OPFN helper functions for TID RDMA feature (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: OPFN support discovery (Alex Estrin) [1660618]
- [infiniband] IB/{hfi1, qib, rvt} Cleanup open coded sge usage (Alex Estrin) [1660618]
- [infiniband] IB/{hfi1,qib}: Cleanup open coded sge sizing (Alex Estrin) [1660618]
- [infiniband] RDMA/qib: Use GUP longterm for PSM page pining (Alex Estrin) [1660618]
- [infiniband] infiniband: qib: no need to check return value of debugfs_create functions (Alex Estrin) [1660618]
- [infiniband] infiniband: hfi1: no need to check return value of debugfs_create functions (Alex Estrin) [1660618]
- [infiniband] infiniband: hfi1: drop crazy DEBUGFS_SEQ_FILE_CREATE() macro (Alex Estrin) [1660618]
- [infiniband] IB/{hfi1, qib}: Fix WC.byte_len calculation for UD_SEND_WITH_IMM (Alex Estrin) [1660618]
- [infiniband] IB/qib: Fix an error code in qib_sdma_verbs_send() (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Reduce lock contention on iowait_lock for sdma and pio (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Close VNIC sdma_progress sleep window (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Allow the driver to initialize QP priv struct (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add OPFN and TID RDMA capability bits (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Unreserve a reserved request when it is completed (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Consider LMC in 16B/bypass ingress packet check (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Limit VNIC use of SDMA engines to the available count (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Correctly process FECN and BECN in packets (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Ignore LNI errors before DC8051 transitions to Polling state (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Dump pio info for non-user send contexts (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Fix a latency issue for small messages (Alex Estrin) [1660618]
- [infiniband] RDMA/qib: Remove all occurrences of BUG_ON() (Alex Estrin) [1660618]
- [infiniband] IB/qib: fix spelling mistake "colescing" -> "coalescing" (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Use VL15 for SM packets (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add mtu check for operational data VLs (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Add static trace for iowait (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Prepare resource waits for dual leg (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Error path MAD response size is incorrect (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Move UnsupportedVL bits definitions to the correct header (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: set_intr_bits uses incorrect source for register modification (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Missing return value in error path for user sdma (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Right size user_sdma sequence numbers and related variables (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Move URGENT IRQ enable to hfi1_rcvctrl() (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Rework the IRQ API to be more flexible (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: PCIe bus width retry (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Make the MSIx resource allocation a bit more flexible (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Prepare for new HFI1 MSIx API (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Get the hfi1_devdata structure as early as possible (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: tune_pcie_caps is arbitrarily placed, poorly (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove duplicated defines (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Rework file list in Makefile (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove incorrect call to do_interrupt callback (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Set in_use_ctxts bits for user ctxts only (Alex Estrin) [1660618]
- [include] include/rdma/opa_addr.h: Fix an endianness issue (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove INTx support and simplify MSIx usage (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Reorg ctxtdata and rightsize fields (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove caches of chip CSRs (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove unused/writeonly devdata fields (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Rightsize ctxt_eager_bufs fields (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove rcvctrl from ctxtdata (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove rcvhdrq_size (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Remove rcvhdrsize (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Move rhf_offset from devdata to ctxtdata (Alex Estrin) [1660618]
- [infiniband] IB/hfi1: Move normal functions from hfi1_devdata to const array (Alex Estrin) [1660618]
- [infiniband] scsi: RDMA/srpt: Fix handling of TMF submission failure (Jonathan Toppins) [1685313]
- [infiniband] scsi: RDMA/srpt: Fix a credit leak for aborted commands (Jonathan Toppins) [1685313]
- [net] xprtrdma: Reduce the doorbell rate (Receive) (Jonathan Toppins) [1685313]
- [net] xprtrdma: Fix sparse warnings (Jonathan Toppins) [1685313]
- [net] xprtrdma: Fix helper that drains the transport (Jonathan Toppins) [1685313]
- [netdrv] enic: fix build warning without CONFIG_CPUMASK_OFFSTACK (Jonathan Toppins) [1685313]
- [infiniband] IB/usnic: Fix out of bounds index check in query pkey (Jonathan Toppins) [1685313]
- [infiniband] IB/usnic: Remove stub functions (Jonathan Toppins) [1685313]
- [infiniband] rdma: fix build errors on s390 and MIPS due to bad ZERO_PAGE use (Jonathan Toppins) [1685313]
- [infiniband] RDMA/ucontext: Fix regression with disassociate (Jonathan Toppins) [1685313]
- [infiniband] IB/iser: Fix dma_nents type definition (Jonathan Toppins) [1685313]
- [infiniband] IB/iser: Pass the correct number of entries for dma mapped SGL (Jonathan Toppins) [1685313]
- [infiniband] RDMA/rxe: Use for_each_sg_page iterator on umem SGL (Jonathan Toppins) [1685313]
- [infiniband] RDMA/vmw_pvrdma: Fix memory leak on pvrdma_pci_remove (Jonathan Toppins) [1685313]
- [infiniband] RDMA/vmw_pvrdma: Support upto 64-bit PFNs (Jonathan Toppins) [1683475]
- [include] IB/mlx5: Remove dead code (Jonathan Toppins) [1685313]
- [infiniband] IB/mlx5: Ranges in implicit ODP MR inherit its write access (Jonathan Toppins) [1685313]
- [infiniband] IB/rdmavt: Fix frwr memory registration (Jonathan Toppins) [1685313]
- [infiniband] IB/rdmavt: Add wc_flags and wc_immdata to cq entry trace (Jonathan Toppins) [1685313]
- [infiniband] IB/rdmavt: Fix concurrency panics in QP post_send and modify to error (Jonathan Toppins) [1685313]
- [infiniband] IB/rdmavt: Fix loopback send with invalidate ordering (Jonathan Toppins) [1685313]
- [infiniband] IB/hfi1: Add limit test for RC/UC send via loopback (Jonathan Toppins) [1685313]
- [infiniband] RDMA/iwcm: Fix string truncation error (Jonathan Toppins) [1685313]
- [infiniband] RDMA/iwcm: add tos_set bool to iw_cm struct (Jonathan Toppins) [1685313]
- [infiniband] RDMA/cma: listening device cm_ids should inherit tos (Jonathan Toppins) [1685313]
- [infiniband] RDMA/cma: Rollback source IP address if failing to acquire device (Jonathan Toppins) [1685313]
- [infiniband] RDMA/device: Call ib_cache_release_one() only from ib_device_release() (Jonathan Toppins) [1685313]
- [infiniband] RDMA/device: Ensure that security memory is always freed (Jonathan Toppins) [1685313]
- [infiniband] RDMA/uverbs: Fix an error flow in ib_uverbs_poll_cq (Jonathan Toppins) [1685313]
- [infiniband] IB/ipoib: Make ipoib_intercept_dev_id_attr() static (Jonathan Toppins) [1685313]
- [infiniband] RDMA: Provide safe ib_alloc_device() function (Jonathan Toppins) [1685313]
- [infiniband] IB/core, ipoib: Do not overreact to SM LID change event (Jonathan Toppins) [1685313]
- [infiniband] IB/core: Abort page fault handler silently during owning process exit (Jonathan Toppins) [1685313]
- [infiniband] RDMA/core: Verify that memory window type is legal (Jonathan Toppins) [1685313]
- [infiniband] IB/core: Don't register each MAD agent for LSM notifier (Jonathan Toppins) [1711086 1685313]
- [include] IB/core: Eliminate a hole in MAD agent struct (Jonathan Toppins) [1711086 1685313]
- [infiniband] IB/core: Fix potential memory leak while creating MAD agents (Jonathan Toppins) [1711086 1685313]
- [infiniband] IB/core: Unregister notifier before freeing MAD security (Jonathan Toppins) [1711086 1685313]
- [infiniband] IB/core: Destroy QP if XRC QP fails (Jonathan Toppins) [1685313]
- [infiniband] IB/core: Declare local functions 'static' (Jonathan Toppins) [1685313]
- [infiniband] RDMA/i40iw: Make sure to initialize ib_device_ops (Jonathan Toppins) [1685313]
- [rpmspec] Update the kernel rpm package description to mention backports/bug fixes ("Herton R. Krzesinski") [1701064]
- [netdrv] bonding: fix arp_validate toggling in active-backup mode (Jarod Wilson) [1654214]
- [scsi] scsi: bnx2i: fix indentation issue, remove a tab (Maurizio Lombardi) [1665626]
- [scsi] scsi: bnx2i: remove set but not used variable 'cid_num' (Maurizio Lombardi) [1665626]
- [scsi] scsi: bnx2i: add error handling for ioremap_nocache (Maurizio Lombardi) [1665626]
- [wireless] iwlwifi: mvm: Send LQ command as async when necessary (Stanislaw Gruszka) [1687265]
- [scsi] scsi: bnx2fc: Fix error handling in probe() (Maurizio Lombardi) [1665625]
- [scsi] scsi: bnx2fc: Fix NULL dereference in error handling (Maurizio Lombardi) [1665625]
- [scsi] scsi: bnx2fc: Remove set but not used variable 'oxid' (Maurizio Lombardi) [1665625]
- [scsi] bnx2fc_fcoe: Use skb_queue_walk_safe(). (Maurizio Lombardi) [1665625]
- [netdrv] hv_netvsc: Fix rndis_per_packet_info internal field initialization (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Add handler for LRO setting change (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Add support for LRO/RSC in the vSwitch (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Fix unwanted wakeup after tx_disable (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Fix IP header checksum for coalesced packets (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: fix typos in code comments (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Fix hash key value reset after other ops (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Refactor assignments of struct netvsc_device_info (Mohammed Gamal) [1691375]
- [netdrv] hv_netvsc: Fix ethtool change hash key error (Mohammed Gamal) [1691375]
- [netdrv] ice: Disable sniffing VF traffic on PF (Kamal Heib) [1659176]
- [netdrv] ice: Use more efficient structures (Kamal Heib) [1659176]
- [netdrv] ice: Use bitfields where possible (Kamal Heib) [1659176]
- [netdrv] ice: Add function to program ethertype based filter rule on VSIs (Kamal Heib) [1659176]
- [netdrv] ice: Separate if conditions for ice_set_features() (Kamal Heib) [1659176]
- [netdrv] ice: Remove __always_unused attribute (Kamal Heib) [1659176]
- [netdrv] ice: Suppress false-positive style issues reported by static analyzer (Kamal Heib) [1659176]
- [netdrv] ice: Refactor getting/setting coalesce (Kamal Heib) [1659176]
- [netdrv] ice: Always free/allocate q_vectors (Kamal Heib) [1659176]
- [netdrv] ice: Do not unnecessarily initialize local variable (Kamal Heib) [1659176]
- [netdrv] ice: Add more validation in ice_vc_cfg_irq_map_msg (Kamal Heib) [1659176]
- [netdrv] ice: Don't remove VLAN filters that were never programmed (Kamal Heib) [1659176]
- [netdrv] ice: Preserve VLAN Rx stripping settings (Kamal Heib) [1659176]
- [netdrv] ice: Fix for allowing too many MDD events on VF (Kamal Heib) [1659176]
- [netdrv] ice: Use pf instead of vsi-back (Kamal Heib) [1659176]
- [netdrv] ice: Use dev_err when ice_cfg_vsi_lan fails (Kamal Heib) [1659176]
- [netdrv] ice: Refactor link event flow (Kamal Heib) [1659176]
- [netdrv] ice: Add missing PHY type to link settings (Kamal Heib) [1659176]
- [netdrv] ice: Add reg_idx variable in ice_q_vector structure (Kamal Heib) [1659176]
- [netdrv] ice: Remove runtime change of PFINT_OICR_ENA register (Kamal Heib) [1659176]
- [netdrv] ice: Fix issue when adding more than allowed VLANs (Kamal Heib) [1659176]
- [netdrv] ice: Remove unnecessary wait when disabling/enabling Rx queues (Kamal Heib) [1659176]
- [netdrv] ice: Add ability to update rx-usecs-high (Kamal Heib) [1659176]
- [netdrv] ice: Add 52 byte RSS hash key support (Kamal Heib) [1659176]
- [netdrv] ice: Use ice_for_each_q_vector macro where possible (Kamal Heib) [1659176]
- [netdrv] ice: Validate ring existence and its q_vector per VSI (Kamal Heib) [1659176]
- [netdrv] ice: Reduce scope of variable in ice_vsi_cfg_rxqs (Kamal Heib) [1659176]
- [netdrv] ice: Resolve static analysis reported issue (Kamal Heib) [1659176]
- [netdrv] ice: Return configuration error without queue to disable (Kamal Heib) [1659176]
- [netdrv] ice: Create framework for VSI queue context (Kamal Heib) [1659176]
- [netdrv] ice: Calculate ITR increment based on direct calculation (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Bump driver version (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code to control FW LLDP and DCBX (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code for DCB rebuild (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code to get DCB related statistics (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add priority information into VLAN header (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Update rings based on TC information (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code to process LLDP MIB change events (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code for DCB initialization part 4/4 (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code for DCB initialization part 3/4 (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code for DCB initialization part 2/4 (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Add code for DCB initialization part 1/4 (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Bump version (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Fix incorrect use of abbreviations (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Fix typos in code comments (Kamal Heib) [1700995 1659176]
- [netdrv] ice: Remove "2 BITS" comment (Kamal Heib) [1659176]
- [netdrv] ice: Update comment regarding the ITR_GRAN_S (Kamal Heib) [1659176]
- [netdrv] ice: Update function header for __ice_vsi_get_qs (Kamal Heib) [1659176]
- [netdrv] ice: Remove unnecessary braces (Kamal Heib) [1659176]
- [netdrv] ice: Remove unused function prototype (Kamal Heib) [1659176]
- [netdrv] ice: Add missing case in print_link_msg for printing flow control (Kamal Heib) [1659176]
- [netdrv] ice: Audit hotpath structures with pahole (Kamal Heib) [1659176]
- [netdrv] ice: Do not bail out when filter already exists (Kamal Heib) [1659176]
- [netdrv] ice: Fix issue with VF attempt to delete default MAC address (Kamal Heib) [1659176]
- [netdrv] ice: enable VF admin queue interrupts (Kamal Heib) [1659176]
- [netdrv] ice: Fix for adaptive interrupt moderation (Kamal Heib) [1659176]
- [netdrv] ice: Implement pci_error_handler ops (Kamal Heib) [1659176]
- [netdrv] ice: Put __ICE_PREPARED_FOR_RESET check in ice_prepare_for_reset (Kamal Heib) [1659176]
- [netdrv] ice: use virt channel status codes (Kamal Heib) [1659176]
- [netdrv] ice: Remove unnecessary newlines from log messages (Kamal Heib) [1659176]
- [netdrv] ice: Create a generic name for the ice_rx_flg64_bits structure (Kamal Heib) [1659176]
- [netdrv] ice: add and use new ice_for_each_traffic_class() macro (Kamal Heib) [1659176]
- [netdrv] ice: change VF VSI tc info along with num_queues (Kamal Heib) [1659176]
- [netdrv] ice: Prevent unintended multiple chain resets (Kamal Heib) [1659176]
- [netdrv] ice: map Rx buffer pages with DMA attributes (Kamal Heib) [1659176]
- [netdrv] ice: Limit the ice_add_rx_frag to frag addition (Kamal Heib) [1659176]
- [netdrv] ice: Gather the rx buf clean-up logic for better reuse (Kamal Heib) [1659176]
- [netdrv] ice: Introduce bulk update for page count (Kamal Heib) [1659176]
- [netdrv] ice: Get rid of ice_pull_tail (Kamal Heib) [1659176]
- [netdrv] ice: Pull out page reuse checks onto separate function (Kamal Heib) [1659176]
- [netdrv] ice: Retrieve rx_buf in separate function (Kamal Heib) [1659176]
- [netdrv] ice: Enable link events over the ARQ (Kamal Heib) [1659176]
- [netdrv] ice: use irq_num var in ice_vsi_req_irq_msix (Kamal Heib) [1659176]
- [netdrv] ice: Restore VLAN switch rule if port VLAN existed before (Kamal Heib) [1659176]
- [netdrv] ice: update VSI config dynamically (Kamal Heib) [1659176]
- [netdrv] ice: Get VF VSI instances directly via PF (Kamal Heib) [1659176]
- [netdrv] ice: Don't let VF know that it is untrusted (Kamal Heib) [1659176]
- [netdrv] ice: Set LAN_EN for all directional rules (Kamal Heib) [1659176]
- [netdrv] ice: Do not set LB_EN for prune switch rules (Kamal Heib) [1659176]
- [netdrv] ice: Enable LAN_EN for the right recipes (Kamal Heib) [1659176]
- [netdrv] ice: Add support for PF/VF promiscuous mode (Kamal Heib) [1659176]
- [netdrv] ice: code cleanup in ice_sched.c (Kamal Heib) [1659176]
- [netdrv] ice: Remove unused vsi_id field (Kamal Heib) [1659176]
- [netdrv] ice: fix some function prototype and signature style issues (Kamal Heib) [1659176]
- [netdrv] ice: fix the divide by zero issue (Kamal Heib) [1659176]
- [netdrv] ice: Fix issue reconfiguring VF queues (Kamal Heib) [1659176]
- [netdrv] ice: Remove unused function prototype (Kamal Heib) [1659176]
- [netdrv] ice: fix static analysis warnings (Kamal Heib) [1659176]
- [netdrv] ice: Fix issue reclaiming resources back to the pool after reset (Kamal Heib) [1659176]
- [netdrv] ice: Enable MAC anti-spoof by default (Kamal Heib) [1659176]
- [netdrv] ice: Determine descriptor count and ring size based on PAGE_SIZE (Kamal Heib) [1659176]
- [netdrv] ice: Reset all VFs with VFLR during SR-IOV init flow (Kamal Heib) [1659176]
- [netdrv] ice: Get resources per function (Kamal Heib) [1659176]
- [netdrv] ice: Implement flow to reset VFs with PFR and other resets (Kamal Heib) [1659176]
- [netdrv] ice: configure GLINT_ITR to always have an ITR gran of 2 (Kamal Heib) [1659176]
- [netdrv] ice: use ice_for_each_vsi macro when possible (Kamal Heib) [1659176]
- [netdrv] ice : Ensure only valid bits are set in ice_aq_set_phy_cfg (Kamal Heib) [1659176]
- [netdrv] ice: remove redundant variable and if condition (Kamal Heib) [1659176]
- [netdrv] ice: avoid multiple unnecessary de-references in probe (Kamal Heib) [1659176]
- [netdrv] ice: Fix issue with VF reset and multiple VFs support on PFs (Kamal Heib) [1659176]
- [netdrv] ice: Fix broadcast traffic in port VLAN mode (Kamal Heib) [1659176]
- [netdrv] ice: fix overlong string, update stats output (Kamal Heib) [1659176]
- [netdrv] ice: Fix for FC get rx/tx pause params (Kamal Heib) [1659176]
- [netdrv] ice: use absolute vector ID for VFs (Kamal Heib) [1659176]
- [netdrv] ice: check for a leaf node presence (Kamal Heib) [1659176]
- [netdrv] ice: flush Tx pipe on disable queue timeout (Kamal Heib) [1659176]
- [netdrv] ice: clear VF ARQLEN register on reset (Kamal Heib) [1659176]
- [netdrv] ice: don't spam VFs with link messages (Kamal Heib) [1659176]
- [netdrv] ice: only use the VF for ICE_VSI_VF in ice_vsi_release (Kamal Heib) [1659176]
- [netdrv] ice: fix numeric overflow warning (Kamal Heib) [1659176]
- [netdrv] ice: fix issue where host reboots on unload when iommu=on (Kamal Heib) [1659176]
- [netdrv] ice: fix ice_remove_rule_internal vsi_list handling (Kamal Heib) [1659176]
- [netdrv] ice: fix stack hogs from struct ice_vsi_ctx structures (Kamal Heib) [1659176]
- [netdrv] ice: sizeof(<type>) should be avoided (Kamal Heib) [1659176]
- [netdrv] ice: Fix added in VSI supported nodes calc (Kamal Heib) [1659176]
- [netdrv] ice: Fix the calculation of ICE_MAX_MTU (Kamal Heib) [1659176]
- [netdrv] ice: Mark extack argument as __always_unused (Kamal Heib) [1659176]
- [netdrv] ice: add const qualifier to mac_addr parameter (Kamal Heib) [1659176]
- [netdrv] ice: Add support for new PHY types (Kamal Heib) [1659176]
- [netdrv] ice: Offload SCTP checksum (Kamal Heib) [1659176]
- [netdrv] ice: Allow for software timestamping (Kamal Heib) [1659176]
- [netdrv] ice: Implement getting and setting ethtool coalesce (Kamal Heib) [1659176]
- [netdrv] ice: Add support for adaptive interrupt moderation (Kamal Heib) [1659176]
- [netdrv] ice: Move aggregator list into ice_hw instance (Kamal Heib) [1659176]
- [netdrv] ice: Rework queue management code for reuse (Kamal Heib) [1659176]
- [netdrv] ice: Add ethtool private flag to make forcing link down optional (Kamal Heib) [1659176]
- [netdrv] ice: Set physical link up/down when an interface is set up/down (Kamal Heib) [1659176]
- [netdrv] ice: Implement support for normal get_eeprom[_len] ethtool ops (Kamal Heib) [1659176]
- [netdrv] ice: Add ethtool set_phys_id handler (Kamal Heib) [1659176]
- [netdrv] ice: Configure RSS LUT and HASH KEY in rebuild path (Kamal Heib) [1659176]
- [netdrv] ice: Refactor a few Tx scheduler functions (Kamal Heib) [1659176]
- [netdrv] ice: Fix unused variable build warning (Kamal Heib) [1659176]
- [netdrv] ice: Do not enable NAPI on q_vectors that have no rings (Kamal Heib) [1659176]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Kamal Heib) [1659176]
- [netdrv] ice: Fix possible NULL pointer de-reference (Kamal Heib) [1659176]
- [netdrv] ice: Use Tx|Rx in comments (Kamal Heib) [1659176]
- [netdrv] ice: Cosmetic formatting changes (Kamal Heib) [1659176]
- [netdrv] ice: Cleanup short function signatures (Kamal Heib) [1659176]
- [netdrv] ice: Cleanup ice_tx_timeout() (Kamal Heib) [1659176]
- [netdrv] ice: Fix return value from NAPI poll (Kamal Heib) [1659176]
- [netdrv] ice: Constify global structures that can/should be (Kamal Heib) [1659176]
- [netdrv] ice: Do not set LAN_EN for MAC-VLAN filters (Kamal Heib) [1659176]
- [netdrv] ice: Pass the return value of ice_init_def_sw_recp() (Kamal Heib) [1659176]
- [netdrv] ice: Cleanup duplicate control queue code (Kamal Heib) [1659176]
- [netdrv] ice: Remove ICE_MAX_TXQ_PER_TXQG check when configuring Tx queue (Kamal Heib) [1659176]
- [netdrv] ice: Destroy scheduler tree in reset path (Kamal Heib) [1659176]
- [netdrv] ice: Fix to make VLAN priority tagged traffic to appear on all TCs (Kamal Heib) [1659176]
- [netdrv] ice: Call pci_disable_sriov before stopping queues for VF (Kamal Heib) [1659176]
- [netdrv] ice: Increase Rx queue disable timeout (Kamal Heib) [1659176]
- [netdrv] ice: Fix NVM mask defines (Kamal Heib) [1659176]
- [netdrv] ice: Avoid nested RTNL locking in ice_dis_vsi (Kamal Heib) [1659176]
- [netdrv] ice: Calculate guaranteed VSIs per function and use it (Kamal Heib) [1659176]
- [netdrv] ice: Remove node before releasing VSI (Kamal Heib) [1659176]
- [netdrv] ice: Check for q_vector when stopping rings (Kamal Heib) [1659176]
- [netdrv] ice: Fix debug print in ice_tx_timeout (Kamal Heib) [1659176]
- [netdrv] intel-ethernet: use correct module license (Kamal Heib) [1659176]
- [netdrv] bnx2x: Add support for detection of P2P event packets. (Manish Chopra) [1638306 1663271]
- [netdrv] bnx2x: Replace magic numbers with macro definitions. (Manish Chopra) [1638306 1663271]
- [netdrv] bnx2x: fix spelling mistake "dicline" -> "decline" (Manish Chopra) [1663271]
- [netdrv] bnx2x: Utilize FW 7.13.11.0. (Manish Chopra) [1663271]
- [netdrv] bnx2x: Remove set but not used variable 'mfw_vn' (Manish Chopra) [1663271]
- [netdrv] bnx2x: Use struct_size() in kzalloc() (Manish Chopra) [1663271]
- [netdrv] broadcom: Mark expected switch fall-throughs (Manish Chopra) [1663271]
- [netdrv] bnx2x: Bump up driver version to 1.713.36 (Manish Chopra) [1663271]
- [netdrv] bnx2x: fix various indentation issues (Manish Chopra) [1663271]
- [netdrv] cross-tree: phase out dma_zalloc_coherent() on headers (Manish Chopra) [1663271]
- [netdrv] bnx2x: Fix NULL pointer dereference in bnx2x_del_all_vlans() on some hw (Manish Chopra) [1663271]
- [netdrv] bnx2x: Send update-svid ramrod with retry/poll flags enabled (Manish Chopra) [1663271]
- [netdrv] bnx2x: Enable PTP only on the PF that initializes the port (Manish Chopra) [1663271]
- [netdrv] bnx2x: Remove configured vlans as part of unload sequence. (Manish Chopra) [1663271]
- [netdrv] bnx2x: Clear fip MAC when fcoe offload support is disabled (Manish Chopra) [1663271]
- [netdrv] bnx2x: Add storm FW version to ethtool driver query output. (Manish Chopra) [1663271]
- [netdrv] bnx2x: Add MBI version to ethtool driver query output. (Manish Chopra) [1663271]
- [netdrv] drivers: net: remove <net/busy_poll.h> inclusion when not needed (Manish Chopra) [1663271]
- [netdrv] bnx2x: remove ndo_poll_controller (Manish Chopra) [1663271]
- [netdrv] bnx2x: Provide VF link status in ndo_get_vf_config (Manish Chopra) [1663271]
- [netdrv] bnx2x: Ignore bandwidth attention in single function mode (Manish Chopra) [1663271]
- [block] block: remove CONFIG_LBDAF (Ming Lei) [1708452]
- [kernel] sched/pelt: Fix warning and clean up IRQ PELT config (Phil Auld) [1637824]
- [kernel] sched/pelt: Fix update_blocked_averages() for RT and DL classes (Phil Auld) [1637824]
- [mm] mm, sched/numa: Remove remaining traces of NUMA rate-limiting (Phil Auld) [1637824]
- [kernel] sched/fair: Fix cpu_util_wake() for 'execl' type workloads (Phil Auld) [1637824]
- [kernel] sched/fair: Consider SD_NUMA when selecting the most idle group to schedule on (Phil Auld) [1637824]
- [kernel] sched/numa: Migrate pages to local nodes quicker early in the lifetime of a task (Phil Auld) [1637824]
- [mm] mm, sched/numa: Remove rate-limiting of automatic NUMA balancing migration (Phil Auld) [1637824]
- [kernel] sched/numa: Avoid task migration for small NUMA improvement (Phil Auld) [1637824]
- [mm] mm/migrate: Use spin_trylock() while resetting rate limit (Phil Auld) [1637824]
- [kernel] sched/numa: Limit the conditions where scan period is reset (Phil Auld) [1637824]
- [kernel] sched/numa: Reset scan rate whenever task moves across nodes (Phil Auld) [1637824]
- [kernel] sched/numa: Pass destination CPU as a parameter to migrate_task_rq (Phil Auld) [1637824]
- [kernel] sched/numa: Stop multiple tasks from moving to the CPU at the same time (Phil Auld) [1637824]
- [kernel] sched/fair: Fix scale_rt_capacity() for SMT (Phil Auld) [1637824]
- [kernel] sched/numa: Move task_numa_placement() closer to numa_migrate_preferred() (Phil Auld) [1637824]
- [kernel] sched/numa: Use group_weights to identify if migration degrades locality (Phil Auld) [1637824]
- [kernel] sched/numa: Update the scan period without holding the numa_group lock (Phil Auld) [1637824]
- [kernel] sched/numa: Remove numa_has_capacity() (Phil Auld) [1637824]
- [kernel] sched/numa: Modify migrate_swap() to accept additional parameters (Phil Auld) [1637824]
- [kernel] sched/numa: Remove unused task_capacity from 'struct numa_stats' (Phil Auld) [1637824]
- [kernel] sched/numa: Skip nodes that are at 'hoplimit' (Phil Auld) [1637824]
- [kernel] sched/debug: Reverse the order of printing faults (Phil Auld) [1637824]
- [kernel] sched/numa: Use task faults only if numa_group is not yet set up (Phil Auld) [1637824]
- [kernel] sched/numa: Set preferred_node based on best_cpu (Phil Auld) [1637824]
- [kernel] sched/numa: Simplify load_too_imbalanced() (Phil Auld) [1637824]
- [kernel] sched/numa: Evaluate move once per node (Phil Auld) [1637824]
- [kernel] sched/fair: Remove #ifdefs from scale_rt_capacity() (Phil Auld) [1637824]
- [kernel] sched/cpufreq: Clarify sugov_get_util() (Phil Auld) [1637824]
- [kernel] sched/sysctl: Remove unused sched_time_avg_ms sysctl (Phil Auld) [1637824]
- [kernel] sched/core: Remove the rt_avg code (Phil Auld) [1637824]
- [kernel] sched/core: Use PELT for scale_rt_capacity() (Phil Auld) [1637824]
- [kernel] sched/cpufreq: Remove sugov_aggregate_util() (Phil Auld) [1637824]
- [kernel] cpufreq/schedutil: Take time spent in interrupts into account (Phil Auld) [1637824]
- [kernel] sched/irq: Add IRQ utilization tracking (Phil Auld) [1637824]
- [kernel] cpufreq/schedutil: Use DL utilization tracking (Phil Auld) [1637824]
- [kernel] sched/dl: Add dl_rq utilization tracking (Phil Auld) [1637824]
- [kernel] cpufreq/schedutil: Use RT utilization tracking (Phil Auld) [1637824]
- [kernel] sched/rt: Add rt_rq utilization tracking (Phil Auld) [1637824]
- [kernel] sched/pelt: Move PELT related code in a dedicated file (Phil Auld) [1637824]
- [char] ipmi_si: Potential array underflow in hotmod_handler() (Tony Camuso) [1665131]
- [char] ipmi_si: Remove hacks for adding a dummy platform devices (Tony Camuso) [1665131]
- [char] ipmi_si: Consolidate scanning the platform bus (Tony Camuso) [1665131]
- [char] ipmi_si: Remove hotmod devices on removal and exit (Tony Camuso) [1665131]
- [char] ipmi_si: Remove hardcode IPMI devices by scanning the platform bus (Tony Camuso) [1665131]
- [char] ipmi_si: Switch hotmod to use a platform device (Tony Camuso) [1665131]
- [char] ipmi: Fix failure on SMBIOS specified devices (Tony Camuso) [1665131]
- [char] ipmi: Consolidate the adding of platform devices (Tony Camuso) [1665131]
- [char] ipmi_si: Rename addr_type to addr_space to match what it does (Tony Camuso) [1665131]
- [char] ipmi_si: Convert some types into unsigned (Tony Camuso) [1665131]
- [char] ipmi: ipmi_si_hardcode.c: init si_type array to fix a crash (Tony Camuso) [1665131]
- [char] ipmi_si: Fix crash when using hard-coded device (Tony Camuso) [1665131]
- [char] ipmi: Use dedicated API for copying a UUID (Tony Camuso) [1665131]
- [char] ipmi: Use defined constant for UUID representation (Tony Camuso) [1665131]
- [char] ipmi:ssif: Change some pr_xxx to dev_xxx calls (Tony Camuso) [1665131]
- [char] ipmi: kcs_bmc: handle devm_kasprintf() failure case (Tony Camuso) [1665131]
- [char] ipmi: Fix return value when a message is truncated (Tony Camuso) [1665131]
- [char] ipmi: clean an indentation issue, remove extraneous space (Tony Camuso) [1665131]
- [char] ipmi: Make the smi watcher be disabled immediately when not needed (Tony Camuso) [1665131]
- [char] ipmi: Fix how the lower layers are told to watch for messages (Tony Camuso) [1665131]
- [char] ipmi: Fix SSIF flag requests (Tony Camuso) [1665131]
- [char] ipmi_si: fix use-after-free of resource->name (Tony Camuso) [1665131]
- [char] ipmi: Don't initialize anything in the core until something uses it (Tony Camuso) [1665131]
- [char] ipmi:ssif: Fix handling of multi-part return messages (Tony Camuso) [1665131]
- [char] ipmi:dmi: Use pr_fmt in the IPMI DMI code (Tony Camuso) [1665131]
- [char] ipmi: Remove platform driver overrides and use the id_table (Tony Camuso) [1665131]
- [char] ipmi: msghandler: Add and use pr_fmt and dev_fmt, remove PFX (Tony Camuso) [1665131]
- [char] ipmi: Use more common logging styles (Tony Camuso) [1665131]
- [acpi] ACPI / glue: Split dev_is_platform() out of module for wide use (Tony Camuso) [1665131]

* Thu May 16 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-90.rt16.30.el8]
- [rt] kernel-rt-4.18.0-90.rt16.29.el8 (Juri Lelli) [1678887]
- [scsi] scsi: hpsa: bump driver version (Joseph Szczypek) [1672669]
- [scsi] scsi: hpsa: remove timeout from TURs (Joseph Szczypek) [1672669]
- [scsi] scsi: hpsa: clean up two indentation issues (Joseph Szczypek) [1672669]
- [scsi] scsi: hpsa: mark expected switch fall-throughs (Joseph Szczypek) [1672669]
- [scsi] scsi: hpsa: switch to generic DMA API (Joseph Szczypek) [1672669]
- [scsi] scsi: hpsa: Use vmemdup_user to replace the open code (Joseph Szczypek) [1672669]
- [netdrv] ibmvnic: Add device identification to requested IRQs (Steve Best) [1665717]
- [crypto] crypto: authenc - fix parsing key with misaligned rta_len (Herbert Xu) [1707546]
- [block] block: don't drain in-progress dispatch in blk_cleanup_queue() (Ming Lei) [1694879]
- [block] blk-mq: move cancel of hctx->run_work into blk_mq_hw_sysfs_release (Ming Lei) [1694879]
- [include] blk-mq: always free hctx after request queue is freed (Ming Lei) [1694879]
- [block] blk-mq: split blk_mq_alloc_and_init_hctx into two parts (Ming Lei) [1694879]
- [block] blk-mq: free hw queue's resource in hctx's release handler (Ming Lei) [1694879]
- [block] blk-mq: move cancel of requeue_work into blk_mq_release (Ming Lei) [1694879]
- [block] blk-mq: grab .q_usage_counter when queuing request from plug code path (Ming Lei) [1694879]
- [block] block: fix use-after-free on gendisk (Ming Lei) [1694879]
- [netdrv] bonding: fix event handling for stacked bonds (Jarod Wilson) [1708390]
- [netdrv] bonding: show full hw address in sysfs for slave entries (Jarod Wilson) [1708390]
- [netdrv] bonding: fix PACKET_ORIGDEV regression (Jarod Wilson) [1708390]
- [netdrv] bonding: check slave set command firstly (Jarod Wilson) [1708390]
- [netdrv] bonding: count master 3ad stats separately (Jarod Wilson) [1708390]
- [netdrv] bonding: add support for xstats and export 3ad stats (Jarod Wilson) [1708390]
- [netdrv] bonding: add 3ad stats (Jarod Wilson) [1708390]
- [netdrv] bonding: 3ad: remove bond_3ad_rx_indication's length argument (Jarod Wilson) [1708390]
- [netdrv] bonding: adjust style of bond_3ad_rx_indication (Jarod Wilson) [1708390]
- [netdrv] bonding: update nest level on unlink (Jarod Wilson) [1708390]
- [netdrv] bonding: fix indentation issues, remove extra spaces (Jarod Wilson) [1708390]
- [netdrv] bonding: convert to DEFINE_SHOW_ATTRIBUTE (Jarod Wilson) [1708390]
- [netdrv] bonding: fix 802.3ad state sent to partner when unbinding slave (Jarod Wilson) [1708390]
- [netdrv] bonding: use netpoll_poll_dev() helper (Jarod Wilson) [1708390]
- [net] netpoll: do not test NAPI_STATE_SCHED in poll_one_napi() (Jarod Wilson) [1708390]
- [net] netpoll: make ndo_poll_controller() optional (Jarod Wilson) [1708390]
- [netdrv] bonding: don't cast const buf in sysfs store (Jarod Wilson) [1708390]
- [netdrv] netdevsim: fix sa_idx out of bounds check (Ivan Vecera) [1708373]
- [tools] selftests: rtnetlink: add ipsec offload API test (Ivan Vecera) [1708373]
- [netdrv] netdevsim: add ipsec offload testing (Ivan Vecera) [1708373]
- [tools] selftests: rtnetlink: use dummydev as a test device (Ivan Vecera) [1708373]
- [tools] selftests: rtnetlink: clear the return code at start of ipsec test (Ivan Vecera) [1708373]
- [tools] selftests: rtnetlink: use a local IP address for IPsec tests (Ivan Vecera) [1708373]
- [tools] selftests: rtnetlink: hide complaint from terminated monitor (Ivan Vecera) [1708373]
- [powerpc] powerpc/watchdog: Use hrtimers for per-CPU heartbeat (Steve Best) [1708327]
- [netdrv] ixgbevf: Update driver version for RHEL-8.1.0 (Ken Cox) [1659166]
- [netdrv] drivers: net: intel: use secpath helpers in more places (Ken Cox) [1659166]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Ken Cox) [1659166]
- [netdrv] ixgbevf: add support for software timestamps (Ken Cox) [1659166]
- [netdrv] ixgbe/ixgbevf: fix XFRM_ALGO dependency (Ken Cox) [1659166]
- [netdrv] ixgbevf: off by one in ixgbevf_ipsec_tx() (Ken Cox) [1659166]
- [netdrv] ixgbevf: fix msglen for ipsec mbx messages (Ken Cox) [1659166]
- [netdrv] ixgbevf: remove ndo_poll_controller (Ken Cox) [1659166]
- [netdrv] intel-ethernet: use correct module license (Ken Cox) [1659166]
- [netdrv] ixgbevf: enable VF IPsec offload operations (Ken Cox) [1659166]
- [netdrv] ixgbevf: add VF IPsec offload code (Ken Cox) [1659166]
- [netdrv] ixgbevf: add defines for IPsec offload request (Ken Cox) [1659166]
- [netdrv] ixgbevf: VF2VF TCP RSS (Ken Cox) [1659166]
- [netdrv] ixgbe: Update driver version for RHEL-8.1.0 (Ken Cox) [1659164]
- [netdrv] intel: correct return from set features callback (Ken Cox) [1659164]
- [netdrv] ixgbe: don't do any AF_XDP zero-copy transmit if netif is not OK (Ken Cox) [1659164]
- [netdrv] ixgbe: fix potential RX buffer starvation for AF_XDP (Ken Cox) [1659164]
- [netdrv] ixgbe: fix older devices that do not support IXGBE_MRQC_L3L4TXSWEN (Ken Cox) [1659164]
- [netdrv] net: bpf: remove XDP_QUERY_XSK_UMEM enumerator (Ken Cox) [1659164]
- [netdrv] ixgbe: Use struct_size() helper (Ken Cox) [1659164]
- [netdrv] ixgbe: remove magic constant in ixgbe_reset_hw_82599() (Ken Cox) [1659164]
- [netdrv] ixgbe: use mii_bus to handle MII related ioctls (Ken Cox) [1659164]
- [netdrv] ixgbe: register a mdiobus (Ken Cox) [1659164]
- [netdrv] drivers: net: intel: use secpath helpers in more places (Ken Cox) [1659164]
- [netdrv] ixgbe: Fix race when the VF driver does a reset (Ken Cox) [1659164]
- [netdrv] ixgbe: recognize 1000BaseLX SFP modules as 1Gbps (Ken Cox) [1659164]
- [netdrv] ixgbe: Replace synchronize_sched() with synchronize_rcu() (Ken Cox) [1659164]
- [netdrv] i40e/ixgbe/igb: fail on new WoL flag setting WAKE_MAGICSECURE (Ken Cox) [1659164]
- [netdrv] intel-ethernet: software timestamp skbs as late as possible (Ken Cox) [1659164]
- [netdrv] ixgbe: allow IPsec Tx offload in VEPA mode (Ken Cox) [1659164]
- [netdrv] ixgbe: don't clear_bit on xdp_ring->state if xdp_ring is null (Ken Cox) [1659164]
- [netdrv] ixgbe: fix MAC anti-spoofing filter after VFLR (Ken Cox) [1659164]
- [netdrv] ixgbe/ixgbevf: fix XFRM_ALGO dependency (Ken Cox) [1659164]
- [netdrv] drivers: net: remove <net/busy_poll.h> inclusion when not needed (Ken Cox) [1659164]
- [netdrv] ixgbe: check return value of napi_complete_done() (Ken Cox) [1659164]
- [netdrv] ixgbe: add AF_XDP zero-copy Tx support (Ken Cox) [1659164]
- [netdrv] ixgbe: move common Tx functions to ixgbe_txrx_common.h (Ken Cox) [1659164]
- [netdrv] ixgbe: add AF_XDP zero-copy Rx support (Ken Cox) [1659164]
- [netdrv] ixgbe: move common Rx functions to ixgbe_txrx_common.h (Ken Cox) [1659164]
- [netdrv] ixgbe: added Rx/Tx ring disable/enable functions (Ken Cox) [1659164]
- [netdrv] ixgbe: Fix crash with VFs and flow director on interface flap (Ken Cox) [1659164]
- [netdrv] ixgbe: remove redundant function ixgbe_fw_recovery_mode() (Ken Cox) [1659164]
- [netdrv] ixgbe: Fix ixgbe TX hangs with XDP_TX beyond queue limit (Ken Cox) [1659164]
- [netdrv] ixgbe: remove ndo_poll_controller (Ken Cox) [1659164]
- [netdrv] intel-ethernet: use correct module license (Ken Cox) [1659164]
- [netdrv] ixgbe: fix the return value for unsupported VF offload (Ken Cox) [1659164]
- [netdrv] ixgbe: disallow IPsec Tx offload when in SR-IOV mode (Ken Cox) [1659164]
- [netdrv] ixgbe: add VF IPsec offload request message handling (Ken Cox) [1659164]
- [netdrv] ixgbe: add VF IPsec offload enable flag (Ken Cox) [1659164]
- [netdrv] ixgbe: add VF IPsec management (Ken Cox) [1659164]
- [netdrv] ixgbe: prep IPsec constants for later use (Ken Cox) [1659164]
- [netdrv] ixgbe: reload IPsec IP table after sa tables (Ken Cox) [1659164]
- [netdrv] ixgbe: don't clear IPsec sa counters on HW clearing (Ken Cox) [1659164]
- [netdrv] ixgbe: firmware recovery mode (Ken Cox) [1659164]
- [netdrv] ixgbe: fix driver behaviour after issuing VFLR (Ken Cox) [1659164]
- [netdrv] ixgbe: Prevent unsupported configurations with XDP (Ken Cox) [1659164]
- [netdrv] ixgbe: Refactor queue disable logic to take completion time into account (Ken Cox) [1659164]
- [netdrv] ixgbe: Reorder Tx/Rx shutdown to reduce time needed to stop device (Ken Cox) [1659164]
- [netdrv] ixgbe: add ipsec security registers into ethtool register dump (Ken Cox) [1659164]
- [netdrv] ixgbe: Do not allow LRO or MTU change with XDP (Ken Cox) [1659164]
- [wireless] brcmfmac: add subtype check for event handling in data path (Stanislaw Gruszka) [1705386] {CVE-2019-9500}
- [wireless] brcmfmac: assure SSID length from firmware is limited (Stanislaw Gruszka) [1705386] {CVE-2019-9500}
- [base] driver core: Postpone DMA tear-down until after devres release (Maurizio Lombardi) [1698053]

* Wed May 15 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-89.rt16.29.el8]
- [rt] kernel-rt-4.18.0-89.rt16.28.el8 (Juri Lelli) [1678887]
- [of] of: Add missing exports of node name compare functions (Neil Horman) [1665660]
- [of] of: add node name compare helper functions (Neil Horman) [1665660]
- [include] gpio: Add API to explicitly name a consumer (Neil Horman) [1665660]
- [drivers] spi: spi-gpio: fix SPI_CS_HIGH capability (Neil Horman) [1665660]
- [drivers] spi: use gpio[d]_set_value_cansleep for setting chipselect GPIO (Neil Horman) [1665660]
- [drivers] spi: gpio: Advertise support for SPI_CS_HIGH (Neil Horman) [1665660]
- [include] spi: support inter-word delay requirement for devices (Neil Horman) [1665660]
- [drivers] spi: dw: Fix default polarity of native chipselect (Neil Horman) [1665660]
- [drivers] spi: Support high CS when using descriptors (Neil Horman) [1665660]
- [include] spi: Go back to immediate teardown (Neil Horman) [1665660]
- [drivers] spi: dw: change snprintf to scnprintf for possible overflow (Neil Horman) [1665660]
- [drivers] spi: dw: fix warning unused variable 'ret' (Neil Horman) [1665660]
- [include] spi: core: avoid waking pump thread from spi_sync instead run teardown delayed (Neil Horman) [1665660]
- [drivers] spi: dw: Convert to use CS GPIO descriptors (Neil Horman) [1665660]
- [include] spi: Optionally use GPIO descriptors for CS GPIOs (Neil Horman) [1665660]
- [drivers] spi: dw: fix potential variable assignment error (Neil Horman) [1665660]
- [drivers] spi: Use of_node_name_eq for node name comparisons (Neil Horman) [1665660]
- [drivers] spi: dw-mmio: add ACPI support (Neil Horman) [1665660]
- [include] spi: add support for octal mode I/O data transfer (Neil Horman) [1665660]
- [drivers] spi: Fix formatting of header block (Neil Horman) [1665660]
- [drivers] spi: Fix core transfer waits after slave support (Neil Horman) [1665660]
- [drivers] spi: Deal with slaves that return from transfer_one() unfinished (Neil Horman) [1665660]
- [include] spi: gpio: Support 3WIRE high-impedance turn-around (Neil Horman) [1665660]
- [drivers] spi: Make GPIO CSs honour the SPI_NO_CS flag (Neil Horman) [1665660]
- [drivers] dw: spi: add support for Amazon's Alpine spi controller (Neil Horman) [1665660]
- [include] spi: Add driver_override SPI device attribute (Neil Horman) [1665660]
- [include] spi: make OF helper available for others (Neil Horman) [1665660]
- [include] spi: switch to SPDX license identifier (Neil Horman) [1665660]
- [drivers] spi: always use software fallback for SPI_CS_WORD when using cs_gio (Neil Horman) [1665660]
- [drivers] spi: add software implementation for SPI_CS_WORD (Neil Horman) [1665660]
- [include] spi: add new SPI_CS_WORD flag (Neil Horman) [1665660]
- [drivers] spi: gpio: No MISO does not imply no RX (Neil Horman) [1665660]
- [drivers] spi: dw: support 4-16 bits per word (Neil Horman) [1665660]
- [drivers] spi: spi-gpio: Remove set but not used variable 'pdata' (Neil Horman) [1665660]
- [drivers] spi: Do not print a message if spi_controller_{suspend,resume}() fails (Neil Horman) [1665660]
- [drivers] spi: gpio: Fix copy-and-paste error (Neil Horman) [1665660]
- [drivers] spi: dw-mmio: avoid hardcoded field mask (Neil Horman) [1665660]
- [drivers] spi: dw-mmio: add MSCC Jaguar2 support (Neil Horman) [1665660]
- [include] spi: Introduce one new field to set word delay (Neil Horman) [1665660]
- [drivers] spi: Fix double IDR allocation with DT aliases (Neil Horman) [1665660]
- [drivers] spi: fix IDR collision on systems with both fixed and dynamic SPI bus numbers (Neil Horman) [1665660]
- [drivers] spi: spi-gpio: add SPI_3WIRE support (Neil Horman) [1665660]
- [drivers] spi: add flags parameter to txrx_word function pointers (Neil Horman) [1665660]
- [drivers] spi: dw-mmio: add MSCC Ocelot support (Neil Horman) [1665660]
- [drivers] spi: dw: export dw_spi_set_cs (Neil Horman) [1665660]
- [drivers] spi: dw: allow providing own set_cs callback (Neil Horman) [1665660]
- [drivers] spi: dw: fix possible race condition (Neil Horman) [1665660]
- [acpi] ACPI / APD: Add clock frequency for Hisilicon Hip08 SPI controller (Neil Horman) [1665660]
- [md] md/raid: raid5 preserve the writeback action after the parity check (Nigel Croxon) [1702309]
- [md] Revert "Don't jump to compute_result state from check_result state" (Nigel Croxon) [1702309]
- [md] md: return -ENODEV if rdev has no mddev assigned (Nigel Croxon) [1702309]
- [md] md: add __acquires/__releases annotations to handle_active_stripes (Nigel Croxon) [1702309]
- [md] md: add __acquires/__releases annotations to (un)lock_two_stripes (Nigel Croxon) [1702309]
- [md] md: mark md_cluster_mod static (Nigel Croxon) [1702309]
- [md] md: use correct type in super_1_sync (Nigel Croxon) [1702309]
- [md] md: use correct type in super_1_load (Nigel Croxon) [1702309]
- [md] md: use correct types in md_bitmap_print_sb (Nigel Croxon) [1702309]
- [md] md: add a missing endianness conversion in check_sb_changes (Nigel Croxon) [1702309]
- [md] md: add mddev->pers to avoid potential NULL pointer dereference (Nigel Croxon) [1702309]
- [md] md: batch flush requests. (Nigel Croxon) [1702309]
- [md] Revert "MD: fix lock contention for flush bios" (Nigel Croxon) [1702309]
- [md] Don't jump to compute_result state from check_result state (Nigel Croxon) [1702309]
- [netdrv] bnxt_en: Reset device on RX buffer errors. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Improve RX consumer index validity check. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Drop oversize TX packets to prevent errors. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Wait longer for the firmware message response to complete. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix typo in firmware message timeout logic. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Return relevant error code when offload fails (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add support for mdio read/write to external PHY (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Propagate trusted VF attribute to firmware. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add support for BCM957504 (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update firmware interface spec. to 1.10.0.47. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Disable interrupts when allocating CP rings or NQs. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix context memory allocation. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix ring checking logic on 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Adjust default RX coalescing ticks to 10 us. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Support for 64-bit flow handle. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Increase context memory allocations on 57500 chips for RDMA. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add Level 2 context memory paging support. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Enhance bnxt_alloc_ring()/bnxt_free_ring(). (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add support for 2nd firmware message channel. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Introduce bnxt_get_hwrm_resp_addr & bnxt_get_hwrm_seq_id routines. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Avoid arithmetic on void * pointer. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Use macros for firmware message doorbell offsets. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Set hwrm_intr_seq_id value to its inverted value. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update firmware interface spec. to 1.10.0.33. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix ethtool self-test loopback. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: query force speeds before disabling autoneg mode. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Do not free port statistics buffer when device is down. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Save ring statistics before reset. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Return linux standard errors in bnxt_ethtool.c (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Don't set ETS on unused TCs. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add ethtool -S priority counters. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add SR-IOV support for 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Disable MSIX before re-reserving NQs/CMPL rings. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Reserve 1 stat_ctx for RDMA driver. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Do not modify max_stat_ctxs after RDMA driver requests/frees stat_ctxs (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: get rid of num_stat_ctxs variable (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add bnxt_get_avail_cp_rings_for_en() helper function. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Store the maximum NQs available on the PF. (Selvin Xavier) [1664477]
- [netdrv] bnxt: remove printing of hwrm message (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix _bnxt_get_max_rings() for 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix NQ/CP rings accounting on the new 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Keep track of reserved IRQs. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix CNP CoS queue regression. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix filling time in bnxt_fill_coredump_record() (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add software "missed_irqs" counter. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Workaround occasional TX timeout on 57500 A0. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Disable RDMA support on the 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix rx_l4_csum_errors counter on 57500 devices. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix RSS context allocation. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Copy and paste bug in extended tx_stats (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add PCI ID for BCM57508 device. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add new NAPI poll function for 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Refactor bnxt_poll_work(). (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add coalescing setup for 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Use bnxt_cp_ring_info struct pointer as parameter for RX path. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add RSS support for 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Increase RSS context array count and skip ring groups on 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Allocate/Free CP rings for 57500 series chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Modify bnxt_ring_alloc_send_msg() to support 57500 chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add helper functions to get firmware CP ring ID. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Allocate completion ring structures for 57500 series chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Modify the ring reservation functions for 57500 series chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Adjust MSIX and ring groups for 57500 series chips. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Re-structure doorbells. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add 57500 new chip ID and basic structures. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Configure context memory on new devices. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Check context memory requirements from firmware. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add new flags to setup new page table PTE bits on newer devices. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Refactor bnxt_ring_struct. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update interrupt coalescing logic. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add maximum extended request length fw message support. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add additional extended port statistics. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update firmware interface spec. to 1.10.0.3. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Remove unnecessary unsigned integer comparison and initialize variable (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: get the reduced max_irqs by the ones used by RDMA (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: free hwrm resources, if driver probe fails. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix enables field in HWRM_QUEUE_COS2BW_CFG request (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix VNIC reservations on the PF. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add a driver specific gre_ver_check devlink parameter. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Use msix_vec_per_pf_max and msix_vec_per_pf_min devlink params. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: return proper error when FW returns HWRM_ERR_CODE_RESOURCE_ACCESS_DENIED (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Use ignore_ari devlink parameter (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix TX timeout during netpoll. (Selvin Xavier) [1664477]
- [netdrv] bnxt: remove ndo_poll_controller (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: don't try to offload VLAN 'modify' action (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: remove set but not used variable 'addr_type' (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: remove set but not used variable 'rx_stats' (Selvin Xavier) [1664477]
- [netdrv] net: bnxt: Fix a uninitialized variable warning. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: take coredump_record structure off stack (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: avoid string overflow for record->system_name (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Fix strcpy() warnings in bnxt_ethtool.c (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Do not use the CNP CoS queue for networking traffic. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add DCBNL DSCP application protocol support. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add hwmon sysfs support to read temperature (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Notify firmware about IF state changes. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Move firmware related flags to a new fw_cap field in struct bnxt. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add BNXT_NEW_RM() macro. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add support for ethtool get dump. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update RSS setup and GRO-HW logic according to the latest spec. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add new VF resource allocation strategy mode. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add PHY retry logic. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add external loopback test to ethtool selftest. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Adjust timer based on ethtool stats-block-usecs settings. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Update firmware interface version to 1.9.2.25. (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: combine 'else if' and 'else' into single branch (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: remove redundant debug register dma mem allocation (Selvin Xavier) [1664477]
- [netdrv] bnxt_en: Add bnxt_en initial params table and register it. (Selvin Xavier) [1664477]
- [netdrv] sfc: mcdi_port: Mark expected switch fall-through (Jarod Wilson) [1685478]
- [netdrv] sfc: ensure recovery after allocation failures (Jarod Wilson) [1685478]
- [netdrv] sfc: Replace dev_kfree_skb_any by dev_consume_skb_any (Jarod Wilson) [1685478]
- [netdrv] sfc: add bundle partition definitions to mtd (Jarod Wilson) [1685478]
- [netdrv] sfc: Replace spin_is_locked() with lockdep (Jarod Wilson) [1685478]
- [netdrv] sfc: remove ndo_poll_controller (Jarod Wilson) [1685478]
- [iommu] iommu/amd: Set exclusion range correctly (Jerry Snitselaar) [1702766]
- [iommu] iommu/amd: Reserve exclusion range in iova-domain (Jerry Snitselaar) [1694835]
- [scsi] scsi: mpt3sas: Fix kernel panic during expander reset (Tomas Henzl) [1677693]
- [mm] mm/vmstat.c: fix /proc/vmstat format for CONFIG_DEBUG_TLBFLUSH=y CONFIG_SMP=n (Waiman Long) [1705607]
- [mm] x86/mm: Drop usage of __flush_tlb_all() in kernel_physical_mapping_init() (Waiman Long) [1705607]
- [include] x86/mm: Validate kernel_physical_mapping_init() PTE population (Waiman Long) [1705607]
- [include] generic/pgtable: Introduce set_pte_safe() (Waiman Long) [1705607]
- [include] generic/pgtable: Introduce {p4d,pgd}_same() (Waiman Long) [1705607]
- [include] generic/pgtable: Make {pmd, pud}_same() unconditionally available (Waiman Long) [1705607]
- [mm] percpu: stop printing kernel addresses (Waiman Long) [1705607]
- [x86] x86/speculation: Prevent deadlock on ssb_state::lock (Waiman Long) [1705607]
- [fs] debugfs: fix use-after-free on symlink traversal (Waiman Long) [1705607]
- [lib] debugobjects: avoid recursive calls with kmemleak (Waiman Long) [1705607]
- [mm] mm/swapfile.c: use kvzalloc for swap_info_struct allocation (Waiman Long) [1705607]
- [mm] hugetlbfs: fix kernel BUG at fs/hugetlbfs/inode.c:444! (Waiman Long) [1705607]
- [include] watchdog/core: Add missing prototypes for weak functions (Waiman Long) [1705607]
- [mm] memory_hotplug: cond_resched in __remove_pages (Waiman Long) [1705607]
- [kernel] genirq: Fix race on spurious interrupt detection (Waiman Long) [1705607]
- [kernel] printk: Fix panic caused by passing log_buf_len to command line (Waiman Long) [1705607]
- [mm] mm/hmm: fix race between hmm_mirror_unregister() and mmu_notifier callback (Waiman Long) [1705607]
- [mm] mm/rmap: map_pte() was not handling private ZONE_DEVICE page properly (Waiman Long) [1705607]
- [mm] hugetlbfs: dirty pages as they are added to pagecache (Waiman Long) [1705607]
- [fs] mm: /proc/pid/smaps_rollup: fix NULL pointer deref in smaps_pte_range() (Waiman Long) [1705607]
- [kernel] sched/fair: Fix the min_vruntime update logic in dequeue_entity() (Waiman Long) [1705607]
- [mm] x86/mm/pat: Disable preemption around __flush_tlb_all() (Waiman Long) [1705607]
- [x86] x86/corruption-check: Fix panic in memory_corruption_check() when boot option without value is provided (Waiman Long) [1705607]
- [x86] x86/time: Correct the attribute on jiffies' definition (Waiman Long) [1705607]
- [x86] x86/percpu: Fix this_cpu_read() (Waiman Long) [1705607]
- [x86] x86/tsc: Force inlining of cyc2ns bits (Waiman Long) [1705607]
- [mm] mm/migrate.c: split only transparent huge pages when allocation fails (Waiman Long) [1705607]
- [mm] mm/thp: fix call to mmu_notifier in set_pmd_migration_entry() v2 (Waiman Long) [1705607]
- [mm] mm/mmap.c: don't clobber partially overlapping VMA with MAP_FIXED_NOREPLACE (Waiman Long) [1705607]
- [mm] percpu: stop leaking bitmap metadata blocks (Waiman Long) [1705607]
- [lib] vsprintf: Fix off-by-one bug in bstr_printf() processing dereferenced pointers (Waiman Long) [1705607]
- [mm] mm/vmstat.c: fix outdated vmstat_text (Waiman Long) [1705607]
- [base] PM / core: Clear the direct_complete flag on errors (Waiman Long) [1705607]
- [tools] x86/vdso: Fix vDSO syscall fallback asm constraint regression (Waiman Long) [1705607]
- [x86] x86/vdso: Only enable vDSO retpolines when enabled and supported (Waiman Long) [1705607]
- [tools] selftests/x86: Add clock_gettime() tests to test_vdso (Waiman Long) [1705607]
- [x86] x86/vdso: Fix asm constraints on vDSO syscall fallbacks (Waiman Long) [1705607]
- [drivers] clocksource/drivers/timer-atmel-pit: Properly handle error cases (Waiman Long) [1705607]
- [mm] mm/vmstat.c: skip NR_TLB_REMOTE_FLUSH* properly (Waiman Long) [1705607]
- [mm] mm, thp: fix mlocking THP page with migration enabled (Waiman Long) [1705607]
- [mm] mm: migration: fix migration of huge PMD shared pages (Waiman Long) [1705607]
- [net] net/smc: improve smc_conn_create reason codes (Philipp Rudo) [1703471]
- [net] net/smc: improve smc_listen_work reason codes (Philipp Rudo) [1703471]
- [net] net/smc: code cleanup smc_listen_work (Philipp Rudo) [1703471]
- [net] net/smc: cleanup of get vlan id (Philipp Rudo) [1703471]
- [net] net/smc: consolidate function parameters (Philipp Rudo) [1703471]
- [net] net/smc: check for ip prefix and subnet (Philipp Rudo) [1703471]
- [net] net/smc: fallback to TCP after connect problems (Philipp Rudo) [1703471]
- [net] net/smc: nonblocking connect rework (Philipp Rudo) [1703471]
- [net] net/smc: move unhash before release of clcsock (Philipp Rudo) [1703471]
- [net] net/smc: fix return code from FLUSH command (Philipp Rudo) [1703471]
- [net] net/smc: propagate file from SMC to TCP socket (Philipp Rudo) [1703471]
- [net] net/smc: fix a NULL pointer dereference (Philipp Rudo) [1703471]
- [net] net/smc: wait for pending work before clcsock release_sock (Philipp Rudo) [1703471]
- [net] net/smc: allow pnetid-less configuration (Philipp Rudo) [1700797]
- [net] net/smc: allow PCI IDs as ib device names in the pnet table (Philipp Rudo) [1700797]
- [net] net/smc: add pnet table namespace support (Philipp Rudo) [1700797]
- [net] net/smc: add smcd support to the pnet table (Philipp Rudo) [1700797]
- [net] net/smc: rework pnet table (Philipp Rudo) [1700797]
- [net] net/smc: cleanup for smcr_tx_sndbuf_nonempty (Philipp Rudo) [1700797]

* Tue May 14 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-88.rt16.28.el8]
- [rt] kernel-rt-4.18.0-88.rt16.27.el8 (Juri Lelli) [1678887]
- [tools] tools power turbostat: Override CFLAGS assignments and add LDFLAGS to build command (Steve Best) [1705959]
- [tools] tools/power turbostat: update version number (Steve Best) [1705959]
- [tools] tools/power turbostat: Add checks for failure of fgets() and fscanf() (Steve Best) [1705959]
- [tools] tools/power turbostat: Warn on bad ACPI LPIT data (Steve Best) [1705959]
- [tools] tools/power turbostat: Also read package power on AMD F17h (Zen) (Steve Best) [1705959]
- [tools] tools/power turbostat: Add support for AMD Fam 17h (Zen) RAPL (Steve Best) [1705959]
- [tools] tools/power turbostat: Do not display an error on systems without a cpufreq driver (Steve Best) [1705959]
- [tools] tools/power turbostat: Add Die column (Steve Best) [1705959]
- [tools] tools/power turbostat: Cleanup CNL-specific code (Steve Best) [1705959]
- [tools] tools/power turbostat: Cleanup CC3-skip code (Steve Best) [1705959]
- [tools] tools/power turbostat: Restore ability to execute in topology-order (Steve Best) [1705959]
- [tools] tools/power turbostat: fix goldmont C-state limit decoding (Steve Best) [1705959]
- [tools] tools/power turbostat: reduce debug output (Steve Best) [1705959]
- [tools] tools/power turbosat: fix AMD APIC-id output (Steve Best) [1705959]
- [mmc] mmc: sdhci-iproc: Add ACPI support (Mark Langsdorf) [1576966]
- [mmc] mmc: sdhci-pltfm: Convert DT properties to generic device properties (Mark Langsdorf) [1576966]
- [tty] serial: 8250_dw: Add ACPI support for uart on Broadcom SoC (Mark Langsdorf) [1576966]
- [watchdog] watchdog: sp805: Add clock-frequency property (Mark Langsdorf) [1576966]
- [watchdog] watchdog: sp805: set WDOG_HW_RUNNING when appropriate (Mark Langsdorf) [1576966]
- [thermal] thermal: broadcom: Add Stingray thermal driver (Mark Langsdorf) [1576966]
- [hv] hv: vmbus: Change server monitor_pages index to 0 (Mohammed Gamal) [1691383]
- [kernel] hv: vmbus: Expose counters for interrupts and full conditions (Mohammed Gamal) [1691383]
- [kernel] vmbus: Switch to use new generic UUID API (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Check for ring when getting debug info (Mohammed Gamal) [1691383]
- [x86] hyper-v: move synic/stimer control structures definitions to hyperv-tlfs.h (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Return -EINVAL for the sys files for unopened channels (Mohammed Gamal) [1691383]
- [hv] x86, hyperv: remove PCI dependency (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Offload the handling of channels to two workqueues (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: check the creation_status in vmbus_establish_gpadl() (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Remove the useless API vmbus_get_outgoing_channel() (Mohammed Gamal) [1691383]
- [hv] hv: kvp: Use u to print U32 (Mohammed Gamal) [1691383]
- [hv] hv_utils: update name in struct hv_driver util_drv (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Get rid of unnecessary state in hv_context (Mohammed Gamal) [1691383]
- [hv] hv: kvp: Fix the recent regression caused by incorrect clean-up (Mohammed Gamal) [1691383]
- [hv] hv_balloon: Replace spin_is_locked() with lockdep (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Use cpumask_var_t for on-stack cpu mask (Mohammed Gamal) [1691383]
- [hv] hv: kvp: Fix two "this statement may fall through" warnings (Mohammed Gamal) [1691383]
- [hv] hv: kvp: Fix the indentation of some "break" statements (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Fix the descriptions of some function parameters (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Use get/put_cpu() in vmbus_connect() (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Fix synic per-cpu context initialization (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Cleanup synic memory free path (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Remove use of slow_virt_to_phys() (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: add numa_node to sysfs (Mohammed Gamal) [1691383]
- [x86] hv: vmbus: Get rid of MSR access from vmbus_drv.c (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Fix the issue with freeing up hv_ctl_table_hdr (Mohammed Gamal) [1691383]
- [hv] hv: vmus: Fix the check for return value from kmsg get dump buffer (Mohammed Gamal) [1691383]
- [hv] hv: Send one page worth of kmsg dump over Hyper-V during panic (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Remove x86 MSR refs in arch independent code (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Fix the offer_in_progress in vmbus_process_offer() (Mohammed Gamal) [1691383]
- [hv] hv: vmbus: Add comments on ring buffer signaling (Mohammed Gamal) [1691383]
- [video] use the new async probing feature for the hyperv drivers (Mohammed Gamal) [1691383]
- [rpmspec] kernel-packaging: Remove kernel files from kernel-modules-extra package (Prarit Bhargava) [1705216]
- [fs] xfs: don't ever put nlink > 0 inodes on the unlinked list (Brian Foster) [1693063]
- [fs] xfs: reserve blocks for ifree transaction during log recovery (Brian Foster) [1693063]
- [fs] xfs: rename m_inotbt_nores to m_finobt_nores (Brian Foster) [1693063]
- [net] xfrm: Honor original L3 slave device in xfrmi policy lookup (Herbert Xu) [1702198]
- [net] xfrm: Fix inbound traffic via XFRM interfaces across network namespaces (Herbert Xu) [1702198]
- [net] xfrm: Make set-mark default behavior backward compatible (Herbert Xu) [1702198]
- [net] xfrm: remove unnecessary check in xfrmi_get_stats64 (Herbert Xu) [1702198]
- [net] xfrm: fix gro_cells leak when remove virtual xfrm interfaces (Herbert Xu) [1702198]
- [net] xfrm: Make function xfrmi_get_link_net() static (Herbert Xu) [1702198]
- [net] xfrm: fix ptr_ret.cocci warnings (Herbert Xu) [1702198]
- [net] xfrm: Return detailed errors from xfrmi_newlink (Herbert Xu) [1702198]
- [net] xfrm: Allow xfrmi if_id to be updated by UPDSA (Herbert Xu) [1702198]
- [net] xfrm: Remove xfrmi interface ID from flowi (Herbert Xu) [1702198]
- [net] xfrm: Allow Set Mark to be Updated Using UPDSA (Herbert Xu) [1702198]
- [net] xfrm: Add virtual xfrm interfaces (Herbert Xu) [1702198]
- [net] xfrm: Add a new lookup key to match xfrm interfaces. (Herbert Xu) [1702198]
- [net] flow: Extend flow informations with xfrm interface id. (Herbert Xu) [1702198]
- [net] xfrm: Extend the output_mark to support input direction and masking. (Herbert Xu) [1702198]
- [fs] xfs: don't account extra agfl blocks as available (Brian Foster) [1656687]
- [scsi] scsi: hisi_sas: Some misc tidy-up (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Don't fail IT nexus reset for Open Reject timeout (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Don't hard reset disk during controller reset (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Support all RAS events with MSI interrupts (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: allocate different SAS address for directly attached situation (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Adjust the printk format of functions hisi_sas_init_device() (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Fix for setting the PHY linkrate when disconnected (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: Remedy inconsistent PHY down state in software (Xiaojun Tan) [1702614]
- [scsi] scsi: hisi_sas: add host reset interface for test (Xiaojun Tan) [1702614]
- [hid] HID: Increase maximum report size allowed by hid_field_extract() (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: remove data[128] usage on stack when sending HBM request (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: move doorbell writing before flush (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: Optimize writing ipc message from queue (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: avoid binding wrong ishtp_cl_device (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: Enable Ice Lake mobile (Tony Camuso) [1688112]
- [hid] HID: increase maximum global item tag report size to 256 (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: Enable Sunrise Point-H ish driver (Tony Camuso) [1688112]
- [hid] HID: intel-ish-hid: remove redundant variable num_frags (Tony Camuso) [1688112]

* Tue May 14 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-87.rt16.27.el8]
- [rt] kernel-rt-4.18.0-87.rt16.26.el8 (Juri Lelli) [1678887]
- [rt] redhat: Make kernel-rt require rt-setup (Juri Lelli) [https://bugzilla.redhat.com/1700666]
- [s390] Disable kexec_load via kernel_lockdown for s390 (Philipp Rudo) [1659399]
- [s390] s390/ipl: Provide has_secure sysfs attribute (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Create ipl report and pass to next kernel (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Signature verification prototype (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Load new kernel to absolute 0 (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Unify loader code (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Simplify parmarea access (Philipp Rudo) [1659399]
- [s390] s390/purgatory: Omit use of bin2c (Philipp Rudo) [1659399]
- [s390] s390/purgatory: Reduce purgatory size (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Fix detection of text segment in ELF loader (Philipp Rudo) [1659399]
- [s390] s390/kexec_file: Fix potential segment overlap in ELF loader (Philipp Rudo) [1659399]
- [s390] s390/zcore: Rename ipl_block to mitigate name collision (Philipp Rudo) [1659399]
- [s390] s390/boot: pad bzImage to 4K (Philipp Rudo) [1659399]
- [s390] s390/ipl: add helper functions to create an IPL report (Philipp Rudo) [1659399]
- [s390] s390/ipl: read IPL report at early boot (Philipp Rudo) [1659399]
- [s390] s390/ipl: add definitions for the IPL report block (Philipp Rudo) [1659399]
- [s390] s390/ipl: provide uapi header for list directed IPL (Philipp Rudo) [1659399]
- [s390] s390/ipl: make ipl_info less confusing (Philipp Rudo) [1659399]
- [s390] s390: introduce .boot.preserved.data section compile time validation (Philipp Rudo) [1659399]
- [s390] s390: move ipl block to .boot.preserved.data section (Philipp Rudo) [1659399]
- [s390] s390: introduce .boot.preserved.data section (Philipp Rudo) [1659399]
- [mm] s390: clean up redundant facilities list setup (Philipp Rudo) [1659399]
- [s390] s390/als: remove duplicated in-place implementation of stfle (Philipp Rudo) [1659399]
- [netdrv] fm10k: Fix a potential NULL pointer dereference (Neil Horman) [1659172]
- [netdrv] fm10k: use struct_size() in kzalloc() (Neil Horman) [1659172]
- [netdrv] fm10k: TRIVIAL cleanup of extra spacing in function comment (Neil Horman) [1659172]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Neil Horman) [1659172]
- [netdrv] fm10k: bump driver version to match out-of-tree release (Neil Horman) [1659172]
- [netdrv] fm10k: add missing device IDs to the upstream driver (Neil Horman) [1659172]
- [netdrv] fm10k: ensure completer aborts are marked as non-fatal after a resume (Neil Horman) [1659172]
- [netdrv] fm10k: fix SM mailbox full condition (Neil Horman) [1659172]
- [netdrv] fm10k: remove ndo_poll_controller (Neil Horman) [1659172]
- [netdrv] intel-ethernet: use correct module license (Neil Horman) [1659172]
- [scsi] Revert "scsi: fcoe: clear FC_RP_STARTED flags when receiving a LOGO" (Nilesh Javali) [1701545]
- [tools] tools: introduce test_and_clear_bit (Peter Xu) [1694926]
- [net] bridge: fix netlink export of vlan_stats_per_port option (Ivan Vecera) [1703551]
- [net] bridge: fix vlan stats use-after-free on destruction (Ivan Vecera) [1703551]
- [tools] headers uapi: Update linux/if_link.h header copy (Ivan Vecera) [1703551]
- [net] bridge: fix a possible memory leak in __vlan_add (Ivan Vecera) [1703551]
- [net] bridge: add support for per-port vlan stats (Ivan Vecera) [1703551]
- [net] bridge: mcast: Default back to multicast enabled state (Ivan Vecera) [1703551]
- [net] bridge: pack net_bridge better (Ivan Vecera) [1703551]
- [net] bridge: convert mtu_set_by_user to a bit (Ivan Vecera) [1703551]
- [net] bridge: convert neigh_suppress_enabled option to a bit (Ivan Vecera) [1703551]
- [net] bridge: convert mcast options to bits (Ivan Vecera) [1703551]
- [net] bridge: convert and rename mcast disabled (Ivan Vecera) [1703551]
- [net] bridge: convert group_addr_set option to a bit (Ivan Vecera) [1703551]
- [net] bridge: convert nf call options to bits (Ivan Vecera) [1703551]
- [net] bridge: add bitfield for options and convert vlan opts (Ivan Vecera) [1703551]
- [net] bridge: make struct opening bracket consistent (Ivan Vecera) [1703551]
- [net] Add netif_is_gretap()/netif_is_ip6gretap() (Ivan Vecera) [1701208]
- [net] sched: register callbacks for indirect tc block binds (Ivan Vecera) [1701214]
- [tools] selftests: tc-testing: fix tunnel_key failure if dst_port is unspecified (Ivan Vecera) [1701210]
- [tools] selftests: tc-testing: drop test on missing tunnel key id (Ivan Vecera) [1701210]
- [net] sched: act_tunnel_key: Don't dump dst port if it wasn't set (Ivan Vecera) [1701210]
- [net] sched: act_tunnel_key: Allow key-less tunnels (Ivan Vecera) [1701210]
- [net] ethtool: Added support for 50Gbps per lane link modes (Ivan Vecera) [1701215]
- [net] ip_gre: fix parsing gre header in ipgre_err (Hangbin Liu) [1702212]
- [net] vxlan: Free a leaked vetoed multicast rdst (Ivan Vecera) [1691695]
- [net] switchdev: Add extack argument to call_switchdev_notifiers() (Ivan Vecera) [1691695]
- [netdrv] vxlan: Add extack to switchdev operations (Ivan Vecera) [1691695]
- [net] net: Add extack argument to ndo_fdb_add() (Ivan Vecera) [1691695]
- [netdrv] vxlan: changelink: Delete remote after update (Ivan Vecera) [1691695]
- [netdrv] vxlan: changelink: Postpone vxlan_config_apply() (Ivan Vecera) [1691695]
- [netdrv] vxlan: changelink: Inline vxlan_dev_configure() (Ivan Vecera) [1691695]
- [netdrv] vxlan: Allow vetoing of FDB notifications (Ivan Vecera) [1691695]
- [netdrv] vxlan: Have vxlan_fdb_replace() save original rdst value (Ivan Vecera) [1691695]
- [netdrv] vxlan: Split vxlan_fdb_update() in two (Ivan Vecera) [1691695]
- [netdrv] vxlan: Move up vxlan_fdb_free(), vxlan_fdb_destroy() (Ivan Vecera) [1691695]
- [net] bridge: Add br_fdb_clear_offload() (Ivan Vecera) [1691695]
- [netdrv] vxlan: Add vxlan_fdb_clear_offload() (Ivan Vecera) [1691695]
- [netdrv] vxlan: Add vxlan_fdb_replay() (Ivan Vecera) [1691695]
- [net] route: add support for directed broadcast forwarding (Xin Long) [1562384]
- [net] erspan: build the header with the right proto according to erspan_ver (Xin Long) [1663862]
- [net] ipv6: make ip6_create_rt_rcu return ip6_null_entry instead of NULL (Xin Long) [1688617]
- [net] tipc: handle the err returned from cmd header function (Jon Maloy) [1693452]
- [net] tipc: check link name with right length in tipc_nl_compat_link_set (Jon Maloy) [1693452]
- [net] tipc: check bearer name with right length in tipc_nl_compat_bearer_enable (Jon Maloy) [1693452]
- [net] tipc: change to check tipc_own_id to return in tipc_net_stop (Jon Maloy) [1693452]
- [net] tipc: tipc clang warning (Jon Maloy) [1693452]
- [net] tipc: fix cancellation of topology subscriptions (Jon Maloy) [1693452]
- [net] tipc: allow service ranges to be connect()'ed on RDM/DGRAM (Jon Maloy) [1693452]
- [net] net: tipc: fix a missing check for nla_nest_start (Jon Maloy) [1693452]
- [net] net: tipc: fix a missing check of nla_nest_start (Jon Maloy) [1693452]
- [net] tipc: fix RDM/DGRAM connect() regression (Jon Maloy) [1693452]
- [net] tipc: fix race condition causing hung sendto (Jon Maloy) [1693452]
- [net] tipc: improve function tipc_wait_for_rcvmsg() (Jon Maloy) [1693452]
- [net] tipc: improve function tipc_wait_for_cond() (Jon Maloy) [1693452]
- [net] tipc: fix link session and re-establish issues (Jon Maloy) [1693452]
- [net] tipc: fix skb may be leaky in tipc_link_input (Jon Maloy) [1693452]
- [net] tipc: remove dead code in struct tipc_topsrv (Jon Maloy) [1693452]
- [net] tipc: mark expected switch fall-throughs (Jon Maloy) [1693452]
- [net] tipc: remove unneeded semicolon in trace.c (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in tipc_nl_compat_doit (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in tipc_nl_compat_name_table_dump (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in tipc_nl_compat_link_set (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in tipc_nl_compat_bearer_enable (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in tipc_nl_compat_link_reset_stats (Jon Maloy) [1693452]
- [net] tipc: fix uninit-value in in tipc_conn_rcv_sub (Jon Maloy) [1693452]
- [net] tipc: fix memory leak in tipc_nl_compat_publ_dump (Jon Maloy) [1693452]
- [net] tipc: fix a missing check of genlmsg_put (Jon Maloy) [1693452]
- [net] tipc: fix a double free in tipc_enable_bearer() (Jon Maloy) [1693452]
- [net] net/netlink_compat: Fix a missing check of nla_parse_nested (Jon Maloy) [1693452]
- [net] tipc: fix uninitialized value for broadcast retransmission (Jon Maloy) [1693452]
- [net] tipc: add trace_events for tipc bearer (Jon Maloy) [1693452]
- [net] tipc: add trace_events for tipc node (Jon Maloy) [1693452]
- [net] tipc: add trace_events for tipc socket (Jon Maloy) [1693452]
- [net] tipc: add trace_events for tipc link (Jon Maloy) [1693452]
- [net] tipc: enable tracepoints in tipc (Jon Maloy) [1693452]
- [net] tipc: handle broadcast NAME_DISTRIBUTOR packet when receiving it (Jon Maloy) [1693452]
- [net] tipc: check group dests after tipc_wait_for_cond() (Jon Maloy) [1693452]
- [net] tipc: check tsk->group in tipc_wait_for_cond() (Jon Maloy) [1693452]
- [net] tipc: compare remote and local protocols in tipc_udp_enable() (Jon Maloy) [1693452]
- [net] tipc: use lock_sock() in tipc_sk_reinit() (Jon Maloy) [1693452]
- [net] tipc: fix node keep alive interval calculation (Jon Maloy) [1693452]
- [net] tipc: fix lockdep warning during node delete (Jon Maloy) [1693452]
- [net] tipc: don't assume linear buffer when reading ancillary data (Jon Maloy) [1693452]
- [net] tipc: fix lockdep warning when reinitilaizing sockets (Jon Maloy) [1693452]
- [net] tipc: fix link re-establish failure (Jon Maloy) [1693452]
- [net] tipc: improve broadcast retransmission algorithm (Jon Maloy) [1693452]
- [net] tipc: use destination length for copy string (Jon Maloy) [1693452]
- [net] tipc: support binding to specific ip address when activating UDP bearer (Jon Maloy) [1677371 1693452]
- [net] tipc: remainder of commit ignore STATE_MSG on wrong link session (Jon Maloy) [1693452]
- [net] tipc: buffer overflow handling in listener socket (Jon Maloy) [1693452]
- [net] tipc: add SYN bit to connection setup messages (Jon Maloy) [1693452]
- [net] tipc: refactor function tipc_sk_filter_connect() (Jon Maloy) [1693452]
- [net] tipc: refactor function tipc_sk_timeout() (Jon Maloy) [1693452]
- [net] tipc: refactor function tipc_msg_reverse() (Jon Maloy) [1693452]
- [net] tipc: Add and use skb_mark_not_on_list(). (Jon Maloy) [1693452]
- [net] tipc: correct spelling errors for tipc_topsrv_queue_evt() comments (Jon Maloy) [1693452]
- [net] tipc: correct spelling errors for struct tipc_bc_base's comment (Jon Maloy) [1693452]
- [net] tipc: correct structure parameter comments for topsrv (Jon Maloy) [1693452]
- [net] net/tipc: remove redundant variables 'tn' and 'oport' (Jon Maloy) [1693452]
- [net] net: tipc: bcast: Replace GFP_ATOMIC with GFP_KERNEL in tipc_bcast_init() (Jon Maloy) [1693452]
- [net] net: tipc: name_table: Replace GFP_ATOMIC with GFP_KERNEL in tipc_nametbl_init() (Jon Maloy) [1693452]
- [net] tipc: make some functions static (Jon Maloy) [1693452]
- [net] tipc: make link capability update thread safe (Jon Maloy) [1693452]
- [net] tipc: remove unused tipc_group_size (Jon Maloy) [1693452]
- [net] tipc: remove unused tipc_link_is_active (Jon Maloy) [1693452]
- [net] tipc: check session number before accepting link protocol messages (Jon Maloy) [1693452]
- [net] tipc: add sequence number check for link STATE messages (Jon Maloy) [1693452]
- [net] tipc: mark expected switch fall-throughs (Jon Maloy) [1693452]
- [net] tipc: extend sock diag for group communication (Jon Maloy) [1693452]
- [net] tipc: Auto removal of peer down node instance (Jon Maloy) [1693452]
- [net] tipc: optimize function tipc_node_timeout() (Jon Maloy) [1693452]
- [net] tipc: eliminate buffer cloning in function tipc_msg_extract() (Jon Maloy) [1693452]
- [net] netfilter: nf_conncount: fix argument order to find_next_bit (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: speculative garbage collection on empty lists (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: move all list iterations under spinlock (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: merge lookup and add functions (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: restart search when nodes have been erased (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: split gc in two phases (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: don't skip eviction when age is negative (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: replace CONNCOUNT_LOCK_SLOTS with CONNCOUNT_SLOTS (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: use rb_link_node_rcu() instead of rb_link_node() (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: remove wrong condition check routine (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: fix unexpected permanent node of list. (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: fix list_del corruption in conn_free (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: use spin_lock_bh instead of spin_lock (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Add list lock and gc worker, and RCU for init tree search (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Split insert and traversal (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Move locking into count_tree() (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Early exit in nf_conncount_lookup() and cleanup (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Switch to plain list (Florian Westphal) [1531074]
- [net] netfilter: nf_conncount: Early exit for garbage collection (Florian Westphal) [1531074]
- [net] ptp: uapi: change _IOW to IOWR in PTP_SYS_OFFSET_EXTENDED definition (Hangbin Liu) [1677215]
- [net] ptp: check that rsv field is zero in struct ptp_sys_offset_extended (Hangbin Liu) [1677215]
- [net] ptp: deprecate gettime64() in favor of gettimex64() (Hangbin Liu) [1677215]
- [net] ptp: add PTP_SYS_OFFSET_EXTENDED ioctl (Hangbin Liu) [1677215]
- [net] ptp: check gettime64 return code in PTP_SYS_OFFSET ioctl (Hangbin Liu) [1677215]
- [net] ptp: reorder declarations in ptp_ioctl() (Hangbin Liu) [1677215]
- [net] tuntap: fix multiqueue rx (Guillaume Nault) [1686563]

* Mon May 13 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-86.rt16.26.el8]
- [rt] kernel-rt-4.18.0-86.rt16.25.el8 (Juri Lelli) [1678887]
- [rt] char/tpm: Remove defined but not used tpm_dev_wq_lock (Juri Lelli)
- [edac] EDAC/amd64: Add Family 17h Model 30h PCI IDs (Aristeu Rozanski) [1696603]
- [x86] Update stepping values for coffee lake desktop (David Arcari) [1704800]
- [security] KEYS: trusted: allow trusted.ko to initialize w/o a TPM (Jerry Snitselaar) [1694208]
- [security] tpm: pass an array of tpm_extend_digest structures to tpm_pcr_extend() (Jerry Snitselaar) [1665130 1665129]
- [security] KEYS: trusted: explicitly use tpm_chip structure from tpm_default_chip() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm/ppi: Enable submission of optional command parameter for PPI 1.3 (Jerry Snitselaar) [1665130]
- [char] tpm/ppi: Possibly show command parameter if TPM PPI 1.3 is used (Jerry Snitselaar) [1665130]
- [char] tpm/ppi: Display up to 101 operations as define for version 1.3 (Jerry Snitselaar) [1665130]
- [char] tpm/ppi: rename TPM_PPI_REVISION_ID to TPM_PPI_REVISION_ID_1 (Jerry Snitselaar) [1665130]
- [char] tpm/ppi: pass function revision ID to tpm_eval_dsm() (Jerry Snitselaar) [1665130]
- [char] tpm: Fix the type of the return value in calc_tpm2_event_size() (Jerry Snitselaar) [1694208 1665129]
- [char] tpm: fix an invalid condition in tpm_common_poll (Jerry Snitselaar) [1694208]
- [char] tpm: turn on TPM on suspend for TPM 1.x (Jerry Snitselaar) [1694208 1665130]
- [char] tpm: move tpm_chip definition to include/linux/tpm.h (Jerry Snitselaar) [1665129]
- [char] tpm: retrieve digest size of unknown algorithms with PCR read (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: rename and export tpm2_digest and tpm2_algorithms (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: dynamically allocate the allocated_banks array (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: remove @flags from tpm_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: take TPM chip power gating out of tpm_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: introduce tpm_chip_start() and tpm_chip_stop() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: remove TPM_TRANSMIT_UNLOCKED flag (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: use tpm_try_get_ops() in tpm-sysfs.c. (Jerry Snitselaar) [1665130]
- [char] tpm: remove @space from tpm_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: move TPM space code out of tpm_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: move tpm_validate_commmand() to tpm2-space.c (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: clean up tpm_try_transmit() error handling flow (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: encapsulate tpm_dev_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: access command header through struct in tpm_try_transmit() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: declare struct tpm_header (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: print tpm2_commit_space() error inside tpm2_commit_space() (Jerry Snitselaar) [1665129]
- [char] tpm: return 0 from pcrs_show() when tpm1_pcr_read() fails (Jerry Snitselaar) [1665130]
- [char] tpm: fix invalid return value in pubek_show() (Jerry Snitselaar) [1694208 1665130]
- [char] tpm: use tpm_buf in tpm_transmit_cmd() as the IO parameter (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: don't return bool from update_timeouts (Jerry Snitselaar) [1665130]
- [char] tpm: don't print error message in tpm_transmit_cmd when tpm still testing (Jerry Snitselaar) [1665129]
- [char] tpm: add _head suffix to tcg_efi_specid_event and tcg_pcr_event2 (Jerry Snitselaar) [1665129]
- [char] tpm: Fix off-by-one when reading binary_bios_measurements (Jerry Snitselaar) [1694208 1665130]
- [char] tpm: Simplify the measurements loop (Jerry Snitselaar) [1665130]
- [char] tpm/tpm_i2c_atmel: Return -E2BIG when the transfer is incomplete (Jerry Snitselaar) [1694208]
- [char] tpm: Unify the send callback behaviour (Jerry Snitselaar) [1665129]
- [char] tpm: Fix some name collisions with drivers/char/tpm.h (Jerry Snitselaar) [1694208]
- [char] tpm/tpm_crb: Avoid unaligned reads in crb_recv() (Jerry Snitselaar) [1694208 1665129]
- [char] tpm: add support for partial reads (Jerry Snitselaar) [1665129]
- [char] tpm: tpm_ibmvtpm: fix kdoc warnings (Jerry Snitselaar) [1665129]
- [char] tpm: fix kdoc for tpm2_flush_context_cmd() (Jerry Snitselaar) [1694208 1665129]
- [char] tpm: tpm_try_transmit() refactor error flow. (Jerry Snitselaar) [1694208 1665129]
- [char] tpm: use u32 instead of int for PCR index (Jerry Snitselaar) [1665130 1665129]
- [security] ima: Get rid of ima_used_chip and use ima_tpm_chip != NULL instead (Jerry Snitselaar) [1665130 1665129]
- [security] ima: Use tpm_default_chip() and call TPM functions with a tpm_chip (Jerry Snitselaar) [1665129]
- [char] tpm1: reimplement tpm1_continue_selftest() using tpm_buf (Jerry Snitselaar) [1665130]
- [char] tpm1: reimplement SAVESTATE using tpm_buf (Jerry Snitselaar) [1665130]
- [char] tpm1: rename tpm1_pcr_read_dev to tpm1_pcr_read() (Jerry Snitselaar) [1665130]
- [char] tpm1: implement tpm1_pcr_read_dev() using tpm_buf structure (Jerry Snitselaar) [1665130]
- [char] tpm: tpm1: rewrite tpm1_get_random() using tpm_buf structure (Jerry Snitselaar) [1665130]
- [char] tpm: tpm-space.c remove unneeded semicolon (Jerry Snitselaar) [1665129]
- [char] tpm: tpm-interface.c drop unused macros (Jerry Snitselaar) [1694208 1665130]
- [char] tpm: add tpm_auto_startup() into tpm-interface.c (Jerry Snitselaar) [1665129]
- [char] tpm: factor out tpm_startup function (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: factor out tpm 1.x pm suspend flow into tpm1-cmd.c (Jerry Snitselaar) [1665130]
- [char] tpm: move tpm 1.x selftest code from tpm-interface.c tpm1-cmd.c (Jerry Snitselaar) [1665130]
- [char] tpm: factor out tpm1_get_random into tpm1-cmd.c (Jerry Snitselaar) [1665130]
- [char] tpm: move tpm_getcap to tpm1-cmd.c (Jerry Snitselaar) [1665130]
- [char] tpm: move tpm1_pcr_extend to tpm1-cmd.c (Jerry Snitselaar) [1665130]
- [char] tpm: factor out tpm_get_timeouts() (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: add tpm_calc_ordinal_duration() wrapper (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: factor out tpm 1.x duration calculation to tpm1-cmd.c (Jerry Snitselaar) [1665130 1665129]
- [char] tpm: sort objects in the Makefile (Jerry Snitselaar) [1665129]
- [char] tpm2: add new tpm2 commands according to TCG 1.36 (Jerry Snitselaar) [1665129]
- [char] tpm: tpm_i2c_nuvoton: use correct command duration for TPM 2.x (Jerry Snitselaar) [1665129]
- [char] tpm: add support for nonblocking operation (Jerry Snitselaar) [1665129]
- [char] tpm: add ptr to the tpm_space struct to file_priv (Jerry Snitselaar) [1665129]
- [char] tpm: Make SECURITYFS a weak dependency (Jerry Snitselaar) [1665129]
- [char] tpm: suppress transmit cmd error logs when TPM 1.2 is disabled/deactivated (Jerry Snitselaar) [1665130]
- [char] tpm: fix response size validation in tpm_get_random() (Jerry Snitselaar) [1694208 1665129]
- [char] tpm: replace TPM_TRANSMIT_RAW with TPM_TRANSMIT_NESTED (Jerry Snitselaar) [1665129]
- [char] tpm: Convert tpm_find_get_ops() to use tpm_default_chip() (Jerry Snitselaar) [1665129]
- [char] tpm: Implement tpm_default_chip() to find a TPM chip (Jerry Snitselaar) [1665129]
- [char] tpm: rename tpm_chip_find_get() to tpm_find_get_ops() (Jerry Snitselaar) [1665129]
- [char] tpm: Allow tpm_tis drivers to set hwrng quality. (Jerry Snitselaar) [1665129]
- [char] tpm: Return the actual size when receiving an unsupported command (Jerry Snitselaar) [1694208 1665129]
- [char] tpm/tpm_i2c_infineon: switch to i2c_lock_bus(..., I2C_LOCK_SEGMENT) (Jerry Snitselaar) [1665129]
- [char] tpm_tis_spi: Pass the SPI IRQ down to the driver (Jerry Snitselaar) [1665129]
- [char] tpm: migrate tpm2_get_random() to use struct tpm_buf (Jerry Snitselaar) [1665129]
- [char] tpm: migrate tpm2_get_tpm_pt() to use struct tpm_buf (Jerry Snitselaar) [1665129]
- [char] tpm: migrate tpm2_probe() to use struct tpm_buf (Jerry Snitselaar) [1665129]
- [char] tpm: migrate tpm2_shutdown() to use struct tpm_buf (Jerry Snitselaar) [1665129]
- [pci] PCI: Fix __initdata issue with "pci=disable_acs_redir" parameter (Myron Stowe) [1704979]
- [s390] s390/pci: skip VF scanning (Myron Stowe) [1704979]
- [pci] PCI/IOV: Add flag so platforms can skip VF scanning (Myron Stowe) [1704979]
- [pci] PCI/IOV: Factor out sriov_add_vfs() (Myron Stowe) [1704979]
- [pci] switchtec: Add MRPC DMA mode support (Myron Stowe) [1704979]
- [pci] switchtec: Improve MRPC efficiency by enabling write combining (Myron Stowe) [1704979]
- [pci] switchtec: Fix SWITCHTEC_IOCTL_EVENT_IDX_ALL flags overwrite (Myron Stowe) [1704979]
- [pci] switchtec: Set DMA coherent mask (Myron Stowe) [1704979]
- [pci] switchtec: Remove immediate status check after submitting MRPC command (Myron Stowe) [1704979]
- [pci] PCI / PM: Allow runtime PM without callback functions (Myron Stowe) [1704979]
- [pci] PCI/P2PDMA: Clean up documentation and kernel-doc (Myron Stowe) [1704979]
- [pci] PCI: Remove unnecessary space before function pointer arguments (Myron Stowe) [1704979]
- [maintainers] MAINTAINERS: Add x86 early-quirks.c file pattern to PCI subsystem (Myron Stowe) [1704979]
- [pci] PCI: Expand the "PF" acronym in Kconfig help text (Myron Stowe) [1704979]
- [x86] x86/PCI: Fix Broadcom CNB20LE unintended sign extension (redux) (Myron Stowe) [1704979]
- [pci] PCI/ASPM: Remove unused lists from struct pcie_link_state (Myron Stowe) [1704979]
- [pci] PCI / ACPI: Identify untrusted PCI devices (Myron Stowe) [1704979]

* Fri May 10 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-85.rt16.25.el8]
- [rt] kernel-rt-4.18.0-85.rt16.24.el8 (Juri Lelli) [1678887]
- [rt] x86/resctrl: Fix cpus_allowed usage (Juri Lelli)
- [documentation] x86/resctrl: Update Documentation/x86/resctrl_ui.txt (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Remove unnecessary check for cbm_validate() (Prarit Bhargava) [1504489]
- [maintainers] MAINTAINERS: Update resctrl filename patterns (Prarit Bhargava) [1504489]
- [documentation] Documentation: Rename and update intel_rdt_ui.txt to resctrl_ui.txt (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Introduce AMD QOS feature (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Fixup the user-visible strings (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Add AMD's X86_FEATURE_MBA to the scattered CPUID features (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Rename the config option INTEL_RDT to RESCTRL (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Add vendor check for the MBA software controller (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Bring cbm_validate() into the resource structure (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Initialize the vendor-specific resource functions (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Move all the macros to resctrl/internal.h (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Re-arrange the RDT init code (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Rename the RDT functions and definitions (Prarit Bhargava) [1504489]
- [x86] x86/resctrl: Rename and move rdt files to a separate directory (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Prevent pseudo-locking from using stale pointers (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix initial allocation to consider CDP (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: CBM overlap should also check for overlap with CDP peer (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce utility to obtain CDP peer (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix out-of-bounds memory access in CBM tests (Prarit Bhargava) [1504489]
- [x86] perf/x86: Add helper to obtain performance counter index (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Switch to bitmap_zalloc() (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Re-enable pseudo-lock measurements (Prarit Bhargava) [1504489]
- [x86] x86/cpu: Sanitize FAM6_ATOM naming (David Arcari) [1504489]
- [x86] x86/intel_rdt: Use perf infrastructure for measurements (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Create required perf event attributes (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Remove local register variables (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix incorrect loop end condition (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix exclusive mode handling of MBA resource (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix incorrect loop end condition (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Do not allow pseudo-locking of MBA resource (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix unchecked MSR access (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix invalid mode warning when multiple resources are managed (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Global closid helper to support future fixes (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix size reporting of MBA resource (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix data type in parsing callbacks (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Disable PMU access (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix possible circular lock dependency (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Make CPU information accessible for pseudo-locked regions (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Support restoration of subset of permissions (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Fix cleanup of plr structure on error (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Move pseudo_lock_region_clear() (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Limit C-states dynamically when pseudo-locking active (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Support L3 cache performance event of Broadwell (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: More precise L2 hit/miss measurements (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Create character device exposing pseudo-locked region (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Create debugfs files for pseudo-locking testing (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Create resctrl debug area (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Ensure RDT cleanup on exit (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Resctrl files reflect pseudo-locked information (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Support creation/removal of pseudo-locked region (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Pseudo-lock region creation/removal core (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Discover supported platforms via prefetch disable bits (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Add utilities to test pseudo-locked region possibility (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Split resource group removal in two (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Enable entering of pseudo-locksetup mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Support enter/exit of locksetup mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce pseudo-locked region (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Add check to determine if monitoring in progress (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Utilities to restrict/restore access to specific files (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Protect against resource group changes during locking (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Add utility to restrict/restore access to resctrl files (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Add utility to test if tasks assigned to resource group (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Respect read and write access (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce the Cache Pseudo-Locking modes (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Display resource groups' allocations' size in bytes (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce "bit_usage" to display cache allocations details (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Ensure requested schemata respects mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Support flexible data to parsing callbacks (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Making CBM name and type more explicit (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Enable setting of exclusive mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce new "exclusive" mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Initialize new resource group with sane defaults (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Make useful functions available internally (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce test to determine if closid is in use (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce resource group's mode resctrl file (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Associate mode with each RDT resource group (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Introduce RDT resource group mode (Prarit Bhargava) [1504489]
- [x86] x86/intel_rdt: Provide pseudo-locking hooks within rdt_mount (Prarit Bhargava) [1504489]
- [x86] perf/x86: Make perf callchains work without CONFIG_FRAME_POINTER (Jiri Olsa) [1699780]

* Wed May 08 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-84.rt16.24.el8]
- [rt] kernel-rt-4.18.0-84.rt16.23.el8 (Juri Lelli) [1678887]
- [kernel] sched/fair: Do not re-read ->h_load_next during hierarchical load calculation (Phil Auld) [1701762]
- [s390] kvm: s390: enable MSA9 keywrapping functions depending on cpu model (Thomas Huth) [1660913]
- [s390] kvm: s390: add deflate conversion facilty to cpu model (Thomas Huth) [1660913]
- [s390] kvm: s390: add enhanced sort facilty to cpu model (Thomas Huth) [1660913]
- [s390] kvm: s390: provide query function for instructions returning 32 byte (Thomas Huth) [1660913]
- [s390] kvm: s390: add MSA9 to cpumodel (Thomas Huth) [1660913]
- [s390] kvm: s390: add vector BCD enhancements facility to cpumodel (Thomas Huth) [1660913]
- [s390] kvm: s390: add vector enhancements facility 2 to cpumodel (Thomas Huth) [1660913]
- [s390] kvm: s390: add debug logging for cpu model subfunctions (Thomas Huth) [1660913]
- [s390] kvm: s390: implement subfunction processor calls (Thomas Huth) [1660913]
- [powercap] powercap: intel_rapl: add support for Jacobsville (Steve Best) [1482401]
- [x86] x86/cpu: Add Atom Tremont (Jacobsville) (Steve Best) [1482401]

* Tue May 07 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-83.rt16.23.el8]
- [rt] kernel-rt-4.18.0-83.rt16.22.el8 (Juri Lelli) [1678887]
- [crypto] crypto: qat - Remove unused goto label (Neil Horman) [1660313]
- [crypto] crypto: prefix header search paths with $(srctree)/ (Neil Horman) [1660313]
- [crypto] crypto: qat - no need to check return value of debugfs_create functions (Neil Horman) [1660313]
- [crypto] cross-tree: phase out dma_zalloc_coherent() (Neil Horman) [1660313]
- [crypto] crypto: qat - move temp buffers off the stack (Neil Horman) [1660313]
- [crypto] crypto: qat - Remove VLA usage (Neil Horman) [1660313]
- [include] block: kill all_q_node in request_queue (Ming Lei) [1702865]
- [block] bfq: update internal depth state when queue depth changes (Ming Lei) [1702865]
- [fs] block: fix the return errno for direct IO (Ming Lei) [1702865]
- [block] block: do not leak memory in bio_copy_user_iov() (Ming Lei) [1702865]
- [nvme] nvme: cancel request synchronously (Ming Lei) [1702865]
- [block] blk-mq: introduce blk_mq_complete_request_sync() (Ming Lei) [1702865]
- [scsi] scsi: virtio_scsi: limit number of hw queues by nr_cpu_ids (Ming Lei) [1702865]
- [block] virtio-blk: limit number of hw queues by nr_cpu_ids (Ming Lei) [1702865]
- [block] block, bfq: fix use after free in bfq_bfqq_expire (Ming Lei) [1702865]
- [block] paride/pcd: Fix potential NULL pointer dereference and mem leak (Ming Lei) [1702865]
- [block] blk-mq: do not reset plug->rq_count before the list is sorted (Ming Lei) [1702865]
- [block] paride/pf: Fix potential NULL pointer dereference (Ming Lei) [1702865]
- [block] blk-mq: add trace block plug and unplug for multiple queues (Ming Lei) [1702865]
- [block] block: use blk_free_flush_queue() to free hctx->fq in blk_mq_init_hctx (Ming Lei) [1702865]
- [block] paride/pcd: cleanup queues when detection fails (Ming Lei) [1702865]
- [block] paride/pf: cleanup queues when detection fails (Ming Lei) [1702865]
- [crypto] crypto: chelsio - Fixed Traffic Stall (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Fix passing zero to 'PTR_ERR' warning in chcr_aead_op (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Inline single pdu only (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - avoid using sa_entry imm (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - remove set but not used variables 'adap' (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - check set_msg_len overflow in generate_b0 (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Fix wrong error counter increments (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Reset counters on cxgb4 Detach (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Handle PCI shutdown event (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - cleanup:send addr as value in function argument (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Use same value for both channel in single WR (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Swap location of AAD and IV sent in WR (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - remove set but not used variable 'kctx_len' (Arjun Vynipadath) [1664679]
- [crypto] drivers: chelsio: use skb_sec_path helper (Arjun Vynipadath) [1664679]
- [crypto] crypto: chcr - ESN for Inline IPSec Tx (Arjun Vynipadath) [1664679]
- [crypto] crypto: chcr - small packet Tx stalls the queue (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - clean up various indentation issues (Arjun Vynipadath) [1664679]
- [crypto] crypto: chelsio - Update ntx queue received from cxgb4 (Arjun Vynipadath) [1664679]

* Fri May 03 2019 Clark Williams <williams@redhat.com> [4.18.0-82.rt16.22.el8]
- [rt] kernel-rt-4.18.0-82.rt16.21.el8 (Clark Williams) [1678887]
- [platform] platform/x86: intel_pmc_core: Convert to INTEL_CPU_FAM6 macro (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Avoid a u32 overflow (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Include Reserved IP for LTR (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Fix file permissions for ltr_show (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Fix PCH IP name (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Fix PCH IP sts reading (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Handle CFL regmap properly (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: convert to DEFINE_SHOW_ATTRIBUTE (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Decode Snoop / Non Snoop LTR (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Fix LTR IGNORE Max offset (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Show Latency Tolerance info (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc: Convert to use SPDX identifier (David Arcari) [1658080]
- [platform] platform/x86: intel_pmc_core: Add CNP SLPS0 debug registers (David Arcari) [1658080]
- [x86] x86/cpu: Introduce INTEL_CPU_FAM*() helper macros (David Arcari) [1658080]
- [include] locking/atomics, asm-generic: Move some macros from <linux/bitops.h> to a new <linux/bits.h> file (David Arcari) [1658080]
- [s390] s390/kasan: fix strncpy_from_user kasan checks (Philipp Rudo) [1665182]
- [s390] s390: correct some inline assembly constraints (Philipp Rudo) [1665182]
- [s390] s390/kasan: improve string/memory functions checks (Philipp Rudo) [1665182]
- [include] compiler: remove __no_sanitize_address_or_inline again (Philipp Rudo) [1665182]
- [s390] s390/kasan: increase instrumented stack size to 64k (Philipp Rudo) [1665182]
- [mm] s390/kasan: support preemptible kernel build (Philipp Rudo) [1665182]
- [mm] s390/kasan: add support for mem= kernel parameter (Philipp Rudo) [1665182]
- [mm] s390/kasan: optimize kasan vmemmap allocation (Philipp Rudo) [1665182]
- [mm] s390/kasan: avoid kasan crash with standby memory defined (Philipp Rudo) [1665182]
- [s390] s390/head: avoid doubling early boot stack size under KASAN (Philipp Rudo) [1665182]
- [mm] s390/mm: improve debugfs ptdump markers walking (Philipp Rudo) [1665182]
- [mm] s390/mm: optimize debugfs ptdump kasan zero page walking (Philipp Rudo) [1665182]
- [s390] s390/kasan: add option for 4-level paging support (Philipp Rudo) [1665182]
- [mm] s390/kasan: free early identity mapping structures (Philipp Rudo) [1665182]
- [s390] s390/kasan: enable stack and global variables access checks (Philipp Rudo) [1665182]
- [s390] s390/dumpstack: disable __dump_trace kasan instrumentation (Philipp Rudo) [1665182]
- [s390] s390/kasan: reipl and kexec support (Philipp Rudo) [1665182]
- [s390] s390/smp: kasan stack instrumentation support (Philipp Rudo) [1665182]
- [include] compiler: introduce __no_sanitize_address_or_inline (Philipp Rudo) [1665182]
- [s390] s390/kasan: use noexec and large pages (Philipp Rudo) [1665182]
- [mm] s390/kasan: dynamic shadow mem allocation for modules (Philipp Rudo) [1665182]
- [mm] s390/mm: add kasan shadow to the debugfs pgtable dump (Philipp Rudo) [1665182]
- [s390] s390/kasan: avoid user access code instrumentation (Philipp Rudo) [1665182]
- [s390] s390/kasan: double the stack size (Philipp Rudo) [1665182]
- [s390] s390/kasan: add initialization code and enable it (Philipp Rudo) [1665182]
- [s390] s390: add pgd_page primitive (Philipp Rudo) [1665182]
- [s390] s390: introduce MAX_PTRS_PER_P4D (Philipp Rudo) [1665182]
- [s390] s390/kasan: replace some memory functions (Philipp Rudo) [1665182]
- [s390] s390/kasan: avoid instrumentation of early C code (Philipp Rudo) [1665182]
- [s390] s390/kasan: avoid vdso instrumentation (Philipp Rudo) [1665182]
- [s390] s390/mm: add missing pfn_to_kaddr helper (Philipp Rudo) [1665182]
- [s390] s390/cpum_cf: Add support for CPU-MF SVN 6 (Philipp Rudo) [1683278]
- [s390] s390: report new CPU capabilities (Philipp Rudo) [1685086]
- [net] net/smc: fix smc_poll in SMC_INIT state (Philipp Rudo) [1700812]
- [net] net/smc: fix byte_order for rx_curs_confirmed (Philipp Rudo) [1700812]
- [net] net/smc: check port_idx of ib event (Philipp Rudo) [1700799]
- [net] net/smc: check connections in smc_lgr_free_work (Philipp Rudo) [1700799]
- [net] net/smc: reduce amount of status updates to peer (Philipp Rudo) [1700799]
- [net] net/smc: no delay for free tx buffer wait (Philipp Rudo) [1700799]
- [net] net/smc: move wake up of close waiter (Philipp Rudo) [1700799]
- [net] net/smc: reset cursor update required flag (Philipp Rudo) [1700799]
- [net] net/smc: correct state change for peer closing (Philipp Rudo) [1700799]
- [net] net/smc: delete rkey first before switching to unused (Philipp Rudo) [1700799]
- [net] net/smc: fix sender_free computation (Philipp Rudo) [1700799]
- [net] net/smc: preallocated memory for rdma work requests (Philipp Rudo) [1700799]
- [net] net/smc: fix use of variable in cleared area (Philipp Rudo) [1700799]
- [net] net/smc: use device link provided in qp_context (Philipp Rudo) [1700799]
- [net] net/smc: call smc_cdc_msg_send() under send_lock (Philipp Rudo) [1700799]
- [net] net/smc: do not wait under send_lock (Philipp Rudo) [1700799]
- [net] net/smc: recvmsg and splice_read should return 0 after shutdown (Philipp Rudo) [1700799]
- [net] net/smc: don't wait for send buffer space when data was already sent (Philipp Rudo) [1700799]
- [net] net/smc: prevent races between smc_lgr_terminate() and smc_conn_free() (Philipp Rudo) [1700799]
- [net] net/smc: allow 16 byte pnetids in netlink policy (Philipp Rudo) [1700799]
- [net] net/smc: fix another sizeof to int comparison (Philipp Rudo) [1700799]
- [net] net/smc: move code to clear the conn->lgr field (Philipp Rudo) [1700799]
- [net] net/smc: use client and server LGR pending locks for SMC-R (Philipp Rudo) [1700799]
- [net] net/smc: unlock LGR pending lock earlier for SMC-D (Philipp Rudo) [1700799]
- [net] net/smc: use smc_curs_copy() for SMC-D (Philipp Rudo) [1700799]
- [net] net/smc: postpone release of clcsock (Philipp Rudo) [1700799]
- [net] smc: move unhash as early as possible in smc_release() (Philipp Rudo) [1700799]
- [net] net/smc: fix TCP fallback socket release (Philipp Rudo) [1700799]
- [s390] s390/ism: ignore some errors during deregistration (Philipp Rudo) [1700799]
- [infiniband] mlx4: trigger IB events needed by SMC (Philipp Rudo) [1700799]
- [s390] s390/smp: fix CPU hotplug deadlock with CPU rescan (Philipp Rudo) [1700836]
- [block] s390/dasd: fix panic for failed online processing (Philipp Rudo) [1700811]
- [netdrv] s390/qeth: fix use-after-free in error path (Philipp Rudo) [1700803]
- [netdrv] s390/qeth: cancel close_dev work before removing a card (Philipp Rudo) [1700802]
- [netdrv] s390/qeth: conclude all event processing before offlining a card (Philipp Rudo) [1700800]
- [scsi] scsi: zfcp: fix posting too many status read buffers leading to adapter shutdown (Philipp Rudo) [1700775]
- [fs] xfs: prohibit fstrim in norecovery mode (Bill O'Donnell) [1697749]
- [x86] perf/x86: Fixup typo in stub functions (Waiman Long) [1688789]
- [x86] perf/x86/intel: Fix memory corruption (Waiman Long) [1688789]
- [x86] perf/x86/intel: Implement support for TSX Force Abort (Waiman Long) [1688789]
- [x86] x86: Add TSX Force Abort CPUID/MSR (Waiman Long) [1688789]
- [x86] perf/x86/intel: Generalize dynamic constraint creation (Waiman Long) [1688789]
- [x86] perf/x86/intel: Make cpuc allocations consistent (Waiman Long) [1688789]
- [x86] perf/x86/intel: Delay memory deallocation until x86_pmu_dead_cpu() (Waiman Long) [1688789]
- [x86] perf/x86/intel: Export mem events only if there's PEBS support (Waiman Long) [1688789]
- [x86] perf/x86/intel: Add a separate Arch Perfmon v4 PMI handler (Waiman Long) [1688789]
- [x86] perf/x86/intel: Factor out common code of PMI handler (Waiman Long) [1688789]
- [x86] perf/x86/intel: Introduce PMU flag for Extended PEBS (Waiman Long) [1688789]
- [x86] x86/speculation: Add PR_SPEC_DISABLE_NOEXEC (Waiman Long) [1671512]

* Tue Apr 30 2019 Clark Williams <williams@redhat.com> [4.18.0-81.rt16.21.el8]
- [rt] kernel-rt-4.18.0-81.rt16.20.el8 (Clark Williams) [1678887]
- [kernel] exit from RHEL 8.1 early ystream mode ("Herton R. Krzesinski")
- [net] Bluetooth: Verify that l2cap_get_conf_opt provides large enough buffer (Gopal Tiwari) [1700507] {CVE-2019-3459}
- [target] scsi: target: iscsi: cxgbit: fix csk leak (Arjun Vynipadath) [1664683]
- [target] scsi: target: iscsi: cxgbit: add missing spin_lock_init() (Arjun Vynipadath) [1664683]
- [scsi] scsi: cxgb4i: fix incorrect spelling "reveive" -> "receive" (Arjun Vynipadath) [1664685]
- [scsi] scsi: libcxgbi: update route finding logic (Arjun Vynipadath) [1664685]
- [scsi] scsi: libcxgbi: find cxgbi device by MAC address (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgbi: remove redundant __kfree_skb call on skb and free cst->atid (Arjun Vynipadath) [1664685]
- [scsi] scsi: libcxgbi: remove uninitialized variable len (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgb4i: validate tcp sequence number only if chip version <= T5 (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgb4i: get pf number from lldi->pf (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgb4i: add wait_for_completion() (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgb4i: fix thermal configuration dependencies (Arjun Vynipadath) [1664685]
- [scsi] scsi: cxgb4i: add DCB support for iSCSI connections (Arjun Vynipadath) [1664685]
- [netdrv] cxgb4: Don't return EAGAIN when TCAM is full. (Arjun Vynipadath) [1664670]
- [netdrv] chelsio: use BUG() instead of BUG_ON(1) (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/chtls: Prefix adapter flags with CXGB4 (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4vf: Call netif_carrier_off properly in pci_probe (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4vf: Revert force link up behaviour (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4: Add VF Link state support (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4vf: Prefix adapter flags with CXGB4VF (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4vf: Enter debugging mode if FW is inaccessible (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4: Enable outer UDP checksum offload for T6 (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/cxgb4vf: Fix up netdev->hw_features (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4: Mask out interrupts that are not enabled. (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Export sge_host_page_size to ulds (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add capability to get/set SGE Doorbell Queue Timer Tick (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/cxgb4vf: Add support for SGE doorbell queue timer (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4vf: Few more link management changes. (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4: add tcb flags and tcb rpl struct (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add new T6 PCI device ids 0x608b (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/cxgb4vf: Program hash region for {t4/t4vf}_change_mac() (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4: smt: use struct_size() in kvzalloc() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: sched: use struct_size() in kvzalloc() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: cxgb4_tc_u32: use struct_size() in kvzalloc() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4vf: Update port information in cxgb4vf_open() (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4/cxgb4vf: Link management changes (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4: TLS record offload enable (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: clip_tbl: Use struct_size() in kvzalloc() (Arjun Vynipadath) [1664670]
- [netdrv] net: cxgb4: fix various indentation issues (Arjun Vynipadath) [1664670]
- [netdrv] net: chelsio: Add a missing check on cudg_get_buffer (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove DEFINE_SIMPLE_DEBUGFS_FILE() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: number of VFs supported is not always 16 (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove set but not used variables 'multitrc, speed' (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: use new fw interface to get the VIN and smt index (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/cxgb4vf: Fix mac_hlist initialization and free (Arjun Vynipadath) [1664682 1664670]
- [netdrv] cxgb4vf: fix memleak in mac_hlist initialization (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4vf: free mac_hlist properly (Arjun Vynipadath) [1664682]
- [netdrv] cxgb4: free mac_hlist properly (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: fix thermal zone build error (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: fix thermal configuration dependencies (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add thermal zone support (Arjun Vynipadath) [1664670]
- [infiniband] cxgb4: use __vlan_hwaccel helpers (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add new T6 PCI device ids 0x608a (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: fix the error path of cxgb4_uld_register() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: use FW_PORT_ACTION_L1_CFG32 for 32 bit capability (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove the unneeded locks (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Use proper enum in IEEE_FAUX_SYNC (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Use proper enum in cxgb4_dcb_handle_fw_update (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove duplicated include from cxgb4_main.c (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: add per rx-queue counter for packet errors (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Fix endianness issue in t4_fwcache() (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: fix abort_req_rss6 struct (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove redundant assignment to vlan_cmd.dropnovlan_fm (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: collect hardware queue descriptors (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add new T5 PCI device ids 0x50af and 0x50b0 (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: remove set but not used variable 'spd' (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: add support to display DCB info (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/t4_hw: mark expected switch fall-throughs (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4/l2t: Mark expected switch fall-through (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: fix endian to test F_FW_PORT_CMD_DCBXDIS32 (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: print ULD queue information managed by LLD (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: move Tx/Rx free pages collection to common code (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add support to read actual provisioned resources (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: Add new T5 PCI device id 0x50ae (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: collect number of free PSTRUCT page pointers (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: display number of rx and tx pages free (Arjun Vynipadath) [1664670]
- [netdrv] cxgb4: collect ASIC LA dumps from ULP TX (Arjun Vynipadath) [1664670]
- [netdrv] libcxgb: replace vmalloc and memset with vzalloc (Arjun Vynipadath) [1664670]
- [netdrv] enic: fix checksum validation for IPv6 (Jonathan Toppins) [1685309]
- [infiniband] RDMA/vmw_pvrdma: Return the correct opcode when creating WR (Jonathan Toppins) [1688010 1685309]
- [infiniband] RDMA/vmw_pvrdma: Use atomic memory allocation in create AH (Jonathan Toppins) [1685309]
- [infiniband] IB/usnic: fix spelling mistake "miniumum" -> "minimum" (Jonathan Toppins) [1685309]
- [infiniband] RDMA/drivers: Fix spelling mistake "initalize" -> "initialize" (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: Reuse code which sets port state (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: Make counters thread safe (Jonathan Toppins) [1685309]
- [infiniband] RDMA: Cleanup undesired pd->uobject usage (Jonathan Toppins) [1685309]
- [infiniband] IB/{mlx5, ocrdma, qedr, rxe}: Omit port validation from IB verbs (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: Fix incorrect cache cleanup in error flow (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: Utilize generic function to validate port number (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: Make function rxe_pool_cleanup return void (Jonathan Toppins) [1685309]
- [infiniband] rxe: IB_WR_REG_MR does not capture MR's iova field (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: make rxe_unregister_device void (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: move the variable into the function that uses it (Jonathan Toppins) [1685309]
- [infiniband] RDMA/rxe: Add link_down, rdma_sends, rdma_recvs stats counters (Jonathan Toppins) [1685309]
- [infiniband] RDMA/rxe: Distinguish between down links and disabled links (Jonathan Toppins) [1685309]
- [infiniband] rxe: fix error completion wr_id and qp_num (Jonathan Toppins) [1685309]
- [infiniband] IB/rxe: clean skb queue directly (Jonathan Toppins) [1685309]
- [net] xprtrdma: Make sure Send CQ is allocated on an existing compvec (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Rework SCSI device reset handling (Jonathan Toppins) [1685309]
- [infiniband] IB/ipoib: Fix for use-after-free in ipoib_cm_tx_start (Jonathan Toppins) [1685309]
- [net] xprtrdma: Double free in rpcrdma_sendctxs_create() (Jonathan Toppins) [1685309]
- [net] xprtrdma: Fix error code in rpcrdma_buffer_create() (Jonathan Toppins) [1685309]
- [infiniband] IB/ipoib: drop useless LIST_HEAD (Jonathan Toppins) [1685309]
- [net] xprtrdma: Prevent leak of rpcrdma_rep objects (Jonathan Toppins) [1685309]
- [net] xprtrdma: Don't leak freed MRs (Jonathan Toppins) [1685309]
- [net] xprtrdma: Add documenting comment for rpcrdma_buffer_destroy (Jonathan Toppins) [1685309]
- [net] xprtrdma: Replace outdated comment for rpcrdma_ep_post (Jonathan Toppins) [1685309]
- [net] xprtrdma: Update comments in frwr_op_send (Jonathan Toppins) [1685309]
- [net] xprtrdma: Trace mapping, alloc, and dereg failures (Jonathan Toppins) [1685309]
- [net] xprtrdma: Add trace points for calls to transport switch methods (Jonathan Toppins) [1685309]
- [net] xprtrdma: Relocate the xprtrdma_mr_map trace points (Jonathan Toppins) [1685309]
- [net] xprtrdma: Clean up of xprtrdma chunk trace points (Jonathan Toppins) [1685309]
- [net] xprtrdma: Remove unused fields from rpcrdma_ia (Jonathan Toppins) [1685309]
- [net] xprtrdma: Cull dprintk() call sites (Jonathan Toppins) [1685309]
- [net] xprtrdma: Simplify locking that protects the rl_allreqs list (Jonathan Toppins) [1685309]
- [net] xprtrdma: Expose transport header errors (Jonathan Toppins) [1685309]
- [net] xprtrdma: Remove request_module from backchannel (Jonathan Toppins) [1685309]
- [net] xprtrdma: Plant XID in on-the-wire RDMA offset (FRWR) (Jonathan Toppins) [1685309]
- [net] xprtrdma: Remove rpcrdma_memreg_ops (Jonathan Toppins) [1685309]
- [net] xprtrdma: Remove support for FMR memory registration (Jonathan Toppins) [1685309]
- [net] xprtrdma: Reduce max_frwr_depth (Jonathan Toppins) [1685309]
- [net] xprtrdma: Fix ri_max_segs and the result of ro_maxpages (Jonathan Toppins) [1685309]
- [net] xprtrdma: Don't wake pending tasks until disconnect is done (Jonathan Toppins) [1685309]
- [net] xprtrdma: No qp_event disconnect (Jonathan Toppins) [1685309]
- [net] xprtrdma: Replace rpcrdma_receive_wq with a per-xprt workqueue (Jonathan Toppins) [1685309]
- [net] xprtrdma: Refactor Receive accounting (Jonathan Toppins) [1685309]
- [net] xprtrdma: Ensure MRs are DMA-unmapped when posting LOCAL_INV fails (Jonathan Toppins) [1685309]
- [net] xprtrdma: Yet another double DMA-unmap (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Use kmem_cache_free() instead of kfree() (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Add support for immediate data (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Rework the srpt_alloc_srq() error path (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Remove driver version and release date (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Make kernel-doc headers complete (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Join split strings (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Improve coding style conformance (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srpt: Fix a use-after-free in the channel release code (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Add support for immediate data (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Rework handling of the maximum information unit length (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Move srp_rdma_ch.max_ti_iu_len declaration (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Propagate ib_post_send() failures to the SCSI mid-layer (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Handle large SCSI CDBs correctly (Jonathan Toppins) [1685309]
- [infiniband] RDMA/srp: Document srp_parse_in() arguments (Jonathan Toppins) [1685309]
- [infiniband] include/scsi/srp.h: Add support for immediate data (Jonathan Toppins) [1685309]
- [infiniband] include/scsi/srp.h: Move response flag definitions into this file (Jonathan Toppins) [1685309]
- [net] svcrdma: Optimize the logic that selects the R_key to invalidate (Jonathan Toppins) [1685309]
- [infiniband] IB/srpt: Drop pointless static qualifier in srpt_make_tpg() (Jonathan Toppins) [1685309]
- [infiniband] IB/uverbs: Fix OOPs in uverbs_user_mmap_disassociate (Jonathan Toppins) [1685309]
- [infiniband] IB/uverbs: Fix ioctl query port to consider device disassociation (Jonathan Toppins) [1685309]
- [infiniband] IB/uverbs: Fix OOPs upon device disassociation (Jonathan Toppins) [1685309]
- [infiniband] RDMA/umem: Add missing initialization of owning_mm (Jonathan Toppins) [1685309]
- [infiniband] RDMA/device: Expose ib_device_try_get(() (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Mark ioctl responses with UVERBS_ATTR_F_VALID_OUTPUT (Jonathan Toppins) [1685309]
- [infiniband] RDMA/cma: Add cm_id restrack resource based on kernel or user cm_id type (Jonathan Toppins) [1685309]
- [infiniband] RDMA/nldev: Don't expose unsafe global rkey to regular user (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Fix post send success return value in case of error (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Add advise_mr to the list of known ops (Jonathan Toppins) [1685309]
- [infiniband] IB/uverbs: Signedness bug in UVERBS_HANDLER() (Jonathan Toppins) [1685309]
- [infiniband] IB/umad: Start using dev_groups of class (Jonathan Toppins) [1685309]
- [infiniband] IB/umad: Use class_groups and let core create class file (Jonathan Toppins) [1685309]
- [infiniband] IB/umad: Refactor code to use cdev_device_add() (Jonathan Toppins) [1685309]
- [infiniband] IB/umad: Avoid destroying device while it is accessed (Jonathan Toppins) [1685309]
- [infiniband] IB/umad: Simplify and avoid dynamic allocation of class (Jonathan Toppins) [1685309]
- [infiniband] RDMA/iwcm: Don't copy past the end of dev_name() string (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Move query port to ioctl (Jonathan Toppins) [1685309]
- [infiniband] RDMA/nldev: Expose port_cap_flags2 (Jonathan Toppins) [1685309]
- [infiniband] IB/core: uverbs copy to struct or zero helper (Jonathan Toppins) [1685309]
- [infiniband] RDMA: Mark if destroy address handle is in a sleepable context (Jonathan Toppins) [1685309]
- [infiniband] RDMA: Mark if create address handle is in a sleepable context (Jonathan Toppins) [1685309]
- [infiniband] RDMA/restrack: Resource-tracker should not use uobject pointers (Jonathan Toppins) [1685309]
- [include] IB/uverbs: Add support to advise_mr (Jonathan Toppins) [1685309]
- [include] IB/uverbs: Add helper to get array size from ptr attribute (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Add an ioctl method to destroy an object (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Add a method to introspect handles in a context (Jonathan Toppins) [1685309]
- [infiniband] RDMA/core: Delete RoCE GID in hw when corresponding IP is deleted (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Implement an ioctl that can call write and write_ex handlers (Jonathan Toppins) [1685309]
- [infiniband] RDMA: Start use ib_device_ops (Jonathan Toppins) [1685309]
- [infiniband] RDMA/rdmavt: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/rxe: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/vmw_pvrdma: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/usnic: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/qib: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/qedr: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/ocrdma: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/nes: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/mthca: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/mlx5: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/mlx4: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/i40iw: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/hns: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/hfi1: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/cxgb4: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/cxgb3: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/bnxt_re: Initialize ib_device_ops struct (Jonathan Toppins) [1685309]
- [infiniband] RDMA/core: Introduce ib_device_ops (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Optimize clearing of extra bytes in response (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Add new IB rates (Jonathan Toppins) [1685309]
- [include] IB/core: Add 2X port width (Jonathan Toppins) [1685309]
- [include] IB/core: Add CapabilityMask2 to port attributes (Jonathan Toppins) [1685309]
- [infiniband] RDMA/core: Validate port number in query_pkey verb (Jonathan Toppins) [1685309]
- [include] RDMA/uverbs: Fix typo in string concatenation macro (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Enable getting an object type from a given uobject (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Introduce UVERBS_IDR_ANY_OBJECT (Jonathan Toppins) [1685309]
- [infiniband] RDMA/nldev: Export to user space number of contexts (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Annotate alloc/deallloc paths with context tracking (Jonathan Toppins) [1685309]
- [include] RDMA/restrack: Track ucontext (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use only attrs for the write() handler signature (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Do not check the input length on create_cq/qp paths (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use the iterator for ib_uverbs_unmarshall_recv() (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Add a simple iterator interface for reading the command (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Simplify ib_uverbs_ex_query_device (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Fill in the response for IB_USER_VERBS_EX_CMD_MODIFY_QP (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_request() and core for write_ex handlers (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_request() for request copying (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_response() for remaining response copying (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Get rid of the 'callback' scheme in the compat path (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_attr_bundle to pass ucore for write/write_ex (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Remove out_len checks that are now done by the core (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: fix ptr_ret.cocci warnings (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_attr_bundle to pass udata for ioctl() (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_attr_bundle to pass udata for write (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use uverbs_attr_bundle to pass udata for write_ex (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Prohibit write() calls with too small buffers (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Add structure size info to write commands (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Do not pass ib_uverbs_file to ioctl methods (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Make write() handlers return 0 on success (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Replace ib_uverbs_file with uverbs_attr_bundle for write (Jonathan Toppins) [1685309]
- [include] RDMA/uverbs: Add missing driver_data (Jonathan Toppins) [1685309]
- [infiniband] RDMA/core: Sync unregistration with netlink commands (Jonathan Toppins) [1685309]
- [infiniband] RDMA/cma: Move cma module specific functions to cma_priv.h (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Check for NULL driver methods for every write call (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Make all the method functions in uverbs_cmd static (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Convert the write interface to use uverbs_api (Jonathan Toppins) [1685309]
- [infiniband] RDMA/verbs: Store the write/write_ex uapi entry points in the uverbs_api (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Require all objects to have a driver destroy function (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Add helpers to mark uapi functions as unsupported (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Factor out the add/get pattern into a helper (Jonathan Toppins) [1685309]
- [infiniband] RDMA/uverbs: Use a linear list to describe the compiled-in uapi (Jonathan Toppins) [1685309]
- [infiniband] IB/core: Make function ib_fmr_pool_unmap return void (Jonathan Toppins) [1685309]
- [include] RDMA/core: Remove unused header files mm.h, socket.h, scatterlist.h (Jonathan Toppins) [1685309]
- [include] IB/uverbs: fix a typo (Jonathan Toppins) [1685309]
- [fs] coredump: fix race condition between mmget_not_zero()/get_task_mm() and core dumping (Andrea Arcangeli) [1696081] {CVE-2019-3892}
- [scsi] scsi: csiostor: fix missing data copy in csio_scsi_err_handler() (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: drop serial_number usage (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: fix calls to dma_set_mask_and_coherent() (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: Remove set but not used variable 'pln' (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: no need to check return value of debugfs_create functions (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: fix NULL pointer dereference in csio_vport_set_state() (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: fix incorrect dma device in case of vport (Arjun Vynipadath) [1664680]
- [scsi] scsi: csiostor: switch to generic DMA API (Arjun Vynipadath) [1664680]
- [netdrv] thunderx: eliminate extra calls to put_page() for pages held for recycling (Dean Nelson) [1644011]
- [netdrv] thunderx: enable page recycling for non-XDP case (Dean Nelson) [1644011]
- [cpufreq] cpufreq: intel_pstate: Also use CPPC nominal_perf for base_frequency (Prarit Bhargava) [1696131]
- [acpi] ACPI / CPPC: Fix guaranteed performance handling (Prarit Bhargava) [1696131]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (Corinna Vinschen) [1659169]
- [netdrv] igbvf: Replace spin_is_locked() with lockdep (Corinna Vinschen) [1659169]
- [netdrv] intel-ethernet: use correct module license (Corinna Vinschen) [1659169]
- [netdrv] igbvf: netdev: Mark expected switch fall-through (Corinna Vinschen) [1659169]
- [x86] x86/MCE: Initialize mce.bank in the case of a fatal error in mce_no_way_out() (David Arcari) [1698959]
- [x86] x86/mce: Restore MCE injector's module name (David Arcari) [1698959]
- [x86] x86/mce: Streamline MCE subsystem's naming (David Arcari) [1698959]
- [x86] x86: Fix various typos in comments (David Arcari) [1698959]
- [x86] x86/MCE/AMD: Fix the thresholding machinery initialization order (David Arcari) [1698959]
- [x86] x86/mce: Fix -Wmissing-prototypes warnings (David Arcari) [1698959]
- [x86] acpi/nfit, x86/mce: Validate a MCE's address before using it (David Arcari) [1698959]
- [x86] acpi/nfit, x86/mce: Handle only uncorrectable machine checks (David Arcari) [1698959]
- [x86] x86: Clean up 'sizeof x' => 'sizeof(x)' (David Arcari) [1698959]
- [x86] x86/mcelog: Remove one mce_helper definition (David Arcari) [1698959]
- [x86] x86/mce-inject: Reset injection struct after injection (David Arcari) [1698959]
- [mm] x86/mce: Fix set_mce_nospec() to avoid #GP fault (David Arcari) [1698959]
- [x86] x86/memory_failure: Introduce {set, clear}_mce_nospec() (David Arcari) [1698959]
- [x86] x86/mce: Cleanup __mc_scan_banks() (David Arcari) [1698959]
- [x86] x86/mce: Carve out bank scanning code (David Arcari) [1698959]
- [x86] x86/mce: Carve out the crashing_cpu check (David Arcari) [1698959]
- [x86] x86/mce: Always use 64-bit timestamps (David Arcari) [1698959]
- [x86] x86/mce: Remove !banks check (David Arcari) [1698959]
- [md] dm cache metadata: Fix loading discard bitset (Mike Snitzer) [1701618]
- [block] null_blk: prevent crash from bad home_node value (Ming Lei) [1696951]
- [powerpc] powerpc/security: Fix spectre_v2 reporting (Gustavo Duarte) [1694456]
- [powerpc] powerpc/powernv: Query firmware for count cache flush settings (Gustavo Duarte) [1694456]
- [powerpc] powerpc/pseries: Query hypervisor for count cache flush settings (Gustavo Duarte) [1694456]
- [powerpc] powerpc/64s: Add support for software count cache flush (Gustavo Duarte) [1694456]
- [powerpc] powerpc/64s: Add new security feature flags for count cache flush (Gustavo Duarte) [1694456]
- [powerpc] powerpc/asm: Add a patch_site macro & helpers for patching instructions (Gustavo Duarte) [1694456]
- [powerpc] powerpc/64: Call setup_barrier_nospec() from setup_arch() (Gustavo Duarte) [1694456]
- [powerpc] powerpc/64: Add CONFIG_PPC_BARRIER_NOSPEC (Gustavo Duarte) [1694456]
- [powerpc] powerpc64s: Show ori31 availability in spectre_v1 sysfs file not v2 (Gustavo Duarte) [1694456]

* Mon Apr 29 2019 Clark Williams <williams@redhat.com> [4.18.0-80.23.rt16.20.el8]
- [rt] kernel-rt-4.18.0-80.23.rt16.19.el8 (Clark Williams) [1678887]
- [kernel] sched/fair: Limit sched_cfs_period_timer() loop to avoid hard lockup (Joel Savitz) [1695651]
- [crypto] crypto: ux500 - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: talitos - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: sun4i-ss - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: stm32 - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: rockchip - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: qce - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: picoxcell - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: omap - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: n2 - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: marvell - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: ixp4xx - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: hifn_795x - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: ccree - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: ccp - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: cavium - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: caam - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: bcm - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: atmel - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: sparc - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [s390] crypto: s390 - Forbid 2-key 3DES in FIPS mode (Herbert Xu) [1687908]
- [crypto] crypto: des_generic - Forbid 2-key in 3DES and add helpers (Herbert Xu) [1687908]
- [crypto] crypto: mxc-scc - Remove broken driver (Herbert Xu) [1687908]
- [kernel] ntp: Audit NTP parameters adjustment (Ondrej Mosnacek) [1680034]
- [kernel] timekeeping: Audit clock adjustments (Ondrej Mosnacek) [1680034]
- [kernel] ntp: Remove duplicated include (Ondrej Mosnacek) [1680034]
- [kernel] timekeeping/ntp: Constify some function arguments (Ondrej Mosnacek) [1680034]
- [kernel] ntp: Use kstrtos64 for s64 variable (Ondrej Mosnacek) [1680034]
- [kernel] ntp: Remove redundant arguments (Ondrej Mosnacek) [1680034]
- [kernel] timekeeping: Use ktime_get_real_ts64() instead of getnstimeofday64() (Ondrej Mosnacek) [1680034]
- [netdrv] hinic: Add pci device ids (Xiaojun Tan) [1662040]
- [netdrv] net-next/hinic:add shutdown callback (Xiaojun Tan) [1662040]
- [netdrv] hinic: optmize rx refill buffer mechanism (Xiaojun Tan) [1662040]
- [netdrv] net: hinic: remove redundant pointer pfhwdev (Xiaojun Tan) [1662040]
- [netdrv] net: hns: fix unsigned comparison to less than zero (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix sparse: some warnings in HNS drivers (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix WARNING when remove HNS driver with SMMU enabled (Xiaojun Tan) [1661885]
- [netdrv] net: hns: fix ICMP6 neighbor solicitation messages discard problem (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix probabilistic memory overwrite when HNS driver initialized (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Use NAPI_POLL_WEIGHT for hns driver (Xiaojun Tan) [1661885]
- [netdrv] net: hns: fix KASAN: use-after-free in hns_nic_net_xmit_hw() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: use struct_size() in devm_kzalloc() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fixes the missing put_device in positive leg for roce reset (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix object reference leaks in hns_dsaf_roce_reset() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Restart autoneg need return failed when autoneg off (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix for missing of_node_put() after of_parse_phandle() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Use struct_size() in devm_kzalloc() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Fix use after free identified by SLUB debug (Xiaojun Tan) [1661885]
- [netdrv] net: hns: make function hns_gmac_wait_fifo_clean() static (Xiaojun Tan) [1661885]
- [netdrv] net: hns: use eth_get_headlen interface instead of hns_nic_get_headlen (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Mark expected switch fall-through (Xiaojun Tan) [1661885]
- [netdrv] net: hns: remove redundant variables 'max_frm' and 'tmp_mac_key' (Xiaojun Tan) [1661885]
- [netdrv] net: hisilicon: hns: Replace mdelay() with msleep() (Xiaojun Tan) [1661885]
- [netdrv] net: hns: make hns_dsaf_roce_reset non static (Xiaojun Tan) [1661885]
- [netdrv] net: hns: Make many functions static (Xiaojun Tan) [1661885]
- [bluetooth] Bluetooth: btusb: Add support for Intel bluetooth device 8087:0029 (Gopal Tiwari) [1678084]
- [bluetooth] Bluetooth: btusb: Use bt_dev_err for Intel firmware loading errors (Gopal Tiwari) [1678084]

* Mon Apr 29 2019 Clark Williams <williams@redhat.com> [4.18.0-80.22.rt16.19.el8]
- [rt] kernel-rt-4.18.0-80.22.rt16.18.el8 (Clark Williams) [1678887]
- [vfio] vfio/pci: Restore device state on PM transition (Alex Williamson) [1700254]
- [vfio] vfio/pci: Parallelize device open and release (Alex Williamson) [1700254]
- [pci] Revert "PCI/ASPM: Do not initialize link state when aspm_disabled is set" (Myron Stowe) [1694143]
- [pci] PCI: Fix incorrect value returned from pcie_get_speed_cap() (Myron Stowe) [1694143]
- [x86] x86/PCI: Apply VMD's AERSID fixup generically (Myron Stowe) [1694143]
- [pci] PCI/IOV: Remove unnecessary include of <linux/pci-ats.h> (Myron Stowe) [1694143]
- [pci] PCI: pcie: Remove redundant 'default n' from Kconfig (Myron Stowe) [1694143]
- [documentation] NTB: switchtec_ntb: Update switchtec documentation with prerequisites for NTB (Myron Stowe) [1694143]
- [pci] PCI: Fix Switchtec DMA aliasing quirk dmesg noise (Myron Stowe) [1694143]
- [pci] PCI: Add macro for Switchtec quirk declarations (Myron Stowe) [1694143]
- [pci] PCI: Add Device IDs for Intel GPU "spurious interrupt" quirk (Myron Stowe) [1694143]
- [pci] PCI / ACPI: Mark expected switch fall-through (Myron Stowe) [1694143]
- [pci] PCI: Remove set but unused variable (Myron Stowe) [1694143]
- [pci] PCI: Fix pci.c kernel-doc parameter warning (Myron Stowe) [1694143]
- [pci] PCI: Allocate dma_alias_mask with bitmap_zalloc() (Myron Stowe) [1694143]
- [include] PCI: Remove unused NFP32xx IDs (Myron Stowe) [1694143]
- [maintainers] maintainers: Add Hyper-V IOMMU driver into Hyper-V CORE AND DRIVERS scope (Vitaly Kuznetsov) [1663292 1669989]
- [iommu] hyper-v: Add Hyper-V stub IOMMU driver (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hyper-v: Set x2apic destination mode to physical when x2apic is available (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hyper-v: Enable PIT shutdown quirk (Vitaly Kuznetsov) [1663292 1669989]
- [clocksource] clockevents/drivers/i8253: Add support for PIT shutdown quirk (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hyperv: Enable PV qspinlock for Hyper-V (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hyperv: Add GUEST_IDLE_MSR support (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hv: vmbus: Make TLFS #define names architecture neutral (Vitaly Kuznetsov) [1663292 1669989]
- [x86] hyperv: Add interrupt handler annotations (Vitaly Kuznetsov) [1663292 1669989]
- [pci] hv: Refactor hv_irq_unmask() to use cpumask_to_vpset() (Vitaly Kuznetsov) [1663292 1669989]
- [pci] hv: Replace hv_vp_set with hv_vpset (Vitaly Kuznetsov) [1663292 1669989]
- [pci] hv: Add __aligned(8) to struct retarget_msi_interrupt (Vitaly Kuznetsov) [1663292 1669989]
- [vfio] vfio-pci/nvlink2: Fix ancient gcc warnings (Sam Bobroff) [1524679]
- [vfio] vfio/pci: Cleanup license mess (Sam Bobroff) [1524679]
- [vfio] vfio/pci: set TRACE_INCLUDE_PATH to fix the build error (Sam Bobroff) [1524679]
- [vfio] vfio_pci: Add NVIDIA GV100GL [Tesla V100 SXM2] subdriver (Sam Bobroff) [1524679]
- [vfio] vfio_pci: Allow regions to add own capabilities (Sam Bobroff) [1524679]
- [vfio] vfio_pci: Allow mapping extra regions (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Fault user page into the hypervisor's pagetable (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Check mmio_atsd array bounds when populating (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Add release_ownership hook (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Add compound IOMMU groups (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Convert NPU IOMMU helpers to iommu_table_group_ops (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Move single TVE handling to NPU PE (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv: Reference iommu_table while it is linked to a group (Sam Bobroff) [1524679]
- [powerpc] powerpc/iommu_api: Move IOMMU groups setup to a single place (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/pseries: Rework device adding to IOMMU groups (Sam Bobroff) [1524679]
- [powerpc] powerpc/pseries: Remove IOMMU API support for non-LPAR systems (Sam Bobroff) [1524679]
- [powerpc] powerpc/pseries/npu: Enable platform support (Sam Bobroff) [1524679]
- [powerpc] powerpc/pseries/iommu: Use memory@ nodes in max RAM address calculation (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/npu: Move OPAL calls away from context manipulation (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv: Move npu struct from pnv_phb to pci_controller (Sam Bobroff) [1524679]
- [powerpc] powerpc/vfio/iommu/kvm: Do not pin device memory (Sam Bobroff) [1524679]
- [vfio] powerpc/mm/iommu/vfio_spapr_tce: Change mm_iommu_get to reference a region (Sam Bobroff) [1524679]
- [powerpc] powerpc/ioda/npu: Call skiboot's hot reset hook when disabling NPU2 (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/ioda: Allocate indirect TCE levels of cached userspace addresses on demand (Sam Bobroff) [1524679]
- [powerpc] powerpc/powernv/ioda1: Remove dead code for a single device PE (Sam Bobroff) [1524679]
- [rpmspec] redhat: add TC selftests to kernel-selftests-internal (Ivan Vecera) [1691376]
- [rpmspec] redhat: add net selftests to kernel-selftests-internal (Ivan Vecera) [1691376]
- [rpmspec] redhat: add pktgen samples to kernel-selftests-internal (Ivan Vecera) [1691376]
- [rpmspec] redhat: rename bpf_samples to kernel-selftests-internal (Ivan Vecera) [1691376]
- [rpmspec] redhat: remove bpf_samples dependency on glibc-static and build it by default (Ivan Vecera) [1691376]
- [tools] selftests: bpf: modify urandom_read and link it non-statically (Ivan Vecera) [1691376]

* Fri Apr 26 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.21.rt16.18.el8]
- [rt] kernel-rt-4.18.0-80.21.rt16.17.el8 (Juri Lelli) [1678887]
- [netdrv] ibmvnic: Fix netdev feature clobbering during a reset (Steve Best) [1699018]
- [netdrv] ibmvnic: Enable GRO (Steve Best) [1699018]
- [x86] x86/perf/amd: Remove need to check "running" bit in NMI handler (David Arcari) [1640238]
- [x86] x86/perf/amd: Resolve NMI latency issues for active PMCs (David Arcari) [1640238]
- [x86] x86/perf/amd: Resolve race condition when disabling PMC (David Arcari) [1640238]
- [netdrv] qed: Fix qed_mcp_halt|resume() (Manish Chopra) [1697310]

* Wed Apr 24 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.20.rt16.17.el8]
- [rt] kernel-rt-4.18.0-80.20.rt16.16.el8 (Juri Lelli) [1678887]
- [x86] x86/kexec: Fix a kexec_file_load() failure (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: include linux/vmalloc.h (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: handle empty command-line (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: return successfully even if kaslr-seed doesn't exist (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: Refactor setup_dtb() to consolidate error checking (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: add kaslr support (Bhupesh Sharma) [1666078]
- [char] random: Make crng state queryable (Bhupesh Sharma) [1666078]
- [include] include: pe.h: remove message[] from mz header definition (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: invoke the kernel without purgatory (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: allow for loading Image-format kernel (Bhupesh Sharma) [1666078]
- [arm64] arm64: kexec_file: load initrd and device-tree (Bhupesh Sharma) [1666078]
- [arm64] arm64: enable KEXEC_FILE config (Bhupesh Sharma) [1666078]
- [arm64] arm64: cpufeature: add MMFR0 helper functions (Bhupesh Sharma) [1666078]
- [arm64] arm64: add image head flag definitions (Bhupesh Sharma) [1666078]
- [kernel] kexec_file: kexec_walk_memblock() only walks a dedicated region at kdump (Bhupesh Sharma) [1666078]
- [kernel] powerpc, kexec_file: factor out memblock-based arch_kexec_walk_mem() (Bhupesh Sharma) [1666078]
- [kernel] s390, kexec_file: drop arch_kexec_mem_walk() (Bhupesh Sharma) [1666078]
- [kernel] kexec_file: make kexec_image_post_load_cleanup_default() global (Bhupesh Sharma) [1666078]
- [include] asm-generic: add kexec_file_load system call to unistd.h (Bhupesh Sharma) [1666078]
- [include] asm-generic: unistd.h: Wire up sys_rseq (Bhupesh Sharma) [1666078]
- [fs] xfs: don't overflow xattr listent buffer (Bill O'Donnell) [1683531]
- [drm] drm/i915/gvt: Add in context mmio 0x20D8 to gen9 mmio list (Paul Lai) [1651589]
- [fs] copy_mount_string: Limit string length to PATH_MAX (Miklos Szeredi) [1655272]
- [include] redhat: Reuse other arch's cpuhp_state to protect kABI (Robert Richter) [1658476]
- [drivers] drivers/perf: Add Cavium ThunderX2 SoC UNCORE PMU driver (Robert Richter) [1658476]
- [documentation] Documentation: perf: Add documentation for ThunderX2 PMU uncore driver (Robert Richter) [1658476]

* Tue Apr 23 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.19.rt16.16.el8]
- [rt] kernel-rt-4.18.0-80.19.rt16.15.el8 (Juri Lelli) [1678887]
- [arm64] arm64: apply workaround on A64FX v1r0 (Mark Langsdorf) [1692306]
- [fs] kernfs: fix xattr name handling in LSM helpers (Ondrej Mosnacek) [1558179]
- [include] LSM: lsm_hooks.h - fix missing colon in docstring (Ondrej Mosnacek) [1558179]
- [security] selinux: Make selinux_kernfs_init_security static (Ondrej Mosnacek) [1558179]
- [fs] kernfs: initialize security of newly created nodes (Ondrej Mosnacek) [1558179]
- [security] selinux: implement the kernfs_init_security hook (Ondrej Mosnacek) [1558179]
- [include] LSM: add new hook for kernfs node initialization (Ondrej Mosnacek) [1558179]
- [fs] kernfs: use simple_xattrs for security attributes (Ondrej Mosnacek) [1558179]
- [security] selinux: try security xattr after genfs for kernfs filesystems (Ondrej Mosnacek) [1558179]
- [fs] kernfs: do not alloc iattrs in kernfs_xattr_get (Ondrej Mosnacek) [1558179]
- [fs] kernfs: clean up struct kernfs_iattrs (Ondrej Mosnacek) [1558179]
- [fs] kernfs: allow creating kernfs objects with arbitrary uid/gid (Ondrej Mosnacek) [1558179]
- [tools] tools/power turbostat: Add Icelake support (Steve Best) [1698546]
- [tools] tools/power turbostat: consolidate duplicate model numbers (Steve Best) [1698546]
- [mm] s390/mm: silence compiler warning when compiling without CONFIG_PGSTE (Thomas Huth) [1698848]
- [scripts] unifdef: use memcpy instead of strncpy (Thomas Huth) [1698848]
- [s390] s390: align struct lowcore to double page size (Thomas Huth) [1698848]
- [powerpc] KVM: PPC: Book3S HV: Perserve PSSCR FAKE_SUSPEND bit on guest exit (Suraj Jitindar Singh) [1689768]

* Fri Apr 19 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.18.rt16.15.el8]
- [rt] kernel-rt-4.18.0-80.18.rt16.14.el8 (Juri Lelli) [1678887]
- [virtio] virtio: Honour 'may_reduce_num' in vring_create_virtqueue (Cornelia Huck) [1697505]
- [s390] setup: set control program code via diag 318 (Thomas Huth) [1592336]
- [s390] kvm: s390: set host program identifier (Thomas Huth) [1592336]
- [edac] EDAC, skx: Fix randconfig builds in a better way (Aristeu Rozanski) [1501612 1649988 1571534]
- [edac] EDAC, skx: Fix randconfig builds (Aristeu Rozanski) [1501612 1649988 1571534]
- [edac] EDAC, skx_edac: Add address translation for non-volatile DIMMs (Aristeu Rozanski) [1501612 1649988 1571534]
- [acpi] ACPI/ADXL: Add address translation interface using an ACPI DSM (Aristeu Rozanski) [1501612 1649988 1571534]
- [x86] x86/mce: Add macros for the corrected error count bit field (Aristeu Rozanski) [1501612 1649988 1571534]
- [x86] x86/mce: Use BIT_ULL(x) for bit mask definitions (Aristeu Rozanski) [1501612 1649988 1571534]
- [crypto] crypto: ecc - regularize scalar for scalar multiplication (Neil Horman) [1687888]
- [crypto] crypto: ecc - check for invalid values in the key verification test (Neil Horman) [1687888]
- [crypto] crypto: dh - make crypto_dh_encode_key() make robust (Neil Horman) [1687888]
- [crypto] crypto: dh - fix calculating encoded key size (Neil Horman) [1687888]
- [crypto] crypto: ecdh - fix typo of P-192 b value (Neil Horman) [1687888]
- [crypto] crypto: ecdh - add public key verification test (Neil Horman) [1687888]
- [crypto] crypto: dh - fix memory leak (Neil Horman) [1687888]
- [crypto] crypto: dh - add public key verification test (Neil Horman) [1687888]
- [scsi] scsi: hisi_sas: Add softreset in hisi_sas_I_T_nexus_reset() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Change SERDES_CFG init value to increase reliability of HiLink (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Send HARD RESET to clear the previous affiliation of STP target port (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Set PHY linkrate when disconnected (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: print PHY RX errors count for later revision of v3 hw (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix a timeout race of driver internal and SMP IO (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Change return variable type in phy_up_v3_hw() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: fix calls to dma_set_mask_and_coherent() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Do some more tidy-up (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Use pci_irq_get_affinity() for v3 hw as experimental (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Issue internal abort on all relevant queues (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: change queue depth from 512 to 4096 (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add manual trigger for debugfs dump (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add support for DIX feature for v3 hw (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add missing seq_printf() call in hisi_sas_show_row_32() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix to only call scsi_get_prot_op() for non-NULL scsi_cmnd (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Some misc tidy-up (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Correct memory allocation size for DQ debugfs (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix losing directly attached disk when hot-plug (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Reject setting programmed minimum linkrate > 1.5G (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Remove unused parameter of function hisi_sas_alloc() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: remove the check of sas_dev status in hisi_sas_I_T_nexus_reset() (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: shutdown axi bus to avoid exception CQ returned (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: send primitive NOTIFY to SSP situation only (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add debugfs ITCT file and add file operations (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix type casting and missing static qualifier in debugfs code (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: No need to check return value of debugfs_create functions (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Set protection parameters prior to adding SCSI host (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add debugfs IOST file and add file operations (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add debugfs DQ file and add file operations (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add debugfs CQ file and add file operations (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add debugfs for port registers (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Debugfs global register create file and add file operations (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Take debugfs snapshot for all regs (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Alloc debugfs snapshot buffer memory for all registers (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Create root and device debugfs directories (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add support for DIF feature for v2 hw (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Make sg_tablesize consistent value (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Relocate some code to reduce complexity (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix warnings detected by sparse (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: change the time of SAS SSP connection (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Relocate some codes to avoid an unused check (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add support for interrupt coalescing for v3 hw (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Add support for interrupt converge for v3 hw (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Create separate host attributes per HBA (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: use dma_set_mask_and_coherent (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Remove set but not used variable 'dq_list' (Xiaojun Tan) [1662038]
- [scsi] scsi: hisi_sas: Fix NULL pointer dereference (Xiaojun Tan) [1662038]
- [nvme] nvme-pci: add missing unlock for reset error (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: fix rapid add remove sequence (Gopal Tiwari) [1665354]
- [nvme] nvme: remove the .stop_ctrl callout (Gopal Tiwari) [1665354]
- [nvme] nvme: add support for the Write Zeroes command (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: fix null dereference under heavy load (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: fix timeout handler (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: fix timeout handler (Gopal Tiwari) [1665354]
- [nvme] nvmet-tcp: fix uninitialized variable access (Gopal Tiwari) [1665354]
- [nvme] nvme: don't initlialize ctrl->cntlid twice (Gopal Tiwari) [1665354]
- [nvme] nvme: introduce NVME_QUIRK_IGNORE_DEV_SUBNQN (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: remove dead code (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: don't ask if controller is fabrics (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: unset write/poll queues for discovery controllers (Gopal Tiwari) [1665354]
- [nvme] nvme: pad fake subsys NQN vid and ssvid with zeros (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: fix out of bounds access in nvme_cqe_pending (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: use the same attributes when freeing host_mem_desc_bufs. (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: fix the wrong setting of nr_maps (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: rerun irq setup on IO queue init errors (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: trace SQ status on completions (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: allow user to pass in nr_poll_queues (Gopal Tiwari) [1665354]
- [nvme] nvme-core: optionally poll sync commands (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: fix spelling mistake "attepmpt" -> "attempt" (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: fix endianess annotations (Gopal Tiwari) [1665354]
- [nvme] nvmet-tcp: fix endianess annotations (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: refactor nvme_poll_irqdisable to make sparse happy (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: only set nr_maps to 2 if poll queues are supported (Gopal Tiwari) [1665354]
- [nvme] nvmet: use a macro for default error location (Gopal Tiwari) [1665354]
- [nvme] nvmet: fix comparison of a u16 with -1 (Gopal Tiwari) [1665354]
- [nvme] nvme: fix kernel paging oops (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: support separate queue maps for read and write (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: support separate queue maps for read and write (Gopal Tiwari) [1665354]
- [include] block: make request_to_qc_t public (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: allow user to set nr_write_queues for separate queue maps (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: add missing nvmf_ctrl_options documentation (Gopal Tiwari) [1665354]
- [nvme] blk-mq-rdma: pass in queue map to blk_mq_rdma_map_queues (Gopal Tiwari) [1665354]
- [nvme] nvmet: update smart log with num err log entries (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support for file backend (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log page cmd handler (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support for bdev backend (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support for admin-cmd (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support for fabrics-cmd (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support for rdma backend (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error log support in the core (Gopal Tiwari) [1665354]
- [nvme] nvmet: add interface to update error-log page (Gopal Tiwari) [1665354]
- [include] nvme: add error log page slot definition (Gopal Tiwari) [1665354]
- [nvme] nvmet: add error-log definitions (Gopal Tiwari) [1665354]
- [nvme] nvme: remove nvme_common command cdw10 array (Gopal Tiwari) [1665354]
- [nvme] nvme: provide fallback for discard alloc failure (Gopal Tiwari) [1665354]
- [nvme] nvmet: remove unused variable (Gopal Tiwari) [1665354]
- [nvme] nvme: add __exit annotation (Gopal Tiwari) [1665354]
- [nvme] nvmet: allow configfs tcp trtype configuration (Gopal Tiwari) [1665354]
- [nvme] nvme-tcp: add NVMe over TCP host driver (Gopal Tiwari) [1665354]
- [nvme] nvmet-tcp: add NVMe over TCP target driver (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: allow user passing data digest (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: allow user passing header digest (Gopal Tiwari) [1665354]
- [nvme] nvmet: Add install_queue callout (Gopal Tiwari) [1665354]
- [nvme] nvmet: use unlikely for req status check (Gopal Tiwari) [1665354]
- [include] nvme-tcp: Add protocol header (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: Add unlikely for response allocated check (Gopal Tiwari) [1665354]
- [nvme] nvmet: fix the structure member indentation (Gopal Tiwari) [1665354]
- [nvme] nvme: implement Enhanced Command Retry (Gopal Tiwari) [1665354]
- [nvme] nvme: remove unused function nvme_ctrl_ready (Gopal Tiwari) [1665354]
- [nvme] nvmet: support fabrics sq flow control (Gopal Tiwari) [1665354]
- [nvme] nvmet: enable Discovery Controller AENs (Gopal Tiwari) [1665354]
- [nvme] nvmet: expose support for fabrics SQ flow control disable in treq (Gopal Tiwari) [1665354]
- [nvme] nvme: disable fabrics SQ flow control when asked by the user (Gopal Tiwari) [1665354]
- [nvme] nvmet-fc: remove the IN_ISR deferred scheduling options (Gopal Tiwari) [1665354]
- [nvme] nvme: Remove unused forward declaration (Gopal Tiwari) [1665354]
- [nvme] nvmet: allow host connect even if no allowed subsystems are exported (Gopal Tiwari) [1665354]
- [nvme] nvmet: don't override treq upon modification. (Gopal Tiwari) [1665354]
- [nvme] nvmet: mark nvmet_genctr static (Gopal Tiwari) [1665354]
- [nvme] nvmet: add defines for discovery change async events (Gopal Tiwari) [1665354]
- [nvme] nvmet: support for traffic based keep-alive (Gopal Tiwari) [1665354]
- [nvme] nvmet: make kato and AEN processing for use by other controllers (Gopal Tiwari) [1665354]
- [nvme] nvmet: change aen mask functions to use bit numbers (Gopal Tiwari) [1665354]
- [nvme] nvmet: provide aen bit functions for multiple controller types (Gopal Tiwari) [1665354]
- [nvme] nvmet: add support to Discovery controllers for commands (Gopal Tiwari) [1665354]
- [nvme] nvmet: use IOCB_NOWAIT for file-ns buffered I/O (Gopal Tiwari) [1665354]
- [nvme] nvmet: allow Keep Alive for Discovery controller (Gopal Tiwari) [1665354]
- [nvme] nvme: support traffic based keep-alive (Gopal Tiwari) [1665354]
- [nvme] nvme: cache controller attributes (Gopal Tiwari) [1665354]
- [nvme] nvme: introduce ctrl attributes enumeration (Gopal Tiwari) [1665354]
- [nvme] nvme: consolidate memset calls in the nvme_setup_cmd path (Gopal Tiwari) [1665354]
- [nvme] nvme: warn when finding multi-port subsystems without multipathing enabled (Gopal Tiwari) [1665354]
- [nvme] Revert "nvmet-rdma: use a private workqueue for delete" (Gopal Tiwari) [1665354]
- [nvme] nvme-fabrics: move controller options matching to fabrics (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: always have a valid trsvcid (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: remove duplicate check (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: fix hot removal during error handling (Gopal Tiwari) [1665354]
- [nvme] nvmet-fcloop: suppress a compiler warning (Gopal Tiwari) [1665354]
- [nvme] nvme-core: make implicit seed truncation explicit (Gopal Tiwari) [1665354]
- [nvme] nvmet-fc: fix kernel-doc headers (Gopal Tiwari) [1665354]
- [nvme] nvmet: avoid integer overflow in the discard code (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: declare local symbols static (Gopal Tiwari) [1665354]
- [nvme] nvmet: use strlcpy() instead of strcpy() (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: fix nvme_suspend_queue() kernel-doc header (Gopal Tiwari) [1665354]
- [nvme] nvme-core: declare local symbols static (Gopal Tiwari) [1665354]
- [nvme] nvme-core: rework a NQN copying operation (Gopal Tiwari) [1665354]
- [nvme] nvmet: use strcmp() instead of strncmp() for subsystem lookup (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: check for timeout in nvme_rdma_wait_for_cm() (Gopal Tiwari) [1665354]
- [nvme] nvmet: remove unreachable code (Gopal Tiwari) [1665354]
- [nvme] nvme: update node paths after adding new path (Gopal Tiwari) [1665354]
- [nvme] nvme: remove ns sibling before clearing path (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: use a private workqueue for delete (Gopal Tiwari) [1665354]
- [nvme] nvmet: don't split large I/Os unconditionally (Gopal Tiwari) [1665354]
- [nvme] nvme-core: add async event trace helper (Gopal Tiwari) [1665354]
- [nvme] nvmet_fc: support target port removal with nvmet layer (Gopal Tiwari) [1665354]
- [nvme] nvmet: remove redundant module prefix (Gopal Tiwari) [1665354]
- [nvme] nvme: fix typo in nvme_identify_ns_descs (Gopal Tiwari) [1665354]
- [nvme] nvme: register ns_id attributes as default sysfs groups (Gopal Tiwari) [1665354]
- [block] block: genhd: add 'groups' argument to device_add_disk (Gopal Tiwari) [1665354]
- [nvme] nvme: count all ANA groups for ANA Log page (Gopal Tiwari) [1665354]
- [nvme] nvmet-rdma: fix possible bogus dereference under heavy load (Gopal Tiwari) [1665354]
- [nvme] nvmet: free workqueue object if module init fails (Gopal Tiwari) [1665354]
- [nvme] nvme-fcloop: Fix dropped LS's to removed target port (Gopal Tiwari) [1665354]
- [nvme] nvme-pci: add a memory barrier to nvme_dbbuf_update_and_check_event (Gopal Tiwari) [1665354]
- [nvme] nvmet: add ns write protect support (Gopal Tiwari) [1665354]
- [nvme] nvme: set gendisk read only based on nsattr (Gopal Tiwari) [1665354]
- [include] nvme.h: add support for ns write protect definitions (Gopal Tiwari) [1665354]
- [nvme] nvmet: use Retain Async Event bit to clear AEN (Gopal Tiwari) [1665354]
- [nvme] nvmet: support configuring ANA groups (Gopal Tiwari) [1665354]
- [nvme] nvmet: add minimal ANA support (Gopal Tiwari) [1665354]
- [nvme] nvmet: track and limit the number of namespaces per subsystem (Gopal Tiwari) [1665354]
- [nvme] nvmet: keep a port pointer in nvmet_ctrl (Gopal Tiwari) [1665354]
- [nvme] nvmet: check fileio lba range access boundaries (Gopal Tiwari) [1665354]
- [nvme] nvmet: don't use uuid_le type (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: centralize admin/io queue teardown sequence (Gopal Tiwari) [1665354]
- [nvme] nvmet: fix file discard return status (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: centralize controller setup sequence (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: unquiesce queues when deleting the controller (Gopal Tiwari) [1665354]
- [nvme] nvme: add disk name to trace events (Gopal Tiwari) [1665354]
- [nvme] nvme-rdma: mark expected switch fall-through (Gopal Tiwari) [1665354]
- [nvme] nvme: add controller name to trace events (Gopal Tiwari) [1665354]
- [nvme] nvme: use hw qid in trace events (Gopal Tiwari) [1665354]
- [nvme] nvmet: add buffered I/O support for file backed ns (Gopal Tiwari) [1665354]
- [nvme] nvme: move init of keep_alive work item to controller initialization (Gopal Tiwari) [1665354]
- [nvme] nvmet: add commands supported and effects log page (Gopal Tiwari) [1665354]
- [nvme] lightnvm: limit get chunk meta request size (Gopal Tiwari) [1665354]
- [nvme] lightnvm: Remove redundant rq->__data_len initialization (Gopal Tiwari) [1665354]
- [block] nbd: restrict use to AF_UNIX sockets (Mike Christie) [1673307]
- [block] nbd: don't allow invalid blocksize settings (Mike Christie) [1673307]
- [documentation] doc, block, bfq: add information on bfq execution time (Ming Lei) [1686682]
- [block] block, bfq: save & resume weight on a queue merge/split (Ming Lei) [1686682]
- [block] block, bfq: print SHARED instead of pid for shared queues in logs (Ming Lei) [1686682]
- [block] block, bfq: always protect newly-created queues from existing active queues (Ming Lei) [1686682]
- [block] block, bfq: do not tag totally seeky queues as soft rt (Ming Lei) [1686682]
- [block] block, bfq: do not merge queues on flash storage with queueing (Ming Lei) [1686682]
- [block] block, bfq: tune service injection basing on request service times (Ming Lei) [1686682]
- [block] block, bfq: do not idle for lowest-weight queues (Ming Lei) [1686682]
- [block] block, bfq: increase idling for weight-raised queues (Ming Lei) [1686682]
- [block] block/bfq: fix ifdef for CONFIG_BFQ_GROUP_IOSCHED=y (Ming Lei) [1686682]
- [block] block, bfq: fix in-service-queue check for queue merging (Ming Lei) [1686682]
- [block] block, bfq: do not overcharge writes in asymmetric scenarios (Ming Lei) [1686682]
- [block] block, bfq: port commit "cfq-iosched: improve hw_tag detection" (Ming Lei) [1686682]
- [block] block, bfq: reduce threshold for detecting command queueing (Ming Lei) [1686682]
- [block] block, bfq: fix queue removal from weights tree (Ming Lei) [1686682]
- [block] block, bfq: fix sequential rq detection in rate estimation (Ming Lei) [1686682]
- [block] block, bfq: unconditionally plug I/O in asymmetric scenarios (Ming Lei) [1686682]
- [block] block, bfq: do not plug I/O of in-service queue when harmful (Ming Lei) [1686682]
- [block] block, bfq: split function bfq_better_to_idle (Ming Lei) [1686682]
- [block] block, bfq: consider also ioprio classes in symmetry detection (Ming Lei) [1686682]
- [block] block, bfq: remove case of redirected bic from insert_request (Ming Lei) [1686682]
- [block] block, bfq: make sure queue budgets are not below service received (Ming Lei) [1686682]
- [block] block, bfq: avoid selecting a queue w/o budget (Ming Lei) [1686682]
- [block] block, bfq: do not consider interactive queues in srt filtering (Ming Lei) [1686682]
- [net] net: switchdev: Add extack to switchdev_handle_port_obj_add() callback (Ivan Vecera) [1690125]
- [net] switchdev: Add extack to struct switchdev_notifier_info (Ivan Vecera) [1690125]
- [net] vxlan: Add a function to init switchdev_notifier_vxlan_fdb_info (Ivan Vecera) [1690125]
- [net] switchdev: Add extack argument to switchdev_port_obj_add() (Ivan Vecera) [1690125]
- [net] bridge: Propagate extack to switchdev (Ivan Vecera) [1690125]
- [net] ndo_bridge_setlink: Add extack (Ivan Vecera) [1690125]
- [net] rocker, dsa, ethsw: Don't filter VLAN events on bridge itself (Ivan Vecera) [1690125]
- [net] switchdev: Replace port obj add/del SDO with a notification (Ivan Vecera) [1690125]
- [net] ocelot: Handle SWITCHDEV_PORT_OBJ_ADD/_DEL (Ivan Vecera) [1690125]
- [net] mlxsw: spectrum_switchdev: Handle SWITCHDEV_PORT_OBJ_ADD/_DEL (Ivan Vecera) [1690125]
- [net] switchdev: Add helpers to aid traversal through lower devices (Ivan Vecera) [1690125]
- [net] staging: fsl-dpaa2: ethsw: Handle SWITCHDEV_PORT_OBJ_ADD/_DEL (Ivan Vecera) [1690125]
- [net] staging: fsl-dpaa2: ethsw: Introduce ethsw_port_dev_check() (Ivan Vecera) [1690125]
- [net] dsa: slave: Handle SWITCHDEV_PORT_OBJ_ADD/_DEL (Ivan Vecera) [1690125]
- [net] rocker: Handle SWITCHDEV_PORT_OBJ_ADD/_DEL (Ivan Vecera) [1690125]
- [net] switchdev: Add SWITCHDEV_PORT_OBJ_ADD, SWITCHDEV_PORT_OBJ_DEL (Ivan Vecera) [1690125]
- [net] switchdev: Add a blocking notifier chain (Ivan Vecera) [1690125]
- [net] switchdev: SWITCHDEV_OBJ_PORT_{VLAN, MDB}(): Sanitize (Ivan Vecera) [1690125]
- [net] selftests: forwarding: Fix test for different devices (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add learning test (Ivan Vecera) [1693316]
- [net] bridge: Allow querying bridge port flags (Ivan Vecera) [1693316]
- [netdrv] vxlan: Allow changing ageing time (Ivan Vecera) [1693316]
- [netdrv] vxlan: Add hardware FDB learning (Ivan Vecera) [1693316]
- [netdrv] vxlan: Don't override user-added entries with ext-learned ones (Ivan Vecera) [1693316]
- [netdrv] vxlan: Mark user-added FDB entries (Ivan Vecera) [1693316]
- [netdrv] vxlan: vxlan_fdb_notify(): Make switchdev notification configurable (Ivan Vecera) [1693316]
- [netdrv] vxlan: __vxlan_fdb_delete(): Drop unused argument vid (Ivan Vecera) [1693316]
- [netdrv] vxlan: support NTF_USE refresh of fdb entries (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d_port_8472: New test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add an ECN decap test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add an ECN encap test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add a TOS test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add a TTL test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Reconfigure & rerun tests (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add unicast test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add flood test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: vxlan_bridge_1d: Add ping test (Ivan Vecera) [1693316]
- [net] selftests: forwarding: Add a skeleton of vxlan_bridge_1d (Ivan Vecera) [1693316]
- [net] selftests: forwarding: lib: Add link_stats_rx_errors_get() (Ivan Vecera) [1693316]
- [net] selftests: forwarding: ping{6, }_do(): Allow passing ping arguments (Ivan Vecera) [1693316]
- [net] selftests: forwarding: ping{6, }_test(): Add description argument (Ivan Vecera) [1693316]
- [net] selftests: forwarding: lib: Add in_ns() (Ivan Vecera) [1693316]
- [net] selftests: forwarding: lib: Support NUM_NETIFS of 0 (Ivan Vecera) [1693316]
- [net] skb_scrub_packet(): Scrub offload_fwd_mark (Ivan Vecera) [1693316]
- [net] selftests: forwarding: lib: extract ping and ping6 so they can be reused (Ivan Vecera) [1693316]
- [net] selftests: forwarding: README: Require diagrams (Ivan Vecera) [1693316]
- [net] selftests: forwarding: lib: Extract interface-init functions (Ivan Vecera) [1693316]
- [net] selftests: forwarding: tc_rule_stats_get: Parameterize direction (Ivan Vecera) [1693316]
- [net] selftests: forwarding: multipath_eval(): Improve style (Ivan Vecera) [1693316]
- [net] selftests: forwarding: Move multipath_eval() to lib.sh (Ivan Vecera) [1693316]
- [net] selftests: Add test_vxlan_fdb_changelink.sh (Ivan Vecera) [1690309]
- [netdrv] vxlan: changelink: Fix handling of default remotes (Ivan Vecera) [1690309]
- [netdrv] vxlan: Fix error path in __vxlan_dev_create() (Ivan Vecera) [1690309]
- [netdrv] vxlan: Unmark offloaded bit on replaced FDB entries (Ivan Vecera) [1690309]
- [net] bridge: switchdev: Allow clearing FDB entry offload indication (Ivan Vecera) [1690309]
- [netdrv] vxlan: Notify for each remote of a removed FDB entry (Ivan Vecera) [1690309]
- [netdrv] vxlan: Support marking RDSTs as offloaded (Ivan Vecera) [1690309]
- [netdrv] vxlan: Add vxlan_fdb_find_uc() for FDB querying (Ivan Vecera) [1690309]
- [netdrv] vxlan: Add switchdev notifications (Ivan Vecera) [1690309]
- [netdrv] net: Add netif_is_vxlan() (Ivan Vecera) [1690309]
- [net] inet: Refactor INET_ECN_decapsulate() (Ivan Vecera) [1690309]
- [netdrv] vxlan: Export address checking functions (Ivan Vecera) [1690309]
- [net] vxlan: Remove duplicated include from vxlan.h (Ivan Vecera) [1690309]
- [netdrv] geneve: correctly handle ipv6.disable module parameter (Jiri Benc) [1692390]
- [net] ipv6: sit: reset ip header pointer in ipip6_rcv (Lorenzo Bianconi) [1691626]
- [net] vxlan: Don't call gro_cells_destroy() before device is unregistered (Andrea Claudi) [1692499]
- [net] xsk: do not remove umem from netdevice on fall-back to copy-mode (Petr Oros) [1690568]
- [net] xsk: Check if a queue exists during umem setup (Petr Oros) [1690568]
- [net] xsk: simplify xdp_clear_umem_at_qid implementation (Petr Oros) [1690568]
- [net] ethtool: don't allow disabling queues with umem installed (Petr Oros) [1690568]
- [net] ethtool: rename local variable max -> curr (Petr Oros) [1690568]
- [net] xsk: fix bug when trying to use both copy and zero-copy on one queue id (Petr Oros) [1690568]
- [net] add umem reference in netdev{_rx}_queue (Petr Oros) [1690568]
- [net] xsk: remove unnecessary assignment (Petr Oros) [1690568]
- [net] xsk: fix return value of xdp_umem_assign_dev() (Petr Oros) [1690568]
- [net] xsk: don't allow umem replace at stack level (Petr Oros) [1690568]
- [net] xsk: refactor xdp_umem_assign_dev() (Petr Oros) [1690568]
- [net] update real_num_rx_queues even when !CONFIG_SYSFS (Petr Oros) [1690568]
- [net] core: add __netdev_sent_queue as variant of __netdev_tx_sent_queue (Petr Oros) [1690127]
- [net] net: do not abort bulk send on BQL status (Petr Oros) [1690129]
- [net] net: bql: add __netdev_tx_sent_queue() (Petr Oros) [1690129]
- [net] net: ip6_gre: fix possible NULL pointer dereference in ip6erspan_set_version (Lorenzo Bianconi) [1666315]
- [net] net: ip6_gre: initialize erspan_ver just for erspan tunnels (Lorenzo Bianconi) [1666315]
- [net] net: ip6_gre: always reports o_key to userspace (Lorenzo Bianconi) [1666315]
- [net] net: ip_gre: always reports o_key to userspace (Lorenzo Bianconi) [1666315]
- [net] tcp: handle inet_csk_reqsk_queue_add() failures (Guillaume Nault) [1690157]
- [net] ip_gre: use erspan key field for tunnel lookup (Lorenzo Bianconi) [1664570]
- [net] ip6_gre: simplify gre header parsing in ip6gre_err (Lorenzo Bianconi) [1664570]
- [net] ipv4: use a dedicated counter for icmp_v4 redirect packets (Lorenzo Bianconi) [1664209]
- [net] virtchnl: Fix off by one error (Ivan Vecera) [1690114]
- [net] virtchnl: white space and reorder (Ivan Vecera) [1690114]
- [net] i40e: Update status codes (Ivan Vecera) [1690114]
- [net] ethtool: Add WAKE_FILTER and RX_CLS_FLOW_WAKE (Ivan Vecera) [1690091]
- [net] geneve: allow to clear ttl inherit (Hangbin Liu) [1671251]
- [net] geneve: add ttl inherit support (Hangbin Liu) [1671251]
- [net] tipc: fix a double kfree_skb() (Jon Maloy) [1684290]
- [net] vxlan: Fix GRO cells race condition between receive and link delete (Andrea Claudi) [1687046]
- [net] sock: consistent handling of extreme SO_SNDBUF/SO_RCVBUF values (Guillaume Nault) [1686564]
- [net] tun: implement carrier change (Guillaume Nault) [1686566]
- [net] ip6_tunnel: respect ttl inherit for ip6tnl (Hangbin Liu) [1664944]
- [net] ip6_gre: update version related info when changing link (Hangbin Liu) [1664900]
- [net] ipv4/route: fail early when inet dev is missing (Paolo Abeni) [1685424]
- [net] bonding/802.3ad: fix link_failure_count tracking (Matteo Croce) [1657905]
- [net] bonding: avoid possible dead-lock (Matteo Croce) [1657905]
- [net] bonding: fix length of actor system (Matteo Croce) [1657905]
- [net] bonding: fix warning message (Matteo Croce) [1657905]
- [net] bonding: pass link-local packets to bonding master also. (Matteo Croce) [1657905]

* Wed Apr 17 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.17.rt16.14.el8]
- [rt] kernel-rt-4.18.0-80.17.rt16.13.el8 (Juri Lelli) [1678887]
- [infiniband] IB/usnic: fix spelling mistake "unvalid" -> "invalid" (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Get rid of ucontext->tgid (Jonathan Toppins) [1685307]
- [infiniband] RDMA/usnic: Do not use ucontext->tgid (Jonathan Toppins) [1685307]
- [infiniband] infiniband: remove redundant condition check before debugfs_remove (Jonathan Toppins) [1685307]
- [infiniband] RDMA/rdmavt: Fix rvt_create_ah function signature (Jonathan Toppins) [1685307]
- [infiniband] RDMA/drivers: Use core provided API for registering device attributes (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Remove unnecessary enum values (Jonathan Toppins) [1685307]
- [infiniband] IB/{hfi1, qib, rdmavt}: Move ruc_loopback to rdmavt (Jonathan Toppins) [1685307]
- [infiniband] IB/{hfi1, qib, rdmavt}: Move send completion logic to rdmavt (Jonathan Toppins) [1685307]
- [infiniband] IB/{hfi1, qib, rdmavt}: Move copy SGE logic into rdmavt (Jonathan Toppins) [1685307]
- [infiniband] RDMA/rxe: Remove unused addr_same() (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: avoid srq memory leak (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: replace kvfree with vfree (Jonathan Toppins) [1685307]
- [infiniband] RDMA/drivers: Use dev_name instead of ibdev->name (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/drivers: Use dev_err/dbg/etc instead of pr_* + ibdev->name (Jonathan Toppins) [1685307 1663226]
- [infiniband] IB/rxe: fixes for rdma read retry (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: avoid back-to-back retries (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Refactor lookup memory function (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Avoid NULL check when search is successful (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Change pool state enums to capital letters (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Replace spinlock with rwlock (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: Simplify rxe_find_route() to avoid GID query for netdev (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: remove redudant qpn check (Jonathan Toppins) [1685307]
- [infiniband] IB/rxe: vary the source udp port for receive scaling (Jonathan Toppins) [1685307]
- [infiniband] iser: set sector for ambiguous mr status errors (Jonathan Toppins) [1685307]
- [net] svcrdma: Remove try_module_get from backchannel (Jonathan Toppins) [1685307]
- [net] svcrdma: Remove ->release_rqst call in bc reply handler (Jonathan Toppins) [1685307]
- [net] xprtrdma: Clean up xprt_rdma_disconnect_inject (Jonathan Toppins) [1685307]
- [net] xprtrdma: Add documenting comments (Jonathan Toppins) [1685307]
- [net] xprtrdma: Report when there were zero posted Receives (Jonathan Toppins) [1685307]
- [net] xprtrdma: Move rb_flags initialization (Jonathan Toppins) [1685307]
- [net] xprtrdma: Don't disable BH's in backchannel server (Jonathan Toppins) [1685307]
- [net] xprtrdma: Remove memory address of "ep" from an error message (Jonathan Toppins) [1685307]
- [net] xprtrdma: Rename rpcrdma_qp_async_error_upcall (Jonathan Toppins) [1685307]
- [net] xprtrdma: Simplify RPC wake-ups on connect (Jonathan Toppins) [1685307]
- [net] xprtrdma: Re-organize the switch() in rpcrdma_conn_upcall (Jonathan Toppins) [1685307]
- [net] xprtrdma: Eliminate "connstate" variable from rpcrdma_conn_upcall() (Jonathan Toppins) [1685307]
- [net] xprtrdma: Conventional variable names in rpcrdma_conn_upcall (Jonathan Toppins) [1685307]
- [net] xprtrdma: Rename rpcrdma_conn_upcall (Jonathan Toppins) [1685307]
- [net] sunrpc: Report connect_time in seconds (Jonathan Toppins) [1685307]
- [net] sunrpc: Fix connect metrics (Jonathan Toppins) [1685307]
- [net] xprtrdma: Name MR trace events consistently (Jonathan Toppins) [1685307]
- [net] xprtrdma: Explicitly resetting MRs is no longer necessary (Jonathan Toppins) [1685307]
- [net] xprtrdma: Create more MRs at a time (Jonathan Toppins) [1685307]
- [net] xprtrdma: xprt_release_rqst_cong is called outside of transport_lock (Jonathan Toppins) [1685307]
- [infiniband] IB/ipoib: Log sysfs 'dev_id' accesses from userspace (Jonathan Toppins) [1685307]
- [infiniband] IB/ipoib: Use dev_port to expose network interface port numbers (Jonathan Toppins) [1685307]
- [infiniband] IB/ipoib: Ensure that MTU isn't less than minimum permitted (Jonathan Toppins) [1685307]
- [infiniband] IB/srp: Remove unnecessary unlikely() (Jonathan Toppins) [1685307]
- [infiniband] IB/core: Fix oops in netdev_next_upper_dev_rcu() (Jonathan Toppins) [1685307]
- [infiniband] IB/umem: Set correct address to the invalidation function (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Add GIDs while changing MAC addr only for registered ndev (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Fix comment for hw stats init for port == 0 (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Refactor ib_register_device() function (Jonathan Toppins) [1685307]
- [infiniband] IB/mlx4: Refer to the device kobject instead of ports_parent (Jonathan Toppins) [1685307]
- [include] RDMA/core: Allow existing drivers to set one sysfs group per device (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umad: Use kernel API to allocate umad indexes (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Use kernel API to allocate uverbs indexes (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Increase total number of RDMA ports across all devices (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Rename ports_parent to ports_kobj (Jonathan Toppins) [1685307]
- [infiniband] RDMA/nldev: Allow IB device rename through RDMA netlink (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/core: Implement IB device rename function (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/core: Annotate timeout as unsigned long (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Align multiple functions to kernel coding style (Jonathan Toppins) [1685307]
- [infiniband] RDMA/cma: Remove unused timeout_ms parameter from cma_resolve_iw_route() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/cm: Respect returned status of cm_init_av_by_path (Jonathan Toppins) [1685307]
- [infiniband] RDMA/restrack: Protect from reentry to resource return path (Jonathan Toppins) [1685307]
- [infiniband] RDMA/restrack: Release task struct which was hold by CM_ID object (Jonathan Toppins) [1685307]
- [infiniband] RDMA/restrack: Consolidate task name updates in one place (Jonathan Toppins) [1685307]
- [infiniband] RDMA/restrack: Un-inline set task implementation (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Check error status of rdma_find_ndev_for_src_ip_rcu (Jonathan Toppins) [1685307]
- [include] IB/mlx4: Avoid implicit enumerated type conversion (Jonathan Toppins) [1685307]
- [infiniband] RDMA/netlink: Simplify netlink listener existence check (Jonathan Toppins) [1685307]
- [infiniband] RDMA: Remove unused parameter from ib_modify_qp_is_ok() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Fix RCU annotation for radix slot deference (Jonathan Toppins) [1685307]
- [infiniband] RDMA: Fix building with CONFIG_MMU=n (Jonathan Toppins) [1685307]
- [infiniband] RDMA/cma: Introduce and use cma_ib_acquire_dev() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/cma: Introduce and use cma_acquire_dev_by_src_ip() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/cma: Allow accepting requests for multi port rdma device (Jonathan Toppins) [1685307]
- [infiniband] IB/rdmavt: Rename check_send_wqe as setup_wqe (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Acquire and release mmap_sem on page range (Jonathan Toppins) [1685307]
- [infiniband] IB/sa: simplify return code logic for ib_nl_send_msg() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/ulp: Use dev_name instead of ibdev->name (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/core: Use dev_name instead of ibdev->name (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/core: Use dev_err/dbg/etc instead of pr_* + ibdev->name (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA: Fully setup the device name in ib_register_device (Jonathan Toppins) [1685307 1663226]
- [infiniband] RDMA/umem: Fix potential addition overflow (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Minor optimizations (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Avoid synchronize_srcu in the ODP MR destruction path (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Handle a half-complete start/end sequence (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Get rid of per_mm->notifier_count (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Use umem->owning_mm inside ODP (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Move all the ODP related stuff out of ucontext and into per_mm (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Get rid of struct ib_umem.odp_data (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Make ib_umem_odp into a sub structure of ib_umem (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Use ib_umem_odp in all function signatures connected to ODP (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Do not use current->tgid to track the mm_struct (Jonathan Toppins) [1685307]
- [infiniband] RDMA/ucontext: Get rid of the old disassociate flow (Jonathan Toppins) [1685307]
- [infiniband] RDMA/ucontext: Add a core API for mmaping driver IO memory (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Fix error unwind in ib_uverbs_add_one (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Properly return the error code of rdma_set_src_addr_rcu (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Remove is_closed from ib_uverbs_file (Jonathan Toppins) [1685307]
- [include] IB/rxe: Revise the ib_wr_opcode enum (Jonathan Toppins) [1685307]
- [include] RDMA: Remove duplicated include from ib_addr.h (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Consider net ns of gid attribute for RoCE (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Introduce rdma_read_gid_attr_ndev_rcu() to check GID attribute (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Simplify roce_resolve_route_from_path() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Protect against changing dst->dev during destination resolve (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Refer to network type instead of device type (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Use common code flow for IPv4/6 for addr resolve (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Rename rdma_copy_addr to rdma_copy_src_l2_addr (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Introduce and use rdma_set_src_addr() between IPv4 and IPv6 (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Let protocol specific function typecast sockaddr structure (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Avoid unnecessary sa_family overwrite (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core Introduce and use rdma_find_ndev_for_src_ip_rcu (Jonathan Toppins) [1685307]
- [infiniband] IB/{hfi1, qib, rdmavt}: Schedule multi RC/UC packets instead of posting (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Move flow resources initialization (Jonathan Toppins) [1685307]
- [infiniband] IB/uverbs: Add IDRs array attribute type to ioctl() interface (Jonathan Toppins) [1685307]
- [include] RDMA/core: Document QP @event_handler function (Jonathan Toppins) [1685307]
- [include] RDMA/core: Document CM @event_handler function (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Assign device ifindex before publishing the device (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Follow correct unregister order between sysfs and cgroup (Jonathan Toppins) [1685307]
- [infiniband] RDMA/umem: Restore lockdep check while downgrading lock (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Define client_data_lock as rwlock instead of spinlock (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Use simpler spin lock irq API from blocking context (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Remove context entries from list while unregistering device (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Use simplified list_for_each (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: No need to protect kfree with spin lock and semaphore (Jonathan Toppins) [1685307]
- [infiniband] RDMA/{cma, core}: Avoid callback on rdma_addr_cancel() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Rate limit MAD error messages (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Fail early if unsupported QP is provided (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Use device.groups to initialize device attributes (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Use cdev_device_add() instead of cdev_add() (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Depend on device_add() to add device attributes (Jonathan Toppins) [1685307]
- [infiniband] RDMA/core: Replace open-coded variant of get_device (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Declare closing variable as boolean (Jonathan Toppins) [1685307]
- [infiniband] IB/core: Add an unbound WQ type to the new CQ API (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Add generic function to fill in flow action object (Jonathan Toppins) [1685307]
- [infiniband] RDMA/uverbs: Add UVERBS_ATTR_CONST_IN to the specs language (Jonathan Toppins) [1685307]
- [netdrv] ibmvnic: Fix completion structure initialization (Steve Best) [1697103]
- [rpmspec] redhat: limit headers_install_all to arches we care about (Denys Vlasenko) [1692404]
- [lib] ida: Add new API (Jonathan Toppins) [1697588]
- [edac] EDAC: Drop per-memory controller buses (Frank Ramsay) [1686477]
- [edac] EDAC: Don't add devices under /sys/bus/edac (Frank Ramsay) [1686477]
- [x86] x86/platform/UV: Use efi_runtime_lock to serialise BIOS calls (Frank Ramsay) [1677695]

* Wed Apr 17 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.16.rt16.13.el8]
- [rt] kernel-rt-4.18.0-80.16.rt16.12.el8 (Juri Lelli) [1678887]
- [pci] PCI: pciehp: Fix re-enabling the slot marked for safe removal (Myron Stowe) [1695922]
- [rpmspec] redhat: Enable gdb_index (Juri Lelli) [1696747]
- [fs] ovl: Do not lose security.capability xattr over metadata file copy-up (Vivek Goyal) [1694757]
- [fs] ovl: During copy up, first copy up data and then xattrs (Vivek Goyal) [1694757]

* Tue Apr 16 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.15.rt16.12.el8]
- [rt] kernel-rt-4.18.0-80.15.rt16.11.el8 (Juri Lelli) [1678887]
- [netdrv] mark the intel igc driver as tech preview (David Arcari) [1495358]
- [netdrv] igc: Remove unneeded hw_dbg prints (David Arcari) [1495358]
- [netdrv] igc: Fix the typo in igc_base.h header definition (David Arcari) [1495358]
- [netdrv] igc: Add support for the ntuple feature (David Arcari) [1495358]
- [netdrv] igc: Add support for statistics (David Arcari) [1495358]
- [netdrv] igc: Extend the ethtool supporting (David Arcari) [1495358]
- [netdrv] igc: Add multiple receive queues control supporting (David Arcari) [1495358]
- [netdrv] igc: Use struct_size() helper (David Arcari) [1495358]
- [netdrv] igc: Add ethtool support (David Arcari) [1495358]
- [netdrv] igc: Remove the 'igc_get_phy_id_base' method (David Arcari) [1495358]
- [netdrv] igc: Remove the 'igc_read_mac_addr_base' method (David Arcari) [1495358]
- [netdrv] igc: Remove unneeded code (David Arcari) [1495358]
- [netdrv] igc: Remove unused code (David Arcari) [1495358]
- [netdrv] igc: Fix code redundancy (David Arcari) [1495358]
- [netdrv] igc: Remove unreachable code from igc_phy.c file (David Arcari) [1495358]
- [netdrv] igc: Remove obsolete IGC_ERR define (David Arcari) [1495358]
- [netdrv] ethernet/intel: consolidate NAPI and NAPI exit (David Arcari) [1495358]
- [netdrv] igc: Clean up code (David Arcari) [1495358]
- [netdrv] igc: Tidy up some white space (David Arcari) [1495358]
- [netdrv] igc: fix error return handling from call to netif_set_real_num_tx_queues (David Arcari) [1495358]
- [netdrv] igc: Remove set but not used variable 'pci_using_dac' (David Arcari) [1495358]
- [netdrv] igc: Remove set but not used variables 'ctrl_ext, link_mode' (David Arcari) [1495358]
- [netdrv] intel-ethernet: software timestamp skbs as late as possible (David Arcari) [1495358]
- [netdrv] igc: Add watchdog (David Arcari) [1495358]
- [netdrv] igc: Add setup link functionality (David Arcari) [1495358]
- [netdrv] igc: Add code for PHY support (David Arcari) [1495358]
- [netdrv] igc: Add NVM support (David Arcari) [1495358]
- [netdrv] igc: Add HW initialization code (David Arcari) [1495358]
- [netdrv] igc: Add transmit and receive fastpath and interrupt handlers (David Arcari) [1495358]
- [netdrv] igc: Add support for Tx/Rx rings (David Arcari) [1495358]
- [netdrv] igc: Add interrupt support (David Arcari) [1495358]
- [netdrv] igc: Add netdev (David Arcari) [1495358]
- [netdrv] igc: Add support for PF (David Arcari) [1495358]
- [netdrv] igc: Add skeletal frame for Intel(R) 2.5G Ethernet Controller support (David Arcari) [1495358]
- [s390] virtio-ccw: wire up ->bus_name callback (Cornelia Huck) [1695630]
- [s390] s390/virtio: handle find on invalid queue gracefully (Cornelia Huck) [1695630]
- [s390] virtio/s390: fix race in ccw_io_helper() (Cornelia Huck) [1695630]
- [s390] virtio/s390: avoid race on vcdev->config (Cornelia Huck) [1695630]
- [kvm] KVM: s390: make bitmap declaration consistent (Thomas Huth) [1695090]
- [kvm] KVM: s390: drop obsolete else path (Thomas Huth) [1695090]
- [kvm] KVM: s390: clarify kvm related kernel message (Thomas Huth) [1695090]
- [kvm] s390: vsie: Use effective CRYCBD.31 to check CRYCBD validity (Thomas Huth) [1695090]
- [kvm] KVM: s390: fix kmsg component kvm-s390 (Thomas Huth) [1695090]
- [kvm] KVM: s390: unregister debug feature on failing arch init (Thomas Huth) [1695090]
- [kvm] KVM: s390/vsie: avoid sparse warning (Thomas Huth) [1695090]

* Fri Apr 12 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.14.rt16.11.el8]
- [rt] kernel-rt-4.18.0-80.14.rt16.10.el8 (Juri Lelli) [1678887]
- [powerpc] powerpc: use mm zones more sensibly (David Gibson) [1654978]
- [s390] s390/mem_detect: add missing include (Philipp Rudo) [1695615]
- [s390] s390: avoid vmlinux segments overlap (Philipp Rudo) [1695615]
- [s390] s390/decompressor: add missing FORCE to build targets (Philipp Rudo) [1695615]
- [s390] s390: move ipl block and cmd line handling to early boot phase (Philipp Rudo) [1695615]
- [s390] s390/sclp: introduce sclp_early_get_hsa_size (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: add info source debug print (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: replace tprot loop with binary search (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: use SCLP info for continuous memory detection (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: introduce z/VM specific diag260 call (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: introduce SCLP storage info (Philipp Rudo) [1695615]
- [s390] s390: introduce .boot.data section compile time validation (Philipp Rudo) [1695615]
- [s390] s390/mem_detect: move tprot loop to early boot phase (Philipp Rudo) [1695615]
- [s390] s390/sclp: move sclp_early_read_info to sclp_early_core.c (Philipp Rudo) [1695615]
- [s390] s390: introduce .boot.data section (Philipp Rudo) [1695615]
- [s390] s390/decompressor: clean up and rename compressed/misc.c (Philipp Rudo) [1695615]
- [s390] s390: rescue initrd as early as possible (Philipp Rudo) [1695615]
- [s390] s390/sclp: simplify early hsa_size detection (Philipp Rudo) [1695615]
- [s390] s390/decompressor: get rid of .bss usage (Philipp Rudo) [1695615]
- [s390] s390/decompressor: rework uncompressed image info collection (Philipp Rudo) [1695615]
- [s390] s390: remove decompressor's head.S (Philipp Rudo) [1695615]
- [s390] s390: clean up stacks setup (Philipp Rudo) [1695615]
- [s390] s390: add initial 64-bit restart PSW (Philipp Rudo) [1695615]
- [s390] s390/hibernate: fix error handling when suspend cpu != resume cpu (Philipp Rudo) [1695615]
- [s390] s390/decompressor: support extra debug flags (Philipp Rudo) [1695615]
- [s390] s390/build: add *.o.chkbss files to targets list (Philipp Rudo) [1695615]
- [s390] s390/decompressor: avoid packing *.o.chkbss files into startup.a (Philipp Rudo) [1695615]
- [s390] s390/decompressor: avoid constant startup.a rebuilds (Philipp Rudo) [1695615]
- [s390] s390/boot: block uncompressed vmlinux booting attempts (Philipp Rudo) [1695615]
- [s390] s390/decompressor: correct EXCLUDE_FILE construct (Philipp Rudo) [1695615]
- [s390] s390: move _text to an actual .text start (Philipp Rudo) [1695615]
- [s390] s390: correct _stext offset (Philipp Rudo) [1695615]
- [s390] s390: get rid of the first mb of uncompressed image (Philipp Rudo) [1695615]
- [s390] s390: remove unused _ehead symbol (Philipp Rudo) [1695615]
- [s390] s390: put expoline execute-trampolines into .text section (Philipp Rudo) [1695615]
- [s390] s390/decompressor: discard ___kcrctab section (Philipp Rudo) [1695615]
- [s390] s390/setup: do not reserve the decompressor code (Philipp Rudo) [1695615]
- [s390] s390/decompressor: support uncompressed kernel (Philipp Rudo) [1695615]
- [init] init/Kconfig: add an option for uncompressed kernel (Philipp Rudo) [1695615]
- [s390] s390/decompressor: allow to pack uncompressed vmlinux.bin into piggy.o (Philipp Rudo) [1695615]
- [s390] s390/decompressor: allow preprocessor in piggy.o linker script (Philipp Rudo) [1695615]
- [s390] s390/decompressor: extend .bss check for early code (Philipp Rudo) [1695615]
- [s390] s390: add custom target and make path extension optional for .bss check (Philipp Rudo) [1695615]
- [s390] s390/decompressor: avoid repeating objects list in Makefile (Philipp Rudo) [1695615]
- [s390] s390/decompressor: reuse lib/mem.S for mem functions (Philipp Rudo) [1695615]
- [s390] s390/decompressor: avoid reusing uncompressed image objects (Philipp Rudo) [1695615]
- [s390] s390/als: avoid .init.* sections usage (Philipp Rudo) [1695615]
- [s390] s390/decompressor: rename entry point to startup_decompressor (Philipp Rudo) [1695615]
- [s390] s390/boot: make head.S and als.c be part of the decompressor only (Philipp Rudo) [1695615]
- [s390] s390/decompressor: trim the kernel image up to 1M (Philipp Rudo) [1695615]
- [s390] s390: remove uncompressed kernel image build (Philipp Rudo) [1695615]
- [s390] s390/decompressor: correct build flags (Philipp Rudo) [1695615]
- [s390] s390/build: remove obsolete -mkernel-backchain flag (Philipp Rudo) [1695615]
- [tools] tools/power turbostat: return the exit status of a command (David Arcari) [1642739]
- [misc] misc: hpilo: Do not claim unsupported hardware (Joseph Szczypek) [1665635]
- [misc] misc: hpilo: Exclude unsupported device via blacklist (Joseph Szczypek) [1665635]

* Thu Apr 11 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.13.rt16.10.el8]
- [rt] kernel-rt-4.18.0-80.13.rt16.9.el8 (Juri Lelli) [1678887]
- [fs] xfs: set buffer ops when repair probes for btree type (Bill O'Donnell) [1689281]
- [fs] xfs: end sync buffer I/O properly on shutdown error (Bill O'Donnell) [1689281]
- [fs] xfs: xfs_fsops: drop useless LIST_HEAD (Bill O'Donnell) [1689281]
- [fs] xfs: xfs_buf: drop useless LIST_HEAD (Bill O'Donnell) [1689281]
- [fs] iomap: fix a use after free in iomap_dio_rw (Bill O'Donnell) [1689281]
- [fs] xfs: reallocate realtime summary cache on growfs (Bill O'Donnell) [1689281]
- [fs] xfs: stringify scrub types in ftrace output (Bill O'Donnell) [1689281]
- [fs] xfs: stringify btree cursor types in ftrace output (Bill O'Donnell) [1689281]
- [fs] xfs: move XFS_INODE_FORMAT_STR mappings to libxfs (Bill O'Donnell) [1689281]
- [fs] xfs: move XFS_AG_BTREE_CMP_FORMAT_STR mappings to libxfs (Bill O'Donnell) [1689281]
- [fs] xfs: fix symbolic enum printing in ftrace output (Bill O'Donnell) [1689281]
- [fs] xfs: fix function pointer type in ftrace format (Bill O'Donnell) [1689281]
- [fs] xfs: Fix x32 ioctls when cmd numbers differ from ia32. (Bill O'Donnell) [1689281]
- [fs] xfs: Fix bulkstat compat ioctls on x32 userspace. (Bill O'Donnell) [1689281]
- [fs] xfs: Align compat attrlist_by_handle with native implementation. (Bill O'Donnell) [1689281]
- [fs] xfs: require both realtime inodes to mount (Bill O'Donnell) [1689281]
- [fs] xfs: cache minimum realtime summary level (Bill O'Donnell) [1689281]
- [fs] xfs: count inode blocks correctly in inobt scrub (Bill O'Donnell) [1689281]
- [fs] xfs: precalculate cluster alignment in inodes and blocks (Bill O'Donnell) [1689281]
- [fs] xfs: precalculate inodes and blocks per inode cluster (Bill O'Donnell) [1689281]
- [fs] xfs: add a block to inode count converter (Bill O'Donnell) [1689281]
- [fs] xfs: remove xfs_rmap_ag_owner and friends (Bill O'Donnell) [1689281]
- [fs] xfs: const-ify xfs_owner_info arguments (Bill O'Donnell) [1689281]
- [fs] xfs: streamline defer op type handling (Bill O'Donnell) [1689281]
- [fs] xfs: idiotproof defer op type configuration (Bill O'Donnell) [1689281]
- [fs] xfs: clean up indentation issues, remove an unwanted space (Bill O'Donnell) [1689281]
- [fs] xfs: libxfs: move xfs_perag_put late (Bill O'Donnell) [1689281]
- [fs] xfs: split up the xfs_reflink_end_cow work into smaller transactions (Bill O'Donnell) [1689281]
- [crypto] crypto: testmgr - add AES-CFB tests (Neil Horman) [1687897]
- [scsi] scsi: iscsi: flush running unbind operations when removing a session (Maurizio Lombardi) [1695007]
- [crypto] crypto: vmx - fix copy-paste error in CTR mode (Herbert Xu) [1693350]
- [rpmspec] Fix cross builds (Jiri Olsa) [1694956]
- [lib] sbitmap: order READ/WRITE freed instance and setting clear bit (Ming Lei) [1694521]
- [block] blk-mq: fix sbitmap ws_active for shared tags (Ming Lei) [1694521]
- [block] blk-mq: update comment for blk_mq_hctx_has_pending() (Ming Lei) [1694521]
- [block] blk-mq: use blk_mq_put_driver_tag() to put tag (Ming Lei) [1694521]
- [include] sbitmap: trivial - update comment for sbitmap_deferred_clear_bit (Ming Lei) [1694521]
- [block] blkcg: Fix kernel-doc warnings (Ming Lei) [1694521]
- [block] block: Unexport blk_mq_add_to_requeue_list() (Ming Lei) [1694521]
- [block] block: add BLK_MQ_POLL_CLASSIC for hybrid poll and return EINVAL for unexpected value (Ming Lei) [1694521]
- [include] blk-mq: remove unused 'nr_expired' from blk_mq_hw_ctx (Ming Lei) [1694521]
- [block] loop: access lo_backing_file only when the loop device is Lo_bound (Ming Lei) [1694521]
- [block] blk-mq: use blk_mq_sched_mark_restart_hctx to set RESTART (Ming Lei) [1694521]
- [kernel] blkcg: annotate implicit fall through (Ming Lei) [1694521]
- [block] block: Replace function name in string with __func__ (Ming Lei) [1694521]
- [block] block: fix NULL pointer dereference in register_disk (Ming Lei) [1694521]
- [fs] fs: fix guard_bio_eod to check for real EOD errors (Ming Lei) [1694521]
- [block] blk-mq: use HCTX_TYPE_DEFAULT but not 0 to index blk_mq_tag_set->map (Ming Lei) [1694521]
- [include] block: remove bvec_iter_rewind() (Ming Lei) [1694521]
- [block] block: don't use bio->bi_vcnt to figure out segment number (Ming Lei) [1694521]
- [fs] btrfs: look at bi_size for repair decisions (Ming Lei) [1694521]
- [block] block: avoid setting none scheduler if it's already none (Ming Lei) [1694521]
- [block] block: avoid setting wbt_lat_usec to current value (Ming Lei) [1694521]
- [block] blk-sysfs: Rework documention of __blk_release_queue (Ming Lei) [1694521]
- [block] blk-cgroup: Fix doc related to blkcg_exit_queue (Ming Lei) [1694521]
- [block] block: kill QUEUE_FLAG_FLUSH_NQ (Ming Lei) [1694521]
- [block] block: avoid setting nr_requests to current value (Ming Lei) [1694521]
- [block] blk-mq: save default hctx into ctx->hctxs for not-supported type (Ming Lei) [1694521]
- [block] blk-mq: save queue mapping result into ctx directly (Ming Lei) [1694521]
- [block] block: mq-deadline: Fix write completion handling (Ming Lei) [1694521]
- [crypto] crypto: user - fix leaking uninitialized memory to userspace (Herbert Xu) [1657880] {CVE-2018-19854}
- [char] ipmi: fix sleep-in-atomic in free_user at cleanup SRCU user->release_barrier (Xiaojun Tan) [1689480]
- [infiniband] usnic_verbs: fix deadlock (Govindarajulu Varadarajan) [1688505]
- [infiniband] IB/usnic: Fix locking when unregistering (Govindarajulu Varadarajan) [1688505]
- [infiniband] IB/usnic: Fix potential deadlock (Govindarajulu Varadarajan) [1688505]
- [netdrv] net: hns3: fix improper error handling in the hclge_init_ae_dev() (Xiaojun Tan) [1687060]
- [netdrv] net: hns3: fix netif_napi_del() not do problem when unloading (Xiaojun Tan) [1687060]
- [netdrv] net: hns3: Fix NULL deref when unloading driver (Xiaojun Tan) [1687060]
- [netdrv] net: hns3: Modify the order of initializing command queue register (Xiaojun Tan) [1687060]
- [netdrv] net: hns3: remove the Redundant put_vector in hns3_client_uninit (Xiaojun Tan) [1687060]
- [netdrv] net: hns3: reuse reinitialization interface in the hns3_set_channels (Xiaojun Tan) [1687060]

* Wed Apr 10 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.12.rt16.9.el8]
- [rt] kernel-rt-4.18.0-80.12.rt16.8.el8 (Juri Lelli) [1678887]
- [powercap] powercap/intel_rapl: add Ice Lake mobile (Steve Best) [1483427]
- [x86] x86/CPU: Add Icelake model number (Steve Best) [1483427]
- [watchdog] watchdog/hpwdt: Update Kconfig documentation (Joseph Szczypek) [1664861]
- [watchdog] watchdog/hpwdt: Update driver version. (Joseph Szczypek) [1664861]
- [watchdog] watchdog/hpwdt: Do not claim unsupported hardware (Joseph Szczypek) [1664861]
- [watchdog] watchdog/hpwdt: Exclude via blacklist (Joseph Szczypek) [1664861]
- [fs] autofs: add strictexpire mount option (Ian Kent) [1672134]
- [fs] autofs: change catatonic setting to a bit flag (Ian Kent) [1672134]
- [fs] autofs: simplify parse_options() function call (Ian Kent) [1672134]
- [fs] autofs: add AUTOFS_EXP_FORCED flag (Ian Kent) [1672134]
- [fs] autofs: make expire flags usage consistent with v5 params (Ian Kent) [1672134]
- [fs] autofs: make autofs_expire_indirect() static (Ian Kent) [1672134]
- [fs] autofs: make autofs_expire_direct() static (Ian Kent) [1672134]
- [fs] autofs: fix clearing AUTOFS_EXP_LEAVES in autofs_expire_indirect() (Ian Kent) [1672134]
- [fs] autofs: fix inconsistent use of now variable (Ian Kent) [1672134]
- [md] md: Fix failed allocation of md_register_thread (Nigel Croxon) [1665346]
- [md] It's wrong to add len to sector_nr in raid10 reshape twice (Nigel Croxon) [1665346]
- [md] raid5: set write hint for PPL (Nigel Croxon) [1665346]
- [netdrv] amd-xgbe: Fix mdio access for non-zero ports and clause 45 PHYs (Gary Hook) [1669565]

* Tue Apr 09 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.11.rt16.8.el8]
- [rt] kernel-rt-4.18.0-80.11.rt16.7.el8 (Juri Lelli) [1678887]
- [x86] x86/retpolines: Disable switch jump tables when retpolines are enabled (Waiman Long) [1688258]
- [x86] x86, retpolines: Raise limit for generating indirect calls from switch-case (Waiman Long) [1688258]
- [net] vsock/virtio: fix kernel panic from virtio_transport_reset_no_sock (Stefano Garzarella) [1676595]
- [net] vsock/virtio: reset connected sockets on device removal (Stefano Garzarella) [1676595]
- [net] vsock/virtio: fix kernel panic after device hot-unplug (Stefano Garzarella) [1676595]
- [powerpc] powerpc/livepatch: return -ERRNO values in save_stack_trace_tsk_reliable() (Joe Lawrence) [1659856]
- [powerpc] powerpc/livepatch: small cleanups in save_stack_trace_tsk_reliable() (Joe Lawrence) [1659856]
- [powerpc] powerpc/livepatch: relax reliable stack tracer checks for first-frame (Joe Lawrence) [1659856]
- [powerpc] powerpc/64s: Make reliable stacktrace dependency clearer (Joe Lawrence) [1659856]
- [powerpc] powerpc/64s: Clear on-stack exception marker upon exception return (Joe Lawrence) [1659856]
- [infiniband] iw_cxgb4: Support FW write completion WR (Arjun Vynipadath) [1671320]
- [infiniband] iw_cxgb4: RDMA write with immediate support (Arjun Vynipadath) [1671320]
- [infiniband] rdma/cxgb4: fix some info leaks (Arjun Vynipadath) [1671320]
- [infiniband] rdma/cxgb4: Add support for 64Byte cqes (Arjun Vynipadath) [1671320]
- [pci] pci: remove unused functionality (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] aacraid: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] be2iscsi: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] mpt3sas: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] qla2xxx: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] qla4xxx: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] megaraid_sas: add removed id table" (Tomas Henzl) [1622638]
- [scsi] lfpc: remove Lancer FCoE (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] lpfc: add removed id table" (Tomas Henzl) [1622638]
- [scsi] Revert "[scsi] lfpc: add Lancer FCoE to the removed devices" (Tomas Henzl) [1622638]

* Mon Apr 08 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.10.rt16.7.el8]
- [rt] kernel-rt-4.18.0-80.10.rt16.6.el8 (Juri Lelli) [1678887]
- [rt][redhat] Enable gdb_index (Juri Lelli)
- [kernel] printk: Export console_printk (Prarit Bhargava) [1642870]
- [video] fbcon: Silence fbcon logo on 'quiet' boots (Prarit Bhargava) [1642870]
- [scsi] scsi: ibmvscsi: Fix empty event pool access during host removal (Steve Best) [1692463]
- [scsi] scsi: ibmvscsi: Protect ibmvscsi_head from concurrent modificaiton (Steve Best) [1692463]
- [scsi] scsi: ibmvscsi: Improve strings handling (Steve Best) [1692463]
- [x86] x86/mce: Handle varying MCA bank counts (David Arcari) [1668779]
- [block] virtio_blk: add discard and write zeroes support (Stefano Garzarella) [1692939]
- [arm64] arm64: kaslr: ensure randomized quantities are clean also when kaslr is off (Mark Salter) [1673068]
- [arm64] arm64: kaslr: ensure randomized quantities are clean to the PoC (Mark Salter) [1673068]
- [tools] perf annotate: Fix getting source line failure (Michael Petlan) [1614435]
- [infiniband] IB/hfi1: Remove overly conservative VM_EXEC flag check (Alex Estrin) [1680018]

* Fri Apr 05 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.9.rt16.6.el8]
- [rt] kernel-rt-4.18.0-80.9.rt16.5.el8 (Juri Lelli) [1678887]
- [scsi] scsi: qla2xxx: Fix NULL pointer crash due to stale CPUID (Himanshu Madhani) [1685013]
- [scsi] scsi: core: Avoid that system resume triggers a kernel warning (Ewan Milne) [1691903]
- [scsi] scsi: core: reset host byte in DID_NEXUS_FAILURE case (Ewan Milne) [1691903]
- [scsi] scsi: core: Synchronize request queue PM status only on successful resume (Ewan Milne) [1691903]
- [scsi] scsi: sd: Fix cache_type_store() (Ewan Milne) [1691903]
- [scsi] scsi: sd: use mempool for discard special page (Ewan Milne) [1691903]
- [scsi] scsi: core: Remove scsi_block_when_processing_errors: message (Ewan Milne) [1691903]
- [scsi] scsi: core: Allow state transitions from OFFLINE to BLOCKED (Ewan Milne) [1691903]
- [scsi] scsi: core: remove unnecessary unlikely() (Ewan Milne) [1691903]
- [scsi] scsi: st: remove redundant pointer STbuffer (Ewan Milne) [1691903]
- [scsi] scsi: core: Avoid that SCSI device removal through sysfs triggers a deadlock (Ewan Milne) [1691903]
- [fs] scsi: sysfs: Introduce sysfs_{un,}break_active_protection() (Ewan Milne) [1691903]
- [scsi] scsi sg: remove incorrect scsi command checking logic (Ewan Milne) [1691903]
- [scsi] scsi: read host_busy via scsi_host_busy() (Ewan Milne) [1691903]
- [scsi] scsi: sd: Remove a superfluous assignment (Ewan Milne) [1691903]
- [scsi] scsi: don't add scsi command result bytes (Ewan Milne) [1691903]
- [scsi] scsi: core: check for equality of result byte values (Ewan Milne) [1691903]
- [scsi] scsi: scsi_transport_fc: use 64-bit timestamps consistently (Ewan Milne) [1691903]
- [scsi] scsi: sg: clean up gfp_mask in sg_build_indirect (Ewan Milne) [1691903]
- [scsi] scsi: core: remove Scsi_Cmnd typedef (Ewan Milne) [1691903]
- [netdrv] ibmvnic: Report actual backing device speed and duplex values (Steve Best) [1691862]
- [kernel] sched/fair: Fix O(nr_cgroups) in the load balancing path (Phil Auld) [1685636] {CVE-2018-20784}
- [kernel] sched/fair: Fix insertion in rq->leaf_cfs_rq_list (Phil Auld) [1685636] {CVE-2018-20784}
- [kernel] sched/fair: Add tmp_alone_branch assertion (Phil Auld) [1685636] {CVE-2018-20784}
- [kernel] sched/fair: Fix infinite loop in update_blocked_averages() by reverting a9e7f6544b9c (Phil Auld) [1685636] {CVE-2018-20784}
- [kernel] tracing: Do a WARN_ON() if start_thread() in hwlat is called when thread exists (Jerome Marchand) [1693050]
- [kernel] ftrace: Add missing check for existing hwlat thread (Jerome Marchand) [1693050]
- [kernel] tracing: Do not call start/stop() functions when tracing_on does not change (Jerome Marchand) [1693050]

* Thu Apr 04 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.8.rt16.5.el8]
- [rt] kernel-rt-4.18.0-80.8.rt16.4.el8 (Juri Lelli) [1678887]
- [scsi] scsi: lpfc: Fixup eq_clr_intr references (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix build error (Dick Kennedy) [1692882]
- [scsi] scsi: be2iscsi: lpfc: fix typo (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Update lpfc version to 12.2.0.1 (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Update Copyright in driver version (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Enhance 6072 log string (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix duplicate log message numbers (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Specify node affinity for queue memory allocation (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Reduce memory footprint for lpfc_queue (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Add loopback testing to trunking mode (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix link speed reporting for 4-link trunk (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix handling of trunk links state reporting (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix protocol support on G6 and G7 adapters (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Correct boot bios information to FDMI registration (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix HDMI2 registration string for symbolic name (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix fc4type information for FDMI (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix FDMI manufacturer attribute value (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix io lost on host resets (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix mailbox hang on adapter init (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix driver crash in target reset handler (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Correct localport timeout duration error (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: nvmet: avoid hang / use-after-free when destroying targetport (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Convert bootstrap mbx polling from msleep to udelay (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Coordinate adapter error handling with offline handling (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Stop adapter if pci errors detected (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix deadlock due to nested hbalock call (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix nvmet handling of first burst cmd (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix lpfc_nvmet_mrq attribute handling when 0 (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix nvmet async receive buffer replenishment (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix location of SCSI ktime counters (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix SLI3 commands being issued on SLI4 devices (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix use-after-free mailbox cmd completion (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Resolve irq-unsafe lockdep heirarchy warning in lpfc_io_free (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Resolve inconsistent check of hdwq in lpfc_scsi_cmd_iocb_cmpl (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix error codes in lpfc_sli4_pci_mem_setup() (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: fix 32-bit format string warning (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: fix unused variable warning (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: resolve static checker warning in lpfc_sli4_hba_unset (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Correct __lpfc_sli_issue_iocb_s4 lockdep check (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: fix calls to dma_set_mask_and_coherent() (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: use dma_set_mask_and_coherent (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Remove set but not used variable 'phys_id' (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: fix a handful of indentation issues (Dick Kennedy) [1692882]
- [scsi] scsi: lpfc: Fix error code if kcalloc() fails (Dick Kennedy) [1692882]
- [security] security/selinux: fix SECURITY_LSM_NATIVE_LABELS on reused superblock (Ondrej Mosnacek) [1683296]
- [security] selinux: add the missing walk_size + len check in selinux_sctp_bind_connect (Ondrej Mosnacek) [1683296]
- [security] selinux: fix avc audit messages (Ondrej Mosnacek) [1670039 1683296]
- [security] selinux: replace BUG_ONs with WARN_ONs in avc.c (Ondrej Mosnacek) [1670039 1683296]
- [security] selinux: log invalid contexts in AVCs (Ondrej Mosnacek) [1670039 1683296]
- [security] selinux: replace some BUG_ON()s with a WARN_ON() (Ondrej Mosnacek) [1670039 1683296]
- [security] selinux: inline some AVC functions used only once (Ondrej Mosnacek) [1670039 1683296]
- [security] selinux: do not override context on context mounts (Ondrej Mosnacek) [1683296]
- [security] selinux: never allow relabeling on context mounts (Ondrej Mosnacek) [1683296]
- [security] selinux: stop passing MAY_NOT_BLOCK to the AVC upon follow_link (Ondrej Mosnacek) [1683296]
- [security] selinux: avoid silent denials in permissive mode under RCU walk (Ondrej Mosnacek) [1683296]
- [security] selinux: fix GPF on invalid policy (Ondrej Mosnacek) [1683296]
- [security] selinux: overhaul sidtab to fix bug and improve performance (Ondrej Mosnacek) [1656787 1683296]
- [security] selinux: use separate table for initial SID lookup (Ondrej Mosnacek) [1656787 1683296]
- [security] selinux: make "selinux_policycap_names[]" const char * (Ondrej Mosnacek) [1683296]
- [security] selinux: always allow mounting submounts (Ondrej Mosnacek) [1647723 1683296]
- [security] selinux: refactor sidtab conversion (Ondrej Mosnacek) [1656787 1683296]
- [security] selinux: fix non-MLS handling in mls_context_to_sid() (Ondrej Mosnacek) [1683296]
- [security] selinux: check length properly in SCTP bind hook (Ondrej Mosnacek) [1683296]
- [security] selinux: policydb - fix byte order and alignment issues (Ondrej Mosnacek) [1668222 1683296]
- [security] selinux: Add __GFP_NOWARN to allocation at str_read() (Ondrej Mosnacek) [1683296]
- [security] selinux: refactor mls_context_to_sid() and make it stricter (Ondrej Mosnacek) [1683296]
- [security] selinux: fix mounting of cgroup2 under older policies (Ondrej Mosnacek) [1683296]
- [security] selinux: cleanup dentry and inodes on error in selinuxfs (Ondrej Mosnacek) [1683296]
- [security] selinux: constify write_op[] (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in netnode (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in avc (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in netif (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in netport (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in sidtab (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in netlink (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in selinuxfs (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in services (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in avtab (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in hooks (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in policydb (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in ebitmap (Ondrej Mosnacek) [1683296]
- [security] selinux: Cleanup printk logging in conditional (Ondrej Mosnacek) [1683296]
- [fs] fs/proc/kcore.c: fix invalid memory access in multi-page read optimization (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: add vmcoreinfo note to /proc/kcore (Bhupesh Sharma) [1627539]
- [kernel] crash_core: use VMCOREINFO_SYMBOL_ARRAY() for swapper_pg_dir (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: optimize multiple page reads (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: clean up ELF header generation (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: hold lock during read (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: fix memory hotplug vs multiple opens race (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: replace kclist_lock rwlock with rwsem (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: don't grab lock for memory hotplug notifier (Bhupesh Sharma) [1627539]
- [fs] proc/kcore: don't grab lock for kclist_add() (Bhupesh Sharma) [1627539]

* Tue Apr 02 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.7.rt16.4.el8]
- [rt] kernel-rt-4.18.0-80.7.rt16.3.el8 (Juri Lelli) [1678887]
- [net] Merge branch 'linus/master' into rdma.git for-next (Jonathan Toppins) [1685304]
- [netdrv] net: cisco: enic: Replace GFP_ATOMIC with GFP_KERNEL (Jonathan Toppins) [1685304]
- [infiniband] RDMA/providers: Remove pointless functions (Jonathan Toppins) [1685304]
- [infiniband] RDMA/usnic: Suppress a compiler warning (Jonathan Toppins) [1685304]
- [infiniband] IB/usnic: usnic should not select INFINIBAND_USER_ACCESS (Jonathan Toppins) [1685304]
- [infiniband] RDMA/vmw_pvrdma: Delete unused function (Jonathan Toppins) [1685304]
- [infiniband] IB/usnic: Update with bug fixes from core code (Jonathan Toppins) [1685304]
- [infiniband] RDMA/providers: Fix return value from create_srq callbacks (Jonathan Toppins) [1685304]
- [infiniband] RDMA/rxe: Simplify the error handling code in rxe_create_ah() (Jonathan Toppins) [1685304]
- [infiniband] IB/rxe: avoid unnecessary NULL check (Jonathan Toppins) [1685304]
- [infiniband] IB/rxe: increase max MR limit (Jonathan Toppins) [1685304]
- [infiniband] IB/rxe: Do not hide uABI stuff in memcpy (Jonathan Toppins) [1685304]
- [net] rpc: remove unneeded variable 'ret' in rdma_listen_handler (Jonathan Toppins) [1685304]
- [net] svcrdma: Clean up Read chunk path (Jonathan Toppins) [1685304]
- [net] svcrdma: Avoid releasing a page in svc_xprt_release() (Jonathan Toppins) [1685304]
- [net] sunrpc: remove redundant variables 'checksumlen', 'blocksize' and 'data' (Jonathan Toppins) [1685304]
- [scsi] scsi: target: srp, vscsi, sbp, qla: use target_remove_session (Jonathan Toppins) [1685304]
- [target] scsi: target: add session removal function (Jonathan Toppins) [1685304]
- [target] scsi: target: rename target_alloc_session (Jonathan Toppins) [1685304]
- [infiniband] RDMA/ipoib: Fix check for return code from ib_create_srq (Jonathan Toppins) [1685304]
- [infiniband] IB/ipoib: Fix error return code in ipoib_dev_init() (Jonathan Toppins) [1685304]
- [infiniband] IPoIB: use kvzalloc to allocate an array of bucket pointers (Jonathan Toppins) [1685304]
- [infiniband] ib_srpt: use kvmalloc to allocate ring pointers (Jonathan Toppins) [1685304]
- [infiniband] RDMA/ipoib: Fix return code from ipoib_cm_dev_init (Jonathan Toppins) [1685304]
- [infiniband] IB/iser: Remove set-but-not-used variables (Jonathan Toppins) [1685304]
- [infiniband] RDMA/ipoib: Prefer unsigned int to bare use of unsigned (Jonathan Toppins) [1685304]
- [infiniband] RDMA/ipoib: Use min_t() macro instead of min() (Jonathan Toppins) [1685304]
- [infiniband] IB/srp: Remove driver version and release data information (Jonathan Toppins) [1685304]
- [target] scsi: target: Remove second argument from fabric_make_tpg() (Jonathan Toppins) [1685304]
- [infiniband] IB/iser: set can_queue earlier to allow setting higher queue depth (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Set right entry state before releasing reference (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Free uapi on destroy (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Fix error cleanup path of ib_uverbs_add_one() (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Release object lock if destroy failed (Jonathan Toppins) [1685304]
- [infiniband] IB/ucm: fix UCM link error (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Change filter function return type from int to bool (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Update GID entries for netdevice whose mac address changes (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Add default GIDs of the bond master netdev (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Consider adding default GIDs of bond device (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Delete lower netdevice default GID entries in bonding scenario (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Avoid confusing del_netdev_default_ips (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Add comment for change upper netevent handling (Jonathan Toppins) [1685304]
- [infiniband] IB/ucm: Fix compiling ucm.c (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Do not check for device disassociation during ioctl (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Remove struct uverbs_root_spec and all supporting code (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Use uverbs_api to unmarshal ioctl commands (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Use uverbs_alloc for allocations (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Add a simple allocator to uverbs_attr_bundle (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Remove the ib_uverbs_attr pointer from each attr (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Provide implementation private memory for the uverbs_attr_bundle (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Use uverbs_api to manage the object type inside the uobject (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Build the specs into a radix tree at runtime (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Have the core code create the uverbs_root_spec (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Fix reading of 32 bit flags (Jonathan Toppins) [1685304]
- [infiniband] IB/ucm: Initialize sgid request GID attribute pointer (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Allow all DESTROY commands to succeed after disassociate (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Do not block disassociate during write() (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Do not pass struct ib_device to the ioctl methods (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Do not pass struct ib_device to the write based methods (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Lower the test for ongoing disassociation (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Allow uobject allocation to work concurrently with disassociate (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Allow RDMA_REMOVE_DESTROY to work concurrently with disassociate (Jonathan Toppins) [1685304]
- [include] IB/uverbs: Convert 'bool exclusive' into an enum (Jonathan Toppins) [1685304]
- [include] IB/uverbs: Consolidate uobject destruction (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Make the write path destroy methods use the same flow as ioctl (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Remove rdma_explicit_destroy() from the ioctl methods (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Prefix _ib to IB/RoCE specific functions (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Simplify gid type check in cma_acquire_dev() (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Return bool instead of int (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Get rid of 1 bit boolean (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Constify path record, ib_cm_event, listen_id pointers (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Constify dst_addr argument (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Simplify rdma_resolve_addr() error flow (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Initialize resource type in __rdma_create_id() (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Check for verbs callbacks before using them (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Remove {create,destroy}_ah from mandatory verbs (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Add UVERBS_ATTR_FLAGS_IN to the specs language (Jonathan Toppins) [1685304]
- [infiniband] RDMA, core and ULPs: Declare ib_post_send() and ib_post_recv() arguments const (Jonathan Toppins) [1685304]
- [infiniband] IB/mlx5, ib_post_send(), IB_WR_REG_SIG_MR: Do not modify the 'wr' argument (Jonathan Toppins) [1685304]
- [net] net/xprtrdma: Restore needed argument to ib_post_send (Jonathan Toppins) [1685304]
- [net] net/xprtrdma: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [nvme] nvmet-rdma: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [nvme] nvme-rdma: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] IB/srpt: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] IB/srp: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] IB/isert: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] IB/iser: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] IB/IPoIB: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Constify the argument of the work request conversion functions (Jonathan Toppins) [1685304]
- [infiniband] IB/iser: Inline two work request conversion functions (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Consider netdevice for RoCE ports (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Introduce and use sgid_attr in CM requests (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Remove extra parentheses (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Fix locking around struct ib_uverbs_file ucontext (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Move the FD uobj type struct file allocation to alloc_commit (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Always propagate errors from rdma_alloc_commit_uobject() (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Rework the locking for cleaning up the ucontext (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Revise and clarify the rwsem and uobjects_lock (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Clarify and revise uverbs_close_fd (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Revise the placement of get/puts on uobject (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Clarify the kref'ing ordering for alloc_commit (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Handle IDR and FD types without truncation (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Get rid of null_obj_type (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Simplify ib_post_(send|recv|srq_recv)() calls (Jonathan Toppins) [1685304]
- [include] IB/core: Allow ULPs to specify NULL as the third ib_post_(send|recv|srq_recv)() argument (Jonathan Toppins) [1685304]
- [include] IB/mlx5: Introduce driver create and destroy flow methods (Jonathan Toppins) [1685304]
- [infiniband] IB: Support ib_flow creation in drivers (Jonathan Toppins) [1685304]
- [infiniband] IB/mlx5: Introduce flow steering matcher uapi object (Jonathan Toppins) [1685304]
- [include] IB/uverbs: Move ib_access_flags and ib_read_counters_flags to uapi (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Remove cma_multicast->igmp_joined (Jonathan Toppins) [1685304]
- [infiniband] RDMA/umem: Refactor exit paths in ib_umem_get (Jonathan Toppins) [1685304]
- [infiniband] IB: Enable uverbs_destroy_def_handler to be used by drivers (Jonathan Toppins) [1685304]
- [include] IB/uverbs: Pass IB_UVERBS_QPF_GRH_REQUIRED to user space (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Validate grh_required when handling AVs (Jonathan Toppins) [1685304]
- [infiniband] RDMA/hfi1: Move grh_required into update_sm_ah (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Simplify check for RoCE route resolve (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Do not use uverbs_cmd_mask in the ioctl path (Jonathan Toppins) [1685304]
- [infiniband] RDMA/rw: Fix rdma_rw_ctx_signature_init() kernel-doc header (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Remove set-but-not-used variables (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Remove ib_find_cached_gid() and ib_find_cached_gid_by_port() (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Remove unused and erroneous msg sequence encoding (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Replace ib_ucq_object uverbs_file with the one in ib_uobject (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Remove ib_uobject_file (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Tidy up remaining references to ucontext (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Replace file->ucontext with file in uverbs_cmd.c (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Replace ib_ucontext with ib_uverbs_file in core function calls (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Move non driver related elements from ib_ucontext to ib_ufile (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Add a uobj_perform_destroy helper (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Combine MIN_SZ_OR_ZERO with UVERBS_ATTR_STRUCT (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Use UVERBS_ATTR_MIN_SIZE correctly and uniformly (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Remove UA_FLAGS (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Get rid of the & in method specifications (Jonathan Toppins) [1685304]
- [infiniband] IB: Improve uverbs_cleanup_ucontext algorithm (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Simplify UVERBS_OBJECT and _TREE family of macros (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Simplify method definition macros (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Simplify UVERBS_ATTR family of macros (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Split UVERBS_ATTR_FLOW_ACTION_ESP_HANDLE (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Store the specs_root in the struct ib_uverbs_device (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Remove now useless rcu_lock in dst_fetch_ha (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Check for rdma_protocol_ib only after validating port_num (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Remove redundant check (Jonathan Toppins) [1685304]
- [infiniband] RDMA/umem: Don't check for a negative return value of dma_map_sg_attrs() (Jonathan Toppins) [1685304]
- [infiniband] RDMA/verbs: Drop kernel variant of destroy_flow (Jonathan Toppins) [1685304]
- [infiniband] RDMA/verbs: Drop kernel variant of create_flow (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Check existence of create_flow callback (Jonathan Toppins) [1685304]
- [infiniband] RDMA/core: Remove unused ib cache functions (Jonathan Toppins) [1685304]
- [infiniband] Revert "[infiniband] RDMA/hns: Only assgin the fields of the av if IB_QP_AV bit is set" (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Convert drivers to use the AH's sgid_attr in post_wr paths (Jonathan Toppins) [1685304]
- [infiniband] IB/mlx4: Use GID attribute from ah attribute (Jonathan Toppins) [1685304]
- [infiniband] IB/rxe: Use rdma GID API (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Use sgid_attr from the AV (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Replace members of sa_path_rec with 'struct sgid_attr *' (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Pass the sgid_attr through various events (Jonathan Toppins) [1685304]
- [infiniband] IB/cm: Keep track of the sgid_attr that created the cm id (Jonathan Toppins) [1685304]
- [infiniband] IB: Make init_ah_attr_grh_fields set sgid_attr (Jonathan Toppins) [1685304]
- [infiniband] IB: Make ib_init_ah_from_mcmember set sgid_attr (Jonathan Toppins) [1685304]
- [infiniband] IB: Make ib_init_ah_attr_from_wc set sgid_attr (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Free GID table entry during GID deletion (Jonathan Toppins) [1685304]
- [infiniband] RDMA/cma: Consider net namespace while leaving multicast group (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Delete type and id from uverbs_obj_attr (Jonathan Toppins) [1685304]
- [infiniband] IB/rdmavt, IB/hfi1: Create device dependent s_flags (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Expose ib_ucontext from a given ib_uverbs_file (Jonathan Toppins) [1685304]
- [include] IB/core: Introduce DECLARE_UVERBS_GLOBAL_METHODS (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Allow an empty namespace in ioctl() framework (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Add a macro to define a type with no kernel known size (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Add PTR_IN attributes that are allocated/copied automatically (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Refactor uverbs_finalize_objects (Jonathan Toppins) [1685304]
- [infiniband] IB/uverbs: Export uverbs idr and fd types (Jonathan Toppins) [1685304]
- [infiniband] IB/mad: Use IDR for agent IDs (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Hold the sgid_attr inside the struct ib_ah/qp (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Convert drivers to use sgid_attr instead of sgid_index (Jonathan Toppins) [1685304]
- [infiniband] IB{cm, core}: Introduce and use ah_attr copy, move, replace APIs (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Tidy ib_resolve_eth_dmac (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Add a sgid_attr pointer to struct rdma_ah_attr (Jonathan Toppins) [1685304]
- [infiniband] IB: Ensure that all rdma_ah_attr's are zero initialized (Jonathan Toppins) [1685304]
- [infiniband] IB/mad: Agent registration is process context only (Jonathan Toppins) [1685304]
- [infiniband] RDMA/uverbs: Refactor flow_resources_alloc() function (Jonathan Toppins) [1685304]
- [infiniband] RDMA/nldev: Return port capability flag for IB only (Jonathan Toppins) [1685304]
- [net] RDMA/smc: Replace ib_query_gid with rdma_get_gid_attr (Jonathan Toppins) [1685304]
- [include] IB/cache: Restore compatibility for ib_query_gid (Jonathan Toppins) [1685304]
- [infiniband] IB: Replace ib_query_gid/ib_get_cached_gid with rdma_query_gid (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Make rdma_find_gid_by_filter support all protocols (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Provide rdma_ versions of the gid cache API (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Replace ib_query_gid with rdma_get_gid_attr (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Introduce GID attribute get, put and hold APIs (Jonathan Toppins) [1685304]
- [infiniband] RDMA: Use GID from the ib_gid_attr during the add_gid() callback (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Introduce GID entry reference counts (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Store default GID property per-table instead of per-entry (Jonathan Toppins) [1685304]
- [infiniband] IB/core: Do not set the gid type when reserving default entries (Jonathan Toppins) [1685304]
- [include] IDR: Expose the XArray lock (Jonathan Toppins) [1688319]
- [x86] x86/cpufeatures: Enumerate MOVDIR64B instruction (Steve Best) [1482754]
- [x86] x86/cpufeatures: Enumerate MOVDIRI instruction (Steve Best) [1482754]
- [nvme] nvme: allow ANA support to be independent of native multipathing (Ewan Milne) [1690940]
- [nvme] nvme: multipath: Change default of kernel NVMe multipath to be disabled (Ewan Milne) [1690940]
- [nvme] nvme: convert to SPDX identifiers (Ewan Milne) [1690940]
- [nvme] nvme-multipath: round-robin I/O policy (Ewan Milne) [1690940]
- [nvme] nvme-multipath: drop optimization for static ANA group IDs (Ewan Milne) [1690940]
- [nvme] nvme-multipath: zero out ANA log buffer (Ewan Milne) [1690940]
- [nvme] nvme-fc: fix numa_node when dev is null (Ewan Milne) [1690940]
- [nvme] nvme: add a numa_node field to struct nvme_ctrl (Ewan Milne) [1690940]
- [nvme] nvme: update node paths after adding new path (Ewan Milne) [1690940]
- [nvme] nvme: take node locality into account when selecting a path (Ewan Milne) [1690940]
- [s390] s390/mm: Fix ERROR: "__node_distance" undefined! (Ewan Milne) [1690940]
- [nvme] nvme: call nvme_complete_rq when nvmf_check_ready fails for mpath I/O (Ewan Milne) [1690940]
- [nvme] nvme: properly propagate errors in nvme_mpath_init (Ewan Milne) [1690940]
- [nvme] nvme: fixup crash on failed discovery (Ewan Milne) [1690940]
- [nvme] nvme: add ANA support (Ewan Milne) [1690940]
- [include] nvme.h: fixup ANA group descriptor format (Ewan Milne) [1690940]
- [include] nvme.h: add ANA definitions (Ewan Milne) [1690940]
- [nvme] nvme: remove nvme_req_needs_failover (Ewan Milne) [1690940]
- [nvme] nvme: simplify the API for getting log pages (Ewan Milne) [1690940]
- [include] nvme.h: add support for the log specific field (Ewan Milne) [1690940]

* Fri Mar 29 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.6.rt16.3.el8]
- [rt] kernel-rt-4.18.0-80.6.rt16.2.el8 (Juri Lelli) [1678887]
- [md] dm writecache: set "Tech Preview" taint using mark_tech_preview() (Mike Snitzer) [1690587]
- [md] dm integrity: limit the rate of error messages (Mike Snitzer) [1690105]
- [md] dm snapshot: don't define direct_access if we don't support it (Mike Snitzer) [1690105]
- [md] dm cache: add support for discard passdown to the origin device (Mike Snitzer) [1690105]
- [md] dm writecache: fix typo in name for writeback_wq (Mike Snitzer) [1690105]
- [md] dm thin: add sanity checks to thin-pool and external snapshot creation (Mike Snitzer) [1690105]
- [md] dm block manager: remove redundant unlikely annotation (Mike Snitzer) [1690105]
- [md] dm verity fec: remove redundant unlikely annotation (Mike Snitzer) [1690105]
- [md] dm integrity: remove redundant unlikely annotation (Mike Snitzer) [1690105]
- [md] dm switch: use struct_size() in kzalloc() (Mike Snitzer) [1690105]
- [md] dm: remove unused _rq_tio_cache and _rq_cache (Mike Snitzer) [1690105]
- [md] dm crypt: don't overallocate the integrity tag space (Mike Snitzer) [1690105]
- [md] dm: eliminate 'split_discard_bios' flag from DM target interface (Mike Snitzer) [1690105]
- [md] dm: always call blk_queue_split() in dm_process_bio() (Mike Snitzer) [1690105]
- [md] dm: update dm_process_bio() to split bio if in ->make_request_fn() (Mike Snitzer) [1690105]
- [md] dm rq: remove unused arguments from rq_completed() (Mike Snitzer) [1690105]
- [md] dm integrity: replace open-coded allocation size multiplication (Mike Snitzer) [1690105]
- [md] dm: Remove VLA usage from hashes (Mike Snitzer) [1690105]
- [crypto] crypto: hash - Remove VLA usage (Mike Snitzer) [1690105]
- [md] dm: Avoid namespace collision with bitmap API (Mike Snitzer) [1690105]
- [md] md/dm-writecache: Don't request pointer dummy_addr when not required (Mike Snitzer) [1690105]
- [scsi] scsi: qla2xxx: avoid printf format warning (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix issue reported by static checker for qla2x00_els_dcmd2_sp_done() (Himanshu Madhani) [1664534]
- [scsi] qla2xxx: Update driver version to 10.00.00.14.08.1-k (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Avoid PCI IRQ affinity mapping when multiqueue is not supported (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add new FW dump template entry types (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix code indentation for qla27xx_fwdt_entry (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move marker request behind QPair (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Prevent SysFS access when chip is down (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add support for setting port speed (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Prevent multiple ADISC commands per session (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Check for FW started flag before aborting (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix unload when NVMe devices are configured (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add First Burst support for FC-NVMe devices (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix LUN discovery if loop id is not assigned yet by firmware (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: remove redundant null check on pointer sess (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move debug messages before sending srb preventing panic (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Use complete switch scan for RSCN events (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix fw options handle eh_bus_reset() (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Restore FAWWPN of Physical Port only for loop down (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Prevent memory leak for CT req/rsp allocation (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix SRB allocation flag to avoid sleeping in IRQ context (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: allow session delete to finish before create. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: fix fcport null pointer access. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: flush IO on chip reset or sess delete (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix session cleanup hang (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Change default ZIO threshold. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add pci function reset support. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix N2N target discovery with Local loop (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: no need to check return value of debugfs_create functions (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix DMA error when the DIF sg buffer crosses 4GB boundary (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add protection mask module parameters (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix for FC-NVMe discovery for NPIV port (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix NPIV handling for FC-NVMe (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Enable FC-NVME on NPIV ports (Himanshu Madhani) [1664534]
- [scsi] Revert "scsi: qla2xxx: Fix NVMe Target discovery" (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: NULL check before some freeing functions is not needed (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Split the __qla2x00_abort_all_cmds() function (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Introduce a switch/case statement in qlt_xmit_tm_rsp() (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix a typo in MODULE_PARM_DESC (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove two arguments from qlafx00_error_entry() (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Make sure that qlafx00_ioctl_iosb_entry() initializes 'res' (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove a set-but-not-used variable (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Make qla2x00_sysfs_write_nvram() easier to analyze (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Declare local functions 'static' (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Improve several kernel-doc headers (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Modify fall-through annotations (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: fully convert to the generic DMA API (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Simplify conditional check (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove unnecessary self assignment (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Return switch command on a timeout (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move log messages before issuing command to firmware (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix for double free of SRB structure (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix recursive mailbox timeout (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix NVMe Target discovery (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: don't allow negative thresholds (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix comment in MODULE_PARM_DESC in qla2xxx (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove set but not used variable 'ptr_dma' (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: fix typo "CT-PASSTRHU" -> "CT-PASSTHRU" (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix an endian bug in fcpcmd_is_corrupted() (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix double increment of switch scan retry count (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix duplicate switch's Nport ID entries (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove stale debug trace message from tcm_qla2xxx (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix premature command free (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Reject bsg request if chip is down. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: shutdown chip if reset fail (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix stuck session in PLOGI state (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix early srb free on abort (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add mode control for each physical port (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix race condition for resource cleanup (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix dropped srb resource. (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix port speed display on chip reset (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Check for Register disconnect (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Increase abort timeout value (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Allow FC-NVMe underrun to be handled by transport (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move ABTS code behind qpair (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove stale ADISC_DONE event (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix Remote port registration (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove ASYNC GIDPN switch command (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Reduce holding sess_lock to prevent CPU lock-up (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move {get|rel}_sp to base_qpair struct (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add support for ZIO6 interrupt threshold (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix out of order Termination and ABTS response (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add logic to detect ABTS hang and response completion (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add appropriate debug info for invalid RX_ID (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix deadlock between ATIO and HW lock (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Serialize mailbox request (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Terminate Plogi/PRLI if WWN is 0 (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Defer chip reset until target mode is enabled (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove all rports if fabric scan retry fails (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Force fw cleanup on ADISC error (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Turn off IOCB timeout timer on IOCB completion (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Decrement login retry count for only plogi (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Move rport registration out of internal work_list (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Remove redundant check for fcport deletion (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Update rscn_rcvd field to more meaningful scan_needed (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Use correct qpair for ABTS/CMD (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix process response queue for ISP26XX and above (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Migrate NVME N2N handling into state machine (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Save frame payload size from ICB (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix race between switch cmd completion and timeout (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix Management Server NPort handle reservation logic (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Flush mailbox commands on chip reset (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix session state stuck in Get Port DB (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix redundant fc_rport registration (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Silent erroneous message (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Prevent sysfs access when chip is down (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Add longer window for chip reset (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix login retry count (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Fix N2N link re-connect (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: Cleanup for N2N code (Himanshu Madhani) [1664534]
- [scsi] scsi: qla2xxx: remove irq save in qla2x00_poll() (Himanshu Madhani) [1664534]
- [netdrv] ice: Do autoneg based on VSI state (Jonathan Toppins) [1687903]
- [fs] xfs: use the latest extent at writeback delalloc conversion time (Brian Foster) [1661968]
- [fs] xfs: create delalloc bmapi wrapper for full extent allocation (Brian Foster) [1661968]
- [fs] xfs: remove superfluous writeback mapping eof trimming (Brian Foster) [1661968]
- [fs] xfs: validate writeback mapping using data fork seq counter (Brian Foster) [1661968]
- [fs] xfs: update fork seq counter on data fork changes (Brian Foster) [1661968]
- [fs] xfs: eof trim writeback mapping as soon as it is cached (Brian Foster) [1661968]
- [perf] drivers/perf: hisi: update the sccl_id/ccl_id when MT is supported (Xiaojun Tan) [1677815]

* Thu Mar 28 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.5.rt16.2.el8]
- [rt] kernel-rt-4.18.0-80.5.rt16.1.el8 (Juri Lelli) [1678887]
- Revert "[redhat-rt] Fix genspec looking at latest rhel (and not rhel-rt) tag" (Juri Lelli)
- [rt] padata: Make padata_do_serial() use get_cpu_light() (Daniel Bristot de Oliveira) [1664257]

* Wed Mar 27 2019 Juri Lelli <juri.lelli@redhat.com> [4.18.0-80.5.rt16.1.el8]
- [rt] kernel-rt-4.18.0-80.5.rt16.0.el8 (Juri Lelli) [1678887]
- Add localversion for -RT release (Thomas Gleixner)
- signals: Allow rt tasks to cache one sigqueue struct (Thomas Gleixner)
- workqueue: Prevent deadlock/stall on RT (Thomas Gleixner)
- apparmor: use a locallock instead preempt_disable() (Sebastian Andrzej Siewior)
- cpuset: Convert callback_lock to raw_spinlock_t (Mike Galbraith)
- cgroups: use simple wait in css_release() (Sebastian Andrzej Siewior)
- drm/i915: skip DRM_I915_LOW_LEVEL_TRACEPOINTS with NOTRACE (Sebastian Andrzej Siewior)
- drm/i915: disable tracing on -RT (Sebastian Andrzej Siewior)
- drm,i915: Use local_lock/unlock_irq() in intel_pipe_update_start/end() (Mike Galbraith)
- drm,radeon,i915: Use preempt_disable/enable_rt() where recommended (Mike Galbraith)
- watchdog: prevent deferral of watchdogd wakeup on RT (Julia Cartwright)
- tpm_tis: fix stall after iowrite*()s (Haris Okanovic)
- drivers/zram: fix zcomp_stream_get() smp_processor_id() use in preemptible code (Mike Galbraith)
- drivers/zram: Don't disable preemption in zcomp_stream_get/put() (Mike Galbraith)
- drivers/block/zram: Replace bit spinlocks with rtmutex for -rt (Mike Galbraith)
- connector/cn_proc: Protect send_msg() with a local lock on RT (Mike Galbraith)
- arch/arm64: Add lazy preempt support (Anders Roxell)
- powerpc: Add support for lazy preemption (Thomas Gleixner)
- arm: Add support for lazy preemption (Thomas Gleixner)
- x86: lazy-preempt: use proper return label on 32bit-x86 (Sebastian Andrzej Siewior)
- x86: lazy-preempt: properly check against preempt-mask (Sebastian Andrzej Siewior)
- x86: Support for lazy preemption (Thomas Gleixner)
- ftrace: Fix trace header alignment (Mike Galbraith)
- sched: Add support for lazy preemption (Thomas Gleixner)
- lockdep: selftest: fix warnings due to missing PREEMPT_RT conditionals (Josh Cartwright)
- lockdep: selftest: Only do hardirq context test for raw spinlock (Yong Zhang)
- net: Add a mutex around devnet_rename_seq (Sebastian Andrzej Siewior)
- net: netfilter: Serialize xt_write_recseq sections on RT (Thomas Gleixner)
- net/core: protect users of napi_alloc_cache against reentrance (Sebastian Andrzej Siewior)
- net: Another local_irq_disable/kmalloc headache (Thomas Gleixner)
- net: Remove preemption disabling in netif_rx() (Priyanka Jain)
- hotplug: duct-tape RT-rwlock usage for non-RT (Sebastian Andrzej Siewior)
- sched: Allow pinned user tasks to be awakened to the CPU they pinned (Mike Galbraith)
- cpu/hotplug: Implement CPU pinning (Thomas Gleixner)
- random: avoid preempt_disable()ed section (Sebastian Andrzej Siewior)
- random: Make it work on rt (Thomas Gleixner)
- x86: stackprotector: Avoid random pool on rt (Thomas Gleixner)
- panic: skip get_random_bytes for RT_FULL in init_oops_id (Thomas Gleixner)
- crypto: cryptd - add a lock instead preempt_disable/local_bh_disable (Sebastian Andrzej Siewior)
- crypto: scompress - serialize RT percpu scratch buffer access with a local lock (Mike Galbraith)
- crypto: limit more FPU-enabled sections (Sebastian Andrzej Siewior)
- crypto: Reduce preempt disabled regions, more algos (Sebastian Andrzej Siewior)
- x86: crypto: Reduce preempt disabled regions (Peter Zijlstra)
- scsi/fcoe: Make RT aware. (Thomas Gleixner)
- arm: Enable highmem for rt (Thomas Gleixner)
- arm/highmem: Flush tlb on unmap (Sebastian Andrzej Siewior)
- x86/highmem: Add a "already used pte" check (Sebastian Andrzej Siewior)
- mm, rt: kmap_atomic scheduling (Peter Zijlstra)
- sysfs: Add /sys/kernel/realtime entry (Clark Williams)
- kgdb/serial: Short term workaround (Jason Wessel)
- arm64: fpsimd: use preemp_disable in addition to local_bh_disable() (Sebastian Andrzej Siewior)
- KVM: arm/arm64: downgrade preempt_disable()d region to migrate_disable() (Josh Cartwright)
- genirq: update irq_set_irqchip_state documentation (Josh Cartwright)
- ARM: enable irq in translation/section permission fault handlers ("Yadi.hu")
- printk: Drop the logbuf_lock more often (Sebastian Andrzej Siewior)
- kernel/printk: Don't try to print from IRQ/NMI region (Sebastian Andrzej Siewior)
- printk: Make rt aware (Thomas Gleixner)
- irqwork: push most work into softirq context (Sebastian Andrzej Siewior)
- net: Have __napi_schedule_irqoff() disable interrupts on RT (Steven Rostedt)
- net: add a lock around icmp_sk() (Sebastian Andrzej Siewior)
- net: add back the missing serialization in ip_send_unicast_reply() (Sebastian Andrzej Siewior)
- net/Qdisc: use a seqlock instead seqcount (Sebastian Andrzej Siewior)
- net: dev: always take qdisc's busylock in __dev_xmit_skb() (Sebastian Andrzej Siewior)
- net: provide a way to delegate processing a softirq to ksoftirqd (Sebastian Andrzej Siewior)
- net: move xmit_recursion to per-task variable on -RT (Sebastian Andrzej Siewior)
- net: Use skbufhead with raw lock (Thomas Gleixner)
- sunrpc: Make svc_xprt_do_enqueue() use get_cpu_light() (Mike Galbraith)
- seqlock: Prevent rt starvation (Thomas Gleixner)
- debugobjects: Make RT aware (Thomas Gleixner)
- sched: Distangle worker accounting from rqlock (Thomas Gleixner)
- workqueue: Prevent workqueue versus ata-piix livelock (Thomas Gleixner)
- workqueue: Use local irq lock instead of irq disable regions (Thomas Gleixner)
- workqueue: Use normal rcu (Thomas Gleixner)
- fs/dcache: use swait_queue instead of waitqueue (Sebastian Andrzej Siewior)
- net: Use cpu_chill() instead of cpu_relax() (Thomas Gleixner)
- fs: dcache: Use cpu_chill() in trylock loops (Thomas Gleixner)
- block: Use cpu_chill() for retry loops (Thomas Gleixner)
- block: blk-mq: move blk_queue_usage_counter_release() into process context (Sebastian Andrzej Siewior)
- hrtimer: cpu_chill(): save task state in ->saved_state() (Sebastian Andrzej Siewior)
- hrtimer: Don't lose state in cpu_chill() (Sebastian Andrzej Siewior)
- rt: Introduce cpu_chill() (Thomas Gleixner)
- md: raid5: Make raid5_percpu handling RT aware (Thomas Gleixner)
- block/mq: don't complete requests via IPI (Sebastian Andrzej Siewior)
- block/mq: do not invoke preempt_disable() (Sebastian Andrzej Siewior)
- block: mq: use cpu_light() (Sebastian Andrzej Siewior)
- mm/vmalloc: Another preempt disable region which sucks (Thomas Gleixner)
- fs/epoll: Do not disable preemption on RT (Thomas Gleixner)
- x86/fpu: Disable preemption around local_bh_disable() (Sebastian Andrzej Siewior)
- thermal: Defer thermal wakups to threads (Daniel Wagner)
- squashfs: make use of local lock in multi_cpu decompressor (Julia Cartwright)
- fs/dcache: disable preemption on i_dir_seq's write side (Sebastian Andrzej Siewior)
- fs/dcache: bring back explicit INIT_HLIST_BL_HEAD init (Sebastian Andrzej Siewior)
- mm: Protect activate_mm() by preempt_[disable&enable]_rt() (Yong Zhang)
- locking/percpu-rwsem: Remove preempt_disable variants (Peter Zijlstra)
- tty: serial: 8250: don't take the trylock during oops (Sebastian Andrzej Siewior)
- rt: Improve the serial console PASS_LIMIT (Ingo Molnar)
- tty: serial: pl011: explicitly initialize the flags variable (Kurt Kanzenbach)
- tty/serial/pl011: Make the locking work on RT (Thomas Gleixner)
- tty/serial/omap: Make the locking RT aware (Thomas Gleixner)
- rcu: enable rcu_normal_after_boot by default for RT (Julia Cartwright)
- srcu: replace local_irqsave() with a locallock (Sebastian Andrzej Siewior)
- srcu: use cpu_online() instead custom check (Sebastian Andrzej Siewior)
- rcu: Eliminate softirq processing from rcutree ("Paul E. McKenney")
- rcu: Make ksoftirqd do RCU quiescent states ("Paul E. McKenney")
- rcu: Merge RCU-bh into RCU-preempt (Thomas Gleixner)
- rcu: Frob softirq test (Peter Zijlstra)
- locking: don't check for __LINUX_SPINLOCK_TYPES_H on -RT archs (Sebastian Andrzej Siewior)
- sched/migrate_disable: fallback to preempt_disable() instead barrier() (Sebastian Andrzej Siewior)
- rtmutex: annotate sleeping lock context (Sebastian Andrzej Siewior)
- ptrace: fix ptrace vs tasklist_lock race (Sebastian Andrzej Siewior)
- locking/rtmutex: re-init the wait_lock in rt_mutex_init_proxy_locked() (Sebastian Andrzej Siewior)
- locking/rt-mutex: Flush block plug on __down_read() (Scott Wood)
- locking/rt-mutex: fix deadlock in device mapper / block-IO (Mikulas Patocka)
- kconfig: Add PREEMPT_RT_FULL (Thomas Gleixner)
- rtmutex: add ww_mutex addon for mutex-rt (Sebastian Andrzej Siewior)
- rtmutex: wire up RT's locking (Thomas Gleixner)
- rtmutex/rwlock: preserve state like a sleeping lock (Sebastian Andrzej Siewior)
- rtmutex: add rwlock implementation based on rtmutex (Thomas Gleixner)
- rtmutex: add rwsem implementation based on rtmutex (Thomas Gleixner)
- rtmutex: add mutex implementation based on rtmutex (Thomas Gleixner)
- rtmutex: add sleeping lock implementation (Thomas Gleixner)
- rtmutex: export lockdep-less version of rt_mutex's lock, trylock and unlock (Thomas Gleixner)
- rtmutex: Provide rt_mutex_slowlock_locked() (Thomas Gleixner)
- rbtree: don't include the rcu header (Sebastian Andrzej Siewior)
- rtmutex: Avoid include hell (Thomas Gleixner)
- spinlock: Split the lock types header (Thomas Gleixner)
- rtmutex: Make lock_killable work (Thomas Gleixner)
- rtmutex: Add rtmutex_lock_killable() (Thomas Gleixner)
- locking: locktorture: Do NOT include rwlock.h directly ("Wolfgang M. Reimer")
- arm: include definition for cpumask_t (Sebastian Andrzej Siewior)
- pid.h: include atomic.h (Grygorii Strashko)
- futex: Ensure lock/unlock symetry versus pi_lock and hash bucket lock (Thomas Gleixner)
- futex: Fix bug on when a requeued RT task times out (Steven Rostedt)
- rtmutex: Handle the various new futex race conditions (Thomas Gleixner)
- fs/nfs: turn rmdir_sem into a semaphore (Sebastian Andrzej Siewior)
- rtmutex: trylock is okay on -RT (Sebastian Andrzej Siewior)
- softirq: Avoid "local_softirq_pending" messages if task is in cpu_chill() (Sebastian Andrzej Siewior)
- softirq: Avoid "local_softirq_pending" messages if ksoftirqd is blocked (Sebastian Andrzej Siewior)
- softirq: split timer softirqs out of ksoftirqd (Sebastian Andrzej Siewior)
- genirq: Allow disabling of softirq processing in irq thread context (Thomas Gleixner)
- net/core: use local_bh_disable() in netif_rx_ni() (Sebastian Andrzej Siewior)
- softirq: Split softirq locks (Thomas Gleixner)
- softirq: Disable softirq stacks for RT (Thomas Gleixner)
- softirq: Check preemption after reenabling interrupts (Thomas Gleixner)
- tasklet: Prevent tasklets from going into infinite spin in RT (Ingo Molnar)
- lockdep: Make it RT aware (Thomas Gleixner)
- trace: Add migrate-disabled counter to tracing output (Thomas Gleixner)
- hotplug: Lightweight get online cpus (Thomas Gleixner)
- rt: Increase/decrease the nr of migratory tasks when enabling/disabling migration (Daniel Bristot de Oliveira)
- sched/workqueue: Only wake up idle workers if not blocked on sleeping spin lock (Steven Rostedt)
- sched: Disable TTWU_QUEUE on RT (Thomas Gleixner)
- sched: Use the proper LOCK_OFFSET for cond_resched() (Thomas Gleixner)
- sched: Do not account rcu_preempt_depth on RT in might_sleep() (Thomas Gleixner)
- sched: Add saved_state for tasks blocked on sleeping locks (Thomas Gleixner)
- kernel/sched: move stack + kprobe clean up to __put_task_struct() (Sebastian Andrzej Siewior)
- sched: Move mmdrop to RCU on RT (Thomas Gleixner)
- sched: Limit the number of task migrations per batch (Thomas Gleixner)
- sched: Move task_struct cleanup to RCU (Thomas Gleixner)
- posix-timers: Thread posix-cpu-timers on -rt (John Stultz)
- hrtimer: move state change before hrtimer_cancel in do_nanosleep() (Sebastian Andrzej Siewior)
- hrtimer: Move schedule_work call to helper thread (Yang Shi)
- sched/fair: Make the hrtimers non-hard again (Sebastian Andrzej Siewior)
- hrtimer: by timers by default into the softirq context (Sebastian Andrzej Siewior)
- hrtimers: Prepare full preemption (Ingo Molnar)
- hrtimer: consolidate hrtimer_init() + hrtimer_init_sleeper() calls (Sebastian Andrzej Siewior)
- time/hrtimer: avoid schedule_work() with interrupts disabled (Sebastian Andrzej Siewior)
- genirq: Do not invoke the affinity callback via a workqueue on RT (Sebastian Andrzej Siewior)
- fs/aio: simple simple work (Sebastian Andrzej Siewior)
- completion: Use simple wait queues (Thomas Gleixner)
- work-simple: drop a shift statement in SWORK_EVENT_PENDING (Sebastian Andrzej Siewior)
- work-simple: Simple work queue implemenation (Daniel Wagner)
- wait.h: include atomic.h (Sebastian Andrzej Siewior)
- pci/switchtec: Don't use completion's wait queue (Sebastian Andrzej Siewior)
- x86: kvm Require const tsc for RT (Thomas Gleixner)
- timers: Prepare for full preemption (Ingo Molnar)
- radix-tree: use local locks (Sebastian Andrzej Siewior)
- x86/mm/pat: disable preemption __split_large_page() after spin_lock() (Sebastian Andrzej Siewior)
- mm/zsmalloc: copy with get_cpu_var() and locking (Mike Galbraith)
- mm/memcontrol: Replace local_irq_disable with local locks (Sebastian Andrzej Siewior)
- mm/memcontrol: Don't call schedule_work_on in preemption disabled context (Yang Shi)
- slub: Disable SLUB_CPU_PARTIAL (Sebastian Andrzej Siewior)
- slub: Enable irqs for __GFP_WAIT (Thomas Gleixner)
- mm: Enable SLUB for RT (Thomas Gleixner)
- ARM: Initialize split page table locks for vector page (Frank Rowand)
- mm/vmstat: Protect per cpu variables with preempt disable on RT (Ingo Molnar)
- mm: perform lru_add_drain_all() remotely (Luiz Capitulino)
- mm/swap: Convert to percpu locked (Ingo Molnar)
- mm: page_alloc: rt-friendly per-cpu pages (Ingo Molnar)
- mm/SLUB: delay giving back empty slubs to IRQ enabled regions (Thomas Gleixner)
- mm/SLxB: change list_lock to raw_spinlock_t (Thomas Gleixner)
- Split IRQ-off and zone->lock while freeing pages from PCP list #2 (Peter Zijlstra)
- Split IRQ-off and zone->lock while freeing pages from PCP list #1 (Peter Zijlstra)
- genirq: Force interrupt thread on RT (Thomas Gleixner)
- genirq: Disable irqpoll on -rt (Ingo Molnar)
- list_bl: fixup bogus lockdep warning (Josh Cartwright)
- list_bl: Make list head locking RT safe (Paul Gortmaker)
- fs: jbd/jbd2: Make state lock and journal head lock rt safe (Thomas Gleixner)
- buffer_head: Replace bh_uptodate_lock for -rt (Thomas Gleixner)
- x86/signal: delay calling signals on 32bit (Yang Shi)
- signal/x86: Delay calling signals in atomic (Oleg Nesterov)
- mm/scatterlist: Do not disable irqs on RT (Thomas Gleixner)
- locallock: provide {get,put}_locked_ptr() variants (Julia Cartwright)
- rt: Add local irq locks (Thomas Gleixner)
- futex: workaround migrate_disable/enable in different context (Thomas Gleixner)
- preempt: Provide preempt_*_(no)rt variants (Thomas Gleixner)
- printk: Add "force_early_printk" boot param to help with debugging (Peter Zijlstra)
- printk: Add a printk kill switch (Ingo Molnar)
- efi: Disable runtime services on RT (Sebastian Andrzej Siewior)
- md: disable bcache (Sebastian Andrzej Siewior)
- cpufreq: drop K8's driver from beeing selected (Sebastian Andrzej Siewior)
- leds: trigger: disable CPU trigger on -RT (Sebastian Andrzej Siewior)
- x86: Use generic rwsem_spinlocks on -rt (Thomas Gleixner)
- mips: Disable highmem on RT (Thomas Gleixner)
- powerpc: Disable highmem on RT (Thomas Gleixner)
- powerpc/kvm: Disable in-kernel MPIC emulation for PREEMPT_RT_FULL (Bogdan Purcareata)
- powerpc: Use generic rwsem on RT (Thomas Gleixner)
- arm*: disable NEON in kernel mode (Sebastian Andrzej Siewior)
- net/core: disable NET_RX_BUSY_POLL (Sebastian Andrzej Siewior)
- sched: Disable CONFIG_RT_GROUP_SCHED on RT (Thomas Gleixner)
- rcu: make RCU_BOOST default on RT (Sebastian Andrzej Siewior)
- rcu: Disable RCU_FAST_NO_HZ on RT (Thomas Gleixner)
- locking: Disable spin on owner for RT (Thomas Gleixner)
- mm: Allow only slub on RT (Ingo Molnar)
- lockdep: disable self-test (Sebastian Andrzej Siewior)
- kconfig: Disable config options which are not RT compatible (Thomas Gleixner)
- jump-label: disable if stop_machine() is used (Thomas Gleixner)
- cpumask: Disable CONFIG_CPUMASK_OFFSTACK for RT (Thomas Gleixner)
- rt: Provide PREEMPT_RT_BASE config switch (Thomas Gleixner)
- usb: do no disable interrupts in giveback (Sebastian Andrzej Siewior)
- net: sched: Use msleep() instead of yield() (Marc Kleine-Budde)
- signal: Revert ptrace preempt magic (Thomas Gleixner)
- timekeeping: Split jiffies seqlock (Thomas Gleixner)
- clocksource: TCLIB: Allow higher clock rates for clock events (Benedikt Spranger)
- arm: at91: do not disable/enable clocks in a row (Sebastian Andrzej Siewior)
- sched/migrate_disable: Add export_symbol_gpl for __migrate_disabled (Sebastian Andrzej Siewior)
- kernel/sched/core: add migrate_disable() (Sebastian Andrzej Siewior)
- kernel: sched: Provide a pointer to the valid CPU mask (Sebastian Andrzej Siewior)
- NFSv4: replace seqcount_t with a seqlock_t (Sebastian Andrzej Siewior)
- kmemleak: Turn kmemleak_lock to raw spinlock on RT (He Zhe)
- EXP rcu: Revert expedited GP parallelization cleverness ("Paul E. McKenney")
- mm/kasan: make quarantine_lock a raw_spinlock_t (Clark Williams)
- arm64: KVM: compute_layout before altenates are applied (Sebastian Andrzej Siewior)
- x86/efi: drop task_lock() from efi_switch_mm() (Sebastian Andrzej Siewior)
- efi: Allow efi=runtime (Sebastian Andrzej Siewior)
- percpu: include irqflags.h for raw_local_irq_save() (Sebastian Andrzej Siewior)
- Drivers: hv: vmbus: include header for get_irq_regs() (Sebastian Andrzej Siewior)
- fscache: initialize cookie hash table raw spinlocks (Clark Williams)
- cgroup: use irqsave in cgroup_rstat_flush_locked() (Sebastian Andrzej Siewior)
- arm/unwind: use a raw_spin_lock (Sebastian Andrzej Siewior)
- arm: kprobe: replace patch_lock to raw lock (Yang Shi)
- x86/ioapic: Don't let setaffinity unmask threaded EOI interrupt too early (Thomas Gleixner)
- arm: Convert arm boot_lock to raw (Frank Rowand)
- sched/fair: Robustify CFS-bandwidth timer locking (Peter Zijlstra)
- crypto: caam/qi - simplify CGR allocation, freeing (=?UTF-8?q?Horia=20Geant=C4=83?=)
- kthread: convert worker lock to raw spinlock (Julia Cartwright)
- ARM: configs: at91: unselect PIT (Alexandre Belloni)
- ARM: configs: at91: use new TCB timer driver (Alexandre Belloni)
- ARM: at91: Implement clocksource selection (Alexandre Belloni)
- clocksource/drivers: atmel-pit: make option silent (Alexandre Belloni)
- clocksource/drivers: timer-atmel-tcb: add clockevent device on separate channel (Alexandre Belloni)
- clocksource/drivers: Add a new driver for the Atmel ARM TC blocks (Alexandre Belloni)
- ARM: at91: add TCB registers definitions (Alexandre Belloni)
- mm: workingset: make shadow_lru_isolate() use locking suffix (Sebastian Andrzej Siewior)
- mm: workingset: remove local_irq_disable() from count_shadow_nodes() (Sebastian Andrzej Siewior)
- iommu/amd: Remove redundant WARN_ON() (Anna-Maria Gleixner)
- mm/list_lru: introduce list_lru_shrink_walk_irq() (Sebastian Andrzej Siewior)
- mm/list_lru.c: pass struct list_lru_node* as an argument to __list_lru_walk_one() (Sebastian Andrzej Siewior)
- mm/list_lru.c: move locking from __list_lru_walk_one() to its caller (Sebastian Andrzej Siewior)
- mm/list_lru.c: use list_lru_walk_one() in list_lru_walk_node() (Sebastian Andrzej Siewior)
- userns: use irqsave variant of refcount_dec_and_lock() (Anna-Maria Gleixner)
- userns: use refcount_t for reference counting instead atomic_t (Sebastian Andrzej Siewior)
- bdi: use irqsave variant of refcount_dec_and_lock() (Anna-Maria Gleixner)
- bdi: use refcount_t for reference counting instead atomic_t (Sebastian Andrzej Siewior)
- random: remove preempt disabled region (Ingo Molnar)
- printk: Remove unnecessary kmalloc() from syslog during clear (Namit Gupta)
- x86/fpu: Disable bottom halves while loading FPU registers (Sebastian Andrzej Siewior)
- Revert "[documentation] doc: Add design documentation on interruption of NMI handlers" (Juri Lelli)
- Revert "[documentation] doc: Fix broken RCU-requirements link to LKML archive" (Juri Lelli)
- Revert "[documentation] doc: Improve rcu_dynticks::dynticks documentation" (Juri Lelli)
- Revert "[tools] torture: Stop overwriting Make.out file with obsolete version" (Juri Lelli)
- Revert "[kernel] rcutorture: Force occasional reader waits" (Juri Lelli)
- Revert "[kernel] rcutorture: Warn on bad torture type for built-in tests" (Juri Lelli)
- Revert "[kernel] rcuperf: Warn on bad perf type for built-in tests" (Juri Lelli)
- Revert "[tools] rcutorture: Remove TREE06 and TREE08 from the default test list" (Juri Lelli)
- Revert "[kernel] rcutorture: Add forward-progress tests for RCU grace periods" (Juri Lelli)
- Revert "[kernel] rcutorture: Also use GP sequence to judge forward progress" (Juri Lelli)
- Revert "[kernel] rcutorture: Avoid no-test complaint if too few forward-progress tries" (Juri Lelli)
- Revert "[kernel] rcutorture: Vary forward-progress test interval" (Juri Lelli)
- Revert "[kernel] rcutorture: Add self-propagating callback to forward-progress testing" (Juri Lelli)
- Revert "[kernel] rcutorture: Increase rcu_read_delay() longdelay_ms" (Juri Lelli)
- Revert "[kernel] rcutorture: Limit reader duration if irq or bh disabled" (Juri Lelli)
- Revert "[kernel] rcutorture: Reduce priority of forward-progress testing" (Juri Lelli)
- Revert "[kernel] rcutorture: Adjust number of reader kthreads per CPU-hotplug operations" (Juri Lelli)
- Revert "[kernel] rcutorture: Print forward-progress test interval on error" (Juri Lelli)
- Revert "[kernel] rcutorture: Check GP completion at stutter end" (Juri Lelli)
- Revert "[kernel] rcutorture: Maintain self-propagating CB only during forward-progress test" (Juri Lelli)
- Revert "[documentation] doc: Update removal of RCU-bh/sched update machinery" (Juri Lelli)
- Revert "[documentation] doc: Fix broken HTML directive" (Juri Lelli)
- Revert "[kernel] rcu: Refactor rcu_{nmi,irq}_{enter,exit}()" (Juri Lelli)
- Revert "[kernel] rcu: Defer reporting RCU-preempt quiescent states when disabled" (Juri Lelli)
- Revert "[kernel] rcutorture: Test extended "rcu" read-side critical sections" (Juri Lelli)
- Revert "[kernel] rcu: Allow processing deferred QSes for exiting RCU-preempt readers" (Juri Lelli)
- Revert "[kernel] rcu: Remove now-unused ->b.exp_need_qs field from the rcu_special union" (Juri Lelli)
- Revert "[kernel] rcu: Add warning to detect half-interrupts" (Juri Lelli)
- Revert "[kernel] rcu: Apply RCU-bh QSes to RCU-sched and RCU-preempt when safe" (Juri Lelli)
- Revert "[kernel] rcu: Report expedited grace periods at context-switch time" (Juri Lelli)
- Revert "[kernel] rcu: Define RCU-bh update API in terms of RCU" (Juri Lelli)
- Revert "[kernel] rcu: Update comments and help text for no more RCU-bh updaters" (Juri Lelli)
- Revert "[kernel] rcu: Drop "wake" parameter from rcu_report_exp_rdp()" (Juri Lelli)
- Revert "[kernel] rcu: Fix typo in rcu_get_gp_kthreads_prio() header comment" (Juri Lelli)
- Revert "[kernel] rcu: Define RCU-sched API in terms of RCU for Tree RCU PREEMPT builds" (Juri Lelli)
- Revert "[kernel] rcu: Express Tiny RCU updates in terms of RCU rather than RCU-sched" (Juri Lelli)
- Revert "[kernel] rcu: Remove RCU_STATE_INITIALIZER()" (Juri Lelli)
- Revert "[kernel] rcu: Eliminate rcu_state structure's ->call field" (Juri Lelli)
- Revert "[kernel] rcu: Remove rcu_state structure's ->rda field" (Juri Lelli)
- Revert "[kernel] rcu: Remove rcu_state_p pointer to default rcu_state structure" (Juri Lelli)
- Revert "[kernel] rcu: Remove rcu_data_p pointer to default rcu_data structure" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_report_qs_rnp()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_report_qs_rsp()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_report_unblock_qs_rnp()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_report_qs_rdp()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_gp_in_progress()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_get_root()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from record_gp_stall_check_time()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_check_gp_kthread_starvation()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_dump_cpu_stacks()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_stall_kick_kthreads()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from print_other_cpu_stall()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from print_cpu_stall()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from check_cpu_stall()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_future_gp_cleanup()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_gp_kthread_wake()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_accelerate_cbs()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_accelerate_cbs_unlocked()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_advance_cbs()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from __note_gp_changes()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from note_gp_changes()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_gp_slow()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_gp_kthread() and friends" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_check_quiescent_state()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from CPU hotplug functions" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_do_batch()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from force-quiescent-state functions" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_check_gp_start_stall()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from __rcu_process_callbacks()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from __call_rcu() and friend" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from __rcu_pending()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from _rcu_barrier() and friends" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_boot_init_percpu_data() and friends" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_init_one() and friends" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_print_detail_task_stall()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from dump_blkd_tasks() and friend" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_spawn_one_boost_kthread()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from print_cpu_stall_info()" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from no-CBs CPU functions" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from expedited grace-period functions" (Juri Lelli)
- Revert "[kernel] rcu: Remove rsp parameter from rcu_node tree accessor macros" (Juri Lelli)
- Revert "[kernel] rcu: Remove rcu_data structure's ->rsp field" (Juri Lelli)
- Revert "[kernel] rcu: Remove last non-flavor-traversal rsp local variable from tree_plugin.h" (Juri Lelli)
- Revert "[kernel] rcu: Remove for_each_rcu_flavor() flavor-traversal macro" (Juri Lelli)
- Revert "[kernel] rcu: Simplify rcutorture_get_gp_data()" (Juri Lelli)
- Revert "[kernel] rcu: Restructure rcu_check_gp_kthread_starvation()" (Juri Lelli)
- Revert "[kernel] rcu: Eliminate stall-warning use of rsp" (Juri Lelli)
- Revert "[kernel] rcu: Eliminate grace-period management code use of rsp" (Juri Lelli)
- Revert "[kernel] rcu: Eliminate callback-invocation/invocation use of rsp" (Juri Lelli)
- Revert "[kernel] rcu: Eliminate quiescent-state and grace-period-nonstart use of rsp" (Juri Lelli)
- Revert "[kernel] rcu: Eliminate RCU-barrier use of rsp" (Juri Lelli)
- Revert "[kernel] rcu: Eliminate initialization-time use of rsp" (Juri Lelli)
- Revert "[kernel] rcu: Fix typo in force_qs_rnp()'s parameter's parameter" (Juri Lelli)
- Revert "[kernel] rcu: Inline increment_cpu_stall_ticks() into its sole caller" (Juri Lelli)
- Revert "[kernel] rcu: Pull rcu_gp_kthread() FQS loop into separate function" (Juri Lelli)
- Revert "[kernel] rcu: Consolidate RCU-bh update-side function definitions" (Juri Lelli)
- Revert "[kernel] rcu: Consolidate RCU-sched update-side function definitions" (Juri Lelli)
- Revert "[kernel] rcutorture: Add RCU-bh and RCU-sched support for extended readers" (Juri Lelli)
- Revert "[kernel] rcu: Stop testing RCU-bh and RCU-sched" (Juri Lelli)
- Revert "[kernel] rcutorture: Remove the "rcu_bh" and "sched" torture types" (Juri Lelli)
- Revert "[kernel] rcuperf: Remove the "rcu_bh" and "sched" torture types" (Juri Lelli)
- Revert "[kernel] rcu: Remove now-unused rcutorture APIs" (Juri Lelli)
- Revert "[kernel] rcu: Clean up flavor-related definitions and comments in rcupdate.h" (Juri Lelli)
- Revert "[kernel] rcu: Clean up flavor-related definitions and comments in rculist.h" (Juri Lelli)
- Revert "[kernel] rcu: Clean up flavor-related definitions and comments in rcupdate_wait.h" (Juri Lelli)
- Revert "[kernel] rcu: Clean up flavor-related definitions and comments in Kconfig" (Juri Lelli)
- Revert "[kernel] rcu: Clean up flavor-related definitions and comments in rcu.h" (Juri Lelli)
- Revert "[kernel] rcu: Clean up flavor-related definitions and comments in rcutorture.c" (Juri Lelli)
- Revert "[kernel] rcu: Clean up flavor-related definitions and comments in srcutree.h" (Juri Lelli)
- Revert "[kernel] rcu: Clean up flavor-related definitions and comments in tiny.c" (Juri Lelli)
- Revert "[kernel] rcu: Clean up flavor-related definitions and comments in tree.c" (Juri Lelli)
- Revert "[kernel] rcu: Clean up flavor-related definitions and comments in tree_exp.h" (Juri Lelli)
- Revert "[kernel] rcu: Clean up flavor-related definitions and comments in tree_plugin.h" (Juri Lelli)
- Revert "[kernel] rcu: Clean up flavor-related definitions and comments in update.c" (Juri Lelli)
- Revert "[kernel] rcu: Remove !PREEMPT code from rcu_note_voluntary_context_switch()" (Juri Lelli)
- Revert "[kernel] rcu: Define rcu_all_qs() only in !PREEMPT builds" (Juri Lelli)
- Revert "[kernel] rcu: Inline _rcu_barrier() into its sole remaining caller" (Juri Lelli)
- Revert "[kernel] rcu: Make need_resched() respond to urgent RCU-QS needs" (Juri Lelli)
- Revert "[kernel] rcu: Provide improved interrupt-from-idle check in rcu_check_callbacks()" (Juri Lelli)
- Revert "[kernel] rcutorture: Dump reader protection sequence if failures or close calls" (Juri Lelli)
- Revert "[kernel] rcu: Motivate Tiny RCU forward progress" (Juri Lelli)
- Revert "[kernel] rcu: Eliminate ->rcu_qs_ctr from the rcu_dynticks structure" (Juri Lelli)
- Revert "[kernel] rcu: Provide functions for determining if call_rcu() has been invoked" (Juri Lelli)
- Revert "[kernel] rcu: Compute jiffies_till_sched_qs from other kernel parameters" (Juri Lelli)
- Revert "[kernel] rcu: More aggressively enlist scheduler aid for nohz_full CPUs" (Juri Lelli)
- Revert "[kernel] rcu: Avoid resched_cpu() when rescheduling the current CPU" (Juri Lelli)
- Revert "[kernel] rcu: Convert "1UL << x" to "BIT(x)"" (Juri Lelli)
- Revert "[kernel] rcu: Remove unused rcu_dynticks_snap() from Tiny RCU" (Juri Lelli)
- Revert "[kernel] rcu: Merge rcu_dynticks structure into rcu_data structure" (Juri Lelli)
- Revert "[kernel] rcu: Switch ->tick_nohz_enabled_snap to rcu_data structure" (Juri Lelli)
- Revert "[kernel] rcu: Switch last accelerate/advance to rcu_data structure" (Juri Lelli)
- Revert "[kernel] rcu: Switch lazy counts to rcu_data structure" (Juri Lelli)
- Revert "[kernel] rcu: Switch urgent quiescent-state requests to rcu_data structure" (Juri Lelli)
- Revert "[kernel] rcu: Switch dyntick nesting counters to rcu_data structure" (Juri Lelli)
- Revert "[kernel] rcu: Switch ->dynticks to rcu_data structure, remove rcu_dynticks" (Juri Lelli)
- Revert "[kernel] rcu: Remove obsolete ->dynticks_fqs and ->cond_resched_completed" (Juri Lelli)
- Revert "[kernel] rcu: Convert rcu_state.ofl_lock to raw_spinlock_t" (Juri Lelli)
- Revert "[kernel] srcu: Make call_srcu() available during very early boot" (Juri Lelli)
- Revert "[tools] rcutorture: Test early boot call_srcu()" (Juri Lelli)
- Revert "[kernel] srcu: Make early-boot call_srcu() reuse workqueue lists" (Juri Lelli)

* Tue Mar 26 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.5.el8]
- [x86] x86/hyperv: Fix kernel panic when kexec on HyperV (Kairui Song) [1684451]
- [rpmspec] apply linux-kernel-test.patch when building ("Herton R. Krzesinski") [1690534]
- [netdrv] net: ena: update driver version from 2.0.2 to 2.0.3 (John Linville) [1690106]
- [netdrv] net: ena: fix race between link up and device initalization (John Linville) [1690106]
- [netdrv] net: phy: add phy_speed_down and phy_speed_up (Petr Oros) [1690131]
- [netdrv] net: phy: add helper phy_config_aneg (Petr Oros) [1690131]
- [nvme] nvme-fabrics: convert to SPDX identifiers (Ewan Milne) [1690909]
- [nvme] nvme-fabrics: fix ctrl_loss_tmo < 0 to reconnect forever (Ewan Milne) [1690909]
- [nvme] nvme-fc: reject reconnect if io queue count is reduced to zero (Ewan Milne) [1690601]
- [nvme] nvme-fc: use nr_phys_segments to determine existence of sgl (Ewan Milne) [1690601]
- [include] nvme-fc: convert to SPDX identifiers (Ewan Milne) [1690601]
- [nvme] nvme-fc: initialize nvme_req(rq)->ctrl after calling __nvme_fc_init_request() (Ewan Milne) [1690601]
- [nvme] nvme-fc: fix request private initialization (Ewan Milne) [1690601]
- [nvme] nvme-fc: rework the request initialization code (Ewan Milne) [1690601]
- [nvme] nvme-fc: introduce struct nvme_fcp_op_w_sgl (Ewan Milne) [1690601]
- [nvme] nvme: cache struct nvme_ctrl reference to struct nvme_request (Ewan Milne) [1690601]
- [nvme] nvme-fc: fix kernel-doc headers (Ewan Milne) [1690601]
- [nvme] nvme_fc: add 'nvme_discovery' sysfs attribute to fc transport device (Ewan Milne) [1690601]
- [nvme] nvme-fc: fix for a minor typos (Ewan Milne) [1690601]
- [crypto] crypto: arm64/aes-ccm - fix logical bug in AAD MAC handling (Neil Horman) [1689185]
- [mm] mm: enforce min addr even if capable() in expand_downwards() (Rafael Aquini) [1687667] {CVE-2019-9213}
- [pci] PCI/VMD: Configure MPS settings before adding devices (Prarit Bhargava) [1659270]
- [pci] PCI: vmd: Detach resources after stopping root bus (Prarit Bhargava) [1659270]
- [char] tpm: separate cmd_ready/go_idle from runtime_pm (Jerry Snitselaar) [1677735]
- [block] loop: set GENHD_FL_NO_PART_SCAN after blkdev_reread_part() (Ming Lei) [1683593]
- [block] loop: do not print warn message if partition scan is successful (Ming Lei) [1683593]
- [block] loop: drop caches if offset or block_size are changed (Ming Lei) [1683593]
- [block] block: loop: remove redundant code (Ming Lei) [1683593]
- [block] block: loop: check error using IS_ERR instead of IS_ERR_OR_NULL in loop_add() (Ming Lei) [1683593]
- [block] loop: Fix double mutex_unlock(&loop_ctl_mutex) in loop_control_ioctl() (Ming Lei) [1683593]
- [block] loop: Get rid of 'nested' acquisition of loop_ctl_mutex (Ming Lei) [1683593]
- [block] loop: Avoid circular locking dependency between loop_ctl_mutex and bd_mutex (Ming Lei) [1683593]
- [block] loop: Fix deadlock when calling blkdev_reread_part() (Ming Lei) [1683593]
- [block] loop: Move loop_reread_partitions() out of loop_ctl_mutex (Ming Lei) [1683593]
- [block] loop: Move special partition reread handling in loop_clr_fd() (Ming Lei) [1683593]
- [block] loop: Push loop_ctl_mutex down to loop_change_fd() (Ming Lei) [1683593]
- [block] loop: Push loop_ctl_mutex down to loop_set_fd() (Ming Lei) [1683593]
- [block] loop: Push loop_ctl_mutex down to loop_set_status() (Ming Lei) [1683593]
- [block] loop: Push loop_ctl_mutex down to loop_get_status() (Ming Lei) [1683593]
- [block] loop: Push loop_ctl_mutex down into loop_clr_fd() (Ming Lei) [1683593]
- [block] loop: Split setting of lo_state from loop_clr_fd (Ming Lei) [1683593]
- [block] loop: Push lo_ctl_mutex down into individual ioctls (Ming Lei) [1683593]
- [block] loop: Get rid of loop_index_mutex (Ming Lei) [1683593]
- [block] loop: Fold __loop_release into loop_release (Ming Lei) [1683593]
- [block] block/loop: Use global lock for ioctl() operation. (Ming Lei) [1683593]
- [block] block/loop: Don't grab "struct file" for vfs_getattr() operation. (Ming Lei) [1683593]
- [crypto] crypto: cfb - fix decryption (Herbert Xu) [1653188]

* Fri Mar 22 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.4.el8]
- [misc] VMCI: Support upto 64-bit PPNs (Cathy Avery) [1683479]
- [mm] mm, page_alloc: fix has_unmovable_pages for HugePages (David Gibson) [1688114]
- [pci] PCI: pciehp: Disable Data Link Layer State Changed event on suspend (Myron Stowe) [1688393 1537397]
- [pci] PCI: pciehp: Assign ctrl->slot_ctrl before writing it to hardware (Myron Stowe) [1688393 1537397]
- [pci] PCI/AER: Queue one GHES event, not several uninitialized ones (Myron Stowe) [1688393 1537397]
- [pci] PCI/AER: Refactor error injection fallbacks (Myron Stowe) [1688393]
- [pci] PCI/AER: Reuse existing pcie_port_find_device() interface (Myron Stowe) [1688393]
- [pci] PCI/AER: Use managed resource allocations (Myron Stowe) [1688393]
- [pci] PCI/AER: Use threaded IRQ for bottom half (Myron Stowe) [1688393]
- [pci] PCI/AER: Use kfifo_in_spinlocked() to insert locked elements (Myron Stowe) [1688393]
- [pci] PCI/AER: Use kfifo for tracking events instead of reimplementing it (Myron Stowe) [1688393]
- [pci] PCI/AER: Remove error source from AER struct aer_rpc (Myron Stowe) [1688393]
- [pci] PCI/AER: Remove unused aer_error_resume() (Myron Stowe) [1688393]
- [pci] PCI: pnv_php: Use kmemdup() (Myron Stowe) [1688393]
- [pci] PCI: cpqphp: Remove set but not used variable 'physical_slot' (Myron Stowe) [1688393]
- [pci] PCI/ERR: Remove duplicated include from err.c (Myron Stowe) [1688393]
- [pci] PCI: Equalize hotplug memory and io for occupied and empty slots (Myron Stowe) [1688393]
- [pci] PCI / ACPI: Whitelist D3 for more PCIe hotplug ports (Myron Stowe) [1688393 1537397]
- [acpi] ACPI / property: Allow multiple property compatible _DSD entries (Myron Stowe) [1688393 1537397]
- [pci] PCI: pciehp: Implement runtime PM callbacks (Myron Stowe) [1688393 1537397]
- [pci] PCI/portdrv: Resume upon exit from system suspend if left runtime suspended (Myron Stowe) [1688393 1537397]
- [pci] PCI: pciehp: Do not handle events if interrupts are masked (Myron Stowe) [1688393 1537397]
- [pci] PCI: pciehp: Disable hotplug interrupt during suspend (Myron Stowe) [1688393 1537397]
- [pci] PCI / ACPI: Enable wake automatically for power managed bridges (Myron Stowe) [1688393 1537397]
- [pci] PCI: Do not skip power-managed bridges in pci_enable_wake() (Myron Stowe) [1688393 1537397]
- [pci] PCI: Unify device inaccessible (Myron Stowe) [1688393]
- [pci] PCI/ERR: Always report current recovery status for udev (Myron Stowe) [1688393]
- [pci] PCI/ERR: Simplify broadcast callouts (Myron Stowe) [1688393]
- [pci] PCI/ERR: Run error recovery callbacks for all affected devices (Myron Stowe) [1688393]
- [pci] PCI/ERR: Handle fatal error recovery (Myron Stowe) [1688393]
- [pci] PCI/ERR: Use slot reset if available (Myron Stowe) [1688393]
- [pci] PCI/AER: Don't read upstream ports below fatal errors (Myron Stowe) [1688393]
- [pci] PCI/AER: Take reference on error devices (Myron Stowe) [1688393]
- [pci] PCI/DPC: Save and restore config state (Myron Stowe) [1688393]
- [pci] PCI: portdrv: Restore PCI config state on slot reset (Myron Stowe) [1688393]
- [pci] PCI: portdrv: Initialize service drivers directly (Myron Stowe) [1688393]
- [x86] x86/intel_rdt: Show missing resctrl mount options (David Arcari) [1689043]
- [xen] xen/balloon: Fix mapping PG_offline pages to user space (David Hildenbrand) [1652790]
- [kernel] PM/Hibernate: exclude all PageOffline() pages (David Hildenbrand) [1652790]
- [kernel] PM/Hibernate: use pfn_to_online_page() (David Hildenbrand) [1652790]
- [hv] hv_balloon: mark inflated pages PG_offline (David Hildenbrand) [1652790]
- [xen] xen/balloon: mark inflated pages PG_offline (David Hildenbrand) [1652790]
- [kernel] kexec: export PG_offline to VMCOREINFO (David Hildenbrand) [1652790]
- [include] mm: convert PG_balloon to PG_offline (David Hildenbrand) [1652790]
- [include] mm: balloon: update comment about isolation/migration/compaction (David Hildenbrand) [1652790]
- [mm] mm/page_alloc.c: memory hotplug: free pages as higher order (David Hildenbrand) [1652790]
- [mm] mm/memory.c: do_fault: avoid usage of stale vm_area_struct ("Herton R. Krzesinski") [1684734]
- [kernel] cpuset: remove unused task_has_mempolicy() (Waiman Long) [1548268]
- [kernel] cpuset: Remove set but not used variable 'cs' (Waiman Long) [1548268]
- [kernel] cgroup: Add .__DEBUG__. prefix to debug file names (Waiman Long) [1548268]
- [kernel] cpuset: Minor cgroup2 interface updates (Waiman Long) [1548268]
- [kernel] cpuset: Expose cpuset.cpus.subpartitions with cgroup_debug (Waiman Long) [1548268]
- [documentation] cpuset: Add documentation about the new "cpuset.sched.partition" flag (Waiman Long) [1548268]
- [kernel] cpuset: Use descriptive text when reading/writing cpuset.sched.partition (Waiman Long) [1548268]
- [kernel] cpuset: Expose cpus.effective and mems.effective on cgroup v2 root (Waiman Long) [1548268]
- [kernel] cpuset: Make generate_sched_domains() work with partition (Waiman Long) [1548268]
- [kernel] cpuset: Make CPU hotplug work with partition (Waiman Long) [1548268]
- [kernel] cpuset: Track cpusets that use parent's effective_cpus (Waiman Long) [1548268]
- [kernel] cpuset: Add an error state to cpuset.sched.partition (Waiman Long) [1548268]
- [kernel] cpuset: Add new v2 cpuset.sched.partition flag (Waiman Long) [1548268]
- [kernel] cpuset: Simply allocation and freeing of cpumasks (Waiman Long) [1548268]
- [kernel] cpuset: Define data structures to support scheduling partition (Waiman Long) [1548268]
- [kernel] cpuset: Enable cpuset controller in default hierarchy (Waiman Long) [1548268]
- [kernel] cgroup/tracing: Move taking of spin lock out of trace event handlers (Waiman Long) [1548268]
- [powerpc] powerpc/powernv/ioda: Fix locked_vm counting for memory used by IOMMU tables (David Gibson) [1674410]
- [pci] PCI: dwc: Fix MSI-X EP framework address calculation bug (Myron Stowe) [1687935]
- [pci] PCI: cadence: Correct probe behaviour when failing to get PHY (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Fix PCI I/O mapping creation sequence (Myron Stowe) [1687935]
- [maintainers] MAINTAINERS: Remove obsolete drivers/pci pattern from ACPI section (Myron Stowe) [1687935]
- [pci] PCI: dwc: Fix scheduling while atomic issues (Myron Stowe) [1687935]
- [maintainers] MAINTAINERS: Move mobiveil PCI driver entry where it belongs (Myron Stowe) [1687935]
- [maintainers] MAINTAINERS: Update PPC contacts for PCI core error handling (Myron Stowe) [1687935]
- [maintainers] MAINTAINERS: Add Gustavo Pimentel as DesignWare PCI maintainer (Myron Stowe) [1687935]
- [maintainers] MAINTAINERS: Add entries for PPC64 RPA PCI hotplug drivers (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Drop bogus comment above mvebu_pcie_map_registers() (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Convert to use pci_host_bridge directly (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Use resource_size() to remap I/O space (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Only remap I/O space if configured (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Fix I/O space end address calculation (Myron Stowe) [1687935]
- [pci] PCI: mvebu: Remove redundant platform_set_drvdata() call (Myron Stowe) [1687935]
- [pci] PCI: mobiveil: Add Kconfig/Makefile entries (Myron Stowe) [1687935]
- [pci] PCI: mobiveil: Add missing ../pci.h include (Myron Stowe) [1687935]
- [pci] PCI: mobiveil: Fix struct mobiveil_pcie.pcie_reg_base address type (Myron Stowe) [1687935]
- [pci] PCI: endpoint: Add MSI set maximum restriction (Myron Stowe) [1687935]
- [tools] tools: PCI: Add MSI-X support (Myron Stowe) [1687935]
- [documentation] pci_endpoint_test: Add 2 ioctl commands (Myron Stowe) [1687935]
- [documentation] pci-epf-test/pci_endpoint_test: Add MSI-X support (Myron Stowe) [1687935]
- [misc] pci-epf-test/pci_endpoint_test: Use irq_type module parameter (Myron Stowe) [1687935]
- [misc] pci-epf-test/pci_endpoint_test: Cleanup PCI_ENDPOINT_TEST memspace (Myron Stowe) [1687935]
- [pci] PCI: dwc: Add legacy interrupt callback handler (Myron Stowe) [1687935]
- [pci] PCI: dwc: Rework MSI callbacks handler (Myron Stowe) [1687935]
- [pci] PCI: dwc: Add MSI-X callbacks handler (Myron Stowe) [1687935]
- [pci] PCI: Update xxx_pcie_ep_raise_irq() and pci_epc_raise_irq() signatures (Myron Stowe) [1687935]
- [pci] PCI: endpoint: Add MSI-X interfaces (Myron Stowe) [1687935]
- [pci] PCI: dwc: Fix EP link notification implementation (Myron Stowe) [1687935]
- [pci] PCI: spear13xx: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: qcom: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: histb: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: designware-plat: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: artpec6: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: armada8k: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: keystone: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: imx6: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: exynos: Drop unnecessary root_bus_nr setting (Myron Stowe) [1687935]
- [pci] PCI: kirin: Add MSI support (Myron Stowe) [1687935]
- [pci] PCI: pcie-cadence-ep: Remove redundant variable mmc (Myron Stowe) [1687935]
- [pci] PCI: cadence: Add shutdown callback to host driver (Myron Stowe) [1687935]
- [pci] PCI: cadence: Add Power Management ops for host and EP (Myron Stowe) [1687935]
- [documentation] dt-bindings: PCI: cadence: Add DT bindings for optional PHYs (Myron Stowe) [1687935]
- [pci] PCI: cadence: Add generic PHY support to host and EP drivers (Myron Stowe) [1687935]
- [pci] PCI: cadence: Update cdns_pcie_writel() function signature (Myron Stowe) [1687935]
- [pci] PCI: aardvark: Convert to use pci_host_probe() (Myron Stowe) [1687935]
- [pci] PCI: aardvark: Size bridges before resources allocation (Myron Stowe) [1687935]
- [pci] PCI: aardvark: Remove PCIe outbound window configuration (Myron Stowe) [1687935]
- [pci] PCI: aardvark: Introduce an advk_pcie_valid_device() helper (Myron Stowe) [1687935]
- [pci] PCI/xilinx: Depend on OF instead of the ARCH (Myron Stowe) [1687935]
- [md] md: convert to kvmalloc (Nigel Croxon) [1661200]
- [md] raid1: simplify raid1_error function (Nigel Croxon) [1661200]
- [md] md-linear: use struct_size() in kzalloc() (Nigel Croxon) [1661200]
- [md] md/raid5: fix 'out of memory' during raid cache recovery (Nigel Croxon) [1661200]
- [md] md: Make bio_alloc_mddev use bio_alloc_bioset (Nigel Croxon) [1661200]
- [md] raid10: refactor common wait code from regular read/write request (Nigel Croxon) [1661200]
- [md] md: remvoe redundant condition check (Nigel Croxon) [1661200]
- [lib] lib/raid6: add option to skip algo benchmarking (Nigel Croxon) [1661200]
- [include] lib/raid6: avoid __attribute_const__ redefinition (Nigel Croxon) [1661200]
- [include] lib/raid6: add missing include for raid6test (Nigel Croxon) [1661200]
- [md] md: remove set but not used variable 'bi_rdev' (Nigel Croxon) [1661200]
- [md] MD: Memory leak when flush bio size is zero (Nigel Croxon) [1661200]
- [md] md: fix memleak for mempool (Nigel Croxon) [1661200]
- [md] md-cluster: remove suspend_info (Nigel Croxon) [1661200]
- [md] md-cluster: send BITMAP_NEEDS_SYNC message if reshaping is interrupted (Nigel Croxon) [1661200]
- [md] md-cluster/bitmap: don't call md_bitmap_sync_with_cluster during reshaping stage (Nigel Croxon) [1661200]
- [md] md-cluster/raid10: don't call remove_and_add_spares during reshaping stage (Nigel Croxon) [1661200]
- [md] md-cluster/raid10: call update_size in md_reap_sync_thread (Nigel Croxon) [1661200]
- [md] md-cluster: introduce resync_info_get interface for sanity check (Nigel Croxon) [1661200]
- [md] md-cluster/raid10: support add disk under grow mode (Nigel Croxon) [1661200]
- [md] md-cluster/raid10: resize all the bitmaps before start reshape (Nigel Croxon) [1661200]
- [md] MD: fix invalid stored role for a disk - try2 (Nigel Croxon) [1661200]
- [md] md/bitmap: use mddev_suspend/resume instead of ->quiesce() (Nigel Croxon) [1661200]
- [md] md: remove redundant code that is no longer reachable (Nigel Croxon) [1661200]
- [md] md: allow metadata updates while suspending an array - fix (Nigel Croxon) [1661200]
- [md] MD: fix invalid stored role for a disk (Nigel Croxon) [1661200]
- [md] md/raid10: Fix raid10 replace hang when new added disk faulty (Nigel Croxon) [1661200]
- [md] raid5: block failing device if raid will be failed (Nigel Croxon) [1661200]
- [md] md-cluster: release RESYNC lock after the last resync message (Nigel Croxon) [1661200]
- [md] RAID10 BUG_ON in raise_barrier when force is true and conf->barrier is 0 (Nigel Croxon) [1661200]
- [md] md/raid5-cache: disable reshape completely (Nigel Croxon) [1661200]
- [md] md/raid5: fix data corruption of replacements after originals dropped (Nigel Croxon) [1661200]
- [md] drivers/md/raid5: Do not disable irq on release_inactive_stripe_list() call (Nigel Croxon) [1661200]
- [md] drivers/md/raid5: Use irqsave variant of atomic_dec_and_lock() (Nigel Croxon) [1661200]
- [md] md/r5cache: remove redundant pointer bio (Nigel Croxon) [1661200]
- [md] md-cluster: don't send msg if array is closing (Nigel Croxon) [1661200]
- [md] md-cluster: show array's status more accurate (Nigel Croxon) [1661200]
- [md] md-cluster: clear another node's suspend_area after the copy is finished (Nigel Croxon) [1661200]
- [powerpc] KVM: PPC: Book3S HV: Add KVM stat largepages_[2M/1G] (Suraj Jitindar Singh) [1581563]
- [tools] perf mem/c2c: Fix perf_mem_events to support powerpc (Steve Best) [1685084]
- [powerpc] powerpc/perf: Add mem access events to sysfs (Steve Best) [1685084]
- [netdrv] net-next/hinic: replace disable_irq_nosync/enable_irq (Xiaojun Tan) [1668958]
- [powerpc] Fix access_ok() fallout for sparc32 and powerpc (Joe Lawrence) [1673980]
- [x86] Remove 'type' argument from access_ok() function (Joe Lawrence) [1673980]
- [arm64] arm64: move untagged_addr macro from uaccess.h to memory.h (Joe Lawrence) [1673980]
- [powerpc] powerpc/uaccess: fix warning/error with access_ok() (Joe Lawrence) [1673980]
- [netdrv] igb: shorten maximum PHC timecounter update interval (Corinna Vinschen) [1637098]
- [netdrv] igb: shorten maximum PHC timecounter update interval (Corinna Vinschen) [1637098]

* Sun Mar 17 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.3.el8]
- [rpmspec] redhat: speed up binary rpm compression (Denys Vlasenko) [1686921]
- [netdrv] net/mlx5e: RX, Verify MPWQE stride size is in range (Alaa Hleihel) [1683589]
- [fs] debugfs: Fix EPERM regression from kernel lockdown check (Lenny Szubowicz) [1686755]
- [infiniband] IB/hfi1: Close race condition on user context disable and close (Alex Estrin) [1682927]
- [rpmspec] redhat: parallelize modules compression (Denys Vlasenko) [1686404]
- [arm64] arm64: Add workaround for Fujitsu A64FX erratum 010001 (Mark Langsdorf) [1666951]
- [s390] vfio_ap: link the vfio_ap devices to the vfio_ap bus subsystem (Cornelia Huck) [1686044]
- [drm] drm/cirrus: fix connector leak at unload (Rob Clark) [1685773]
- [powerpc] powerpc/hugetlb: Handle mmap_min_addr correctly in get_unmapped_area callback (Steve Best) [1685181]
- [netdrv] net/mlx4_en: Force CHECKSUM_NONE for short ethernet frames (Alaa Hleihel) [1663914 1651509]
- [netdrv] net/mlx5e: Force CHECKSUM_UNNECESSARY for short ethernet frames (Alaa Hleihel) [1651509]
- [include] Fix RH_KABI_SET_SIZE to use dereference operator (Tony Camuso) [1670118]

* Thu Mar 14 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.2.el8]
- [x86] x86/tsc: Make calibration refinement more robust (David Arcari) [1686254]
- [powerpc] powerpc/hugetlb: Don't do runtime allocation of 16G pages in LPAR configuration (Steve Best) [1686756]
- [rpmspec] parallelize "make mrproper" (Denys Vlasenko) [1686865]
- [rpmspec] use "make -jN" (via _smp_mflags) for modules_install (Denys Vlasenko) [1686308]
- [fs] xfs: zero length symlinks are not valid (Carlos Maiolino) [1589618]
- [drm] drm/bufs: Fix Spectre v1 vulnerability (Rob Clark) [1663467]
- [drm] drm/ioctl: Fix Spectre v1 vulnerabilities (Rob Clark) [1663467]
- [scsi] scsi: lpfc: Update lpfc version to 12.2.0.0 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Update 12.2.0.0 file copyrights to 2019 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix nvmet issues when link bounce under IO load (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct upcalling nvmet_fc transport during io done downcall (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix default driver parameter collision for allowing NPIV support (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Rework locking on SCSI io completion (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Enable SCSI and NVME fc4s by default (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Resize cpu maps structures based on possible cpus (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Utilize new IRQ API when allocating MSI-X vectors (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Rework EQ/CQ processing to address interrupt coalescing (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: cleanup: convert eq_delay to usdelay (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Support non-uniform allocation of MSIX vectors to hardware queues (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix setting affinity hints to correlate with hardware queues (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Allow override of hardware queue selection policies (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Adapt partitioned XRI lists to efficient sharing (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Synchronize hardware queues with SCSI MQ interface (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Convert ring number to hardware queue for nvme wqe posting. (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Move SCSI and NVME Stats to hardware queue structures (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Adapt cpucheck debugfs logic to Hardware Queues (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: cleanup: Remove unused FCP_XRI_ABORT_EVENT slowpath event (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Partition XRI buffer list across Hardware Queues (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Replace io_channels for nvme and fcp with general hdw_queues per cpu (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Remove extra vector and SLI4 queue for Expresslane (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Implement common IO buffers between NVME and SCSI (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: cleanup: Remove excess check on NVME io submit code path (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: cleanup: remove nrport from nvme command structure (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: no need to check return value of debugfs_create functions (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Update lpfc version to 12.0.0.10 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Adding ability to reset chip via pci bus reset (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Add log messages to aid in debugging fc4type discovery issues (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix discovery failure when PLOGI is defered (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: update fault value on successful trunk events. (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct MDS loopback diagnostics support (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix link state reporting for trunking when adapter is offline (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: do not set queue->page_count to 0 if pc_sli4_params.wqpcnt is invalid (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: update driver version to 12.0.0.9 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix dif and first burst use in write commands (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix driver release of fw-logging buffers (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct topology type reporting on G7 adapters (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct code setting non existent bits in sli4 ABORT WQE (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Defer LS_ACC to FLOGI on point to point logins (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: ls_rjt erroneus FLOGIs (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Cap NPIV vports to 256 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix kernel Oops due to null pring pointers (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix a duplicate 0711 log message number. (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix panic when FW-log buffsize is not initialized (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: fix block guard enablement on SLI3 adapters (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Use dma_zalloc_coherent (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: update driver version to 12.0.0.8 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: add Trunking support (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Implement GID_PT on Nameserver query to support faster failover (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix odd recovery in duplicate FLOGIs in point-to-point (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct LCB RJT handling (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: fcoe: Fix link down issue after 1000+ link bounces (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct errors accessing fw log (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Reset link or adapter instead of doing infinite nameserver PLOGI retry (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix LOGO/PLOGI handling when triggerd by ABTS Timeout event (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix lpfc_sli4_read_config return value check (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct speeds on SFP swap (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: fix remoteport access (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Remove set but not used variables 'tgtp' (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Remove set but not used variable 'psli' (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Remove set but not used variables 'fc_hdr' and 'hw_page_size' (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: fix spelling mistake "Resrouce" -> "Resource" (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: remove a bogus pci_dma_sync_single_for_device call (Dick Kennedy) [1665288]
- [netdrv] PCI/AER: Remove pci_cleanup_aer_uncorrect_error_status() calls (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Synchronize access to remoteport via rport (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Remove set but not used variable 'sgl_size' (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: update driver version to 12.0.0.7 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: add support to retrieve firmware logs (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: reduce locking when updating statistics (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix errors in log messages. (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct invalid EQ doorbell write on if_type=6 (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct irq handling via locks when taking adapter offline (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct soft lockup when running mds diagnostics (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Correct race with abort on completion path (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Raise nvme defaults to support a larger io and more connectivity (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: raise sg count for nvme to use available sg resources (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Fix GFT_ID and PRLI logic for RSCN (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: remove an unnecessary NULL check (Dick Kennedy) [1665288]
- [scsi] scsi: lpfc: Default fdmi_on to on (Dick Kennedy) [1665288]
- [powerpc] powerpc/mm/hash: Increase vmalloc space with hash translation mode (Steve Best) [1676974]
- [net] sunrpc: fix 4 more call sites that were using stack memory with a scatterlist (Scott Mayhew) [1679183]
- [net] sunrpc: Don't use stack buffer with scatterlist (Scott Mayhew) [1679183]
- [powerpc] powerpc/pseries: Perform full re-add of CPU for topology update post-migration (Steve Best) [1678209]
- [fs] proc/stat: Make the interrupt statistics more efficient (Waiman Long) [1675168]
- [kernel] genirq: Avoid summation loops for /proc/stat (Waiman Long) [1675168]
- [powerpc] powerpc/pseries: fix EEH recovery of some IOV devices (Steve Best) [1676889]
- [block] nvme: lock NS list changes while handling command effects (David Milburn) [1672759]
- [powerpc] powerpc/radix: Fix kernel crash with mremap() (Steve Best) [1674186]
- [crypto] crypto: ccp - fix the SEV probe in kexec boot path (Gary Hook) [1658806]
- [netdrv] HDLC Frame Relay: mark driver unsupported in RHEL8 (John Linville) [1660627]
- [netdrv] DLCI: mark driver unsupported in RHEL8 (John Linville) [1660627]
- [netdrv] ethoc: mark hardware unsupported in RHEL8 (John Linville) [1660627]
- [netdrv] dnet: mark hardware unsupported in RHEL8 (John Linville) [1660627]
- [netdrv] dl2k: mark hardware unsupported in RHEL8 (John Linville) [1660627]
- [netdrv] mark qla3xxx driver as unsupported (John Linville) [1658840]
- [netdrv] sfc: initialise found bitmap in efx_ef10_mtd_probe (Jarod Wilson) [1668656]
- [netdrv] sfc: suppress duplicate nvmem partition types in efx_ef10_mtd_probe (Jarod Wilson) [1668656]
- [netdrv] sfc: extend MTD support for newer hardware (Jarod Wilson) [1668656]
- [netdrv] sfc: add missing NVRAM partition types for EF10 (Jarod Wilson) [1668656]
- [netdrv] ibmvnic: Fix non-atomic memory allocation in IRQ context (Steve Best) [1671474]
- [netdrv] ibmvnic: Convert reset work item mutex to spin lock (Steve Best) [1671474]
- [powerpc] powerpc/pseries: Export raw per-CPU VPA data via debugfs (Steve Best) [1608797]
- [powerpc] powerpc/pseries: Export maximum memory value (Steve Best) [1608797]
- [netdrv] ibmveth: Do not process frames after calling napi_reschedule (Desnes Augusto Nunes do Rosario) [1635577]
- [cpufreq] cpufreq: powernv: Remove global pstate ramp-down timer in POWER9 (Steve Best) [1670030]
- [of] of: __of_detach_node() - remove node from phandle cache (Steve Best) [1669198]
- [of] of: of_node_get()/of_node_put() nodes held in phandle cache (Steve Best) [1669198]
- [edac] EDAC, sb_edac: Fix signedness bugs in *_get_ha() functions (Aristeu Rozanski) [1641574]
- [edac] EDAC, sb_edac: Fix reporting for patrol scrubber errors (Aristeu Rozanski) [1641574]
- [documentation] proc.txt: Adding 'HardwareCorrupted' field and description. (Prashant Dhamdhere) [1658233]
- [netdrv] qed: Fix command number mismatch between driver and the mfw (Chad Dupuis) [1663500]
- Revert "[redhat] switch secureboot kernel image signing to release keys" ("Herton R. Krzesinski")

* Wed Mar 13 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-80.1.el8]
- [arm64] revert "arm64: tlb: Avoid synchronous TLBIs when freeing page tables" (Christoph von Recklinghausen) [1685697]

* Wed Mar 13 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-79.1.el8]
- [firmware] drivers/firmware: psci_checker: stash and use topology_core_cpumask for hotplug tests (Josh Poimboeuf) [1687101]
- [arm64] arm64: topology: re-introduce numa mask check for scheduler MC selection (Josh Poimboeuf) [1687101]
- [arm64] arm64: topology: rename llc_siblings to align with other struct members (Josh Poimboeuf) [1687101]
- [arm64] arm64: smp: remove cpu and numa topology information when hotplugging out CPU (Josh Poimboeuf) [1687101]
- [arm64] arm64: topology: restrict updating siblings_masks to online cpus only (Josh Poimboeuf) [1687101]
- [arm64] arm64: topology: add support to remove cpu topology sibling masks (Josh Poimboeuf) [1687101]
- [arm64] arm64: numa: separate out updates to percpu nodeid and NUMA node cpumap (Josh Poimboeuf) [1687101]
- [arm64] arm64: topology: refactor reset_cpu_topology to add support for removing topology (Josh Poimboeuf) [1687101]

* Tue Mar 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-78.1.el8]
- [fs] gfs2: Fix missed wakeups in find_insert_glock (Andreas Grunbacher) [1678907]

* Tue Mar 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-77.1.el8]
- [firmware] efi: Reduce the amount of memblock reservations for persistent allocations (Bhupesh Sharma) [1682988]
- [firmware] efi: Permit multiple entries in persistent memreserve data structure (Bhupesh Sharma) [1682988]
- [kernel] cpu/hotplug: Create SMT sysfs interface for all arches (Josh Poimboeuf) [1686068]
- [net] netfilter: nft_set_hash: bogus element self comparison from deactivation path (Florian Westphal) [1678574]
- [net] netfilter: nft_set_hash: fix lookups with fixed size hash on big endian (Florian Westphal) [1678574]

* Tue Mar 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-76.1.el8]
- [security] revert "Add a SysRq option to lift kernel lockdown" (Lenny Szubowicz) [1684348]
- [s390] s390/setup: fix boot crash for machine without EDAT-1 (Philipp Rudo) [1677357]
- [s390] s390/setup: fix early warning messages (Philipp Rudo) [1677357]

* Tue Mar 12 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-75.1.el8]
- [netdrv] net: hns3: add 8 BD limit for tx flow (Xiaojun Tan) [1676771]
- [netdrv] net: hns3: fix a SSU buffer checking bug (Xiaojun Tan) [1676771]
- [netdrv] net: hns3: aligning buffer size in SSU to 256 bytes (Xiaojun Tan) [1676771]
- [netdrv] net: hns3: getting tx and dv buffer size through firmware (Xiaojun Tan) [1676771]
- [net] netfilter: nf_nat_snmp_basic: add missing length checks in ASN.1 cbs (Florian Westphal) [1676602]
- [char] ipmi: fix use-after-free of user->release_barrier.rda (Xiaojun Tan) [1677550]
- [char] ipmi: Prevent use-after-free in deliver_response (Xiaojun Tan) [1677550]

* Mon Mar 11 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-74.1.el8]
- [x86] revert "cpu/hotplug: Add SMT policy options" (Josh Poimboeuf) [1683690]
- [crypto] net: crypto set sk to NULL when af_alg_release (Neil Horman) [1679450] {CVE-2019-8912}
- [drm] drm/i915/gvt: update force-to-nonpriv register whitelist (Paul Lai) [1643972]
- [kernel] MODSIGN: Also check platform keyring in mod_verify_sig() (Lenny Szubowicz) [1568532]
- [kernel] Fix for module sig verification (Lenny Szubowicz) [1568532]
- [security] efi: Lock down the kernel if booted in secure boot mode (Lenny Szubowicz) [1568532]
- [firmware] efi: Add an EFI_SECURE_BOOT flag to indicate secure boot mode (Lenny Szubowicz) [1568532]
- [x86] Copy secure_boot flag in boot params across kexec reboot (Lenny Szubowicz) [1568532]
- [fs] debugfs: Restrict debugfs when the kernel is locked down (Lenny Szubowicz) [1568532]
- [mm] x86/mmiotrace: Lock down the testmmiotrace module (Lenny Szubowicz) [1568532]
- [kernel] Lock down module params that specify hardware parameters (eg. ioport) (Lenny Szubowicz) [1568532]
- [tty] Lock down TIOCSSERIAL (Lenny Szubowicz) [1568532]
- [pcmcia] Prohibit PCMCIA CIS storage when the kernel is locked down (Lenny Szubowicz) [1568532]
- [acpi] acpi: Disable ACPI table override if the kernel is locked down (Lenny Szubowicz) [1568532]
- [acpi] acpi: Ignore acpi_rsdp kernel param when the kernel has been locked down (Lenny Szubowicz) [1568532]
- [acpi] ACPI: Limit access to custom_method when the kernel is locked down (Lenny Szubowicz) [1568532]
- [x86] x86/msr: Restrict MSR access when the kernel is locked down (Lenny Szubowicz) [1568532]
- [x86] x86: Lock down IO port access when the kernel is locked down (Lenny Szubowicz) [1568532]
- [pci] PCI: Lock down BAR access when the kernel is locked down (Lenny Szubowicz) [1568532]
- [kernel] uswsusp: Disable when the kernel is locked down (Lenny Szubowicz) [1568532]
- [kernel] hibernate: Disable when the kernel is locked down (Lenny Szubowicz) [1568532]
- [kernel] kexec_load: Disable at runtime if the kernel is locked down (Lenny Szubowicz) [1568532]
- [char] Restrict /dev/{mem, kmem, port} when the kernel is locked down (Lenny Szubowicz) [1568532]
- [kernel] MODSIGN: Enforce module signatures if the kernel is locked down (Lenny Szubowicz) [1568532]
- [security] Add a SysRq option to lift kernel lockdown (Lenny Szubowicz) [1568532]
- [security] Add the ability to lock down access to the running kernel image (Lenny Szubowicz) [1568532]

* Mon Mar 11 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-73.1.el8]
- [net] tun: forbid iface creation with rtnl ops (Sabrina Dubroca) [1680969]
- [net] revert "bridge: do not add port to router list when receives query with source 0.0.0.0" (Hangbin Liu) [1679896]
- [net] sctp: walk the list of asoc safely (Marcelo Leitner) [1679920] {CVE-2019-8956}
- [net] netfilter: nf_nat: skip nat clash resolution for same-origin entries (Florian Westphal) [1677647]
- [net] netfilter: nf_conntrack: resolve clash for matching conntracks (Florian Westphal) [1677647]
- [net] netfilter: nf_tables: fix flush after rule deletion in the same batch (Phil Sutter) [1677672]
- [net] gro_cell: add napi_disable in gro_cells_destroy (Stefano Brivio) [1674408]
- [net] sctp: call gso_reset_checksum when computing checksum in sctp_gso_segment (Xin Long) [1669386]
- [net] ipvs: fix dependency on nf_defrag_ipv6 (Andrea Claudi) [1660808]
- [net] sctp: check and update stream->out_curr when allocating stream_out (Xin Long) [1651877]

* Mon Mar 11 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-72.1.el8]
- [x86] cpu/hotplug: Add SMT policy options (Josh Poimboeuf) [1677405]

* Tue Mar 05 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-71.1.el8]
- [kernel] open the RHEL 8.1 development ("Herton R. Krzesinski")
- [pci] pci/quirks: Add quirk to reset nvgpu at boot for the Lenovo ThinkPad P50 (Lyude Paul) [1677022]
- [arm64] arm64, vmcoreinfo : Append 'MAX_USER_VA_BITS' to vmcoreinfo (Bhupesh Sharma) [1672962]
- [md] dm thin: fix bug where bio that overwrites thin block ignores FUA (Mike Snitzer) [1679211]
- [pci] PCI: Fix "try" semantics of bus and slot reset (Myron Stowe) [1662901]
- [acpi] acpi/nfit: Fix bus command validation (Jeff Moyer) [1673958]
- [pci] PCI/MSI: Return -ENOSPC from pci_alloc_irq_vectors_affinity() (Myron Stowe) [1667773]
- [fs] NFS: Don't use page_file_mapping after removing the page (Benjamin Coddington) [1664190]
- [fs] NFS: Fix up return value on fatal errors in nfs_page_async_flush() (Benjamin Coddington) [1664190]
- [md] md: fix raid10 hang issue caused by barrier (Xiao Ni) [1630921]
- [md] md/raid1: don't clear bitmap bits on interrupted recovery. (Xiao Ni) [1677360]
- [virt] kvm: fix kvm_ioctl_create_device() reference counting (CVE-2019-6974) (Paolo Bonzini) [1673843] {CVE-2019-6974}
- [block] blk-mq: fix a hung issue when fsync (Ming Lei) [1674399]
- [block] Revert "block: cover another queue enter recursion via BIO_QUEUE_ENTERED" (Ming Lei) [1673966]
- [tools] perf tools: Check for null when copying nsinfo. (Jiri Olsa) [1676451]
- [iommu] iommu/amd: Fix IOMMU page flush when detach device from a domain (Suravee Suthikulpanit) [1672476]

* Tue Feb 19 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-70.el8]
- [kernel] namespace: Add padding fix to user_table[] (Prarit Bhargava) [1677103]
- [x86] KVM: nVMX: unconditionally cancel preemption timer in free_nested (CVE-2019-7221) (Paolo Bonzini) [1673841] {CVE-2019-7221}
- [scsi] scsi: sd: fix entropy gathering for most rotational disks (Ewan Milne) [1676735]
- [scsi] scsi: sd: Contribute to randomness when running rotational device (Ewan Milne) [1676735]
- [rpmspec] Revert "Drop -doc subpackage" (Prarit Bhargava) [1657609]
- [net] svcrdma: Remove max_sge check at connect time (Don Dutile) [1638869]
- [net] svcrdma: Reduce max_send_sges (Don Dutile) [1638869]
- [arm64] arm64: mm: Introduce MAX_USER_VA_BITS definition (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Rewrite stale comment in asm/tlbflush.h (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Avoid synchronous TLBIs when freeing page tables (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Remove redundant !CONFIG_HAVE_RCU_TABLE_FREE code (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlbflush: Allow stride to be specified for __flush_tlb_range() (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Justify non-leaf invalidation in flush_tlb_range() (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Add DSB ISHST prior to TLBI in __flush_tlb_[kernel_]pgtable() (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlb: Use last-level invalidation in flush_tlb_kernel_range() (Christoph von Recklinghausen) [1672997]
- [mm] arm64: mm: EXPORT vabits_user to modules (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: fix ARM64_USER_VA_BITS_52 builds (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: Kconfig: Re-jig CONFIG options for 52-bit VA (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: Allow forcing all userspace addresses to 52-bit (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: introduce 52-bit userspace support (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: Prevent mismatched 52-bit VA support (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: Offset TTBR1 to allow 52-bit PTRS_PER_PGD (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: Define arch_get_mmap_end, arch_get_mmap_base (Christoph von Recklinghausen) [1672997]
- [firmware] arm64: mm: Introduce DEFAULT_MAP_WINDOW (Christoph von Recklinghausen) [1672997]
- [mm] mm: mmap: Allow for "high" userspace addresses (Christoph von Recklinghausen) [1672997]
- [mm] arm64: mm: apply r/o permissions of VM areas to its linear alias as well (Christoph von Recklinghausen) [1672997]
- [mm] arm64: mm: purge lazily unmapped vm regions before changing permissions (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: mm: Don't wait for completion of TLB invalidation when page aging (Christoph von Recklinghausen) [1672997]
- [mm] arm64: mm: Use __pa_symbol() for set_swapper_pgd() (Christoph von Recklinghausen) [1672997]
- [mm] arm64: mm: Drop the unused cpu parameter (Christoph von Recklinghausen) [1672997]
- [arm64] arm64/mm: move runtime pgds to rodata (Christoph von Recklinghausen) [1672997]
- [mm] arm64/mm: use fixmap to modify swapper_pg_dir (Christoph von Recklinghausen) [1672997]
- [arm64] arm64/mm: Separate boot-time page tables from swapper_pg_dir (Christoph von Recklinghausen) [1672997]
- [arm64] arm64/mm: Pass ttbr1 as a parameter to __enable_mmu() (Christoph von Recklinghausen) [1672997]
- [mm] arm64: fix erroneous warnings in page freeing functions (Christoph von Recklinghausen) [1672997]
- [mm] arm64: Implement page table free interfaces (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: tlbflush: Introduce __flush_tlb_kernel_pgtable (Christoph von Recklinghausen) [1672997]
- [lib] ioremap: Update pgtable free interfaces with addr (Christoph von Recklinghausen) [1672997]
- [mm] x86/mm: Disable ioremap free page handling on x86-PAE (Christoph von Recklinghausen) [1672997]
- [arm64] arm64: KVM: Enable Common Not Private translations (Christoph von Recklinghausen) [1504991]
- [arm64] arm64: mm: Support Common Not Private translations (Christoph von Recklinghausen) [1504991]
- [kernel] cpu/hotplug: Fix "SMT disabled by BIOS" detection for KVM (Igor Mammedov) [1668147]
- [tools] perf tools: Compile perf with -g instead of -ggdb3 to workaround gdb crash (Jiri Olsa) [1667109]

* Thu Feb 14 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-69.el8]
- [fs] Revert "gfs2: Fix loop in gfs2_rbm_find" (Andreas Grunbacher) [1658528]
- [net] bpf: fix sanitation of alu op with pointer / scalar type from different paths (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf: prevent out of bounds speculation on pointer arithmetic (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf: move {prev_,}insn_idx into verifier env (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf/verifier: per-register parent pointers (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf: restrict unknown scalars of mixed signed bounds for unprivileged (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf: Simplify ptr_min_max_vals adjustment (Jiri Olsa) [1673631] {CVE-2019-7308}
- [net] bpf: fix inner map masking to prevent oob under speculation (Jiri Olsa) [1673631] {CVE-2019-7308}
- [include] KABI: struct class padding (Prarit Bhargava) [1670035]
- [include] KABI: struct timer_list padding (Prarit Bhargava) [1670035]
- [include] KABI: struct irq_domain padding (Prarit Bhargava) [1670035]
- [nvdimm] libnvdimm, pmem: Fix badblocks population for 'raw' namespaces (Jeff Moyer) [1672315]
- [netdrv] net/mlx5e: FPGA, fix Innova IPsec TX offload data path performance (Alaa Hleihel) [1648230]
- [kernel] exec: increase BINPRM_BUF_SIZE to 256 (Oleg Nesterov) [1447445]

* Wed Feb 13 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-68.el8]
- [include] KABI: struct kset padding (Prarit Bhargava) [1669796]
- [include] KABI: struct kobject and kobj_type padding (Prarit Bhargava) [1669796]
- [include] KABI: struct delayed_work padding (Prarit Bhargava) [1669796]
- [include] KABI: struct work_struct padding (Prarit Bhargava) [1669796]
- [include] KABI: struct hrtimer padding (Prarit Bhargava) [1669796]
- [include] KABI: struct user_namespace padding (Prarit Bhargava) [1669796]
- [include] KABI: struct resource padding (Prarit Bhargava) [1669796]
- [include] KABI: Protect device_driver struct (Prarit Bhargava) [1666316]
- [include] KABI: Protect radix functions (Prarit Bhargava) [1669079]
- [char] ipmi: msghandler: Fix potential Spectre v1 vulnerabilities (Tony Camuso) [1672582]
- [vhost] vhost: fix OOB in get_rx_bufs() (Jason Wang) [1668665] {CVE-2018-16880}

* Sat Feb 09 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-67.el8]
- [md] dm: don't use bio_trim() afterall (Mike Snitzer) [1673657]
- [md] dm: add memory barrier before waitqueue_active (Mike Snitzer) [1673110]
- [x86] x86: uaccess: Inhibit speculation past access_ok() in user_access_begin() (Joe Lawrence) [1670113] {CVE-2018-20669}
- [kernel] make 'user_access_begin()' do 'access_ok()' (Joe Lawrence) [1670113] {CVE-2018-20669}
- [drm] i915: fix missing user_access_end() in page fault exception case (Joe Lawrence) [1670113] {CVE-2018-20669}
- [drm] drm/i915: Force the slow path after a user-write error (Joe Lawrence) [1670113] {CVE-2018-20669}
- [x86] x86/microcode/amd: Don't falsely trick the late loading mechanism (David Arcari) [1654904]
- [fs] iomap: get/put the page in iomap_page_create/release() (Artem Savkov) [1664298]
- [scsi] scsi: qla2xxx: Add new FC-NVMe enable BIT to enable FC-NVMe feature (Himanshu Madhani) [1671569]
- [message] mptsas: pci-id table changes (Tomas Henzl) [1666730]
- [message] mptsas: Taint kernel if mptsas is loaded (Tomas Henzl) [1666730]
- [kernel] genirq/matrix: Improve target CPU selection for managed interrupts. (Gary Hook) [1669557]
- [kernel] irq/matrix: Spread managed interrupts on allocation (Gary Hook) [1669557]
- [kernel] irq/matrix: Split out the CPU selection code into a helper (Gary Hook) [1669557]
- [net] sit: check if IPv6 enabled before calling ip6_err_gen_icmpv6_unreach() (Stefano Brivio) [1671680]
- [net] geneve: should not call rt6_lookup() when ipv6 was disabled (Stefano Brivio) [1671680]
- [net] netfilter: physdev: relax br_netfilter dependency (Phil Sutter) [1650382]
- [net] netfilter: nf_tables: add NFTA_RULE_POSITION_ID to nla_policy (Phil Sutter) [1670563]
- [net] netfilter: nf_tables: Support RULE_ID reference in new rule (Phil Sutter) [1670563]
- [net] rtnetlink: fix incorrect handling of device stats passed to userspace (Ivan Vecera) [1668298]
- [net] netfilter: nf_tables: handle nft_object lookups via rhltable (Phil Sutter) [1659725]
- [net] netfilter: nf_tables: prepare nft_object for lookups via hashtable (Phil Sutter) [1659725]
- [net] netfilter: nf_tables: selective rule dump needs table to be specified (Phil Sutter) [1659725]
- [net] netfilter: nf_tables: Fix for endless loop when dumping ruleset (Phil Sutter) [1659725]
- [net] netfilter: nf_tables: Speed up selective rule dumps (Phil Sutter) [1659725]
- [net] exclude sock_reuseport from kABI protection (Paolo Abeni) [1665984]
- [include] KABI: struct device padding (Don Dutile) [1664445]
- [include] KABI: struct dma_map_ops padding (Don Dutile) [1664482]
- [kernel] swiotlb: clear io_tlb_start and io_tlb_end in swiotlb_exit (Don Dutile) [1664484]
- [kernel] dma-mapping: remove a few unused exports (Don Dutile) [1664484]
- [include] dma-mapping: properly stub out the DMA API for !CONFIG_HAS_DMA (Don Dutile) [1664484]
- [kernel] dma-mapping: remove dmam_{declare,release}_coherent_memory (Don Dutile) [1664484]
- [kernel] dma-mapping: implement dmam_alloc_coherent using dmam_alloc_attrs (Don Dutile) [1664484]
- [include] dma-mapping: implement dma_map_single_attrs using dma_map_page_attrs (Don Dutile) [1664484]
- [include] dma-mapping: fix flags in dma_alloc_wc (Don Dutile) [1664484]
- [include] dma-mapping: deprecate dma_zalloc_coherent (Don Dutile) [1664484]
- [arm64] arm64: default to the direct mapping in get_arch_dma_ops (Don Dutile) [1664484]
- [kernel] dma-mapping: fix inverted logic in dma_supported (Don Dutile) [1664484]
- [include] dma-mapping: bypass indirect calls for dma-direct (Don Dutile) [1664484]
- [kernel] dma-direct: merge swiotlb_dma_ops into the dma_direct code (Don Dutile) [1664484]
- [kernel] dma-direct: do not include SME mask in the DMA supported check (Don Dutile) [1664484]
- [kernel] dma-direct: use dma_direct_map_page to implement dma_direct_map_sg (Don Dutile) [1664484]
- [kernel] dma-direct: improve addressability error reporting (Don Dutile) [1664484]
- [kernel] dma-direct: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [xen] swiotlb: remove dma_mark_clean (Don Dutile) [1664484]
- [xen] swiotlb: remove SWIOTLB_MAP_ERROR (Don Dutile) [1664484]
- [xen] xen-swiotlb: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [kernel] swiotlb: Skip cache maintenance on map error (Don Dutile) [1664484]
- [kernel] swiotlb: add support for non-coherent DMA (Don Dutile) [1664484]
- [kernel] swiotlb: mark is_swiotlb_buffer static (Don Dutile) [1664484]
- [kernel] swiotlb: remove a pointless comment (Don Dutile) [1664484]
- [kernel] swiotlb: clean up reporting (Don Dutile) [1664484]
- [kernel] dma-direct: reject highmem pages from dma_alloc_from_contiguous (Don Dutile) [1664484]
- [kernel] dma-direct: provide page based alloc/free helpers (Don Dutile) [1664484]
- [include] dma-direct: Make DIRECT_MAPPING_ERROR viable for SWIOTLB (Don Dutile) [1664484]
- [kernel] dma-direct: respect DMA_ATTR_NO_WARN (Don Dutile) [1664484]
- [kernel] dma-direct: document the zone selection logic (Don Dutile) [1664484]
- [kernel] dma-direct: fix return value of dma_direct_supported (Don Dutile) [1664484]
- [kernel] dma-direct: always allow dma mask <= physiscal memory size (Don Dutile) [1664484]
- [kernel] dma-direct: implement complete bus_dma_mask handling (Don Dutile) [1664484]
- [kernel] dma-direct: refine dma_direct_alloc zone selection (Don Dutile) [1664484]
- [kernel] dma-direct: add an explicit dma_direct_get_required_mask (Don Dutile) [1664484]
- [kernel] kernel/dma/direct: take DMA offset into account in dma_direct_supported (Don Dutile) [1664484]
- [kernel] dma-mapping: factor out dummy DMA ops (Don Dutile) [1664484]
- [mm] arm64: dma-mapping: Fix FORCE_CONTIGUOUS buffer clearing (Don Dutile) [1664484]
- [iommu] iommu/dma-iommu: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [iommu] iommu/vt-d: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [iommu] iommu/intel: small map_page cleanup (Don Dutile) [1664484]
- [iommu] intel-iommu: mark intel_dma_ops static (Don Dutile) [1664484]
- [iommu] ia64: remove iommu_dma_supported (Don Dutile) [1664484]
- [iommu] iommu: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [iommu] iommu/dma: Use fast DMA domain lookup (Don Dutile) [1664484]
- [x86] x86/amd_gart: fix unmapping of non-GART mappings (Don Dutile) [1664484]
- [x86] x86/amd_gart: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [mm] arm64: remove the dummy_dma_ops mapping_error method (Don Dutile) [1664484]
- [powerpc] powerpc: Do not redefine NEED_DMA_MAP_STATE (Don Dutile) [1664484]
- [powerpc] powerpc/iommu: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [s390] s390: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [kernel] dma-mapping: always build the direct mapping code (Don Dutile) [1664484]
- [kernel] dma-mapping: move dma_cache_sync out of line (Don Dutile) [1664484]
- [kernel] dma-mapping: move various slow path functions out of line (Don Dutile) [1664484]
- [base] dma-mapping: move dma_get_required_mask to kernel/dma (Don Dutile) [1664484]
- [base] dma-mapping: move dma_default_get_required_mask under ifdef (Don Dutile) [1664484]
- [include] dma-mapping: merge dma_unmap_page_attrs and dma_unmap_single_attrs (Don Dutile) [1664484]
- [include] dma-mapping: simplify the dma_sync_single_range_for_{cpu,device} implementation (Don Dutile) [1664484]
- [include] dma-mapping: return an error code from dma_mapping_error (Don Dutile) [1664484]
- [pci] dma-mapping: remove the mapping_error dma_map_ops method (Don Dutile) [1664484]
- [include] dma-mapping: provide a generic DMA_MAPPING_ERROR (Don Dutile) [1664484]
- [kernel] dma-mapping: move the arm64 noncoherent alloc/free support to common code (Don Dutile) [1664484]
- [mm] arm64: fix warnings without CONFIG_IOMMU_DMA (Don Dutile) [1664484]
- [arm64] arm64: use the generic swiotlb_dma_ops (Don Dutile) [1664484]
- [kernel] swiotlb: don't dip into swiotlb pool for coherent allocations (Don Dutile) [1664484]
- [kernel] swiotlb: refactor swiotlb_map_page (Don Dutile) [1664484]
- [kernel] swiotlb: use swiotlb_map_page in swiotlb_map_sg_attrs (Don Dutile) [1664484]
- [kernel] swiotlb: merge swiotlb_unmap_page and unmap_single (Don Dutile) [1664484]
- [kernel] swiotlb: remove the overflow buffer (Don Dutile) [1664484]
- [kernel] swiotlb: do not panic on mapping failures (Don Dutile) [1664484]
- [mm] arm64/dma-mapping: Mildly optimise non-coherent IOMMU ops (Don Dutile) [1664484]
- [iommu] iommu: Add fast hook for getting DMA domains (Don Dutile) [1664484]
- [iommu] iommu: Remove the ->map_sg indirection (Don Dutile) [1664484]
- [iommu] kernel/dma: remove unsupported gfp_mask parameter from dma_alloc_from_contiguous() (Don Dutile) [1664484]
- [mm] mm/cma: remove unsupported gfp_mask parameter from cma_alloc() (Don Dutile) [1664484]
- [kernel] dma-mapping: move the remap helpers to a separate file (Don Dutile) [1664484]
- [include] dma-mapping: fix return type of dma_set_max_seg_size() (Don Dutile) [1664484]
- [include] dma-mapping: translate __GFP_NOFAIL to DMA_ATTR_NO_WARN (Don Dutile) [1664484]
- [include] dma-debug: Check for drivers mapping invalid addresses in dma_map_single() (Don Dutile) [1664484]
- [base] dma-mapping: make the get_required_mask method available unconditionally (Don Dutile) [1664484]
- [xen] dma-mapping: support non-coherent devices in dma_common_get_sgtable (Don Dutile) [1664484]
- [kernel] dma-mapping: consolidate the dma mmap implementations (Don Dutile) [1664484]
- [kernel] dma-mapping: merge direct and noncoherent ops (Don Dutile) [1664484]
- [include] dma-mapping: move the dma_coherent flag to struct device (Don Dutile) [1664484]
- [include] dma-mapping: remove dma_deconfigure (Don Dutile) [1664484]
- [base] dma-mapping: remove dma_configure (Don Dutile) [1664484]
- [include] dma-mapping: relax warning for per-device areas (Don Dutile) [1664484]
- [kernel] dma-mapping: add the missing ARCH_HAS_SYNC_DMA_FOR_CPU_ALL declaration (Don Dutile) [1664484]
- [kernel] dma-noncoherent: add a arch_sync_dma_for_cpu_all hook (Don Dutile) [1664484]
- [block] deprecate elevator= kernel parameter (Jeff Moyer) [1665295]
- [rpmspec] kernel.spec: disable kabi checks until RC (=?UTF-8?q?=C4=8Cestm=C3=ADr=20Kalina?=) [1671007]
- [iommu] iommu/amd: Unmap all mapped pages in error path of map_sg (Jerry Snitselaar) [1668448]
- [iommu] iommu/amd: Call free_iova_fast with pfn in map_sg (Jerry Snitselaar) [1668448]

* Thu Feb 07 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-66.el8]
- [arm64] arm64, vmcoreinfo : Append 'MAX_PHYSMEM_BITS' to vmcoreinfo (Bhupesh Sharma) [1666679]
- [kernel] sched/debug: Initialize sd_sysctl_cpus if !CONFIG_CPUMASK_OFFSTACK (Joe Lawrence) [1667840]
- [init] Small change to the message about certified hardware (Steve Best) [1671765]
- [x86] x86/kdump: make the behavior of crashkernel=X consistent with kaslr (Pingfan Liu) [1640799]
- [x86] Add back support for Intel processors (Steve Best) [1670529]
- [net] SUNRPC: Clean up initialisation of the struct rpc_rqst (Benjamin Coddington) [1650494]
- [x86] KABI, x86/paravirt: Protect paravirt ops structures (Waiman Long) [1669957]
- [include] KABI: struct module padding (Prarit Bhargava) [1669480]
- [include] KABI: struct stack_trace_struct padding (Prarit Bhargava) [1669480]
- [documentation] iommu: Fix passthrough option documentation (Gary Hook) [1658391]
- [iommu] iommu: Add config option to set passthrough as default (Gary Hook) [1658391]
- [kernel] redhat: kernel: clean up taint flags (Jiri Benc) [1654313]

* Wed Feb 06 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-65.el8]
- [scsi] scsi: qedi: Add the CRC size within iSCSI NVM image (Charles Rose) [1670186]
- [fs] iomap: don't search past page end in iomap_is_partially_uptodate (Eric Sandeen) [1657588]
- [netdrv] cxgb4: update supported DCB version (Arjun Vynipadath) [1668571]
- [x86] kexec, KEYS: Make use of platform keyring for signature verify (Kairui Song) [1640486]
- [security] integrity, KEYS: add a reference to platform keyring (Kairui Song) [1640486]
- [security] efi: Allow the "db" UEFI variable to be suppressed (Kairui Song) [1640486]
- [security] efi: Import certificates from UEFI Secure Boot (Kairui Song) [1640486]
- [security] efi: Add an EFI signature blob parser (Kairui Song) [1640486]
- [include] efi: Add EFI signature data types (Kairui Song) [1640486]
- [security] integrity: Load certs to the platform keyring (Kairui Song) [1640486]
- [security] integrity: Define a trusted platform keyring (Kairui Song) [1640486]
- [security] security/integrity: remove unnecessary 'init_keyring' variable (Kairui Song) [1640486]
- [x86] Fix kexec forbidding kernels signed with keys in the secondary keyring to boot (Kairui Song) [1640486]
- [crypto] Replace magic for trusting the secondary keyring with #define (Kairui Song) [1640486]
- [acpi] acpi/nfit: Fix command-supported detection (Jeff Moyer) [1665812]
- [acpi] acpi/nfit: Block function zero DSMs (Jeff Moyer) [1665812]
- [md] dm: add missing trace_block_split() to __split_and_process_bio() (Mike Snitzer) [1645283]
- [md] dm: fix dm_wq_work() to only use __split_and_process_bio() if appropriate (Mike Snitzer) [1645283]
- [md] dm: fix redundant IO accounting for bios that need splitting (Mike Snitzer) [1645283]
- [md] dm: fix clone_bio() to trigger blk_recount_segments() (Mike Snitzer) [1645283]
- [block] block: cover another queue enter recursion via BIO_QUEUE_ENTERED (Mike Snitzer) [1645283]
- [md] dm thin: fix passdown_double_checking_shared_status() (Mike Snitzer) [1668039]
- [tools] bpftool: Fix prog dump by tag (Jiri Olsa) [1667305]
- [arm64] arm64: ftrace: Fix to enable syscall events on arm64 (Don Dutile) [1668035]
- [arm64] arm64: implement syscall wrappers (Don Dutile) [1668035]
- [arm64] arm64: convert compat wrappers to C (Don Dutile) [1668035]
- [arm64] arm64: use SYSCALL_DEFINE6() for mmap (Don Dutile) [1668035]
- [arm64] arm64: use {COMPAT,}SYSCALL_DEFINE0 for sigreturn (Don Dutile) [1668035]
- [arm64] arm64: remove in-kernel call to sys_personality() (Don Dutile) [1668035]
- [include] kernel: add ksys_personality() (Don Dutile) [1668035]
- [arm64] arm64: drop alignment from syscall tables (Don Dutile) [1668035]
- [arm64] arm64: entry: remove unused register aliases (Don Dutile) [1668035]
- [arm64] arm64: convert native/compat syscall entry to C (Don Dutile) [1668035]
- [arm64] arm64: svc: Ensure hardirq tracing is updated before return (Don Dutile) [1668035]
- [arm64] arm64: convert syscall trace logic to C (Don Dutile) [1668035]
- [arm64] arm64: move sve_user_{enable,disable} to <asm/fpsimd.h> (Don Dutile) [1668035]
- [arm64] arm64: kill change_cpacr() (Don Dutile) [1668035]
- [arm64] arm64: convert raw syscall invocation to C (Don Dutile) [1668035]
- [arm64] arm64: introduce syscall_fn_t (Don Dutile) [1668035]
- [arm64] arm64: remove sigreturn wrappers (Don Dutile) [1668035]
- [arm64] arm64: rseq: Implement backend rseq calls and select HAVE_RSEQ (Don Dutile) [1668035]
- [sound] ALSA: usb-audio: Add vendor and product name for Dell WD19 Dock (Jaroslav Kysela) [1664249]
- [infiniband] IB/hfi1: Fix an out-of-bounds access in get_hw_stats (Alex Estrin) [1667104]
- [infiniband] IB/hfi1: Incorrect sizing of sge for PIO will OOPs (Alex Estrin) [1667095]
- [drm] drm/nouveau: register backlight on pascal and newer (Ben Skeggs) [1664899]
- [drm] drm/nouveau/disp/gm200-: enforce identity-mapped SOR assignment for LVDS/eDP panels (Ben Skeggs) [1664899]
- [drm] drm/nouveau/disp: move eDP panel power handling (Ben Skeggs) [1664899]
- [drm] drm/nouveau/devinit: don't fail when PMU/PRE_OS is missing from VBIOS (Ben Skeggs) [1664899]
- [kernel] locking/rwsem: Fix (possible) missed wakeup (Waiman Long) [1668014]
- [kernel] futex: Fix (possible) missed wakeup (Waiman Long) [1668014]
- [kernel] sched/wake_q: Fix wakeup ordering for wake_q (Waiman Long) [1668014]
- [kernel] sched/wake_q: Document wake_q_add() (Waiman Long) [1668014]
- [kernel] sched/wait: Fix rcuwait_wake_up() ordering (Waiman Long) [1668014]
- [kernel] sched/Documentation: Update wake_up() & co. memory-barrier guarantees (Waiman Long) [1668014]
- [kvm] KVM: PPC: Book3S HV: Flush guest mappings when turning dirty tracking on/off (Laurent Vivier) [1650386]
- [kvm] KVM: PPC: Book3S HV: Cleanups - constify memslots, fix comments (Laurent Vivier) [1650386]
- [kvm] KVM: PPC: Book3S HV: Map single pages when doing dirty page logging (Laurent Vivier) [1650386]
- [kvm] KVM: PPC: Pass change type down to memslot commit function (Laurent Vivier) [1650386]
- [vhost] vhost: log dirty page correctly (Jason Wang) [1657578]
- [netdrv] netxen: taint as unsupported in RHEL8 (Tony Camuso) [1654825]
- [hid] HID: hiddev: fix potential Spectre v1 (Benjamin Tissoires) [1664611]
- [net] resort to custom code for sk_buff padding (Paolo Abeni) [1665984]
- [net] add padding to cipher_context (Paolo Abeni) [1665984]
- [net] add padding to tls_crypto_context (Paolo Abeni) [1665984]
- [net] add padding to ipv4_devconf (Paolo Abeni) [1665984]
- [net] ip6mr: Fix potential Spectre v1 vulnerability (Stefano Brivio) [1663472]
- [net] ipv4: Fix potential Spectre v1 vulnerability (Stefano Brivio) [1663472]
- [include] add KABI padding to file_system_type (Eric Sandeen) [1665320 1650565]
- [include] add KABI padding to multiple fs ops vectors (Eric Sandeen) [1665320]
- [fs] add KABI padding to dentry structure (Eric Sandeen) [1665320]
- [fs] add KABI padding to inode structure (Eric Sandeen) [1665320]
- [include] add KABI padding to file_lock structure (Eric Sandeen) [1665320]
- [include] KABI: add an iopoll method to struct file_operations (Eric Sandeen) [1665320]
- [sound] ALSA: emux: Fix potential Spectre v1 vulnerabilities (Jaroslav Kysela) [1663477]
- [sound] ALSA: pcm: Fix potential Spectre v1 vulnerability (Jaroslav Kysela) [1663477]
- [sound] ALSA: rme9652: Fix potential Spectre v1 vulnerability (Jaroslav Kysela) [1663477]
- [sound] ALSA: emu10k1: Fix potential Spectre v1 vulnerabilities (Jaroslav Kysela) [1663477]
- [powerpc] powerpc/tm: Unset MSR[TS] if not recheckpointing (Gustavo Duarte) [1663853]
- [netdrv] r8152: Add support for MAC address pass through on RTL8153-BND (Perry Yuan) [1658433]
- [hid] HID: debug: fix the ring buffer implementation (Tony Camuso) [1669469] {CVE-2019-3819}

* Wed Jan 23 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-64.el8]
- [netdrv] net: hns: Fix WARNING when hns modules installed (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Fix ping failed when use net bridge and send multicast (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Add mac pcs config when enable|disable mac (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Fix ntuple-filters status error. (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Free irq when exit from abnormal branch (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Clean rx fbd when ae stopped. (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Some registers use wrong address according to the datasheet. (Xiaojun Tan) [1662120]
- [netdrv] net: hns: All ports can not work when insmod hns ko after rmmod. (Xiaojun Tan) [1662120]
- [netdrv] net: hns: Incorrect offset address used for some registers. (Xiaojun Tan) [1662120]
- [include] ipmi: RH_KABI macros to pad kabi exposed structs (Tony Camuso) [1658175]
- [scsi] reserve space in structures for KABI (Ewan Milne) [1664397]

* Sat Jan 19 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-63.el8]
- [include] PCI: Add reserved fields to 'struct hotplug_slot' (Myron Stowe) [1663534]
- [include] PCI: Add reserved fields to 'struct hotplug_slot_ops' (Myron Stowe) [1663534]
- [pci] PCI: Add reserved fields to 'struct pci_sriov' (Myron Stowe) [1663534]
- [include] PCI: Add reserved fields to 'struct pci_driver' (Myron Stowe) [1663534]
- [include] PCI: Add reserved fields to 'struct pci_bus' (Myron Stowe) [1663534]
- [include] PCI: Add reserved fields, and extension, to 'struct pci_dev' (Myron Stowe) [1663534]
- [pci] PCI: Add missing include to drivers/pci.h (Myron Stowe) [1663534]
- [pci] PCI/IOV: Use VF0 cached config space size for other VFs (Myron Stowe) [1663534]
- [include] PCI: always include 'p2pdma' in 'struct pci_dev' (Myron Stowe) [1663534]
- [ata] PCI: Remove pci_set_dma_max_seg_size() (Myron Stowe) [1663534]
- [pci] PCI: Remove pci_set_dma_seg_boundary() (Myron Stowe) [1663534]
- [include] PCI: Remove pci_unmap_addr() wrappers for DMA API (Myron Stowe) [1663534]
- [pci] PCI/AER: Abstract AER interrupt handling (Myron Stowe) [1663534]
- [pci] PCI: Uninline PCI bus accessors for better ftracing (Myron Stowe) [1663534]
- [pci] PCI/portdrv: Add runtime PM hooks for port service drivers (Myron Stowe) [1663534]
- [pci] PCI: Make link active reporting detection generic (Myron Stowe) [1663534]
- [block] block: don't lose track of REQ_INTEGRITY flag (Ming Lei) [1665684]
- [nvme] nvme-pci: fix nvme_setup_irqs() (Ming Lei) [1661439]
- [lib] sbitmap: Protect swap_lock from hardirq (Ming Lei) [1666192]
- [lib] sbitmap: Protect swap_lock from softirqs (Ming Lei) [1666192]
- [scsi] scsi: isci: initialize shost fully before calling scsi_add_host() (Ming Lei) [1664918]
- [nvme] nvmet-fc: Mark NVMe/FC target mode driver as unsupported (Ewan Milne) [1664838]
- [netdrv] bnx2x: Assign unique DMAE channel number for FW DMAE transactions. (Jonathan Toppins) [1638306]
- [fs] block: don't use un-ordered __set_current_state(TASK_UNINTERRUPTIBLE) (Ming Lei) [1664580]
- [netdrv] qed: Wait for ready indication before rereading the shmem (Chad Dupuis) [1652417]
- [netdrv] qed: Avoid sending mailbox commands when MFW is not responsive (Chad Dupuis) [1652417]
- [netdrv] qed: Wait for MCP halt and resume commands to take place (Chad Dupuis) [1652417]
- [netdrv] qed: Prevent a possible deadlock during driver load and unload (Chad Dupuis) [1652417]
- [fs] gfs2: Fix loop in gfs2_rbm_find (Andreas Grunbacher) [1658528]
- [fs] gfs2: Get rid of potential double-freeing in gfs2_create_inode (Andreas Grunbacher) [1658539]

* Thu Jan 17 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-62.el8]
- [vhost] vhost/vsock: fix vhost vsock cid hashing inconsistent (Stefan Hajnoczi) [1619848] {CVE-2018-14625}
- [vhost] vhost/vsock: fix use-after-free in network stack callers (Stefan Hajnoczi) [1619848] {CVE-2018-14625}
- [netdrv] bnx2x: Add VF spoof-checking configuration (Jonathan Toppins) [1646842]
- [netdrv] net-next: hinic: fix a problem in free_tx_poll() (Xiaojun Tan) [1642016]
- [netdrv] net: hns: fix for unmapping problem when SMMU is on (Xiaojun Tan) [1640526]
- [netdrv] net: hns: add netif_carrier_off before change speed and duplex (Xiaojun Tan) [1640526]
- [netdrv] net: hns: add the code for cleaning pkt in chip (Xiaojun Tan) [1640526]
- [netdrv] net: hns: modify variable type in hns_nic_reuse_page (Xiaojun Tan) [1640526]

* Wed Jan 16 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-61.el8]
- [irqchip] Mark GICv2 deprecated (Wei Huang) [1609391]
- [scsi] qla2xxx: Use correct number of vectors for online CPUs (Himanshu Madhani) [1644058]
- [scsi] megaraid_sas: mark Aero controllers as tech preview (Tomas Henzl) [1659972]
- [scsi] megaraid_sas: add retry logic in megasas_readl (Tomas Henzl) [1659972]
- [scsi] scsi: megaraid_sas: Introduce new Aero adapter type (Tomas Henzl) [1659972]
- [scsi] scsi: megaraid_sas: Fix Ventura series based checks (Tomas Henzl) [1659972]
- [scsi] scsi: libfc: retry PRLI if we cannot analyse the payload (Chris Leech) [1631843]
- [scsi] scsi: libfc: check fc_frame_payload_get() return value for null (Chris Leech) [1631843]
- [scsi] scsi: libfc: hold disc_mutex in fc_disc_stop_rports() (Chris Leech) [1631843]
- [scsi] scsi: libfc: fixup lockdep annotations (Chris Leech) [1631843]
- [scsi] scsi: libfc: fixup 'sleeping function called from invalid context' (Chris Leech) [1631843]
- [scsi] scsi: libfc: Add lockdep annotations (Chris Leech) [1631843]
- [md] dm crypt: fix parsing of extended IV arguments (Mike Snitzer) [1665290]
- [kernel] redhat: kabi: reserved padding for kernel sched data structures (Rafael Aquini) [1664858]
- [kernel] redhat: kabi: reserved padding for MM related data structures (Rafael Aquini) [1664858]
- [vfio] vfio/type1: Fix unmap overflow off-by-one (Alex Williamson) [1662291]
- [message] mptspi: pci-id table changes (Tomas Henzl) [1651803]
- [message] mptspi: Taint kernel if mptspi is loaded (Tomas Henzl) [1651803]
- [block] kabi: reserve space for public data structure (Ming Lei) [1551939]
- [block] kabi: reserve space for blk-mq related structure (Ming Lei) [1551939]
- [block] kabi: reserve space for bsg related structure (Ming Lei) [1551939]
- [block] kabi: reserve space for integrity related structure (Ming Lei) [1551939]
- [block] kabi: reserve space for CONFIG_BLK_DEV_ZONED (Ming Lei) [1551939]
- [ata] ata: Disable AHCI ALPM feature for Ampere Computing eMAG SATA (David Milburn) [1663347]
- [kvm] KVM: x86: Add CPUID support for new instruction WBNOINVD (Andrew Jones) [1659491]
- [x86] KVM: x86: Use jmp to invoke kvm_spurious_fault() from .fixup (Andrew Jones) [1659491]
- [virt] kvm: Change offset in kvm_write_guest_offset_cached to unsigned (Andrew Jones) [1659491]
- [virt] kvm: Disallow wraparound in kvm_gfn_to_hva_cache_init (Andrew Jones) [1659491]
- [kvm] KVM: x86: svm: report MSR_IA32_MCG_EXT_CTL as unsupported (Andrew Jones) [1659491]
- [virt] arm/arm64: KVM: Add ARM_EXCEPTION_IS_TRAP macro (Andrew Jones) [1659491]
- [arm64] arm64: KVM: Avoid setting the upper 32 bits of VTCR_EL2 to 1 (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: Fix unintended stage 2 PMD mappings (Andrew Jones) [1659491]
- [virt] arm/arm64: KVM: vgic: Force VM halt when changing the active state of GICv3 PPIs/SGIs (Andrew Jones) [1659491]
- [arm64] KVM: arm/arm64: Fixup the kvm_exit tracepoint (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: vgic: Consider priority and active state for pending irq (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: vgic: Fix off-by-one bug in vgic_get_irq() (Andrew Jones) [1659491]
- [kvm] KVM: X86: Fix NULL deref in vcpu_scan_ioapic (Andrew Jones) [1659491]
- [kvm] KVM: Fix UAF in nested posted interrupt processing (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: vgic: Cap SPIs to the VM-defined maximum (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: vgic: Do not cond_resched_lock() with IRQs disabled (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: vgic-v2: Set active_source to 0 when restoring state (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: Fix VMID alloc race by reverting to lock-less (Andrew Jones) [1659491]
- [kvm] KVM: nVMX: Free the VMREAD/VMWRITE bitmaps if alloc_kvm_area() fails (Andrew Jones) [1659491]
- [kvm] arm64: KVM: Install stage-2 translation before enabling traps (Andrew Jones) [1659491]
- [kvm] arm64: KVM: Make VHE Stage-2 TLB invalidation operations non-interruptible (Andrew Jones) [1659491]
- [arm64] arm64: entry: Remove confusing comment (Andrew Jones) [1659491]
- [kvm] arm64: entry: Place an SB sequence following an ERET instruction (Andrew Jones) [1659491]
- [arm64] arm64: Add support for SB barrier and patch in over DSB; ISB sequences (Andrew Jones) [1659491]
- [kvm] kvm: nVMX: Set VM instruction error for VMPTRLD of unbacked page (Andrew Jones) [1659491]
- [kvm] kvm: svm: Ensure an IBPB on all affected CPUs when freeing a vmcb (Andrew Jones) [1659491]
- [kvm] kvm: mmu: Fix race in emulated page table writes (Andrew Jones) [1659491]
- [kvm] KVM: nVMX/nSVM: Fix bug which sets vcpu->arch.tsc_offset to L1 tsc_offset (Andrew Jones) [1659491]
- [kvm] KVM: VMX: Update shared MSRs to be saved/restored on MSR_EFER.LMA changes (Andrew Jones) [1659491]
- [kvm] KVM: x86: Fix kernel info-leak in KVM_HC_CLOCK_PAIRING hypercall (Andrew Jones) [1659491]
- [kvm] svm: Add mutex_lock to protect apic_access_page_done on AMD systems (Andrew Jones) [1659491]
- [kvm] KVM/nVMX: Do not validate that posted_intr_desc_addr is page aligned (Andrew Jones) [1659491]
- [kvm] KVM: arm64: Safety check PSTATE when entering guest and handle IL (Andrew Jones) [1659491]
- [virt] KVM: arm64: Fix caching of host MDCR_EL2 value (Andrew Jones) [1659491]
- [kvm] x86/kvm/nVMX: allow bare VMXON state migration (Andrew Jones) [1659491]
- [kvm] x86/kvm/lapic: preserve gfn_to_hva_cache len on cache reinit (Andrew Jones) [1659491]
- [kvm] KVM: hyperv: define VP assist page helpers (Andrew Jones) [1659491]
- [kvm] KVM: nVMX: move check_vmentry_postreqs() call to nested_vmx_enter_non_root_mode() (Andrew Jones) [1659491]
- [kvm] KVM: nVMX: Always reflect #NM VM-exits to L1 (Andrew Jones) [1659491]
- [kvm] KVM: x86: hyperv: consistently use 'hv_vcpu' for 'struct kvm_vcpu_hv' variables (Andrew Jones) [1659491]
- [kvm] KVM: x86: hyperv: enforce vp_index < KVM_MAX_VCPUS (Andrew Jones) [1659491]
- [kvm] KVM: nVMX: restore host state in nested_vmx_vmexit for VMFail (Andrew Jones) [1659491]
- [kvm] KVM: nVMX: Clear reserved bits of #DB exit qualification (Andrew Jones) [1659491]
- [virt] KVM: arm/arm64: Ensure only THP is candidate for adjustment (Andrew Jones) [1659491]
- [kvm] x86: kvm: avoid unused variable warning (Andrew Jones) [1659491]
- [kvm] powerpc64/ftrace: Include ftrace.h needed for enable/disable calls (Andrew Jones) [1659491]
- [kvm] x86/kvm/vmx: Remove duplicate l1d flush definitions (Andrew Jones) [1659491]
- [tools] perf kvm: Fix subcommands on s390 (Andrew Jones) [1659491]
- [arm64] arm64: add PSR_AA32_* definitions (Andrew Jones) [1659491]
- [pci] PCI: hotplug: Document TODOs (Myron Stowe) [1664454]
- [pci] PCI: hotplug: Embed hotplug_slot (Myron Stowe) [1664454]
- [pci] PCI: hotplug: Drop hotplug_slot_info (Myron Stowe) [1664454]
- [pci] PCI: hotplug: Constify hotplug_slot_ops (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Reshuffle controller struct for clarity (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Rename controller struct members for clarity (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Unify controller and slot structs (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Tolerate Presence Detect hardwired to zero (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Drop hotplug_slot_ops wrappers (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Drop unnecessary includes (Myron Stowe) [1664454]
- [pci] PCI: pciehp: Differentiate between surprise and safe removal (Myron Stowe) [1664454]
- [pci] PCI: Simplify disconnected marking (Myron Stowe) [1664454]
- [tools] perf vendor events arm64: Revise core JSON events for eMAG (Jiri Olsa) [1663353]
- [tools] perf vendor events arm64: Enable JSON events for eMAG (Jiri Olsa) [1663353]
- [perf] drivers/perf: xgene: Add CPU hotplug support (Jiri Olsa) [1663349]
- [scsi] mpt3sas: mark Aero controllers as tech preview (Tomas Henzl) [1663281]
- [powerpc] KVM: PPC: Book3S HV: Keep rc bits in shadow pgtable in sync with host (Suraj Jitindar Singh) [1662029]
- [powerpc] KVM: PPC: Book3S HV: Introduce kvmhv_update_nest_rmap_rc_list() (Suraj Jitindar Singh) [1662029]
- [powerpc] KVM: PPC: Book3S HV: Apply combination of host and l1 pte rc for nested guest (Suraj Jitindar Singh) [1662029]
- [powerpc] KVM: PPC: Book3S HV: Align gfn to L1 page size when inserting nest-rmap entry (Suraj Jitindar Singh) [1662029]
- [powerpc] KVM: PPC: Book3S HV: Hold kvm->mmu_lock across updating nested pte rc bits (Suraj Jitindar Singh) [1662029]
- [tools] perf python: Do not force closing original perf descriptor in evlist.get_pollfd (Jiri Olsa) [1659445]
- [mm] mm: thp: relax __GFP_THISNODE for MADV_HUGEPAGE mappings (Andrea Arcangeli) [1613993]
- [rpmspec] spec: Add libperf-jvmti.so into perf debuginfo rpm (Jiri Olsa) [1653570]
- [scsi] scsi: hisi_sas: Fix spin lock management in slot_index_alloc_quirk_v2_hw() (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Update v3 hw AIP_LIMIT and CFG_AGING_TIME register values (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Use block layer tag instead for IPTT (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: unmask interrupts ent72 and ent74 (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Free slot later in slot_complete_vx_hw() (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Fix the race between IO completion and timeout for SMP/internal IO (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Move evaluation of hisi_hba in hisi_sas_task_prep() (Xiaojun Tan) [1642819]
- [scsi] scsi: hisi_sas: Feed back linkrate(max/min) when re-attached (Xiaojun Tan) [1642819]
- [hwtracing] intel_th: pci: Add Ice Lake PCH support (Jiri Olsa) [1485529]

* Fri Jan 11 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-60.el8]
- [kernel] userns: also map extents in the reverse map to kernel IDs (Chris von Recklinghausen) [1652679] {CVE-2018-18955}
- [net] ipv6: route: Fix return value of ip6_neigh_lookup() on neigh_create() error (Stefano Brivio) [1662789]
- [net] ipv6: frags: Fix bogus skb->sk in reassembled packets (Herbert Xu) [1645839]
- [net] redhat: blacklist auto-loadable net modules in modules-extra (Marcelo Leitner) [1642795]
- [net] redhat: move sctp modules to kernel-modules-extra (Marcelo Leitner) [1642795]
- [net] add reserved fields to neighbour (Paolo Abeni) [1655084]
- [net] add reserved fields to rtnl_link_stats* (Paolo Abeni) [1655084]
- [net] reserve bits in netdev_features_t for future features (Paolo Abeni) [1655084]
- [net] add reserved fields to sk_buff (Paolo Abeni) [1655084]
- [net] add reserved fields to ipv6_devconf (Paolo Abeni) [1655084]
- [net] add reserved fields to fib_rule (Paolo Abeni) [1655084]
- [net] add reserved fields to sock (Paolo Abeni) [1655084]
- [net] add reserved fields to genl_family (Paolo Abeni) [1655084]
- [net] add reserved fields to proto_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to proto (Paolo Abeni) [1655084]
- [net] add reserved fields to genl_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to dst_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to dst_entry (Paolo Abeni) [1655084]
- [net] add reserved fields to lwtunnel_state (Paolo Abeni) [1655084]
- [net] add reserved fields to packet_type (Paolo Abeni) [1655084]
- [net] add reserved fields to napi_struct (Paolo Abeni) [1655084]
- [net] add reserved fields to net_device (Paolo Abeni) [1655084]
- [net] exclude wireless_dev from KABI protection (Paolo Abeni) [1655084]
- [net] add reserved fields to dcbnl_rtnl_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to xfrm_* (Paolo Abeni) [1655084]
- [net] add reserved fields to switchdev_obj (Paolo Abeni) [1655084]
- [net] add reserved fields to switchdev_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to l3mdev_ops (Paolo Abeni) [1655084]
- [net] exclude ndisc_ops from kABI protection (Paolo Abeni) [1655084]
- [net] add reserved fields to xfrmdev_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to tlsdev_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to netdev_rx_queue (Paolo Abeni) [1655084]
- [net] add reserved fields to netdev_queue (Paolo Abeni) [1655084]
- [net] add reserved fields to rtnl_link_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to ethtool_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to header_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to net_device_ops (Paolo Abeni) [1655084]
- [net] add reserved fields to flowi* structs (Paolo Abeni) [1655084]
- [arm64] KVM: arm64: Clarify explanation of STAGE2_PGTABLE_LEVELS (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] KVM: arm/arm64: Rename kvm_arm_config_vm to kvm_arm_setup_stage2 (Christoph von Recklinghausen) [1643586 1643522]
- [virt] KVM: arm64: Drop __cpu_init_stage2 on the VHE path (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Allow tuning the physical address size for VM (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Limit the minimum number of page table levels (Christoph von Recklinghausen) [1643586 1643522]
- [virt] kvm: arm64: Set a limit on the IPA size (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Add 52bit support for PAR to HPFAR conversoin (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm64: Switch to per VM IPA limit (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Configure VTCR_EL2.SL0 per VM (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm64: Dynamic configuration of VTTBR mask (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm64: Make stage2 page table layout dynamic (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm64: Prepare for dynamic stage2 page table layout (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm/arm64: Prepare for VM specific stage2 translations (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] kvm: arm64: Configure VTCR_EL2 per VM (Christoph von Recklinghausen) [1643586 1643522]
- [virt] kvm: arm/arm64: Allow arch specific configurations for VM (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Clean up VTCR_EL2 initialisation (Christoph von Recklinghausen) [1643586 1643522]
- [arm64] arm64: Add a helper for PARange to physical shift conversion (Christoph von Recklinghausen) [1643586 1643522]
- [kvm] kvm: arm64: Add helper for loading the stage2 setting for a VM (Christoph von Recklinghausen) [1643586 1643522]
- [virt] kvm: arm/arm64: Remove spurious WARN_ON (Christoph von Recklinghausen) [1643586 1643522]
- [virt] kvm: arm/arm64: Fix stage2_flush_memslot for 4 level page table (Christoph von Recklinghausen) [1643586 1643522]
- [hv] hv_balloon: avoid touching uninitialized struct page during tail onlining (Vitaly Kuznetsov) [1662277]
- [x86] Mark AMD EPYC guests as supported (David Arcari) [1663356]
- [netdrv] be2net: Disable queue dump in be_tx_timeout handler (Petr Oros) [1646838]
- [vhost] vhost: Fix Spectre V1 vulnerability (Jason Wang) [1663469]
- [mm] mm/hugetlb.c: teach follow_hugetlb_page() to handle FOLL_NOWAIT (Andrea Arcangeli) [1575028]
- [tools] cpupower: Fix AMD Family 0x17 msr_pstate size (Prarit Bhargava) [1659883]
- [tools] cpupower: Fix coredump on VMWare (Prarit Bhargava) [1659883]
- [scsi] scsi: csiostor: remove flush_scheduled_work() (Arjun Vynipadath) [1663973]
- [powerpc] KVM: PPC: Book3S HV: Fix race between kvm_unmap_hva_range and MMU mode switch (David Gibson) [1663225]
- [fs] userfaultfd: check VM_MAYWRITE was set after verifying the uffd is registered (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: shmem: UFFDIO_COPY: set the page dirty if VM_WRITE is not set (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: shmem: add i_size checks (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: shmem/hugetlbfs: only allow to register VM_MAYWRITE vmas (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: shmem: allocate anonymous memory for MAP_PRIVATE shmem (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: use ENOENT instead of EFAULT if the atomic copy user fails (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [mm] userfaultfd: allow get_mempolicy(MPOL_F_NODE|MPOL_F_ADDR) to trigger userfaults (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [fs] userfaultfd: clear flag if remap event not enabled (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [fs] userfaultfd: disable irqs when taking the waitqueue lock (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [fs] fs/userfaultfd.c: remove redundant pointer uwq (Andrea Arcangeli) [1657615] {CVE-2018-18397}
- [fs] NFS: nfs_compare_mount_options always compare auth flavors. (Steve Dickson) [1661619]
- [infiniband] RDMA/hns: Bugfix for RoCE loopback test (Xiaojun Tan) [1663359]
- [infiniband] RDMA/hns: Update posting & querying mailbox (Xiaojun Tan) [1663359]
- [infiniband] RDMA/hns: Fix the bug while use multi-hop of pbl (Xiaojun Tan) [1663359]
- [infiniband] RDMA/hns: Init qp context when modify qp from reset to init (Xiaojun Tan) [1663359]
- [infiniband] RDMA/hns: Bugfix pbl configuration for rereg mr (Xiaojun Tan) [1663359]
- [security] selinux: add support for RTM_NEWCHAIN, RTM_DELCHAIN, and RTM_GETCHAIN (Ondrej Mosnacek) [1660564]
- [scsi] scsi: megaraid_sas: driver version update (Tomas Henzl) [1656261]
- [scsi] scsi: megaraid_sas: Use 63-bit DMA addressing (Tomas Henzl) [1656261]
- [x86] x86/kvm: mark as TechPreview when running as a nested hypervisor (Vitaly Kuznetsov) [1519039]
- [rpmspec] kernel.spec: Fix kernel-tools files section logic (Prarit Bhargava) [1661247]
- [crypto] crypto: ccp - Make function sev_get_firmware() static (Gary Hook) [1632894]
- [crypto] crypto: ccp - Allow SEV firmware to be chosen based on Family and Model (Gary Hook) [1632894]
- [crypto] crypto: ccp - Fix static checker warning (Gary Hook) [1632894]
- [crypto] crypto: ccp - add timeout support in the SEV command (Gary Hook) [1632894]
- [nvdimm] nvdimm: Use namespace index data to reduce number of label reads needed (Jeff Moyer) [1634345]
- [nvdimm] nvdimm: Split label init out from the logic for getting config data (Jeff Moyer) [1634345]
- [nvdimm] nvdimm: Remove empty if statement (Jeff Moyer) [1634345]
- [nvdimm] nvdimm: Clarify comment in sizeof_namespace_index (Jeff Moyer) [1634345]
- [nvdimm] nvdimm: Sanity check labeloff (Jeff Moyer) [1634345]
- [nvdimm] libnvdimm, dimm: Maximize label transfer size (Jeff Moyer) [1634345]
- [mm] mm/page-writeback.c: fix range_cyclic writeback vs writepages deadlock (Brian Foster) [1659528]
- [input] Input: elantech - disable elan-i2c for P52 and P72 (Benjamin Tissoires) [1658602]
- [fs] cachefiles: avoid deprecated get_seconds() (David Howells) [1655613]
- [fs] fscache, cachefiles: remove redundant variable 'cache' (David Howells) [1655613]
- [fs] cachefiles: Explicitly cast enumerated type in put_object (David Howells) [1655613]
- [fs] fscache: fix race between enablement and dropping of object (David Howells) [1655613]
- [fs] cachefiles: Fix page leak in cachefiles_read_backing_file while vmscan is active (David Howells) [1655613]
- [fs] fscache: Fix race in fscache_op_complete() due to split atomic_sub & read (David Howells) [1655613]
- [fs] cachefiles: Fix an assertion failure when trying to update a failed object (David Howells) [1655613]
- [fs] fscache: Fix out of bound read in long cookie keys (David Howells) [1655613]
- [fs] fscache: Fix incomplete initialisation of inline key space (David Howells) [1655613]
- [fs] cachefiles: fix the race between cachefiles_bury_object() and rmdir(2) (David Howells) [1655613]
- [kernel] ebpf: record usage of eBPF (Jiri Benc) [1654279]
- [kernel] add rh_features to /proc (Jiri Benc) [1654279]
- [kernel] add support for rh_features (Jiri Benc) [1654279]
- [fs] fs/lock: show locks taken by processes from another pidns (Miklos Szeredi) [1616125]
- [iommu] iommu/arm-smmu: Support non-strict mode (Xiaojun Tan) [1643114]
- [iommu] iommu/io-pgtable-arm-v7s: Add support for non-strict mode (Xiaojun Tan) [1643114]
- [iommu] iommu/arm-smmu-v3: Add support for non-strict mode (Xiaojun Tan) [1643114]
- [iommu] iommu/io-pgtable-arm: Add support for non-strict mode (Xiaojun Tan) [1643114]
- [iommu] iommu: Add "iommu.strict" command line option (Xiaojun Tan) [1643114]
- [iommu] iommu/dma: Add support for non-strict mode (Xiaojun Tan) [1643114]
- [iommu] iommu/arm-smmu: Ensure that page-table updates are visible before TLBI (Xiaojun Tan) [1643114]
- [iommu] iommu/arm-smmu-v3: Implement flush_iotlb_all hook (Xiaojun Tan) [1643114]
- [iommu] iommu/arm-smmu-v3: Avoid back-to-back CMD_SYNC operations (Xiaojun Tan) [1643114]
- [iommu] iommu/arm-smmu-v3: Fix unexpected CMD_SYNC timeout (Xiaojun Tan) [1643114]
- [iommu] iommu/io-pgtable-arm: Fix race handling in split_blk_unmap() (Xiaojun Tan) [1643114]
- [infiniband] RDMA/hns: Update some attributes of the RoCE device (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Limit the size of extend sge of sq (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Bugfix for CM test (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Submit bad wr when post send wr exception (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Bugfix for reserved qp number (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Refactor the codes for setting transport opode (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Move all prints out of irq handle (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Fix an error code in hns_roce_v2_init_eq_table() (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Fix usage of bitmap allocation functions return values (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Support flush cqe for hip08 in kernel space (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Program the tclass and flow label into the hardware (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Use macro instead of magic number (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Modify qp will return errno when qp type is illegal (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Assign the value for vlan field of qp context (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Only assgin the fields of the av if IB_QP_AV bit is set (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Enable modify_cq for uverbs. (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Update the data type of immediate data (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Use delay instead of usleep (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Add illegal hop_num judgement (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Add 50GE type of hnae3 device match (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Do not overwrite the error code during error unwind in hns_roce_init (Xiaojun Tan) [1639578]
- [infiniband] hns: Remove a set-but-not-used variable (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Update the implementation of set_mac (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Update the implementation of set_gid (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Add TPQ link table support (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Add TSQ link table support (Xiaojun Tan) [1639578]
- [infiniband] RDMA/hns: Fix endian conversions and annotations (Xiaojun Tan) [1639578]
- [scsi] scsi: hisi_sas: Add SATA FIS check for v3 hw (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: add memory barrier in task delivery function (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Tidy hisi_sas_task_prep() (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Implement handlers of PCIe FLR for v3 hw (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: relocate some common code for v3 hw (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: tidy host controller reset function a bit (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Fix the failure of recovering PHY from STP link timeout (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: tidy channel interrupt handler for v3 hw (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Drop hisi_sas_slot_abort() (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Update a couple of register settings for v3 hw (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Add missing PHY spinlock init (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Pre-allocate slot DMA buffers (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Release all remaining resources in clear nexus ha (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Add a flag to filter PHY events during reset (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Adjust task reject period during host reset (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Fix the conflict between dev gone and host reset (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Only process broadcast change in phy_bcast_v3_hw() (Zhou Wang) [1639541]
- [scsi] scsi: hisi_sas: Use dmam_alloc_coherent() (Zhou Wang) [1639541]
- [netdrv] xen/netfront: fix waiting for xenbus state change (Petr Oros) [1638456]

* Thu Jan 10 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-59.el8]
- [x86] expand cpu feature/bug bits (David Arcari) [1662434]
- [x86] add kabi support for cpuinfo_x86 (David Arcari) [1662434]
- [init] Display a message about certified hardware (Steve Best) [1660523]
- [scsi] scsi: t10-pi: Return correct ref tag when queue has no integrity profile (Ming Lei) [1660719]
- [scsi] scsi: storvsc: Fix a race in sub-channel creation that can cause panic (Mohammed Gamal) [1650149]
- [uio] uio_hv_generic: set callbacks on open (Mohammed Gamal) [1650149]
- [hv] vmbus: fix subchannel removal (Mohammed Gamal) [1650149]
- [uio] uio_hv_generic: defer opening vmbus until first use (Mohammed Gamal) [1650149]
- [hv] vmbus: split ring buffer allocation from open (Mohammed Gamal) [1650149]
- [hv] vmbus: pass channel to hv_process_channel_removal (Mohammed Gamal) [1650149]
- [hv] Drivers: hv: vmbus: Reset the channel callback in vmbus_onoffer_rescind() (Mohammed Gamal) [1650149]
- [uio] hv_uio_generic: map ringbuffer phys addr (Mohammed Gamal) [1650149]
- [uio] uio: introduce UIO_MEM_IOVA (Mohammed Gamal) [1650149]
- [hv] vmbus: add driver_override support (Mohammed Gamal) [1650149]
- [hv] vmbus: keep pointer to ring buffer page (Mohammed Gamal) [1650149]
- [uio] uio_hv_generic: increase size of receive and send buffers (Mohammed Gamal) [1650149]
- [uio] uio: add SPDX license tags (Mohammed Gamal) [1650149]
- [fs] gfs2: take jdata unstuff into account in do_grow (Robert S Peterson) [1660519]
- [drm] drm/dp_mst: Check if primary mstb is null (Lyude Paul) [1658711]
- [tools] perf tests: Use shebangs in the shell scripts (Michael Petlan) [1613523]

* Mon Jan 07 2019 Herton R. Krzesinski <herton@redhat.com> [4.18.0-58.el8]
- [mm] mm: put_and_wait_on_page_locked() while page is migrated (Baoquan He) [1649214]
- [netdrv] i40e: define proper net_device::neigh_priv_len (Stefan Assmann) [1658743]
- [netdrv] i40e: fix VLAN.TCI == 0 RX HW offload (Stefan Assmann) [1658743]
- [netdrv] i40e: fix mac filter delete when setting mac address (Stefan Assmann) [1658743]
- [netdrv] i40e: prevent overlapping tx_timeout recover (Stefan Assmann) [1658743]
- [netdrv] i40e: Use correct shift for VLAN priority (Stefan Assmann) [1658743]
- [netdrv] i40e: always set ks->base.speed in i40e_get_settings_link_up (Stefan Assmann) [1658743]
- [netdrv] i40e: don't restart nway if autoneg not supported (Stefan Assmann) [1658743]
- [netdrv] i40e: enable NETIF_F_NTUPLE and NETIF_F_HW_TC at driver load (Stefan Assmann) [1658743]
- [netdrv] i40e: restore NETIF_F_GSO_IPXIP[46] to netdev features (Stefan Assmann) [1658743]
- [acpi] ACPI/APEI: Clear GHES block_status before panic() (David Arcari) [1662442]
- [misc] VMCI: Resource wildcard match fixed (Vitaly Kuznetsov) [1652868]
- [mm] mm/page_alloc.c: don't call kasan_free_pages() at deferred mem init (Waiman Long) [1655964]
- [block] block/bio: Do not zero user pages (Ming Lei) [1662502]
- [vhost] disable zerocopy by default (Jason Wang) [1582756]
- [block] kyber: use sbitmap add_wait_queue/list_del wait helpers (Ming Lei) [1661426]
- [lib] sbitmap: add helpers for add/del wait queue handling (Ming Lei) [1661426]
- [net] Revert "sunrpc: Ensure we always close the socket after a connection shuts down" (Dave Wysochanski) [1657449]
- [vhost] vhost/vsock: fix reset orphans race with close timeout (Stefan Hajnoczi) [1660445]
- [misc] genwqe: Fix size check (Steve Best) [1660126]
- [fs] aio: fix spectre gadget in lookup_ioctx (Jeff Moyer) [1660963]
- [block] block: save irq state in blkg_lookup_create() (Ming Lei) [1660299]
- [md] dm: don't reuse bio for flushes (Ming Lei) [1660401]
- [wireless] mac80211_hwsim: Fix possible Spectre-v1 for hwsim_world_regdom_custom (Stanislaw Gruszka) [1637113]
- [wireless] nl80211: Fix possible Spectre-v1 for NL80211_TXRATE_HT (Stanislaw Gruszka) [1637113]
- [wireless] nl80211: Fix possible Spectre-v1 for CQM RSSI thresholds (Stanislaw Gruszka) [1637113]
- [block] blk-mq: enable IO poll if .nr_queues of type poll > 0 (Ming Lei) [1660826]
- [powerpc] powerpc/rtas: Fix a potential race between CPU-Offline & Migration (Desnes Augusto Nunes do Rosario) [1639266]
- [x86] kvm: x86: Add AMD's EX_CFG to the list of ignored MSRs (Eduardo Habkost) [1625111]
- [scsi] scsi_sysfs: make unpriv_sgio queue attribute accessible for non-block devices (Paolo Bonzini) [1584504]
- [block] scsi_ioctl: introduce unpriv_sgio queue flag (Paolo Bonzini) [1584504]
- [block] scsi_ioctl: pass request_queue to blk_verify_command (Paolo Bonzini) [1584504]
- [fs] ext4: missing !bh check in ext4_xattr_inode_write() (Lukas Czerner) [1659481]
- [fs] ext4: fix buffer leak in __ext4_read_dirblock() on error path (Lukas Czerner) [1659481]
- [fs] ext4: fix buffer leak in ext4_expand_extra_isize_ea() on error path (Lukas Czerner) [1659481]
- [fs] ext4: fix buffer leak in ext4_xattr_move_to_block() on error path (Lukas Czerner) [1659481]
- [fs] ext4: release bs.bh before re-using in ext4_xattr_block_find() (Lukas Czerner) [1659481]
- [fs] ext4: fix buffer leak in ext4_xattr_get_block() on error path (Lukas Czerner) [1659481]
- [fs] ext4: fix possible leak of s_journal_flag_rwsem in error path (Lukas Czerner) [1659481]
- [fs] ext4: fix possible leak of sbi->s_group_desc_leak in error path (Lukas Czerner) [1659481]
- [fs] ext4: avoid possible double brelse() in add_new_gdb() on error path (Lukas Czerner) [1659481]
- [fs] ext4: avoid buffer leak in ext4_orphan_add() after prior errors (Lukas Czerner) [1659481]
- [fs] ext4: avoid buffer leak on shutdown in ext4_mark_iloc_dirty() (Lukas Czerner) [1659481]
- [fs] ext4: fix possible inode leak in the retry loop of ext4_resize_fs() (Lukas Czerner) [1659481]
- [fs] ext4: fix missing cleanup if ext4_alloc_flex_bg_array() fails while resizing (Lukas Czerner) [1659481]
- [fs] ext4: add missing brelse() update_backups()'s error path (Lukas Czerner) [1659481]
- [fs] ext4: add missing brelse() add_new_gdb_meta_bg()'s error path (Lukas Czerner) [1659481]
- [fs] ext4: add missing brelse() in set_flexbg_block_bitmap()'s error path (Lukas Czerner) [1659481]
- [fs] ext4: avoid potential extra brelse in setup_new_flex_group_blocks() (Lukas Czerner) [1659481]
- [scsi] scsi: lpfc: Enable Management features for IF_TYPE=6 (Dick Kennedy) [1658755]
- [scsi] scsi: mpt3sas: Update driver version to 27.101.00.00 (Tomas Henzl) [1659035]
- [scsi] scsi: mpt3sas: Replace readl with ioc->base_readl (Tomas Henzl) [1659035]
- [scsi] scsi: mpt3sas: Add separate function for aero doorbell reads (Tomas Henzl) [1659035]
- [scsi] scsi: mpt3sas: Introduce flag for aero based controllers (Tomas Henzl) [1659035]
- [md] dm: do not allow readahead to limit IO size (Mike Snitzer) [1658757]
- [md] dm raid: fix false -EBUSY when handling check/repair message (Mike Snitzer) [1658757]
- [block] blk-mq: change blk_mq_queue_busy() to blk_mq_queue_inflight() (Mike Snitzer) [1658757]
- [md] dm rq: cleanup leftover code from recently removed q->mq_ops branching (Mike Snitzer) [1658757]
- [md] dm verity: log the hash algorithm implementation (Mike Snitzer) [1658757]
- [md] dm crypt: log the encryption algorithm implementation (Mike Snitzer) [1658757]
- [md] dm integrity: fix spelling mistake in workqueue name (Mike Snitzer) [1658757]
- [md] dm flakey: Properly corrupt multi-page bios. (Mike Snitzer) [1658757]
- [md] dm: Check for device sector overflow if CONFIG_LBDAF is not set (Mike Snitzer) [1658757]
- [md] dm crypt: use u64 instead of sector_t to store iv_offset (Mike Snitzer) [1658757]
- [md] dm kcopyd: Fix bug causing workqueue stalls (Mike Snitzer) [1658757]
- [md] dm snapshot: Fix excessive memory usage and workqueue stalls (Mike Snitzer) [1658757]
- [md] dm bufio: update comment in dm-bufio.c (Mike Snitzer) [1658757]
- [md] dm writecache: fix typo in error msg for creating writecache_flush_thread (Mike Snitzer) [1658757]
- [md] dm: remove indirect calls from __send_changing_extent_only() (Mike Snitzer) [1658757]
- [md] dm mpath: only flush workqueue when needed (Mike Snitzer) [1658757]
- [md] dm: avoid indirect call in __dm_make_request (Mike Snitzer) [1658757]
- [md] dm thin: bump target version (Mike Snitzer) [1658757]
- [md] dm thin: send event about thin-pool state change _after_ making it (Mike Snitzer) [1658757]
- [md] dm cache metadata: verify cache has blocks in blocks_are_clean_separate_dirty() (Mike Snitzer) [1658757]
- [md] dm writecache: remove disabled code in memory_entry() (Mike Snitzer) [1658757]
- [md] dm raid: avoid bitmap with raid4/5/6 journal device (Mike Snitzer) [1658757]
- [md] dm crypt: make workqueue names device-specific (Mike Snitzer) [1658757]
- [md] dm: add dm_table_device_name() (Mike Snitzer) [1658757]
- [md] dm ioctl: harden copy_params()'s copy_from_user() from malicious users (Mike Snitzer) [1658757]
- [md] dm: remove unnecessary unlikely() around WARN_ON_ONCE() (Mike Snitzer) [1658757]
- [md] dm thin: use refcount_t for thin_c reference counting (Mike Snitzer) [1658757]
- [netdrv] nfp: provide a better warning when ring allocation fails (Pablo Cascon) [1645456]
- [netdrv] nfp: use kvcalloc() to allocate SW buffer descriptor arrays (Pablo Cascon) [1645456]
- [scsi] scsi: lpfc: rport port swap discovery issue. (Dick Kennedy) [1656635]
- [scsi] scsi: lpfc: Fix discovery failures during port failovers with lots of vports (Dick Kennedy) [1656635]
- [scsi] scsi: lpfc: refactor mailbox structure context fields (Dick Kennedy) [1656635]
- [scsi] scsi: lpfc: Correct loss of fc4 type on remote port address change (Dick Kennedy) [1656635]
- [hid] HID: multitouch: Add pointstick support for Cirque Touchpad (Perry Yuan) [1656673]
- [powerpc] KVM: PPC: Book3S HV: Fix handling for interrupted H_ENTER_NESTED (Suraj Jitindar Singh) [1649980]
- [powerpc] powerpc: Select CONFIG_SWIOTLB (Gustavo Duarte) [1648466]
- [fs] nfs: Fix a missed page unlock after pg_doio() (Benjamin Coddington) [1651287]
- [arm64] arm64: fix possible spectre-v1 write in ptrace_hbp_set_event() (Mark Salter) [1637585]
- [fs] fsnotify: Fix busy inodes during unmount (Lukas Czerner) [1650462]
- [tools] perf vendor events arm64: Update ThunderX2 implementation defined pmu core events (Robert Richter) [1501638]
- [tools] perf tools: Fix undefined symbol scnprintf in libperf-jvmti.so (Jiri Olsa) [1579484]

* Tue Dec 18 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-57.el8]
- [block] blk-mq: export hctx->type in debugfs instead of sysfs (Ming Lei) [1660040]
- [block] blk-mq: fix dispatch from sw queue (Ming Lei) [1660040]
- [block] blk-mq: skip zero-queue maps in blk_mq_map_swqueue (Ming Lei) [1660040]
- [nvme] nvme-pci: don't share queue maps (Ming Lei) [1660040]
- [block] blk-mq: only dispatch to non-defauly queue maps if they have queues (Ming Lei) [1660040]
- [x86] KVM: LAPIC: Fix pv ipis use-before-initialization (Paul Lai) [1657702]
- [fs] autofs: fix directory and symlink access (Ian Kent) [1611967]
- [infiniband] IB/iser: Fix possible NULL deref at iser_inv_desc() (Don Dutile) [1657574]
- [infiniband] RDMA/core: Fix unwinding flow in case of error to register device (Don Dutile) [1657574]
- [infiniband] IB/rxe: fix for duplicate request processing and ack psns (Don Dutile) [1657574]
- [infiniband] IB/ipoib: Clear IPCB before icmp_send (Don Dutile) [1657574]
- [infiniband] RDMA/core: Do not expose unsupported counters (Don Dutile) [1657574]
- [infiniband] IB/ucm: Fix Spectre v1 vulnerability (Don Dutile) [1657574]
- [infiniband] RDMA/ucma: Fix Spectre v1 vulnerability (Don Dutile) [1657574]
- [infiniband] RDMA/uverbs: Don't overwrite NULL pointer with ZERO_SIZE_PTR (Don Dutile) [1657574]
- [infiniband] RDMA/cma: Do not ignore net namespace for unbound cm_id (Don Dutile) [1657574]
- [net] xprtrdma: Reset credit grant properly after a disconnect (Don Dutile) [1657574]
- [input] Input: hyper-v - fix wakeup from suspend-to-idle (Vitaly Kuznetsov) [1588888]
- [kernel] kernel: hung_task.c: disable on suspend (Vitaly Kuznetsov) [1588888]
- [kernel] redhat: add a comment with warning about RH_KABI_EXCLUDE usage (Jiri Benc) [1656933]
- [rpmspec] Sign the aarch64 kernel (Jeremy Linton) [1659158]

* Mon Dec 17 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-56.el8]
- [netdrv] nfp: flower: add geneve option match offload (Pablo Cascon) [1655604]
- [netdrv] nfp: flower: add geneve option push action offload (Pablo Cascon) [1655604]
- [netdrv] nfp: flower: offload tos and tunnel flags for ipv4 udp tunnels (Pablo Cascon) [1655604]
- [netdrv] nfp: flower: set ip tunnel ttl from encap action (Pablo Cascon) [1655604]
- [netdrv] nfp: flower: extract ipv4 udp tunnel ttl from route (Pablo Cascon) [1655604]
- [net] sctp: hold transport before accessing its asoc in sctp_transport_get_next (Marcelo Leitner) [1656271]
- [net] sctp: fix the data size calculation in sctp_data_size (Marcelo Leitner) [1656271]
- [net] sctp: fix race on sctp_id2asoc (Marcelo Leitner) [1656271]
- [net] rtnetlink: ndo_dflt_fdb_dump() only work for ARPHRD_ETHER devices (Hangbin Liu) [1657120]
- [netdrv] mlx5e: fix csum adjustments caused by RXFCS (Hangbin Liu) [1657120]
- [net] drop skb on failure in ip_check_defrag() (Hangbin Liu) [1657120]
- [net] rtnl_configure_link: fix dev flags changes arg to __dev_notify_flags (Hangbin Liu) [1657120]
- [net] socket: fix a missing-check bug (Hangbin Liu) [1657120]
- [net] rtnetlink: Disallow FDB configuration for non-Ethernet device (Hangbin Liu) [1657120]
- [net] rtnetlink: Fail dump if target netnsid is invalid (Hangbin Liu) [1657120]
- [net] rtnetlink: fix rtnl_fdb_dump() for ndmsg header (Hangbin Liu) [1657120]
- [net] rtnl: limit IFLA_NUM_TX_QUEUES and IFLA_NUM_RX_QUEUES to 4096 (Hangbin Liu) [1657120]
- [net] socket: fix struct ifreq size in compat ioctl (Hangbin Liu) [1657120]
- [net] fix pskb_trim_rcsum_slow() with odd trim offset (Hangbin Liu) [1657120]
- [net] gso_segment: Reset skb->mac_len after modifying network header (Hangbin Liu) [1657120]
- [net] Use __kernel_clockid_t in uapi net_stamp.h (Davide Caratti) [1638022]
- [net] tun: Consistently configure generic netdev params via rtnetlink (Matteo Croce) [1657910]
- [net] tun: napi flags belong to tfile (Matteo Croce) [1657910]
- [net] tun: initialize napi_mutex unconditionally (Matteo Croce) [1657910]
- [net] tun: remove unused parameters (Matteo Croce) [1657910]
- [net] team: Forbid enslaving team device to itself (Matteo Croce) [1658725]
- [net] sched: Remove TCA_OPTIONS from policy (Davide Caratti) [1658516]
- [net] sched: cls_api: add missing validation of netlink attributes (Davide Caratti) [1658516]
- [net] sched: gred: pass the right attribute to gred_change_table_def() (Davide Caratti) [1658516]
- [net] sched: cls_u32: fix hnode refcounting (Davide Caratti) [1658516]
- [net] sched: Add policy validation for tc attributes (Davide Caratti) [1658516]
- [net] bpf: use __GFP_COMP while allocating page (Andrea Claudi) [1658231]
- [net] xsk: do not call synchronize_net() under RCU read lock (Andrea Claudi) [1658231]
- [net] bpf: fix partial copy of map_ptr when dst is scalar (Andrea Claudi) [1658231]
- [net] bpf: Fix bpf_msg_pull_data() (Andrea Claudi) [1658231]
- [net] bpf: fix shift upon scatterlist ring wrap-around in bpf_msg_pull_data (Andrea Claudi) [1658231]
- [net] bpf: fix sg shift repair start offset in bpf_msg_pull_data (Andrea Claudi) [1658231]
- [net] bpf: fix msg->data/data_end after sg shift repair in bpf_msg_pull_data (Andrea Claudi) [1658231]
- [net] bpf: fix several offset tests in bpf_msg_pull_data (Andrea Claudi) [1658231]
- [net] vlan: add support for tunnel offload (Andrea Claudi) [1656804]
- [net] 8021q: move vlan offload registrations into vlan_core (Hangbin Liu) [1657658]
- [net] ipv6/ndisc: Preserve IPv6 control buffer if protocol error handlers are called (Stefano Brivio) [1658010]
- [net] ipv6: Allow onlink routes to have a device mismatch if it is the default route (Stefano Brivio) [1658010]
- [net] ipv6: Fix index counter for unicast addresses in in6_dump_addrs (Stefano Brivio) [1658010]
- [net] ipv6: mcast: fix a use-after-free in inet6_mc_check (Stefano Brivio) [1658010]
- [net] ipv6: rate-limit probes for neighbourless routes (Stefano Brivio) [1658010]
- [net] ipv6: stop leaking percpu memory in fib6 info (Stefano Brivio) [1658010]
- [net] ipv6: Remove extra call to ip6_convert_metrics for multipath case (Stefano Brivio) [1658010]
- [net] ipv6: Display all addresses in output of /proc/net/if_inet6 (Stefano Brivio) [1658010]
- [net] ipv6: do not copy dst flags on rt init (Stefano Brivio) [1658010]
- [net] ipv6: Only update MTU metric if it set (Stefano Brivio) [1658010]
- [net] ipv6: don't get lwtstate twice in ip6_rt_copy_init() (Stefano Brivio) [1658010]
- [net] ipv6: Put lwtstate when destroying fib6_info (Stefano Brivio) [1658010]
- [net] ip6_tunnel: Fix encapsulation layout (Stefano Brivio) [1658008]
- [net] vxlan: fill ttl inherit info (Stefano Brivio) [1658008]
- [net] ip_tunnel: be careful when accessing the inner header (Stefano Brivio) [1658008]
- [net] vti6: remove !skb->ignore_df check from vti6_xmit() (Stefano Brivio) [1658008]
- [net] ip6_vti: fix a null pointer deference when destroy vti6 tunnel (Stefano Brivio) [1658008]
- [net] ip6_vti: fix creating fallback tunnel device for vti6 (Stefano Brivio) [1658008]
- [net] ip_vti: fix a null pointer deferrence when create vti fallback tunnel (Stefano Brivio) [1658008]
- [net] l2tp: use sk_dst_check() to avoid race on sk->sk_dst_cache (Stefano Brivio) [1658008]
- [net] macsec: let the administrator set UP state even if lowerdev is down (Sabrina Dubroca) [1645540]
- [net] macsec: update operstate when lower device changes (Sabrina Dubroca) [1645540]
- [net] tcp: do not restart timewait timer on rst reception (Paolo Abeni) [1657988]
- [net] tcp: really ignore MSG_ZEROCOPY if no SO_ZEROCOPY (Paolo Abeni) [1657988]
- [net] tcp, ulp: add alias for all ulp modules (Paolo Abeni) [1657988]
- [net] tcp, ulp: fix leftover icsk_ulp_ops preventing sock from reattach (Paolo Abeni) [1657988]
- [net] ipv4: tcp: send zero IPID for RST and ACK sent in SYN-RECV and TIME-WAIT state (Paolo Abeni) [1657988]
- [net] neighbour: Avoid writing before skb->head in neigh_hh_output() (Stefano Brivio) [1643336]
- [net] ipv6: Check available headroom in ip6_xmit() even without options (Stefano Brivio) [1643336]
- [net] ipv6: fix possible use-after-free in ip6_xmit() (Stefano Brivio) [1643336]
- [net] openvswitch: Fix push/pop ethernet validation (Hangbin Liu) [1657226]
- [net] cgroup, netclassid: add a preemption point to write_classid (Hangbin Liu) [1657226]
- [net] ethtool: fix a privilege escalation bug (Hangbin Liu) [1657226]
- [net] llc: set SOCK_RCU_FREE in llc_sap_add_socket() (Hangbin Liu) [1657226]
- [net] dcb: For wild-card lookups, use priority -1, not 0 (Hangbin Liu) [1657226]
- [net] packet: fix packet drop as of virtio gso (Hangbin Liu) [1657226]
- [net] netlabel: check for IPV4MASK in addrinfo_get (Hangbin Liu) [1657226]
- [net] netfilter: seqadj: re-load tcp header pointer after possible head reallocation (Florian Westphal) [1654259]
- [net] netfilter: nf_tables: avoid BUG_ON usage (Florian Westphal) [1654259]
- [net] netfilter: nf_tables: deactivate expressions in rule replecement routine (Florian Westphal) [1654259]
- [net] netfilter: nat: fix double register in masquerade modules (Florian Westphal) [1654259]
- [net] netfilter: add missing error handling code for register functions (Florian Westphal) [1654259]
- [net] netfilter: nf_tables: fix use-after-free when deleting compat expressions (Florian Westphal) [1654259]
- [net] netfilter: xt_RATEEST: remove netns exit routine (Florian Westphal) [1654259]
- [net] netfilter: nf_tables: don't use position attribute on rule replacement (Florian Westphal) [1654259]
- [net] revert "netfilter: nft_numgen: add map lookups for numgen random operations" (Florian Westphal) [1654259]
- [net] netfilter: xt_IDLETIMER: add sysfs filename checking routine (Florian Westphal) [1654259]
- [net] netfilter: conntrack: fix calculation of next bucket number in early_drop (Florian Westphal) [1654259]
- [net] netfilter: conntrack: get rid of double sizeof (Florian Westphal) [1654259]
- [net] netfilter: nft_set_rbtree: add missing rb_erase() in GC routine (Florian Westphal) [1654259]
- [net] netfilter: nfnetlink_queue: Solve the NFQUEUE/conntrack clash for NF_REPEAT (Florian Westphal) [1654259]
- [net] netfilter: nf_tables: release chain in flushing set (Florian Westphal) [1654259]
- [net] netfilter: xt_checksum: ignore gso skbs (Florian Westphal) [1654259]
- [net] netfilter: xt_cluster: add dependency on conntrack module (Florian Westphal) [1654259]
- [net] netfilter: fix memory leaks on netlink_dump_start error (Florian Westphal) [1654259]
- [net] netfilter: x_tables: do not fail xt_alloc_table_info too easilly (Florian Westphal) [1654259]
- [net] ipvs: fix race between ip_vs_conn_new() and ip_vs_del_dest() (Florian Westphal) [1654259]
- [net] netfilter: ip6t_rpfilter: set F_IFACE for linklocal addresses (Florian Westphal) [1654259]
- [net] xfrm: policy: use hlist rcu variants on insert (Sabrina Dubroca) [1657272]
- [net] xfrm: validate template mode (Sabrina Dubroca) [1657272]
- [net] xfrm: Fix NULL pointer dereference when skb_dst_force clears the dst_entry. (Sabrina Dubroca) [1657272]
- [net] xfrm: reset transport header back to network header after all input transforms ahave been applied (Sabrina Dubroca) [1657272]
- [net] xfrm: reset crypto_done when iterating over multiple input xfrms (Sabrina Dubroca) [1657272]
- [net] xfrm: Validate address prefix lengths in the xfrm selector. (Sabrina Dubroca) [1657272]
- [net] tls: fix currently broken MSG_PEEK behavior (Sabrina Dubroca) [1657225]
- [net] tls: zero the crypto information from tls_context before freeing (Sabrina Dubroca) [1657225]
- [net] tls: clear key material from kernel memory when do_tls_setsockopt_conf fails (Sabrina Dubroca) [1657225]
- [net] tls: don't copy the key out of tls12_crypto_info_aes_gcm_128 (Sabrina Dubroca) [1657225]
- [net] tls: Set count of SG entries if sk_alloc_sg returns -ENOSPC (Sabrina Dubroca) [1657225]
- [net] tls: possible hang when do_tcp_sendpages hits sndbuf is full case (Sabrina Dubroca) [1657225]
- [net] tls: Fix improper revert in zerocopy_from_iter (Sabrina Dubroca) [1657225]
- [net] tls: Fix zerocopy_from_iter iov handling (Sabrina Dubroca) [1657225]
- [net] netfilter: conntrack: reset tcp maxwin on re-register (Florian Westphal) [1647310]
- [net] configs: Enable CONFIG_IP_SET_HASH_IPMAC as a module (Stefano Brivio) [1655301]
- [net] udp: fix handling of CHECKSUM_COMPLETE packets (Paolo Abeni) [1655656]
- [net] udp: Unbreak modules that rely on external __skb_recv_udp() availability (Paolo Abeni) [1655656]
- [net] udp6: fix encap return code for resubmitting (Paolo Abeni) [1655656]
- [net] team: no need to do team_notify_peers or team_mcast_rejoin when disabling port (Hangbin Liu) [1653197]
- [net] sctp: not increase stream's incnt before sending addstrm_in request (Xin Long) [1651428]
- [net] sctp: not allow to set asoc prsctp_enable by sockopt (Xin Long) [1647272]
- [net] revert "sctp: remove sctp_transport_pmtu_check" (Xin Long) [1643330]
- [net] fix XPS static_key accounting (Ivan Vecera) [1651781]
- [net] restore call to netdev_queue_numa_node_write when resetting XPS (Ivan Vecera) [1651781]
- [net] allow fallback function to pass netdev (Ivan Vecera) [1651781]
- [net] allow ndo_select_queue to pass netdev (Ivan Vecera) [1651781]
- [net] Add generic ndo_select_queue functions (Ivan Vecera) [1651781]
- [net] Add support for subordinate traffic classes to netdev_pick_tx (Ivan Vecera) [1651781]
- [net] ixgbe: Add code to populate and use macvlan TC to Tx queue map (Ivan Vecera) [1651781]
- [net] Add support for subordinate device traffic classes (Ivan Vecera) [1651781]
- [net] net-sysfs: Drop support for XPS and traffic_class on single queue device (Ivan Vecera) [1651781]
- [net] Provide stub for __netif_set_xps_queue if there is no CONFIG_XPS (Ivan Vecera) [1651781]
- [net] allow to call netif_reset_xps_queues() under cpus_read_lock (Ivan Vecera) [1651781]
- [net] documentation: Add explanation for XPS using Rx-queue(s) map (Ivan Vecera) [1651781]
- [net] net-sysfs: Add interface for Rx queue(s) map per Tx queue (Ivan Vecera) [1651781]
- [net] Enable Tx queue selection based on Rx queues (Ivan Vecera) [1651781]
- [net] Record receive queue number for a connection (Ivan Vecera) [1651781]
- [net] sock: Change tx_queue_mapping in sock_common to unsigned short (Ivan Vecera) [1651781]
- [net] Use static_key for XPS maps (Ivan Vecera) [1651781]
- [net] Refactor XPS for CPUs and Rx queues (Ivan Vecera) [1651781]
- [net] devlink: Add helper function for safely copy string param (Ivan Vecera) [1647914]
- [net] devlink: Fix param cmode driverinit for string type (Ivan Vecera) [1647914]
- [net] devlink: Fix param set handling for string type (Ivan Vecera) [1647914]
- [net] devlink: Add Documentation/networking/devlink-params-bnxt.txt (Ivan Vecera) [1647914]
- [net] devlink: Add Documentation/networking/devlink-params.txt (Ivan Vecera) [1647914]
- [net] devlink: Add generic parameter msix_vec_per_pf_min (Ivan Vecera) [1647914]
- [net] devlink: Add generic parameter msix_vec_per_pf_max (Ivan Vecera) [1647914]
- [net] devlink: Add generic parameter ignore_ari (Ivan Vecera) [1647914]
- [net] devlink: double free in devlink_resource_fill() (Ivan Vecera) [1647914]
- [net] devlink: Add extack for eswitch operations (Ivan Vecera) [1647914]
- [net] devlink: Add generic parameters region_snapshot (Ivan Vecera) [1647914]
- [net] devlink: Add support for region snapshot read command (Ivan Vecera) [1647914]
- [net] devlink: Add support for region snapshot delete command (Ivan Vecera) [1647914]
- [net] devlink: Extend the support querying for region snapshot IDs (Ivan Vecera) [1647914]
- [net] devlink: Add support for region get command (Ivan Vecera) [1647914]
- [net] devlink: Add support for creating region snapshots (Ivan Vecera) [1647914]
- [net] devlink: Add callback to query for snapshot id before snapshot create (Ivan Vecera) [1647914]
- [net] devlink: Add support for creating and destroying regions (Ivan Vecera) [1647914]
- [net] devlink: fix incorrect return statement (Ivan Vecera) [1647914]
- [net] devlink: Add enable_sriov boolean generic parameter (Ivan Vecera) [1647914]
- [net] devlink: Add generic parameters internal_err_reset and max_macs (Ivan Vecera) [1647914]
- [net] devlink: Add devlink notifications support for params (Ivan Vecera) [1647914]
- [net] devlink: Add support for get/set driverinit value (Ivan Vecera) [1647914]
- [net] devlink: Add param set command (Ivan Vecera) [1647914]
- [net] devlink: Add param get command (Ivan Vecera) [1647914]
- [net] devlink: Add devlink_param register and unregister (Ivan Vecera) [1647914]
- [net] ipvs: call ip_vs_dst_notifier earlier than ipv6_dev_notf (Xin Long) [1645064]
- [net] ipv6: fix a dst leak when removing its exception (Xin Long) [1645064]
- [net] netfilter: ipset: list:set: Decrease refcount synchronously on deletion and replace (Stefano Brivio) [1649089]
- [net] bridge: remove ipv6 zero address check in mcast queries (Hangbin Liu) [1639666]
- [net] bridge: do not add port to router list when receives query with source 0.0.0.0 (Hangbin Liu) [1639666]
- [net] netfilter: ipv6: fix oops when defragmenting locally generated fragments (Florian Westphal) [1642341]
- [net] xfrm6: call kfree_skb when skb is toobig (Sabrina Dubroca) [1628851]
- [net] sched: act_police: fix memory leak in case of invalid control action (Ivan Vecera) [1638022]
- [net] sched: act_police: add missing spinlock initialization (Ivan Vecera) [1638022]
- [net] netfilter: xt_socket: check sk before checking for netns. (Ivan Vecera) [1638022]
- [net] sched: act_police: fix race condition on state variables (Ivan Vecera) [1638022]
- [net] sched: cls_flower: validate nested enc_opts_policy to avoid warning (Ivan Vecera) [1638022]
- [net] sched: act_pedit: fix memory leak when IDR allocation fails (Ivan Vecera) [1638022]
- [net] configs: disable CAKE, ETF & SKBPRIO qdisc in config (Ivan Vecera) [1638022]
- [net] tc-tests: test denial of 'goto chain' for exceed traffic in police.json (Ivan Vecera) [1638022]
- [net] tc-tests: test denial of 'goto chain' on 'random' traffic in gact.json (Ivan Vecera) [1638022]
- [net] sched: act_police: disallow 'goto chain' on fallback control action (Ivan Vecera) [1638022]
- [net] sched: act_gact: disallow 'goto chain' on fallback control action (Ivan Vecera) [1638022]
- [net] net_sched: fix a crash in tc_new_tfilter() (Ivan Vecera) [1638022]
- [net] core: make function ___gnet_stats_copy_basic() static (Ivan Vecera) [1638022]
- [net] net_sched: convert idrinfo->lock from spinlock to a mutex (Ivan Vecera) [1638022]
- [net] loopback: clear skb->tstamp before netif_rx() (Ivan Vecera) [1638022]
- [net] skbuff: preserve sock reference when scrubbing the skb. (Ivan Vecera) [1638022]
- [net] netfilter: check if the socket netns is correct. (Ivan Vecera) [1638022]
- [net] sched: make function qdisc_free_cb() static (Ivan Vecera) [1638022]
- [net] sched: use reference counting for tcf blocks on rules update (Ivan Vecera) [1638022]
- [net] sched: implement tcf_block_refcnt_{get|put}() (Ivan Vecera) [1638022]
- [net] sched: protect block idr with spinlock (Ivan Vecera) [1638022]
- [net] sched: implement functions to put and flush all chains (Ivan Vecera) [1638022]
- [net] sched: change tcf block reference counter type to refcount_t (Ivan Vecera) [1638022]
- [net] sched: use Qdisc rcu API instead of relying on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: add helper function to take reference to Qdisc (Ivan Vecera) [1638022]
- [net] sched: extend Qdisc with rcu (Ivan Vecera) [1638022]
- [net] sched: rename qdisc_destroy() to qdisc_put() (Ivan Vecera) [1638022]
- [net] core: netlink: add helper refcount dec and lock function (Ivan Vecera) [1638022]
- [net] sched: act_ipt: check for underflow in __tcf_ipt_init() (Ivan Vecera) [1638022]
- [net] sched: Add hardware specific counters to TC actions (Ivan Vecera) [1638022]
- [net] core: Add new basic hardware counter (Ivan Vecera) [1638022]
- [net] net_sched: change tcf_del_walker() to take idrinfo->lock (Ivan Vecera) [1638022]
- [net] sched: Use FIELD_SIZEOF directly instead of reimplementing its function (Ivan Vecera) [1638022]
- [net] sched: act_sample: fix NULL dereference in the data path (Ivan Vecera) [1638022]
- [net] sched: act_police: don't use spinlock in the data path (Ivan Vecera) [1638022]
- [net] sched: act_police: use per-cpu counters (Ivan Vecera) [1638022]
- [net] net_sched: notify filter deletion when deleting a chain (Ivan Vecera) [1638022]
- [net] htb: use anonymous union for simplicity (Ivan Vecera) [1638022]
- [net] net_sched: remove redundant qdisc lock classes (Ivan Vecera) [1638022]
- [net] sched: cls_flower: dump offload count value (Ivan Vecera) [1638022]
- [net] net_sched: properly cancel netlink dump on failure (Ivan Vecera) [1638022]
- [net] sched: fix memory leak in act_tunnel_key_init() (Ivan Vecera) [1638022]
- [net] sched: action_ife: take reference to meta module (Ivan Vecera) [1638022]
- [net] act_ife: fix a potential use-after-free (Ivan Vecera) [1638022]
- [net] sched: act_nat: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_skbedit: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: null actions array pointer before releasing action (Ivan Vecera) [1638022]
- [net] sched: fix type of htb statistics (Ivan Vecera) [1638022]
- [net] net_sched: add missing tcf_lock for act_connmark (Ivan Vecera) [1638022]
- [net] revert "net: sched: act: add extack for lookup callback" (Ivan Vecera) [1638022]
- [net] tc-testing: add test-cases for numeric and invalid control action (Ivan Vecera) [1638022]
- [net] net_sched: reject unknown tcfa_action values (Ivan Vecera) [1638022]
- [net] sched: act_pedit: fix dump of extended layered op (Ivan Vecera) [1638022]
- [net] sched: return -ENOENT when trying to remove filter from non-existent chain (Ivan Vecera) [1638022]
- [net] sched: fix extack error message when chain is failed to be created (Ivan Vecera) [1638022]
- [net] sched: Fix memory exposure from short TCA_U32_SEL (Ivan Vecera) [1638022]
- [net] net_sched: fix unused variable warning in stmmac (Ivan Vecera) [1638022]
- [net] sch_cake: Fix TC filter flow override and expand it to hosts as well (Ivan Vecera) [1638022]
- [net] sch_cake: Remove unused including <linux/version.h> (Ivan Vecera) [1638022]
- [net] act_ife: fix a potential deadlock (Ivan Vecera) [1638022]
- [net] act_ife: move tcfa_lock down to where necessary (Ivan Vecera) [1638022]
- [net] revert "net: sched: act_ife: disable bh when taking ife_mod_lock" (Ivan Vecera) [1638022]
- [net] net_sched: remove unused tcfa_capab (Ivan Vecera) [1638022]
- [net] net_sched: remove list_head from tc_action (Ivan Vecera) [1638022]
- [net] net_sched: remove unused tcf_idr_check() (Ivan Vecera) [1638022]
- [net] net_sched: remove unused parameter for tcf_action_delete() (Ivan Vecera) [1638022]
- [net] net_sched: remove unnecessary ops->delete() (Ivan Vecera) [1638022]
- [net] net_sched: improve and refactor tcf_action_put_many() (Ivan Vecera) [1638022]
- [net] sched: always disable bh when taking tcf_lock (Ivan Vecera) [1638022]
- [net] sched: act_ife: always release ife action on init error (Ivan Vecera) [1638022]
- [net] cls_matchall: fix tcf_unbind_filter missing (Ivan Vecera) [1638022]
- [net] sched: act_ife: disable bh when taking ife_mod_lock (Ivan Vecera) [1638022]
- [net] sched: act_mirred method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_vlan method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_skbmod method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_skbedit method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_simple method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_police method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_pedit method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_nat method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_ipt method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_gact method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_sum method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_bpf method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_connmark method rename for grep-ability and consistency (Ivan Vecera) [1638022]
- [net] sched: act_police: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] core: protect rate estimator statistics pointer with lock (Ivan Vecera) [1638022]
- [net] sched: act_mirred: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: extend action ops with put_dev callback (Ivan Vecera) [1638022]
- [net] sched: act_vlan: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_tunnel_key: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_skbmod: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_simple: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_sample: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_pedit: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_ipt: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_ife: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_gact: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_csum: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] sched: act_bpf: remove dependency on rtnl lock (Ivan Vecera) [1638022]
- [net] tc: Update README and add config (Ivan Vecera) [1638022]
- [net] sched: fix block->refcnt decrement (Ivan Vecera) [1638022]
- [net] tc-tests: initial version of nat action unit tests (Ivan Vecera) [1638022]
- [net] sched: allow flower to match tunnel options (Ivan Vecera) [1638022]
- [net] flow_dissector: allow dissection of tunnel options from metadata (Ivan Vecera) [1638022]
- [net] tc-testing: remove duplicate spaces in skbedit match patterns (Ivan Vecera) [1638022]
- [net] tc-testing: remove duplicate spaces in connmark match patterns (Ivan Vecera) [1638022]
- [net] tc-testing: flush gact actions on test teardown (Ivan Vecera) [1638022]
- [net] tc-testing: fix ip address in u32 test (Ivan Vecera) [1638022]
- [net] sched: cls_flower: Fix an error code in fl_tmplt_create() (Ivan Vecera) [1638022]
- [net] sched: fix flush on non-existing chain (Ivan Vecera) [1638022]
- [net] sched: make tcf_chain_{get, put}() static (Ivan Vecera) [1638022]
- [net] sched: fix notifications for action-held chains (Ivan Vecera) [1638022]
- [net] sched: change name of zombie chain to "held_by_acts_only" (Ivan Vecera) [1638022]
- [net] act_mirred: use TC_ACT_REINSERT when possible (Ivan Vecera) [1638022]
- [net] tc: introduce TC_ACT_REINSERT. (Ivan Vecera) [1638022]
- [net] tc/act: remove unneeded RCU lock in action callback (Ivan Vecera) [1638022]
- [net] sched: user-space can't set unknown tcfa_action values (Ivan Vecera) [1638022]
- [net] Add and use skb_mark_not_on_list(). (Ivan Vecera) [1638022]
- [net] sch_netem: Move private queue handler to generic location. (Ivan Vecera) [1638022]
- [net] sch_htb: Remove local SKB queue handling code. (Ivan Vecera) [1638022]
- [net] act_bpf: Use kmemdup instead of duplicating it in tcf_bpf_init_from_ops (Ivan Vecera) [1638022]
- [net] cls_bpf: Use kmemdup instead of duplicating it in cls_bpf_prog_from_ops (Ivan Vecera) [1638022]
- [net] act_pedit: remove unnecessary semicolon (Ivan Vecera) [1638022]
- [net] sched: don't dump chains only held by actions (Ivan Vecera) [1638022]
- [net] sch_cake: Make gso-splitting configurable from userspace (Ivan Vecera) [1638022]
- [net] sched: unmark chain as explicitly created on delete (Ivan Vecera) [1638022]
- [net] sched: cls_api: fix dead code in switch (Ivan Vecera) [1638022]
- [net] sched: cls_flower: Use correct inline function for assignment of vlan tpid (Ivan Vecera) [1638022]
- [net] sched: fix trailing whitespace (Ivan Vecera) [1638022]
- [net] cbs: Add support for the graft function (Ivan Vecera) [1638022]
- [net] sched: add skbprio scheduler (Ivan Vecera) [1638022]
- [net] selftests: forwarding: add tests for TC chain templates (Ivan Vecera) [1638022]
- [net] selftests: forwarding: add tests for TC chains creation adn destruction (Ivan Vecera) [1638022]
- [net] selftests: forwarding: move shblock tc support check to a separate helper (Ivan Vecera) [1638022]
- [net] sched: cls_flower: propagate chain teplate creation and destruction to drivers (Ivan Vecera) [1638022]
- [net] sched: cls_flower: implement chain templates (Ivan Vecera) [1638022]
- [net] sched: cls_flower: change fl_init_dissector to accept mask and dissector (Ivan Vecera) [1638022]
- [net] sched: cls_flower: move key/mask dumping into a separate function (Ivan Vecera) [1638022]
- [net] sched: introduce chain templates (Ivan Vecera) [1638022]
- [net] sched: introduce chain object to uapi (Ivan Vecera) [1638022]
- [net] sched: Avoid implicit chain 0 creation (Ivan Vecera) [1638022]
- [net] sched: push ops lookup bits into tcf_proto_lookup_ops() (Ivan Vecera) [1638022]
- [net] nfp: bring back support for offloading shared blocks (Ivan Vecera) [1638022]
- [net] sched: use PTR_ERR_OR_ZERO macro in tcf_block_cb_register (Ivan Vecera) [1638022]
- [net] tc-tests: initial version of fw filter unit tests (Ivan Vecera) [1638022]
- [net] sch_cake: Fix tin order when set through skb->priority (Ivan Vecera) [1638022]
- [net] sched: act_skbedit: don't use spinlock in the data path (Ivan Vecera) [1638022]
- [net] sched: skbedit: use per-cpu counters (Ivan Vecera) [1638022]
- [net] tc-testing: add geneve options in tunnel_key unit tests (Ivan Vecera) [1638022]
- [net] sched: fix unprotected access to rcu cookie pointer (Ivan Vecera) [1638022]
- [net] sched: act_ife: fix memory leak in ife init (Ivan Vecera) [1638022]
- [net] sched: refactor flower walk to iterate over idr (Ivan Vecera) [1638022]
- [net] sched: flower: Fix null pointer dereference when run tc vlan command (Ivan Vecera) [1638022]
- [net] sched: Fix warnings from xchg() on RCU'd cookie pointer. (Ivan Vecera) [1638022]
- [net] cls_flower: fix error values for commands not supported by drivers (Ivan Vecera) [1638022]
- [net] nfp: handle cls_flower command default case (Ivan Vecera) [1638022]
- [net] bnxt: simplify cls_flower command switch and handle default case (Ivan Vecera) [1638022]
- [net] sch_cake: Conditionally split GSO segments (Ivan Vecera) [1638022]
- [net] sch_cake: Add overhead compensation support to the rate shaper (Ivan Vecera) [1638022]
- [net] sch_cake: Add DiffServ handling (Ivan Vecera) [1638022]
- [net] sch_cake: Add NAT awareness to packet classifier (Ivan Vecera) [1638022]
- [net] netfilter: Add nf_ct_get_tuple_skb global lookup function (Ivan Vecera) [1638022]
- [net] sch_cake: Add optional ACK filter (Ivan Vecera) [1638022]
- [net] sch_cake: Add ingress mode (Ivan Vecera) [1638022]
- [net] sched: Add Common Applications Kept Enhanced (cake) qdisc (Ivan Vecera) [1638022]
- [net] Use __u32 in uapi net_stamp.h (Ivan Vecera) [1638022]
- [net] sched: flower: Add supprt for matching on QinQ vlan headers (Ivan Vecera) [1638022]
- [net] sched: flower: Dump the ethertype encapsulated in vlan (Ivan Vecera) [1638022]
- [net] flow_dissector: Add support for QinQ dissection (Ivan Vecera) [1638022]
- [net] sched: flower: Add support for matching on vlan ethertype (Ivan Vecera) [1638022]
- [net] flow_dissector: Save vlan ethertype from headers (Ivan Vecera) [1638022]
- [net] sched: change action API to use array of pointers to actions (Ivan Vecera) [1638022]
- [net] sched: atomically check-allocate action (Ivan Vecera) [1638022]
- [net] sched: use reference counting action init (Ivan Vecera) [1638022]
- [net] sched: don't release reference on action overwrite (Ivan Vecera) [1638022]
- [net] sched: implement reference counted action release (Ivan Vecera) [1638022]
- [net] sched: add 'delete' function to action ops (Ivan Vecera) [1638022]
- [net] sched: implement action API that deletes action by index (Ivan Vecera) [1638022]
- [net] sched: always take reference to action (Ivan Vecera) [1638022]
- [net] sched: implement unlocked action init API (Ivan Vecera) [1638022]
- [net] sched: change type of reference and bind counters (Ivan Vecera) [1638022]
- [net] sched: use rcu for action cookie update (Ivan Vecera) [1638022]
- [net] sched: Make etf report drops on error_queue (Ivan Vecera) [1638022]
- [net] sched: Add HW offloading capability to ETF (Ivan Vecera) [1638022]
- [net] sched: Introduce the ETF Qdisc (Ivan Vecera) [1638022]
- [net] sched: Allow creating a Qdisc watchdog with other clocks (Ivan Vecera) [1638022]
- [net] packet: Hook into time based transmission. (Ivan Vecera) [1638022]
- [net] ipv6: Hook into time based transmission (Ivan Vecera) [1638022]
- [net] ipv4: Hook into time based transmission (Ivan Vecera) [1638022]
- [net] Add a new socket option for a future transmit time. (Ivan Vecera) [1638022]
- [net] Clear skb->tstamp only on the forwarding path (Ivan Vecera) [1638022]
- [net] sched: act_pedit: fix possible memory leak in tcf_pedit_init() (Ivan Vecera) [1638022]
- [net] net sched actions: add extack messages in pedit action (Ivan Vecera) [1638022]
- [net] net:sched: add action inheritdsfield to skbedit (Ivan Vecera) [1638022]
- [net] tc-testing: initial version of tunnel_key unit tests (Ivan Vecera) [1638022]
- [net] net sched actions: avoid bitwise operation on signed value in pedit (Ivan Vecera) [1638022]
- [net] net sched actions: fix misleading text strings in pedit action (Ivan Vecera) [1638022]
- [net] net sched actions: use sizeof operator for buffer length (Ivan Vecera) [1638022]
- [net] net sched actions: fix sparse warning (Ivan Vecera) [1638022]
- [net] net sched actions: fix coding style in pedit headers (Ivan Vecera) [1638022]
- [net] net sched actions: fix coding style in pedit action (Ivan Vecera) [1638022]
- [net] netem: slotting with non-uniform distribution (Ivan Vecera) [1638022]
- [net] check tunnel option type in tunnel flags (Ivan Vecera) [1638022]
- [net] sched: act_tunnel_key: add extended ack support (Ivan Vecera) [1638022]
- [net] tc-tests: add an extreme-case csum action test (Ivan Vecera) [1638022]
- [net] net_sched: remove unused htb drop_list (Ivan Vecera) [1638022]

* Sun Dec 16 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-55.el8]
- [rpmspec] always run make with HOSTCFLAGS/HOSTLDFLAGS set (Jiri Olsa) [1624124]
- [rpmspec] Pass global build flags to tools build (Jiri Olsa) [1624124]
- [rpmspec] Pass global build flags to bpftool build (Jiri Olsa) [1624124]
- [kernel] kbuild: Use HOST*FLAGS options from the command line (Jiri Olsa) [1624124]
- [scripts] kbuild: Rename HOST_LOADLIBES to KBUILD_HOSTLDLIBS (Jiri Olsa) [1624124]
- [tools] kbuild: Rename HOSTLDFLAGS to KBUILD_HOSTLDFLAGS (Jiri Olsa) [1624124]
- [scripts] kbuild: Rename HOSTCXXFLAGS to KBUILD_HOSTCXXFLAGS (Jiri Olsa) [1624124]
- [tools] kbuild: Rename HOSTCFLAGS to KBUILD_HOSTCFLAGS (Jiri Olsa) [1624124]
- [tools] tools cpupower: Override CFLAGS assignments (Jiri Olsa) [1624124]
- [tools] tools cpupower debug: Allow to use outside build flags (Jiri Olsa) [1624124]
- [tools] perf tools: Pass build flags to traceevent build (Jiri Olsa) [1624124]
- [tools] tools lib traceevent: Use LDFLAGS in the build commands (Jiri Olsa) [1624124]
- [tools] perf tools: Link libperf-jvmti.so with LDFLAGS variable (Jiri Olsa) [1624124]
- [tools] bpftool: Allow add linker flags via EXTRA_LDFLAGS variable (Jiri Olsa) [1624124]
- [tools] bpftool: Allow to add compiler flags via EXTRA_CFLAGS variable (Jiri Olsa) [1624124]
- [block] blkcg: handle dying request_queue when associating a blkg (Ming Lei) [1655485]
- [block] block: deactivate blk_stat timer in wbt_disable_default() (Ming Lei) [1655485]
- [lib] sbitmap: flush deferred clears for resize and shallow gets (Ming Lei) [1655485]
- [md] dm: fix request-based dm's use of dm_wait_for_completion (Ming Lei) [1655485]
- [nvme] nvme: fix irq vs io_queue calculations (Ming Lei) [1655485]
- [md] dm: fix inflight IO check (Ming Lei) [1655485]
- [md] dm: remove the pending IO accounting (Ming Lei) [1655485]
- [block] block: return just one value from part_in_flight (Ming Lei) [1655485]
- [block] block: switch to per-cpu in-flight counters (Ming Lei) [1655485]
- [block] block: delete part_round_stats and switch to less precise counting (Ming Lei) [1655485]
- [block] block: stop passing 'cpu' to all percpu stats methods (Ming Lei) [1655485]
- [md] dm rq: leverage blk_mq_queue_busy() to check for outstanding IO (Ming Lei) [1655485]
- [md] dm: dont rewrite dm_disk(md)->part0.in_flight (Ming Lei) [1655485]
- [lib] sbitmap: silence bogus lockdep IRQ warning (Ming Lei) [1655485]
- [scsi] scsi: Fix a harmless double shift bug (Ming Lei) [1655485]
- [block] blk-mq: re-build queue map in case of kdump kernel (Ming Lei) [1655485]
- [block] blkcg: put back rcu lock in blkcg_bio_issue_check() (Ming Lei) [1655485]
- [block] block: convert io-latency to use rq_qos_wait (Ming Lei) [1655485]
- [block] block: convert wbt_wait() to use rq_qos_wait() (Ming Lei) [1655485]
- [block] block: add rq_qos_wait to rq_qos (Ming Lei) [1655485]
- [block] blkcg: rename blkg_try_get() to blkg_tryget() (Ming Lei) [1655485]
- [block] blkcg: change blkg reference counting to use percpu_ref (Ming Lei) [1655485]
- [block] blkcg: remove bio_disassociate_task() (Ming Lei) [1655485]
- [block] blkcg: remove additional reference to the css (Ming Lei) [1655485]
- [block] blkcg: remove bio->bi_css and instead use bio->bi_blkg (Ming Lei) [1655485]
- [block] blkcg: associate writeback bios with a blkg (Ming Lei) [1655485]
- [block] blkcg: associate a blkg for pages being evicted by swap (Ming Lei) [1655485]
- [block] blkcg: consolidate bio_issue_init() to be a part of core (Ming Lei) [1655485]
- [block] blkcg: associate blkg when associating a device (Ming Lei) [1655485]
- [block] dm: set the static flush bio device on demand (Ming Lei) [1655485]
- [block] blkcg: introduce common blkg association logic (Ming Lei) [1655485]
- [block] blkcg: convert blkg_lookup_create() to find closest blkg (Ming Lei) [1655485]
- [block] blkcg: update blkg_lookup_create() to do locking (Ming Lei) [1655485]
- [block] blkcg: fix ref count issue with bio_blkcg() using task_css (Ming Lei) [1655485]
- [block] blk-mq: remove QUEUE_FLAG_POLL from default MQ flags (Ming Lei) [1655485]
- [block] block: enable polling by default if a poll map is initalized (Ming Lei) [1655485]
- [block] block: only allow polling if a poll queue_map exists (Ming Lei) [1655485]
- [block] block: remove ->poll_fn (Ming Lei) [1655485]
- [nvme] nvme-mpath: remove I/O polling support (Ming Lei) [1655485]
- [nvme] nvme-rdma: remove I/O polling support (Ming Lei) [1655485]
- [nvme] nvme-pci: remove the CQ lock for interrupt driven queues (Ming Lei) [1655485]
- [nvme] nvme-pci: don't poll from irq context when deleting queues (Ming Lei) [1655485]
- [nvme] nvme-pci: refactor nvme_disable_io_queues (Ming Lei) [1655485]
- [nvme] nvme-pci: consolidate code for polling non-dedicated queues (Ming Lei) [1655485]
- [nvme] nvme-pci: only allow polling with separate poll queues (Ming Lei) [1655485]
- [nvme] nvme-pci: cleanup SQ allocation a bit (Ming Lei) [1655485]
- [nvme] nvme-pci: use atomic bitops to mark a queue enabled (Ming Lei) [1655485]
- [block] block: move queues types to the block layer (Ming Lei) [1655485]
- [fs] aio: clear IOCB_HIPRI (Ming Lei) [1655485]
- [lib] sbitmap: fix sbitmap_for_each_set() (Ming Lei) [1655485]
- [block] blk-mq: don't call ktime_get_ns() if we don't need it (Ming Lei) [1655485]
- [block] block: add cmd_flags to print_req_error (Ming Lei) [1655485]
- [lib] sbitmap: optimize wakeup check (Ming Lei) [1655485]
- [lib] sbitmap: ammortize cost of clearing bits (Ming Lei) [1655485]
- [block] block: avoid extra bio reference for async O_DIRECT (Ming Lei) [1655485]
- [lib] sbitmap: don't loop for find_next_zero_bit() for !round_robin (Ming Lei) [1655485]
- [block] blk-mq: use plug for devices that implement ->commits_rqs() (Ming Lei) [1655485]
- [block] blk-mq: use bd->last == true for list inserts (Ming Lei) [1655485]
- [block] ataflop: implement mq_ops->commit_rqs() hook (Ming Lei) [1655485]
- [block] virtio_blk: implement mq_ops->commit_rqs() hook (Ming Lei) [1655485]
- [nvme] nvme: implement mq_ops->commit_rqs() hook (Ming Lei) [1655485]
- [block] blk-mq: add mq_ops->commit_rqs() (Ming Lei) [1655485]
- [block] block: improve logic around when to sort a plug list (Ming Lei) [1655485]
- [block] blk-mq: Add a NULL check in blk_mq_free_map_and_requests() (Ming Lei) [1655485]
- [block] ataflop: fix error handling in atari_floppy_init() (Ming Lei) [1655485]
- [block] block: add io timeout to sysfs (Ming Lei) [1655485]
- [block] block: use rcu_work instead of call_rcu to avoid sleep in softirq (Ming Lei) [1655485]
- [block] blk-mq: fix failure to decrement plug count on single rq removal (Ming Lei) [1655485]
- [block] sunvdc: Do not spin in an infinite loop when vio_ldc_send() returns EAGAIN (Ming Lei) [1655485]
- [block] block: sum requests in the plug structure (Ming Lei) [1655485]
- [block] blk-mq: Simplify request completion state (Ming Lei) [1655485]
- [scsi] scsi: Do not rely on blk-mq for double completions (Ming Lei) [1655485]
- [block] blk-mq: Return true if request was completed (Ming Lei) [1655485]
- [block] blk-mq: never redirect polled IO completions (Ming Lei) [1655485]
- [block] blk-mq: ensure mq_ops ->poll() is entered at least once (Ming Lei) [1655485]
- [block] block: make blk_poll() take a parameter on whether to spin or not (Ming Lei) [1655485]
- [nvme] nvme: remove opportunistic polling from bdev target (Ming Lei) [1655485]
- [block] blk-mq: remove 'tag' parameter from mq_ops->poll() (Ming Lei) [1655485]
- [block] blk-mq: when polling for IO, look for any completion (Ming Lei) [1655485]
- [block] block: fix attempt to assign NULL io_context (Ming Lei) [1655485]
- [block] block: Initialize BIO I/O priority early (Ming Lei) [1655485]
- [block] block: prevent merging of requests with different priorities (Ming Lei) [1655485]
- [fs] aio: Fix fallback I/O priority value (Ming Lei) [1655485]
- [block] block: Introduce get_current_ioprio() (Ming Lei) [1655485]
- [block] block: Remove bio->bi_ioc (Ming Lei) [1655485]
- [fs] aio: Comment use of IOCB_FLAG_IOPRIO aio flag (Ming Lei) [1655485]
- [nvme] nvme-fc: remove ->poll implementation (Ming Lei) [1655485]
- [block] block: have ->poll_fn() return number of entries polled (Ming Lei) [1655485]
- [block] block: avoid ordered task state change for polled IO (Ming Lei) [1655485]
- [nvme] nvme: default to 0 poll queues (Ming Lei) [1655485]
- [block] floppy: remove now unused 'flags' variable (Ming Lei) [1655485]
- [mmc] mmc: stop abusing the request queue_lock pointer (Ming Lei) [1655485]
- [block] ide: don't acquire queue_lock in ide_complete_pm_rq (Ming Lei) [1655485]
- [block] ide: don't acquire queue lock in ide_pm_execute_rq (Ming Lei) [1655485]
- [block] pktcdvd: remove queue_lock around blk_queue_max_hw_sectors (Ming Lei) [1655485]
- [block] floppy: remove queue_lock around floppy_end_request (Ming Lei) [1655485]
- [block] block: remove the rq_alloc_data request_queue field (Ming Lei) [1655485]
- [block] block: don't plug for aio/O_DIRECT HIPRI IO (Ming Lei) [1655485]
- [block] block: for async O_DIRECT, mark us as polling if asked to (Ming Lei) [1655485]
- [block] block: add polled wakeup task helper (Ming Lei) [1655485]
- [block] blk-rq-qos: inline check for q->rq_qos functions (Ming Lei) [1655485]
- [block] block: add queue_is_mq() helper (Ming Lei) [1655485]
- [nvme] nvme: provide optimized poll function for separate poll queues (Ming Lei) [1655485]
- [block] ide: clear ide_req()->special for non-passthrough requests (Ming Lei) [1655485]
- [nvme] nvme: fix handling of EINVAL on pci_alloc_irq_vectors_affinity() (Ming Lei) [1655485]
- [block] block: add wbt_disable_default export for BFQ (Ming Lei) [1655485]
- [block] block: remove the queue_lock indirection (Ming Lei) [1655485]
- [block] block: remove the lock argument to blk_alloc_queue_node (Ming Lei) [1655485]
- [mmc] mmc: stop abusing the request queue_lock pointer (Ming Lei) [1655485]
- [mmc] mmc: simplify queue initialization (Ming Lei) [1655485]
- [block] umem: don't override the queue_lock (Ming Lei) [1655485]
- [block] drbd: don't override the queue_lock (Ming Lei) [1655485]
- [block] blk-cgroup: move locking into blkg_destroy_all (Ming Lei) [1655485]
- [block] blk-cgroup: consolidate error handling in blkcg_init_queue (Ming Lei) [1655485]
- [block] block: remove a few unused exports (Ming Lei) [1655485]
- [block] block: update a few comments for the legacy request removal (Ming Lei) [1655485]
- [block] block: remove the unused lock argument to rq_qos_throttle (Ming Lei) [1655485]
- [block] block: remove queue_lockdep_assert_held (Ming Lei) [1655485]
- [block] block: use atomic bitops for ->queue_flags (Ming Lei) [1655485]
- [block] block: don't hold the queue_lock over blk_abort_request (Ming Lei) [1655485]
- [block] block: remove deadline __deadline manipulation helpers (Ming Lei) [1655485]
- [block] block: remove QUEUE_FLAG_BYPASS and ->bypass (Ming Lei) [1655485]
- [nvme] nvmet-rdma: fix response use after free (Ming Lei) [1655485]
- [nvme] nvme: validate controller state before rescheduling keep alive (Ming Lei) [1655485]
- [block] block, bfq: fix decrement of num_active_groups (Ming Lei) [1655485]
- [ata] libata: whitelist all SAMSUNG MZ7KM* solid-state disks (Ming Lei) [1655485]
- [nvme] nvme-rdma: fix double freeing of async event data (Ming Lei) [1655485]
- [nvme] nvme-pci: fix surprise removal (Ming Lei) [1655485]
- [nvme] nvme: Free ctrl device name on init failure (Ming Lei) [1655485]
- [nvme] nvme-fc: resolve io failures during connect (Ming Lei) [1655485]
- [nvme] nvme: make sure ns head inherits underlying device limits (Ming Lei) [1655485]
- [nvme] nvmet: don't try to add ns to p2p map unless it actually uses it (Ming Lei) [1655485]
- [nvme] nvme-pci: fix conflicting p2p resource adds (Ming Lei) [1655485]
- [nvme] nvmet: Optionally use PCI P2P memory (Ming Lei) [1655485]
- [nvme] nvmet: Introduce helper functions to allocate and free request SGLs (Ming Lei) [1655485]
- [nvme] nvme-pci: Add support for P2P memory in requests (Ming Lei) [1655485]
- [nvme] nvme-pci: Use PCI p2pmem subsystem to manage the CMB (Ming Lei) [1655485]
- [infiniband] IB/core: Ensure we map P2P memory correctly in rdma_rw_ctx_[init|destroy]() (Ming Lei) [1655485]
- [block] block: Add PCI P2P flag for request queue (Ming Lei) [1655485]
- [documentation] PCI/P2PDMA: Add P2P DMA driver writer's documentation (Ming Lei) [1655485]
- [documentation] docs-rst: Add a new directory for PCI documentation (Ming Lei) [1655485]
- [pci] PCI/P2PDMA: Introduce configfs/sysfs enable attribute helpers (Ming Lei) [1655485]
- [pci] PCI/P2PDMA: Add PCI p2pmem DMA mappings to adjust the bus offset (Ming Lei) [1655485]
- [pci] PCI/P2PDMA: Add sysfs group to display p2pmem stats (Ming Lei) [1655485]
- [pci] PCI/P2PDMA: Support peer-to-peer memory (Ming Lei) [1655485]
- [nvme] nvmet-rdma: support max(16KB, PAGE_SIZE) inline data (Ming Lei) [1655485]
- [nvme] nvme-rdma: support up to 4 segments of inline data (Ming Lei) [1655485]
- [fs] aio: fix failure to put the file pointer (Ming Lei) [1655485]
- [lib] scsi: Remove percpu_ida (Ming Lei) [1655485]
- [scsi] scsi: target: Convert target drivers to use sbitmap (Ming Lei) [1655485]
- [scsi] scsi: target: Abstract tag freeing (Ming Lei) [1655485]
- [block] mmc: block: Fix unsupported parallel dispatch of requests (Ming Lei) [1655485]
- [scsi] scsi: target: sbitmap: add seq_file forward declaration (Ming Lei) [1655485]
- [mm] mm, memory_hotplug: do not clear numa_node association after hot_remove (Waiman Long) [1657422]
- [fs] iomap: partially revert 4721a601099 (simulated directio short read on EFAULT) (Brian Foster) [1654713]
- [fs] splice: don't read more than available pipe space (Brian Foster) [1654713]
- [fs] vfs: allow some remap flags to be passed to vfs_clone_file_range (Brian Foster) [1654713]
- [fs] xfs: fix inverted return from xfs_btree_sblock_verify_crc (Brian Foster) [1654713]
- [fs] xfs: fix PAGE_MASK usage in xfs_free_file_space (Brian Foster) [1654713]
- [fs] fs/xfs: fix f_ffree value for statfs when project quota is set (Brian Foster) [1654713]
- [fs] iomap: readpages doesn't zero page tail beyond EOF (Brian Foster) [1654713]
- [fs] vfs: vfs_dedupe_file_range() doesn't return EOPNOTSUPP (Brian Foster) [1654713]
- [fs] iomap: dio data corruption and spurious errors when pipes fill (Brian Foster) [1654713]
- [fs] iomap: sub-block dio needs to zeroout beyond EOF (Brian Foster) [1654713]
- [fs] iomap: FUA is wrong for DIO O_DSYNC writes into unwritten extents (Brian Foster) [1654713]
- [fs] xfs: delalloc -> unwritten COW fork allocation can go wrong (Brian Foster) [1654713]
- [fs] xfs: flush removing page cache in xfs_reflink_remap_prep (Brian Foster) [1654713]
- [fs] xfs: extent shifting doesn't fully invalidate page cache (Brian Foster) [1654713]
- [fs] xfs: finobt AG reserves don't consider last AG can be a runt (Brian Foster) [1654713]
- [fs] xfs: fix transient reference count error in xfs_buf_resubmit_failed_buffers (Brian Foster) [1654713]
- [fs] xfs: uncached buffer tracing needs to print bno (Brian Foster) [1654713]
- [fs] xfs: make xfs_file_remap_range() static (Brian Foster) [1654713]
- [fs] xfs: fix shared extent data corruption due to missing cow reservation (Brian Foster) [1654713]
- [fs] xfs: fix overflow in xfs_attr3_leaf_verify (Brian Foster) [1654713]
- [fs] xfs: print buffer offsets when dumping corrupt buffers (Brian Foster) [1654713]
- [fs] xfs: Fix error code in 'xfs_ioc_getbmap()' (Brian Foster) [1654713]
- [fs] xfs: cancel COW blocks before swapext (Brian Foster) [1654713]
- [fs] xfs: clear ail delwri queued bufs on unmount of shutdown fs (Brian Foster) [1654713]
- [fs] xfs: use offsetof() in place of offset macros for __xfsstats (Brian Foster) [1654713]
- [fs] xfs: Fix xqmstats offsets in /proc/fs/xfs/xqmstat (Brian Foster) [1654713]
- [fs] xfs: fix use-after-free race in xfs_buf_rele (Brian Foster) [1654713]
- [fs] xfs: Add attibute remove and helper functions (Brian Foster) [1654713]
- [fs] xfs: Add attibute set and helper functions (Brian Foster) [1654713]
- [fs] xfs: Add helper function xfs_attr_try_sf_addname (Brian Foster) [1654713]
- [fs] xfs: Move fs/xfs/xfs_attr.h to fs/xfs/libxfs/xfs_attr.h (Brian Foster) [1654713]
- [fs] xfs: issue log message on user force shutdown (Brian Foster) [1654713]
- [fs] xfs: fix buffer state management in xrep_findroot_block (Brian Foster) [1654713]
- [fs] xfs: always assign buffer verifiers when one is provided (Brian Foster) [1654713]
- [fs] xfs: xrep_findroot_block should reject root blocks with siblings (Brian Foster) [1654713]
- [fs] xfs: add a define for statfs magic to uapi (Brian Foster) [1654713]
- [fs] xfs: print dangling delalloc extents (Brian Foster) [1654713]
- [fs] xfs: fix fork selection in xfs_find_trim_cow_extent (Brian Foster) [1654713]
- [fs] xfs: remove the unused trimmed argument from xfs_reflink_trim_around_shared (Brian Foster) [1654713]
- [fs] xfs: remove the unused shared argument to xfs_reflink_reserve_cow (Brian Foster) [1654713]
- [fs] xfs: handle zeroing in xfs_file_iomap_begin_delay (Brian Foster) [1654713]
- [fs] xfs: remove suport for filesystems without unwritten extent flag (Brian Foster) [1654713]
- [fs] xfs: remove XFS_IO_INVALID (Brian Foster) [1654713]
- [fs] xfs: remove [cm]time update from reflink calls (Brian Foster) [1654713]
- [fs] xfs: remove xfs_reflink_remap_range (Brian Foster) [1654713]
- [fs] xfs: remove redundant remap partial EOF block checks (Brian Foster) [1654713]
- [fs] xfs: support returning partial reflink results (Brian Foster) [1654713]
- [fs] xfs: clean up xfs_reflink_remap_blocks call site (Brian Foster) [1654713]
- [fs] xfs: fix pagecache truncation prior to reflink (Brian Foster) [1654713]
- [fs] vfs: clean up generic_remap_file_range_prep return value (Brian Foster) [1654713]
- [fs] vfs: hide file range comparison function (Brian Foster) [1654713]
- [fs] vfs: enable remap callers that can handle short operations (Brian Foster) [1654713]
- [fs] vfs: plumb remap flags through the vfs dedupe functions (Brian Foster) [1654713]
- [fs] vfs: plumb remap flags through the vfs clone functions (Brian Foster) [1654713]
- [fs] vfs: make remap_file_range functions take and return bytes completed (Brian Foster) [1654713]
- [fs] vfs: remap helper should update destination inode metadata (Brian Foster) [1654713]
- [fs] vfs: pass remap flags to generic_remap_checks (Brian Foster) [1654713]
- [fs] vfs: pass remap flags to generic_remap_file_range_prep (Brian Foster) [1654713]
- [fs] vfs: combine the clone and dedupe into a single remap_file_range (Brian Foster) [1654713]
- [fs] vfs: rename clone_verify_area to remap_verify_area (Brian Foster) [1654713]
- [fs] vfs: rename vfs_clone_file_prep to be more descriptive (Brian Foster) [1654713]
- [fs] vfs: skip zero-length dedupe requests (Brian Foster) [1654713]
- [fs] vfs: avoid problematic remapping requests into partial EOF block (Brian Foster) [1654713]
- [fs] vfs: strengthen checking of file range inputs to generic_remap_checks (Brian Foster) [1654713]
- [fs] vfs: exit early from zero length remap operations (Brian Foster) [1654713]
- [fs] vfs: check file ranges before cloning files (Brian Foster) [1654713]
- [fs] vfs: vfs_clone_file_prep_inodes should return EINVAL for a clone from beyond EOF (Brian Foster) [1654713]
- [block] blk-mq: not embed .mq_kobj and ctx->kobj into queue instance (Ming Lei) [1653124]
- [fs] fs: fix lost error code in dio_complete (Ming Lei) [1655364]
- [iommu] iommu/iova: Optimise attempts to allocate iova from 32bit address range (Robert Richter) [1639202]

* Fri Dec 14 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-54.el8]
- [drm] drm/nouveau/drm/nouveau: Check rc from drm_dp_mst_topology_mgr_resume() (Lyude Paul) [1658810]
- [x86] Mark Intel Apollo Lake supported (David Arcari) [1653799]
- [infiniband] IB/mlx5: Fix implicit ODP interrupted page fault (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Improve ODP debugging messages (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Use multi threaded workqueue for page fault handling (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Return success for PAGE_FAULT_RESUME in internal error state (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Lock QP during page fault handling (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Enumerate page fault types (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Add interface to hold and release core resources (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Release resource on error flow (Alaa Hleihel) [1658085]
- [netdrv] net/mlx4_core: Correctly set PFC param if global pause is turned off. (Alaa Hleihel) [1658085]
- [netdrv] net/mlx4_en: Change min MTU size to ETH_MIN_MTU (Alaa Hleihel) [1658085]
- [netdrv] mlx5: fix get_ip_proto() (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Fix page fault handling for MW (Alaa Hleihel) [1658085]
- [infiniband] RDMA/mlx5: Initialize return variable in case pagefault was skipped (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Skip non-ODP MR when handling a page fault (Alaa Hleihel) [1658085]
- [net] net/dim: Update DIM start sample after each DIM iteration (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Avoid load failure due to unknown link width (Alaa Hleihel) [1658085]
- [infiniband] RDMA/mlx5: Fix fence type for IB_WR_LOCAL_INV WR (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Removed unnecessary warnings in FEC caps query (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Fix selftest for small MTUs (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: RX, verify received packet size in Linear Striding RQ (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Apply the correct check for supporting TC esw rules split (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Adjust to max number of channles when re-attaching (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Always use the match level enum when parsing TC rule match (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Claim TC hw offloads support only under a proper build config (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Don't match on vlan non-existence if ethertype is wildcarded (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: IPoIB, Reset QP after channels are closed (Alaa Hleihel) [1658085]
- [netdrv] net/mlx4: Fix UBSAN warning of signed integer overflow (Alaa Hleihel) [1658085]
- [netdrv] net/mlx4_core: Fix uninitialized variable compilation warning (Alaa Hleihel) [1658085]
- [netdrv] net/mlx4_core: Zero out lkey field in SW2HW_MPT fw command (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Fix MR cache initialization (Alaa Hleihel) [1658085]
- [infiniband] RDMA/mlx5: Remove extraneous error check (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Take only bit 24-26 of wqe.pftype_wq for page fault type (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Fix memory leak when setting fpga ipsec caps (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Unmap DMA addr from HCA before IOMMU (Alaa Hleihel) [1658085]
- [infiniband] RDMA/mlx5: Remove superfluous version print (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Allow transition of DCI QP to reset (Alaa Hleihel) [1658085]
- [infiniband] IB/mlx5: Don't hold spin lock while checking device state (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Move mlx5e_priv_flags into en_ethtool.c (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5: Fix atomic_mode enum values (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: Delete unneeded function argument (Alaa Hleihel) [1658085]
- [netdrv] net/mlx5e: RX, Prefetch the xdp_frame data area (Alaa Hleihel) [1658085]
- [drm] drm/i915: Synchronize hpd work in i915_hpd_storm_ctl_show() (Lyude Paul) [1658376]
- [drm] drm/i915: Add short HPD IRQ storm detection for non-MST systems (Lyude Paul) [1658376]
- [drm] drm/i915: Clarify flow for disabling IRQs on storms (Lyude Paul) [1658376]
- [drm] drm/i915: Fix threshold check in intel_hpd_irq_storm_detect() (Lyude Paul) [1658376]
- [drm] drm/i915: Fix NULL deref when re-enabling HPD IRQs on systems with MST (Lyude Paul) [1658376]
- [drm] drm/i915: Fix possible race in intel_dp_add_mst_connector() (Lyude Paul) [1658376]
- [x86] kvm: x86: bump KVM_(SOFT_)MAX_VCPUS to 384 (Radim Krcmar) [1635205]
- [block] blk-mq: punt failed direct issue to dispatch list (Ming Lei) [1656653]
- [block] blk-mq: fix corruption with direct issue (Ming Lei) [1656653]
- [pci] PCI: Add support for Immediate Readiness (Myron Stowe) [1483409]
- [x86] x86/PCI: Remove node-local allocation when initialising host controller (Myron Stowe) [1483409]
- [arm64] arm64: PCI: Remove node-local allocations when initialising host controller (Myron Stowe) [1483409]
- [cpufreq] cpufreq: intel_pstate: Add base_frequency attribute (Prarit Bhargava) [1648207]
- [acpi] ACPI / CPPC: Add support for guaranteed performance (Prarit Bhargava) [1648207]
- [block] block: fix single range discard merge (Ming Lei) [1654096]
- [scsi] SCSI: fix queue cleanup race before queue initialization is done (Ming Lei) [1642404]
- [netdrv] net: hinic: fix null pointer dereference on pointer hwdev (Xiaojun Tan) [1654207]
- [netdrv] net-next/hinic: fix a bug in rx data flow (Xiaojun Tan) [1654207]
- [netdrv] net-next/hinic:fix a bug in set mac address (Xiaojun Tan) [1654207]
- [netdrv] net-next/hinic:add rx checksum offload for HiNIC (Xiaojun Tan) [1654207]
- [netdrv] net-next/hinic:replace multiply and division operators (Xiaojun Tan) [1654207]
- [netdrv] hinic: Fix l4_type parameter in hinic_task_set_tunnel_l4 (Xiaojun Tan) [1654207]
- [netdrv] net-next/hinic: add checksum offload and TSO support (Xiaojun Tan) [1654207]
- [netdrv] cxgb4: Remove SGE_HOST_PAGE_SIZE dependency on page size (Arjun Vynipadath) [1651082]

* Thu Dec 13 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-53.el8]
- [x86] kvm: x86: Report STIBP on GET_SUPPORTED_CPUID (Eduardo Habkost) [1644870]
- [kernel] power: remove possible deadlock when unregistering power_supply (Benjamin Tissoires) [1657623]
- [md] dm: call blk_queue_split() to impose device limits on bios (Mike Snitzer) [1657340]
- [pinctrl] Revert "pinctrl: intel: Do pin translation when lock IRQ" (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: cannonlake: Fix HOSTSW_OWN register offset of H variant (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: intel: Do pin translation in other GPIO operations as well (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: cannonlake: Fix gpio base for GPP-E (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: intel: Don't shadow error code of gpiochip_lock_as_irq() (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: cannonlake: Fix community ordering for H variant (Benjamin Tissoires) [1658075]
- [pinctrl] pinctrl: intel: Do pin translation when lock IRQ (Benjamin Tissoires) [1658075]
- [firmware] efi: Prevent GICv3 WARN() by mapping the memreserve table before first use (Bhupesh Sharma) [1638640]
- [firmware] efi: Permit calling efi_mem_reserve_persistent() from atomic context (Bhupesh Sharma) [1638640]
- [firmware] efi/arm: Defer persistent reservations until after paging_init() (Bhupesh Sharma) [1638640]
- [firmware] efi/arm: Revert deferred unmap of early memmap mapping (Bhupesh Sharma) [1638640]
- [arm64] arm64: memblock: don't permit memblock resizing until linear mapping is up (Bhupesh Sharma) [1638640]
- [arm64] arm64: Fix /proc/iomem for reserved but not memory regions (Bhupesh Sharma) [1638640]
- [tty] tty: wipe buffer. (Christoph von Recklinghausen) [1655051]
- [tty] tty: wipe buffer if not echoing data (Christoph von Recklinghausen) [1655051]

* Wed Dec 12 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-52.el8]
- [powerpc] powerpc/perf: Remove sched_task function defined for thread-imc (Steve Best) [1657153]
- [s390] Add reserved fields to mm_context_t (Philipp Rudo) [1656874]
- [s390] Add reserved fields to thread_struct (Philipp Rudo) [1656874]
- [documentation] kdump: correct crashkernel=auto threshold (Raghavendra Rao) [1656698]
- [fs] NFSv4.x: fix lock recovery during delegation recall (Steve Dickson) [1656410]
- [x86] x86/spec_ctrl: Synchronize RHEL8 percpu SPEC_CTRL MSR states with new STIBP logic (Waiman Long) [1655662]
- [x86] x86/speculation: Provide IBPB always command line options (Waiman Long) [1655662]
- [x86] x86/speculation: Add seccomp Spectre v2 user space protection mode (Waiman Long) [1655662]
- [x86] x86/speculation: Enable prctl mode for spectre_v2_user (Waiman Long) [1655662]
- [x86] x86/speculation: Add prctl() control for indirect branch speculation (Waiman Long) [1655662]
- [x86] x86/speculation: Prepare arch_smt_update() for PRCTL mode (Waiman Long) [1655662]
- [x86] x86/speculation: Prevent stale SPEC_CTRL msr content (Waiman Long) [1655662]
- [x86] x86/speculation: Split out TIF update (Waiman Long) [1655662]
- [x86] ptrace: Remove unused ptrace_may_access_sched() and MODE_IBRS (Waiman Long) [1655662]
- [x86] x86/speculation: Prepare for conditional IBPB in switch_mm() (Waiman Long) [1655662]
- [x86] x86/speculation: Avoid __switch_to_xtra() calls (Waiman Long) [1655662]
- [x86] x86/process: Consolidate and simplify switch_to_xtra() code (Waiman Long) [1655662]
- [x86] x86/speculation: Prepare for per task indirect branch speculation control (Waiman Long) [1655662]
- [x86] x86/speculation: Add command line control for indirect branch speculation (Waiman Long) [1655662]
- [x86] x86/speculation: Unify conditional spectre v2 print functions (Waiman Long) [1655662]
- [x86] x86/speculataion: Mark command line parser data __initdata (Waiman Long) [1655662]
- [x86] x86/speculation: Mark string arrays const correctly (Waiman Long) [1655662]
- [x86] x86/speculation: Reorder the spec_v2 code (Waiman Long) [1655662]
- [x86] x86/l1tf: Show actual SMT state (Waiman Long) [1655662]
- [x86] x86/speculation: Rework SMT state change (Waiman Long) [1655662]
- [x86] sched/smt: Expose sched_smt_present static key (Waiman Long) [1655662]
- [x86] x86/Kconfig: Select SCHED_SMT if SMP enabled (Waiman Long) [1655662]
- [x86] sched/smt: Make sched_smt_present track topology (Waiman Long) [1655662]
- [x86] x86/speculation: Reorganize speculation control MSRs update (Waiman Long) [1655662]
- [x86] x86/speculation: Rename SSBD update functions (Waiman Long) [1655662]
- [x86] x86/speculation: Disable STIBP when enhanced IBRS is in use (Waiman Long) [1655662]
- [x86] x86/speculation: Move STIPB/IBPB string conditionals out of cpu_show_common() (Waiman Long) [1655662]
- [x86] x86/speculation: Remove unnecessary ret variable in cpu_show_common() (Waiman Long) [1655662]
- [x86] x86/speculation: Clean up spectre_v2_parse_cmdline() (Waiman Long) [1655662]
- [x86] x86/speculation: Update the TIF_SSBD comment (Waiman Long) [1655662]
- [x86] x86/retpoline: Remove minimal retpoline support (Waiman Long) [1655662]
- [x86] x86/retpoline: Make CONFIG_RETPOLINE depend on compiler support (Waiman Long) [1655662]
- [x86] x86/spec_ctrl: Temporarily remove the IBRS code from process.c & bugs.c (Waiman Long) [1655662]
- [nvme] nvme: flush namespace scanning work just before removing namespaces (Ewan Milne) [1656028]
- [netdrv] i40e: Fix deletion of MAC filters (Stefan Assmann) [1646847]
- [scsi] mpt3sas: Display message on Configurable secure HBA (Tomas Henzl) [1649314]
- [scsi] scsi: mpt3sas: Add support for Aero controllers (Tomas Henzl) [1649314]
- [scsi] scsi: mpt3sas: Update MPI headers to support Aero controllers (Tomas Henzl) [1649314]
- [scsi] megaraid_sas: Add support for MegaRAID Aero controllers (Tomas Henzl) [1649384]
- [netdrv] nfp: flower: enabled offloading of Team LAG (Pablo Cascon) [1649876]
- [netdrv] net/mlx5: IPSec, Fix the SA context hash key (Alaa Hleihel) [1645857]
- [hwmon] hwmon/k10temp: Add support for AMD family 17h, model 30h CPUs (Gary Hook) [1640681]
- [x86] x86/amd_nb: Add PCI device IDs for family 17h, model 30h (Gary Hook) [1640681]
- [x86] x86/amd_nb: Add support for newer PCI topologies (Gary Hook) [1640681]
- [hwmon] hwmon/k10temp, x86/amd_nb: Consolidate shared device IDs (Gary Hook) [1640681]
- [net] tipc: fix info leak from kernel tipc_event (Jon Maloy) [1643279]
- [net] tipc: eliminate message disordering during binding table update (Jon Maloy) [1643279]
- [net] tipc: fix unsafe rcu locking when accessing publication list (Jon Maloy) [1643279]
- [net] tipc: queue socket protocol error messages into socket receive buffer (Jon Maloy) [1643279]
- [net] tipc: ignore STATE_MSG on wrong link session (Jon Maloy) [1643279]
- [net] tipc: fix failover problem (Jon Maloy) [1643279]
- [net] tipc: eliminate possible recursive locking detected by LOCKDEP (Jon Maloy) [1643279]
- [net] tipc: lock wakeup & inputq at tipc_link_reset() (Jon Maloy) [1643279]
- [net] tipc: reset bearer if device carrier not ok (Jon Maloy) [1643279]
- [net] tipc: fix flow control accounting for implicit connect (Jon Maloy) [1643279]
- [net] tipc: check return value of __tipc_dump_start() (Jon Maloy) [1643279]
- [net] tipc: call start and done ops directly in __tipc_nl_compat_dumpit() (Jon Maloy) [1643279]
- [net] tipc: orphan sock in tipc_release() (Jon Maloy) [1643279]
- [net] tipc: switch to rhashtable iterator (Jon Maloy) [1643279]
- [net] tipc: fix a missing rhashtable_walk_exit() (Jon Maloy) [1643279]
- [net] tipc: add missing dev_put() on error in tipc_enable_l2_media (Jon Maloy) [1643279]
- [net] tipc: initialize broadcast link stale counter correctly (Jon Maloy) [1643279]
- [net] tipc: set link tolerance correctly in broadcast link (Jon Maloy) [1643279]
- [net] tipc: extend link reset criteria for stale packet retransmission (Jon Maloy) [1643279]
- [crypto] crypto: ccp - Add support for new CCP/PSP device ID (Gary Hook) [1634201]
- [crypto] crypto: ccp - Support register differences between PSP devices (Gary Hook) [1634201]
- [crypto] crypto: ccp - Remove unused #defines (Gary Hook) [1634201]
- [crypto] crypto: ccp - Add psp enabled message when initialization succeeds (Gary Hook) [1634201]
- [crypto] crypto: ccp - Fix command completion detection race (Gary Hook) [1634201]
- [crypto] crypto: ccp - Check for NULL PSP pointer at module unload (Gary Hook) [1634201]
- [net] sctp: increase sk_wmem_alloc when head->truesize is increased (Xin Long) [1645419]
- [net] sctp: count sk_wmem_alloc by skb truesize in sctp_packet_transmit (Xin Long) [1645419]
- [net] ipv6: re-do dad when interface has IFF_NOARP flag change (Hangbin Liu) [1644594]
- [net] netfilter: nf_tables: don't skip inactive chains during update (Florian Westphal) [1643746]
- [net] inet: frags: better deal with smp races (Sabrina Dubroca) [1645397]
- [net] geneve, vxlan: Don't set exceptions if skb->len < mtu (Xin Long) [1642842]
- [net] geneve, vxlan: Don't check skb_dst() twice (Xin Long) [1642842]
- [net] sctp: fix strchange_flags name for Stream Change Event (Xin Long) [1641852]
- [net] sctp: update dst pmtu with the correct daddr (Xin Long) [1644478]
- [net] sctp: not free the new asoc when sctp_wait_for_connect returns err (Xin Long) [1644155]
- [net] l2tp: fix a sock refcnt leak in l2tp_tunnel_register (Xin Long) [1642749]
- [net] sctp: check policy more carefully when getting pr status (Xin Long) [1637786]
- [net] sctp: get pr_assoc and pr_stream all status with SCTP_PR_SCTP_ALL instead (Xin Long) [1637786]
- [net] ipv4/igmp: fix v1/v2 switchback timeout based on rfc3376, 8.12 (Hangbin Liu) [1638598]
- [net] netfilter: nft_compat: ebtables 'nat' table is normal chain type (Florian Westphal) [1645377]
- [net] sched: exclude TC from kABI guarantee (Ivan Vecera) [1628454]
- [net] netfilter: nft_set_rbtree: allow loose matching of closing element in interval (Phil Sutter) [1641993]
- [net] netfilter: xt_nat: fix DNAT target for shifted portmap ranges (Paolo Abeni) [1634258]
- [net] sched: Fix for duplicate class dump (Phil Sutter) [1631179]
- [x86] KVM: X86: Fix scan ioapic use-before-initialization (Bandan Das) [1653835] {CVE-2018-19407}

* Fri Dec 07 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-51.el8]
- [scsi] scsi: vmw_pscsi: Rearrange code to avoid multiple calls to free_irq during unload (Cathy Avery) [1590875]
- [netdrv] net/ibmvnic: Fix RTNL deadlock during device reset (Steve Best) [1656076]
- [s390] s390/qeth: fix length check in SNMP processing (Philipp Rudo) [1655612]
- [s390] s390/ism: clear dmbe_mask bit before SMC IRQ handling (Philipp Rudo) [1655611]
- [net] net/smc: use after free fix in smc_wr_tx_put_slot() (Philipp Rudo) [1655611]
- [net] net/smc: atomic SMCD cursor handling (Philipp Rudo) [1655611]
- [net] net/smc: add SMC-D shutdown signal (Philipp Rudo) [1655611]
- [net] net/smc: use queue pair number when matching link group (Philipp Rudo) [1655611]
- [net] net/smc: abort CLC connection in smc_release (Philipp Rudo) [1655611]
- [net] net/smc: unregister rkeys of unused buffer (Philipp Rudo) [1655611]
- [net] net/smc: add infrastructure to send delete rkey messages (Philipp Rudo) [1655611]
- [net] net/smc: avoid a delay by waiting for nothing (Philipp Rudo) [1655611]
- [net] net/smc: cleanup listen worker mutex unlocking (Philipp Rudo) [1655611]
- [net] net/smc: short wait for late smc_clc_wait_msg (Philipp Rudo) [1655611]
- [net] net/smc: no link delete for a never active link (Philipp Rudo) [1655611]
- [net] net/smc: allow fallback after clc timeouts (Philipp Rudo) [1655611]
- [net] net/smc: remove sock_error detour in clc-functions (Philipp Rudo) [1655611]
- [net] net/smc: make smc_lgr_free() static (Philipp Rudo) [1655611]
- [net] net/smc: cleanup tcp_listen_worker initialization (Philipp Rudo) [1655611]
- [net] net/smc: fix smc_buf_unuse to use the lgr pointer (Philipp Rudo) [1655611]
- [net] Revert "net: simplify sock_poll_wait" (Philipp Rudo) [1655611]
- [powerpc] powerpc/pseries: Fix unitialized timer reset on migration (Steve Best) [1655053]
- [powerpc] powerpc/pseries/mobility: Extend start/stop topology update scope (Steve Best) [1655053]
- [x86] Mark Intel Cascade Lake supported (Steve Best) [1641425]

* Wed Dec 05 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-50.el8]
- [x86] KVM: VMX: re-add ple_gap module parameter (Gary Hook) [1652953]
- [netdrv] tg3: Add PHY reset for 5717/5719/5720 in change ring and flow control paths (Steve Best) [1655515]
- [pci] PCI/ASPM: Do not initialize link state when aspm_disabled is set (Myron Stowe) [1655246]
- [pci] PCI/ACPI: Allow _OSC presence to be optional for PCI (Myron Stowe) [1655246]
- [pci] PCI/ACPI: Correct error message for ASPM disabling (Myron Stowe) [1655246]
- [pci] PCI/ASPM: Fix link_state teardown on device removal (Myron Stowe) [1655246]
- [netdrv] ice: Change req_speeds to be u16 (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix the bytecount sent to netdev_tx_sent_queue (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix tx_timeout in PF driver (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix napi delete calls for remove (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix typo in error message (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix flags for port VLAN (Jonathan Toppins) [1644403]
- [netdrv] ice: Remove duplicate addition of VLANs in replay path (Jonathan Toppins) [1644403]
- [netdrv] ice: Free VSI contexts during for unload (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix dead device link issue with flow control (Jonathan Toppins) [1644403]
- [netdrv] ice: Check for reset in progress during remove (Jonathan Toppins) [1644403]
- [netdrv] ice: Set carrier state and start/stop queues in rebuild (Jonathan Toppins) [1644403]
- [netdrv] virtchnl: Added support to exchange additional speed values (Jonathan Toppins) [1644403]
- [netdrv] ice: Poll for link status change (Jonathan Toppins) [1644403]
- [netdrv] ice: Allocate VF interrupts and set queue map (Jonathan Toppins) [1644403]
- [netdrv] ice: Introduce ice_dev_onetime_setup (Jonathan Toppins) [1644403]
- [netdrv] ice: Use capability count returned by the firmware (Jonathan Toppins) [1644403]
- [netdrv] ice: Update expected FW version (Jonathan Toppins) [1644403]
- [netdrv] ice: Change device ID define names to align with branding string (Jonathan Toppins) [1644403]
- [netdrv] ice: Make ice_msix_clean_rings static (Jonathan Toppins) [1644403]
- [netdrv] ice: Update version string (Jonathan Toppins) [1644403]
- [netdrv] ice: Use the right function to enable/disable VSI (Jonathan Toppins) [1644403]
- [netdrv] ice: Add more flexibility on how we assign an ITR index (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix potential null pointer issues (Jonathan Toppins) [1644403]
- [netdrv] ice: Add code to go from ICE_FWD_TO_VSI_LIST to ICE_FWD_TO_VSI (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix forward to queue group logic (Jonathan Toppins) [1644403]
- [netdrv] ice: Extend malicious operations detection logic (Jonathan Toppins) [1644403]
- [netdrv] ice: Notify VF of link status change (Jonathan Toppins) [1644403]
- [netdrv] ice: Implement virtchnl commands for AVF support (Jonathan Toppins) [1644403]
- [netdrv] ice: Add handlers for VF netdevice operations (Jonathan Toppins) [1644403]
- [netdrv] ice: Add support for VF reset events (Jonathan Toppins) [1644403]
- [netdrv] ice: Update VSI and queue management code to handle VF VSI (Jonathan Toppins) [1644403]
- [netdrv] ice: Add handler to configure SR-IOV (Jonathan Toppins) [1644403]
- [netdrv] ice: Add support to detect SR-IOV capability and mailbox queues (Jonathan Toppins) [1644403]
- [netdrv] ice: Fix error on driver remove (Jonathan Toppins) [1644403]
- [netdrv] ice: Add support for dynamic interrupt moderation (Jonathan Toppins) [1644403]
- [netdrv] ice: Align ice_reset_req enum values to hardware reset values (Jonathan Toppins) [1644403]
- [netdrv] ice: Implement ethtool hook for RSS switch (Jonathan Toppins) [1644403]
- [netdrv] ice: Split irq_tracker into sw_irq_tracker and hw_irq_tracker (Jonathan Toppins) [1644403]
- [netdrv] ice: Check for actual link state of port after reset (Jonathan Toppins) [1644403]
- [netdrv] ice: Implement VSI replay framework (Jonathan Toppins) [1644403]
- [netdrv] ice: Expand use of VSI handles part 2/2 (Jonathan Toppins) [1644403]
- [netdrv] ice: Expand use of VSI handles part 1/2 (Jonathan Toppins) [1644403]
- [netdrv] ice: Change pf state behavior to protect reset path (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 7/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 6/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 5/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 4/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 3/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 2/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: Move common functions out of ice_main.c part 1/7 (Jonathan Toppins) [1644403]
- [netdrv] ice: fix changing of ring descriptor size (ethtool -G) (Jonathan Toppins) [1644403]
- [netdrv] ice: Update to capabilities admin queue command (Jonathan Toppins) [1644403]
- [netdrv] ice: Query the Tx scheduler node before adding it (Jonathan Toppins) [1644403]
- [netdrv] ice: Update comment for ice_fltr_mgmt_list_entry (Jonathan Toppins) [1644403]
- [netdrv] ice: update fw version check logic (Jonathan Toppins) [1644403]
- [netdrv] ice: update branding strings and supported device ids (Jonathan Toppins) [1644403]
- [netdrv] ice: replace unnecessary memcpy with direct assignment (Jonathan Toppins) [1644403]
- [netdrv] ice: use [sr]q.count when checking if queue is initialized (Jonathan Toppins) [1644403]
- [netdrv] ice: remove ndo_poll_controller (Jonathan Toppins) [1644403]
- [fs] fanotify: fix handling of events on child sub-directory (Miklos Szeredi) [1652432]
- [fs] fsnotify: generalize handling of extra event flags (Miklos Szeredi) [1652432]
- [netdrv] net: hns3: add common validation in hclge_dcb (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: fix for multiple unmapping DMA problem (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: rename hns_nic_dma_unmap (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: add handling for big TX fragment (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: move DMA map into hns3_fill_desc (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: remove hns3_fill_desc_tso (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Resume promisc mode and vlan filter status after loopback test (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Resume promisc mode and vlan filter status after reset (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Enable promisc mode when mac vlan table is full (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for rx vlan id handle to support Rev 0x21 hardware (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add egress/ingress vlan filter for revision 0x21 (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Optimize for unicast mac vlan table (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix loss of coal configuration while doing reset (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Modify hns3_get_max_available_channels (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Change return type of hclge_tm_schd_info_update() (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for netdev not up problem when setting mtu (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for packet buffer setting bug (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Set extra mac address of pause param for HW (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix speed/duplex information loss problem when executing ethtool ethx cmd of VF (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add get_media_type ops support for VF (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Remove print messages for error packet (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add nic state check before calling netif_tx_wake_queue (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add handle for default case (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Unify the prefix of vf functions (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix tqp array traversal condition for vf (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix ets validate issue (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix parameter type for q_id in hclge_tm_q_to_qs_map_cfg() (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix client initialize state issue when roce client initialize failed (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Clear client pointer when initialize client failed or unintialize finished (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix cmdq registers initialization issue for vf (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for setting speed for phy failed problem (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Check hdev state when getting link status (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Set STATE_DOWN bit of hdev state when stopping net (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Remove packet statistics of public (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Remove tx budget to clean more TX descriptors in a napi (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Refine hns3_get_link_ksettings() (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Remove redundant codes of query advertised flow control abilitiy (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Change the dst mac addr of loopback packet (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Only update mac configuation when necessary (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Preserve vlan 0 in hardware table (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix ping exited problem when doing lp selftest (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for loopback selftest failed problem (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix error of checking used vlan id (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for multicast failure (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for vf vlan delete failed problem (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: modify variable type in hns3_nic_reuse_page (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add vlan filter setting by ethtool command -K (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Set tx ring' tc info when netdev is up (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix desc num set to default when setting channel (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for information of phydev lost problem when down/up (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add support for serdes loopback selftest (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Refine the MSIX allocation for PF (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix MSIX allocation issue for VF (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: fix return value error while hclge_cmd_csq_clean failed (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Modify inconsistent bit mask macros (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for using wrong mask and shift in hclge_get_ring_chain_from_mbx (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Correct reset event status register (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Prevent to request reset frequently (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Prevent sending command during global or core reset (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Add configure for mac minimal frame size (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for l4 checksum offload bug (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix for waterline not setting correctly (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: Fix tc setup when netdev is first up (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: modify hnae_ to hnae3_ (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: simplify hclge_cmd_csq_clean (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: remove some redundant assignments (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: remove back in struct hclge_hw (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: add unlikely for error check (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: add l4_type check for both ipv4 and ipv6 (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: add vector status check before free vector (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: rename the interface for init_client_instance and uninit_client_instance (Xiaojun Tan) [1640945]
- [netdrv] net: hns3: remove hclge_get_vector_index from hclge_bind_ring_with_vector (Xiaojun Tan) [1640945]
- [kernel] redhat: Enable -Werror for architectures (Laura Abbott) [1582754]
- [drm] drm/atomic_helper: Remove dangling variable (Laura Abbott) [1582754]
- [s390] s390/tools: fix gcc 8 stringop-truncation warnings (Laura Abbott) [1582754]
- [tty] kgdboc: Fix restrict error (Laura Abbott) [1582754]
- [misc] misc: kgdbts: Fix restrict error (Laura Abbott) [1582754]
- [scsi] scsi: ibmvscsis: Fix a stringop-overflow warning (Laura Abbott) [1582754]
- [s390] s390/extmem: fix gcc 8 stringop-overflow warning (Laura Abbott) [1582754]
- [s390] s390/perf: fix gcc 8 array-bounds warning (Laura Abbott) [1582754]
- [kernel] kdb: Use strscpy with destination buffer size (Laura Abbott) [1582754]
- [fs] configfs: replace strncpy with memcpy (Laura Abbott) [1582754]
- [fs] kernfs: Replace strncpy with memcpy (Laura Abbott) [1582754]
- [kernel] disable stringop truncation warnings for now (Laura Abbott) [1582754]
- [sound] ALSA: intel_hdmi: Use strlcpy() instead of strncpy() (Laura Abbott) [1582754]
- [sound] ALSA: trident: Suppress gcc string warning (Laura Abbott) [1582754]
- [lib] kobject: Replace strncpy with memcpy (Laura Abbott) [1582754]
- [tty] TTY: isdn: Replace strncpy with memcpy (Laura Abbott) [1582754]
- [target] scsi: target/iscsi: Make iscsit_ta_authentication() respect the output buffer size (Laura Abbott) [1582754]
- [fs] fuse: don't need GETATTR after every READ (Miklos Szeredi) [1650538]
- [fs] fuse: allow fine grained attr cache invaldation (Miklos Szeredi) [1650538]

* Tue Dec 04 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-49.el8]
- [mm] mm: mremap: properly flush TLB before releasing the page (Rafael Aquini) [1645122] {CVE-2018-18281}
- [x86] x86/spec_ctrl: Change default Skylake Spectre v2 mitigation to retpoline (Waiman Long) [1651806]
- [fs] gfs2: write revokes should traverse sd_ail1_list in reverse (Andreas Grunbacher) [1652763]
- [fs] gfs2: Fix marking bitmaps non-full (Andreas Grunbacher) [1652762]
- [fs] GFS2: Flush the GFS2 delete workqueue before stopping the kernel threads (Andreas Grunbacher) [1652761]
- [fs] gfs2: Don't leave s_fs_info pointing to freed memory in init_sbd (Andreas Grunbacher) [1652759]
- [fs] gfs2: Use fs_* functions instead of pr_* function where we can (Andreas Grunbacher) [1652757]
- [fs] gfs2: slow the deluge of io error messages (Andreas Grunbacher) [1652757]
- [fs] gfs2_meta: ->mount() can get NULL dev_name (Andreas Grunbacher) [1652754]
- [powerpc] powerpc/vdso: Correct call frame information (Steve Best) [1651281]
- [i2c] i2c: i801: Add support for Intel Ice Lake (David Arcari) [1637435]
- [usb] xhci: Add quirk to workaround the errata seen on Cavium Thunder-X2 Soc (Robert Richter) [1649829]
- [x86] x86: numa_emulation: fix uniform-split numa emulation (Rafael Aquini) [1620341]
- [x86] x86: numa_emulation: introduce uniform split capability (Rafael Aquini) [1620341]
- [kernel] perf/hw_breakpoint: Modify breakpoint even if the new attr has disabled set (Mark Salter) [1643174]
- [x86] KVM: vmx: hyper-v: don't pass EPT configuration info to vmx_hv_remote_flush_tlb() (Paolo Bonzini) [1636610]
- [x86] KVM: x86: support CONFIG_KVM_AMD=y with CONFIG_CRYPTO_DEV_CCP_DD=m (Paolo Bonzini) [1636610]
- [x86] kvm: nVMX: fix entry with pending interrupt if APICv is enabled (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: hide flexpriority from guest when disabled at the module level (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: check for existence of secondary exec controls before accessing (Paolo Bonzini) [1636610]
- [x86] KVM: x86: fix L1TF's MMIO GFN calculation (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: cut down decimal places in update interval dialog (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: Fix emulation of VM_ENTRY_LOAD_BNDCFGS (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Do not use kvm_x86_ops->mpx_supported() directly (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: Do not expose MPX VMX controls when guest MPX disabled (Paolo Bonzini) [1636610]
- [x86] KVM: x86: never trap MSR_KERNEL_GS_BASE (Paolo Bonzini) [1636610]
- [x86] KVM: LAPIC: Fix pv ipis out-of-bounds access (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: Fix loss of pending IRQ/NMI before entering L2 (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: re-animate display of dead guests (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: indicate dead guests as such (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: handle guest removals more gracefully (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: don't reset stats when setting PID filter for debugfs (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: fix updates for dead guests (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: fix handling of invalid paths in debugfs provider (Paolo Bonzini) [1636610]
- [tools] tools/kvm_stat: fix python3 issues (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Unexport x86_emulate_instruction() (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Rename emulate_instruction() to kvm_emulate_instruction() (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Do not re-{try, execute} after failed emulation in L2 (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Default to not allowing emulation retry in kvm_mmu_page_fault (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Merge EMULTYPE_RETRY and EMULTYPE_ALLOW_REEXECUTE (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Invert emulation re-execute behavior to make it opt-in (Paolo Bonzini) [1636610]
- [x86] KVM: x86: SVM: Set EMULTYPE_NO_REEXECUTE for RSM emulation (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: Do not allow reexecute_instruction() when skipping MMIO instr (Paolo Bonzini) [1636610]
- [x86] KVM: SVM: remove unused variable dst_vaddr_end (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: avoid redundant double assignment of nested_run_pending (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: Fix bad cleanup on error of get/set nested state IOCTLs (Paolo Bonzini) [1636610]
- [tools] kvm: selftests: Add platform_info_test (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Control guest reads of MSR_PLATFORM_INFO (Paolo Bonzini) [1636610]
- [x86] KVM: x86: Turbo bits in MSR_PLATFORM_INFO (Paolo Bonzini) [1636610]
- [x86] nVMX x86: Check VPID value on vmentry of L2 guests (Paolo Bonzini) [1636610]
- [x86] nVMX x86: check posted-interrupt descriptor addresss on vmentry of L2 (Paolo Bonzini) [1636610]
- [x86] KVM: nVMX: Wake blocked vCPU in guest-mode if pending interrupt in virtual APICv (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: check nested state and CR4.VMXE against SMM (Paolo Bonzini) [1636610]
- [x86] kvm: x86: make kvm_{load|put}_guest_fpu() static (Paolo Bonzini) [1636610]
- [x86] x86/hyper-v: rename ipi_arg_{ex, non_ex} structures (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: use preemption timer to force immediate VMExit (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: modify preemption timer bit only when arming timer (Paolo Bonzini) [1636610]
- [x86] KVM: VMX: immediately mark preemption timer expired only for zero value (Paolo Bonzini) [1636610]
- [x86] KVM: SVM: Switch to bitmap_zalloc() (Paolo Bonzini) [1636610]
- [lib] bitmap: Add bitmap_alloc(), bitmap_zalloc() and bitmap_free() (Paolo Bonzini) [1636610]
- [x86] KVM/MMU: Fix comment in walk_shadow_page_lockless_end() (Paolo Bonzini) [1636610]
- [tools] kvm: selftests: use -pthread instead of -lpthread (Paolo Bonzini) [1636610]
- [tools] kvm: selftest: add dirty logging test (Paolo Bonzini) [1636610]
- [tools] kvm: selftest: pass in extra memory when create vm (Paolo Bonzini) [1636610]
- [tools] kvm: selftest: include the tools headers (Paolo Bonzini) [1636610]
- [tools] kvm: selftest: unify the guest port macros (Paolo Bonzini) [1636610]
- [x86] KVM: x86: don't reset root in kvm_mmu_setup() (Paolo Bonzini) [1636610]
- [x86] kvm: mmu: Don't read PDPTEs when paging is not enabled (Paolo Bonzini) [1636610]
- [x86] x86/kvm/lapic: always disable MMIO interface in x2APIC mode (Paolo Bonzini) [1636610]
- [s390] KVM: s390: Make huge pages unavailable in ucontrol VMs (Paolo Bonzini) [1636610]
- [s390] s390/mm: Check for valid vma before zapping in gmap_discard (Paolo Bonzini) [1636610]
- [tools] selftests: add headers_install to lib.mk (Paolo Bonzini) [1636610]
- [tools] selftests: kselftest: Remove outdated comment (Paolo Bonzini) [1636610]
- [tools] selftests: android: move config up a level (Paolo Bonzini) [1636610]
- [md] md: Avoid namespace collision with bitmap API (Paolo Bonzini) [1636610]

* Fri Nov 30 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-48.el8]
- [cpufreq] cpufreq / CPPC: Add cpuinfo_cur_freq support for CPPC (Prarit Bhargava) [1654361]
- [netdrv] nfp: flower: add ipv6 set flow label and hop limit offload (Pablo Cascon) [1651639]
- [netdrv] nfp: flower: add ipv4 set ttl and tos offload (Pablo Cascon) [1651639]
- [netdrv] ibmvnic: Update driver queues after change in ring size support (Steve Best) [1651947]
- [netdrv] ibmvnic: Fix RX queue buffer cleanup (Steve Best) [1651947]
- [netdrv] net/ibmnvic: Fix deadlock problem in reset (Steve Best) [1651947]
- [netdrv] ibmvnic: fix accelerated VLAN handling (Steve Best) [1651947]
- [netdrv] ibmvnic: Add ethtool private flag for driver-defined queue limits (Steve Best) [1651947]
- [netdrv] ibmvnic: Introduce driver limits for ring sizes (Steve Best) [1651947]
- [netdrv] ibmvnic: Increase maximum queue size limit (Steve Best) [1651947]
- [netdrv] ibmvnic: remove ndo_poll_controller (Steve Best) [1651947]
- [powerpc] powerpc/powernv/npu: Remove atsd_threshold debugfs setting (Steve Best) [1653661]
- [powerpc] powerpc/powernv/npu: Use size-based ATSD invalidates (Steve Best) [1653661]
- [powerpc] powerpc/powernv/npu: Reduce eieio usage when issuing ATSD invalidates (Steve Best) [1653661]
- [powerpc] powerpc/powernv/npu: Add a debugfs setting to change ATSD threshold (Steve Best) [1653661]
- [net] libceph: fall back to sendmsg for slab pages (Ilya Dryomov) [1653395]
- [s390] s390/qeth: utilize virtual MAC for Layer2 OSD devices (Philipp Rudo) [1653246]
- [fs] vfs: fix FIGETBSZ ioctl on an overlayfs file (Miklos Szeredi) [1651362]
- [fs] ovl: fix decode of dir file handle with multi lower layers (Miklos Szeredi) [1651362]
- [fs] ovl: fix missing override creds in link of a metacopy upper (Miklos Szeredi) [1651362]
- [fs] ovl: automatically enable redirect_dir on metacopy=on (Miklos Szeredi) [1651362]
- [fs] ovl: check whiteout in ovl_create_over_whiteout() (Miklos Szeredi) [1651362]
- [fs] ovl: fix recursive oi->lock in ovl_link() (Miklos Szeredi) [1651362]
- [fs] ovl: fix error handling in ovl_verify_set_fh() (Miklos Szeredi) [1651362]
- [mm] mm, memory_hotplug: check zone_movable in has_unmovable_pages (Baoquan He) [1643839]
- [netdrv] hv_netvsc: fix vf serial matching with pci slot info (Vitaly Kuznetsov) [1637519]
- [netdrv] hv_netvsc: remove ndo_poll_controller (Vitaly Kuznetsov) [1637519]
- [netdrv] hv_netvsc: pair VF based on serial number (Vitaly Kuznetsov) [1637519]
- [netdrv] hv_netvsc: fix schedule in RCU context (Vitaly Kuznetsov) [1637519]
- [pci] PCI: hv: Fix return value check in hv_pci_assign_slots() (Vitaly Kuznetsov) [1637519]
- [pci] PCI: hv: support reporting serial number as slot information (Vitaly Kuznetsov) [1637519]
- [pci] PCI: hv: Replace GFP_ATOMIC with GFP_KERNEL in new_pcichild_device() (Vitaly Kuznetsov) [1637519]
- [char] ipmi: Fix timer race with module unload (Robert Richter) [1649812]
- [arm64] arm64: hugetlb: Avoid unnecessary clearing in huge_ptep_set_access_flags (Christoph von Recklinghausen) [1635192]
- [arm64] arm64: hugetlb: Fix handling of young ptes (Christoph von Recklinghausen) [1635192]
- [mm] mm: Preserve _PAGE_DEVMAP across mprotect() calls (Jeff Moyer) [1647647]

* Thu Nov 29 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-47.el8]
- [crypto] crypto: vmx - Fix sleep-in-atomic bugs (Steve Best) [1653662]
- [netdrv] net: ena: update driver version from 2.0.1 to 2.0.2 (John Linville) [1634044]
- [netdrv] net: ena: fix crash during ena_remove() (John Linville) [1634044]
- [netdrv] net: ena: fix crash during failed resume from hibernation (John Linville) [1634044]
- [netdrv] net: ena: enable CONFIG_ENA_ETHERNET for aarch64 (John Linville) [1634044]
- [netdrv] net: ena: enable Low Latency Queues (John Linville) [1634044]
- [netdrv] net: ena: Fix Kconfig dependency on X86 (John Linville) [1634044]
- [netdrv] net: ena: fix indentations in ena_defs for better readability (John Linville) [1634044]
- [netdrv] net: ena: update driver version to 2.0.1 (John Linville) [1634044]
- [netdrv] net: ena: remove redundant parameter in ena_com_admin_init() (John Linville) [1634044]
- [netdrv] net: ena: change rx copybreak default to reduce kernel memory pressure (John Linville) [1634044]
- [netdrv] net: ena: limit refill Rx threshold to 256 to avoid latency issues (John Linville) [1634044]
- [netdrv] net: ena: explicit casting and initialization, and clearer error handling (John Linville) [1634044]
- [netdrv] net: ena: use CSUM_CHECKED device indication to report skb's checksum status (John Linville) [1634044]
- [netdrv] net: ena: add functions for handling Low Latency Queues in ena_netdev (John Linville) [1634044]
- [netdrv] net: ena: add functions for handling Low Latency Queues in ena_com (John Linville) [1634044]
- [netdrv] net: ena: introduce Low Latency Queues data structures according to ENA spec (John Linville) [1634044]
- [netdrv] net: ena: complete host info to match latest ENA spec (John Linville) [1634044]
- [netdrv] net: ena: minor performance improvement (John Linville) [1634044]
- [netdrv] net: ena: fix auto casting to boolean (John Linville) [1634044]
- [netdrv] net: ena: fix NULL dereference due to untimely napi initialization (John Linville) [1634044]
- [netdrv] net: ena: fix rare bug when failed restart/resume is followed by driver removal (John Linville) [1634044]
- [netdrv] net: ena: fix warning in rmmod caused by double iounmap (John Linville) [1634044]
- [netdrv] net: ena: remove ndo_poll_controller (John Linville) [1634044]
- [netdrv] net: ena: fix incorrect usage of memory barriers (John Linville) [1634044]
- [netdrv] net: ena: fix missing calls to READ_ONCE (John Linville) [1634044]
- [netdrv] net: ena: fix missing lock during device destruction (John Linville) [1634044]
- [netdrv] net: ena: fix potential double ena_destroy_device() (John Linville) [1634044]
- [netdrv] net: ena: fix device destruction to gracefully free resources (John Linville) [1634044]
- [netdrv] net: ena: fix driver when PAGE_SIZE == 64kB (John Linville) [1634044]
- [netdrv] net: ena: fix surprise unplug NULL dereference kernel crash (John Linville) [1634044]
- [s390] s390/zcrypt: reinit ap queue state machine during device probe (Philipp Rudo) [1653668]
- [s390] s390/kdump: Make elfcorehdr size calculation ABI compliant (Philipp Rudo) [1653245]
- [s390] s390/kdump: Fix elfcorehdr size calculation (Philipp Rudo) [1653245]
- [block] block: fix 32 bit overflow in __blkdev_issue_discard() (Ming Lei) [1638826]
- [ata] libata: blacklist SAMSUNG MZ7TD256HAFV-000L9 SSD (Ming Lei) [1638826]
- [block] block: copy ioprio in __bio_clone_fast() and bounce (Ming Lei) [1638826]
- [trace] kyber: fix wrong strlcpy() size in trace_kyber_latency() (Ming Lei) [1638826]
- [block] floppy: fix race condition in __floppy_read_block_0() (Ming Lei) [1638826]
- [block] block: make blk_try_req_merge() static (Ming Lei) [1638826]
- [block] block: remove dead queue members (Ming Lei) [1638826]
- [block] block: clean up dead code that is now redundant (Ming Lei) [1638826]
- [nvme] nvme: fix boot hang with only being able to get one IRQ vector (Ming Lei) [1638826]
- [block] ide: don't clear special on ide_queue_rq() entry (Ming Lei) [1638826]
- [block] null_blk: remove unused nullb device (Ming Lei) [1638826]
- [block] ide: don't use req->special (Ming Lei) [1638826]
- [block] pd: replace ->special use with private data in the request (Ming Lei) [1638826]
- [block] aoe: replace ->special use with private data in the request (Ming Lei) [1638826]
- [block] skd_main: don't use req->special (Ming Lei) [1638826]
- [block] nullb: remove leftover legacy request code (Ming Lei) [1638826]
- [scsi] fnic: fix fnic_scsi_host_{start,end}_tag (Ming Lei) [1638826]
- [block] block: remove set but not used variable 'et' (Ming Lei) [1638826]
- [block] block: remove the BLKPREP_* values. (Ming Lei) [1638826]
- [scsi] scsi: return blk_status_t from device handler ->prep_fn (Ming Lei) [1638826]
- [scsi] scsi: return blk_status_t from scsi_init_io and ->init_command (Ming Lei) [1638826]
- [scsi] scsi: clean up error handling in scsi_init_io (Ming Lei) [1638826]
- [scsi] scsi: push blk_status_t up into scsi_setup_{fs,scsi}_cmnd (Ming Lei) [1638826]
- [scsi] scsi: simplify scsi_prep_state_check (Ming Lei) [1638826]
- [block] ide: cleanup ->prep_rq calling convention (Ming Lei) [1638826]
- [block] block: remove req->timeout_list (Ming Lei) [1638826]
- [block] blk-mq: provide a helper to check if a queue is busy (Ming Lei) [1638826]
- [block] blk-mq-tag: change busy_iter_fn to return whether to continue or not (Ming Lei) [1638826]
- [block] ms_block: remove unused pointer 'set' (Ming Lei) [1638826]
- [block] sunvdc: fix compiler warning (Ming Lei) [1638826]
- [nvme] nvme: add separate poll queue map (Ming Lei) [1638826]
- [block] block: add REQ_HIPRI and inherit it from IOCB_HIPRI (Ming Lei) [1638826]
- [nvme] nvme: utilize two queue maps, one for reads and one for writes (Ming Lei) [1638826]
- [block] blk-mq: initial support for multiple queue maps (Ming Lei) [1638826]
- [block] blk-mq: improve plug list sorting (Ming Lei) [1638826]
- [block] blk-mq: cleanup and improve list insertion (Ming Lei) [1638826]
- [block] blk-mq: cache request hardware queue mapping (Ming Lei) [1638826]
- [block] blk-mq: separate number of hardware queues from nr_cpu_ids (Ming Lei) [1638826]
- [block] blk-mq: support multiple hctx maps (Ming Lei) [1638826]
- [block] blk-mq: add 'type' attribute to the sysfs hctx directory (Ming Lei) [1638826]
- [block] blk-mq: allow software queue to map to multiple hardware queues (Ming Lei) [1638826]
- [block] blk-mq: pass in request/bio flags to queue mapping (Ming Lei) [1638826]
- [block] blk-mq: provide dummy blk_mq_map_queue_type() helper (Ming Lei) [1638826]
- [block] blk-mq: abstract out queue map (Ming Lei) [1638826]
- [block] blk-mq: kill q->mq_map (Ming Lei) [1638826]
- [kernel] genirq/affinity: Add support for allocating interrupt sets (Ming Lei) [1638826]
- [kernel] genirq/affinity: Pass first vector to __irq_build_affinity_masks() (Ming Lei) [1638826]
- [kernel] genirq/affinity: Move two stage affinity spreading into a helper function (Ming Lei) [1638826]
- [kernel] genirq/affinity: Spread IRQs to all available NUMA nodes (Ming Lei) [1638826]
- [block] block: kill request ->cpu member (Ming Lei) [1638826]
- [block] block: get rid of q->softirq_done_fn() (Ming Lei) [1638826]
- [block] block: get rid of blk_queued_rq() (Ming Lei) [1638826]
- [block] blk-merge: kill dead queue lock held check (Ming Lei) [1638826]
- [block] block: remove req_no_special_merge() from merging code (Ming Lei) [1638826]
- [block] block: kill request slab cache (Ming Lei) [1638826]
- [block] block: remove request_list code (Ming Lei) [1638826]
- [block] bsg: move bsg-lib parts outside of request queue (Ming Lei) [1638826]
- [block] block: kill legacy parts of timeout handling (Ming Lei) [1638826]
- [block] block: remove __blk_put_request() (Ming Lei) [1638826]
- [block] block: get rid of MQ scheduler ops union (Ming Lei) [1638826]
- [block] block: remove dead elevator code (Ming Lei) [1638826]
- [block] block: remove legacy IO schedulers (Ming Lei) [1638826]
- [block] block: cleanup kick/queued handling (Ming Lei) [1638826]
- [block] block: remove non mq parts from the flush code (Ming Lei) [1638826]
- [block] block: remove legacy rq tagging (Ming Lei) [1638826]
- [block] blk-cgroup: remove legacy queue bypassing (Ming Lei) [1638826]
- [block] blk-wbt: kill check for legacy queue type (Ming Lei) [1638826]
- [block] block: remove blk_complete_request() (Ming Lei) [1638826]
- [block] bsg: convert to use blk-mq (Ming Lei) [1638826]
- [block] bsg: provide bsg_remove_queue() helper (Ming Lei) [1638826]
- [block] bsg: pass in desired timeout handler (Ming Lei) [1638826]
- [s390] dasd: remove dead code (Ming Lei) [1638826]
- [block] block: remove q->lld_busy_fn() (Ming Lei) [1638826]
- [scsi] scsi: kill off the legacy IO path (Ming Lei) [1638826]
- [scsi] scsi: provide mq_ops->busy() hook (Ming Lei) [1638826]
- [block] blk-mq: provide mq_ops->busy() hook (Ming Lei) [1638826]
- [block] blk-mq: remove legacy check in queue blk_freeze_queue() (Ming Lei) [1638826]
- [block] blk-mq: remove the request_list usage (Ming Lei) [1638826]
- [block] ide: convert to blk-mq (Ming Lei) [1638826]
- [block] mspro_block: convert to blk-mq (Ming Lei) [1638826]
- [block] ms_block: convert to blk-mq (Ming Lei) [1638826]
- [block] sunvdc: convert to blk-mq (Ming Lei) [1638826]
- [block] null_blk: Add conventional zone configuration for zoned support (Ming Lei) [1638826]
- [ata] libata: Apply NOLPM quirk for SAMSUNG MZ7TD256HAFV-000L9 (Ming Lei) [1638826]
- [block] block, bfq: fix asymmetric scenarios detection (Ming Lei) [1638826]
- [cdrom] gdrom: fix mistake in assignment of error (Ming Lei) [1638826]
- [block] blk-mq: place trace_block_getrq() in correct place (Ming Lei) [1638826]
- [block] block: Introduce blk_revalidate_disk_zones() (Ming Lei) [1638826]
- [block] block: add a report_zones method (Ming Lei) [1638826]
- [block] block: Expose queue nr_zones in sysfs (Ming Lei) [1638826]
- [block] block: Improve zone reset execution (Ming Lei) [1638826]
- [block] block: Introduce BLKGETNRZONES ioctl (Ming Lei) [1638826]
- [block] block: Introduce BLKGETZONESZ ioctl (Ming Lei) [1638826]
- [block] block: Limit allocation of zone descriptors for report zones (Ming Lei) [1638826]
- [block] block: Introduce blkdev_nr_zones() helper (Ming Lei) [1638826]
- [scsi] scsi: sd_zbc: Fix sd_zbc_check_zones() error checks (Ming Lei) [1638826]
- [scsi] scsi: sd_zbc: Reduce boot device scan and revalidate time (Ming Lei) [1638826]
- [scsi] scsi: sd_zbc: Rearrange code (Ming Lei) [1638826]
- [scsi] scsi: sd_zbc: Remove an assignment from sd_zbc_setup_report_cmnd() (Ming Lei) [1638826]
- [scsi] scsi: sd: don't crash the host on invalid commands (Ming Lei) [1638826]
- [pci] PCI/MSI: Warn and return error if driver enables MSI/MSI-X twice (Ming Lei) [1638826]
- [fs] f2fs: remove request_list check in is_idle() (Ming Lei) [1638826]
- [scsi] scsi: osd: initiator should use mq variant of request ending (Ming Lei) [1638826]
- [scsi] scsi: fnic: replace gross legacy tag hack with blk-mq hack (Ming Lei) [1638826]
- [infiniband] ib_srp: Remove WARN_ON in srp_terminate_io() (Ming Lei) [1638826]
- [scsi] scsi: ufs: Disable blk-mq for now (Ming Lei) [1638826]
- [block] sx8: convert to blk-mq (Ming Lei) [1638826]
- [block] z2ram: convert to blk-mq (Ming Lei) [1638826]
- [cdrom] gdrom: convert to blk-mq (Ming Lei) [1638826]
- [block] floppy: convert to blk-mq (Ming Lei) [1638826]
- [block] ataflop: convert to blk-mq (Ming Lei) [1638826]
- [block] ataflop: fix error handling during setup (Ming Lei) [1638826]
- [block] ataflop: fold headers into C file (Ming Lei) [1638826]
- [block] amiflop: convert to blk-mq (Ming Lei) [1638826]
- [block] amiflop: clean up on errors during setup (Ming Lei) [1638826]
- [block] amiflop: fold headers into C file (Ming Lei) [1638826]
- [block] swim3: convert to blk-mq (Ming Lei) [1638826]
- [block] swim3: add real error handling in setup (Ming Lei) [1638826]
- [block] swim: convert to blk-mq (Ming Lei) [1638826]
- [block] swim: fix cleanup on setup error (Ming Lei) [1638826]
- [mtd] mtd_blkdevs: convert to blk-mq (Ming Lei) [1638826]
- [block] xsysace: convert to blk-mq (Ming Lei) [1638826]
- [block] paride: convert pf to blk-mq (Ming Lei) [1638826]
- [block] paride: convert pd to blk-mq (Ming Lei) [1638826]
- [block] paride: convert pcd to blk-mq (Ming Lei) [1638826]
- [block] ps3disk: convert to blk-mq (Ming Lei) [1638826]
- [block] blk-mq: provide helper for setting up an SQ queue and tag set (Ming Lei) [1638826]
- [block] null_blk: remove set but not used variable 'q' (Ming Lei) [1638826]
- [cdrom] cdrom: don't attempt to fiddle with cdo->capability (Ming Lei) [1638826]
- [block] block: remove bogus check for queue_lock assignment (Ming Lei) [1638826]
- [block] null_blk: remove legacy IO path (Ming Lei) [1638826]
- [block] um: Convert ubd driver to blk-mq (Ming Lei) [1638826]
- [block] skd: fixup usage of legacy IO API (Ming Lei) [1638826]
- [block] aoe: convert aoeblk to blk-mq (Ming Lei) [1638826]
- [block] ide: remove redundant variables queue_run_ms and left (Ming Lei) [1638826]
- [scsi] scsi: core: scsi_io_completion convert BUGs to WARNs (Ming Lei) [1638826]
- [scsi] scsi: core: scsi_io_completion hints on fastpath (Ming Lei) [1638826]
- [scsi] scsi: core: add scsi_io_completion_reprep helper (Ming Lei) [1638826]
- [scsi] scsi: core: add scsi_io_completion_action helper (Ming Lei) [1638826]
- [scsi] scsi: core: add scsi_io_completion_nz_result function (Ming Lei) [1638826]
- [scsi] scsi: core: scsi_io_completion: rename variables (Ming Lei) [1638826]
- [scsi] scsi: core: scsi_io_completion: comment on end_request return (Ming Lei) [1638826]
- [scsi] scsi: core: use blk_mq_run_hw_queues in scsi_kick_queue (Ming Lei) [1638826]
- [scsi] scsi: sg: remove bad blk_end_request_all() call (Ming Lei) [1638826]
- [block] blk-mq: complete req in softirq context in case of single queue (Ming Lei) [1638826]
- [block] block, bfq: improve asymmetric scenarios detection (Ming Lei) [1638826]
- [block] block: remove redundant 'default n' from Kconfig-s (Ming Lei) [1638826]
- [block] blk-mq-debugfs: Also show requests that have not yet been started (Ming Lei) [1638826]
- [block] block: Finish renaming REQ_DISCARD into REQ_OP_DISCARD (Ming Lei) [1638826]
- [block] kyber: fix integer overflow of latency targets on 32-bit (Ming Lei) [1638826]
- [block] kyber: add tracepoints (Ming Lei) [1638826]
- [block] kyber: implement improved heuristics (Ming Lei) [1638826]
- [block] kyber: don't make domain token sbitmap larger than necessary (Ming Lei) [1638826]
- [block] block: export blk_stat_enable_accounting() (Ming Lei) [1638826]
- [block] block: move call of scheduler's ->completed_request() hook (Ming Lei) [1638826]
- [block] blk-mq: Enable support for runtime power management (Ming Lei) [1638826]
- [block] block: Make blk_get_request() block for non-PM requests while suspended (Ming Lei) [1638826]
- [block] block: Allow unfreezing of a queue while requests are in progress (Ming Lei) [1638826]
- [lib] percpu-refcount: Introduce percpu_ref_resurrect() (Ming Lei) [1638826]
- [block] block: Schedule runtime resume earlier (Ming Lei) [1638826]
- [block] block: Split blk_pm_add_request() and blk_pm_put_request() (Ming Lei) [1638826]
- [block] block, scsi: Change the preempt-only flag into a counter (Ming Lei) [1638826]
- [block] block: Move power management code into a new source file (Ming Lei) [1638826]
- [block] Blk-throttle: update to use rbtree with leftmost node cached (Ming Lei) [1638826]
- [block] block: use bio_add_page in bio_iov_iter_get_pages (Ming Lei) [1638826]
- [block] blok, bfq: do not plug I/O if all queues are weight-raised (Ming Lei) [1638826]
- [block] block, bfq: inject other-queue I/O into seeky idle queues on NCQ flash (Ming Lei) [1638826]
- [block] block, bfq: correctly charge and reset entity service in all cases (Ming Lei) [1638826]

* Wed Nov 28 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-46.el8]
- [rpmspec] redhat: fix bpf_samples build (Jiri Benc) [1611579]
- [fs] mnt: fix __detach_mounts infinite loop (Benjamin Coddington) [1628736]
- [pci] pcie: Enable Broadom iProc PCIE and mark it is as tech preview (Mark Langsdorf) [1576958]
- [pci] PCI/ACPI: Add iProc PCIe MCFG quirk (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Add ACPI/ECAM support (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Remove PAXC slot check to allow VF support (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Reduce inbound/outbound mapping print level (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Reject unconfigured physical functions from PAXC (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Disable MSI parsing in certain PAXC blocks (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Fix up corrupted PAXC root complex config registers (Mark Langsdorf) [1576958]
- [pci] PCI: iproc: Activate PAXC bridge quirk for more devices (Mark Langsdorf) [1576958]

* Tue Nov 27 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-45.el8]
- [s390] s390/mm: fix mis-accounting of pgtable_bytes (Joe Lawrence) [1644481]
- [mm] mm: add mm_pxd_folded checks to pgtable_bytes accounting functions (Joe Lawrence) [1644481]
- [mm] mm: introduce mm_[p4d|pud|pmd]_folded (Joe Lawrence) [1644481]
- [mm] mm: make the __PAGETABLE_PxD_FOLDED defines non-empty (Joe Lawrence) [1644481]
- [x86] x86/cpu/vmware: Do not trace vmware_sched_clock() (Vitaly Kuznetsov) [1650273]
- [fs] fuse: fix possibly missed wake-up after abort (Lukas Czerner) [1649244]
- [fs] fuse: fix leaked notify reply (Lukas Czerner) [1649244]
- [fs] fuse: fix blocked_waitq wakeup (Lukas Czerner) [1649244]
- [fs] fuse: set FR_SENT while locked (Lukas Czerner) [1649244]
- [fs] fuse: Fix use-after-free in fuse_dev_do_write() (Lukas Czerner) [1649244]
- [fs] fuse: Fix use-after-free in fuse_dev_do_read() (Lukas Czerner) [1649244]
- [fs] fuse: Add missed unlock_page() to fuse_readpages_fill() (Lukas Czerner) [1649244]
- [fs] fuse: Don't access pipe->buffers without pipe_lock() (Lukas Czerner) [1649244]
- [fs] fuse: fix initial parallel dirops (Lukas Czerner) [1649244]
- [fs] fuse: Fix oops at process_init_reply() (Lukas Czerner) [1649244]
- [fs] fuse: umount should wait for all requests (Lukas Czerner) [1649244]
- [fs] fuse: fix unlocked access to processing queue (Lukas Czerner) [1649244]
- [fs] fuse: fix double request_end() (Lukas Czerner) [1649244]
- [fs] fuse: fix use-after-free in fuse_direct_IO() (Lukas Czerner) [1599195]

* Fri Nov 23 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-44.el8]
- [firmware] efi: Fix debugobjects warning on 'efi_rts_work' (Waiman Long) [1652190]
- [rpmspec] kernel.spec: Do not zip modules on noarch builds (Prarit Bhargava) [1646471]
- [iommu] iommu/amd: Clear memory encryption mask from physical address (Gary Hook) [1640384]

* Thu Nov 22 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-43.el8]
- [powerpc] powerpc/mm/radix: Only need the Nest MMU workaround for R -> RW transition (Steve Best) [1651276]
- [powerpc] powerpc/mm/books3s: Add new pte bit to mark pte temporarily invalid (Steve Best) [1651276]
- [powerpc] powerpc/tm: Fix HFSCR bit for no suspend case (Steve Best) [1651275]

* Wed Nov 21 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-42.el8]
- [powerpc] powerpc/powernv: Fix concurrency issue with npu->mmio_atsd_usage (Steve Best) [1651267]
- [tools] perf tools: Remove ext from struct kmod_path (Jiri Olsa) [1581390]
- [tools] perf tools: Add gzip_is_compressed function (Jiri Olsa) [1581390]
- [tools] perf tools: Add lzma_is_compressed function (Jiri Olsa) [1581390]
- [tools] perf tools: Add is_compressed callback to compressions array (Jiri Olsa) [1581390]
- [tools] perf tools: Move the temp file processing into decompress_kmodule (Jiri Olsa) [1581390]
- [tools] perf tools: Use compression id in decompress_kmodule() (Jiri Olsa) [1581390]
- [tools] perf tools: Store compression id into struct dso (Jiri Olsa) [1581390]
- [tools] perf tools: Add compression id into 'struct kmod_path' (Jiri Olsa) [1581390]
- [tools] perf tools: Make is_supported_compression() static (Jiri Olsa) [1581390]
- [tools] perf tools: Make decompress_to_file() function static (Jiri Olsa) [1581390]
- [tools] perf tools: Get rid of dso__needs_decompress() call in __open_dso() (Jiri Olsa) [1581390]
- [tools] perf tools: Get rid of dso__needs_decompress() call in symbol__disassemble() (Jiri Olsa) [1581390]
- [tools] perf tools: Get rid of dso__needs_decompress() call in read_object_code() (Jiri Olsa) [1581390]
- [rpmspec] redhat: Enable kernel-tools (for kvm_stat) on s390x, too (Thomas Huth) [1631222]

* Tue Nov 20 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-41.el8]
- [drm] drm/atomic_helper: Stop modesets on unregistered connectors harder (Lyude Paul) [1631575]
- [drm] drm/nouveau: Fix nv50_mstc->best_encoder() (Lyude Paul) [1631575]
- [drm] drm/atomic_helper: Allow DPMS On<->Off changes for unregistered connectors (Lyude Paul) [1631575]
- [drm] drm/i915: Fix intel_dp_mst_best_encoder() (Lyude Paul) [1631575]
- [drm] drm/i915: Skip vcpi allocation for MSTB ports that are gone (Lyude Paul) [1631575]
- [drm] drm/i915: Don't unset intel_connector->mst_port (Lyude Paul) [1631575]
- [drm] drm/atomic_helper: Disallow new modesets on unregistered connectors (Lyude Paul) [1631575]
- [s390] s390/qeth: fix HiperSockets sniffer (Philipp Rudo) [1649773]
- [s390] s390/qeth: report 25Gbit link speed (Philipp Rudo) [1649772]
- [s390] s390/qeth: sanitize strings in debug messages (Philipp Rudo) [1649770]
- [s390] s390/qeth: fix initial operstate (Philipp Rudo) [1649769]
- [s390] s390/qeth: unregister netdevice only when registered (Philipp Rudo) [1649769]
- [powerpc] powerpc/64s: consolidate MCE counter increment (Steve Best) [1633550]
- [powerpc] powerpc/64s: move machine check SLB flushing to mm/slb.c (Steve Best) [1633550]
- [powerpc] powernv/pseries: consolidate code for mce early handling (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Dump the SLB contents on SLB MCE errors (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Display machine check error details (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Flush SLB contents on SLB MCE errors (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Define MCE error event section (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Avoid using the size greater than RTAS_ERROR_LOG_MAX (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Defer the logging of rtas error to irq work queue (Steve Best) [1633550]
- [powerpc] powerpc/pseries: Fix endianness while restoring of r3 in MCE handler (Steve Best) [1633550]
- [cdrom] cdrom: fix improper type cast, which can leat to information leak (Maurizio Lombardi) [1650476]

* Thu Nov 15 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-40.el8]
- [drm] drm/amdgpu/pm: Fix potential Spectre v1 (Rob Clark) [1637115]
- [drm] drm/i915/kvmgt: Fix potential Spectre v1 (Rob Clark) [1637115]
- [fs] gfs2: Fix metadata read-ahead during truncate (2) (Andreas Grunbacher) [1647982]
- [block] block: make sure writesame bio is aligned with logical block size (Ming Lei) [1648750]
- [block] block: cleanup __blkdev_issue_discard() (Ming Lei) [1648750]
- [block] block: make sure discard bio is aligned with logical block size (Ming Lei) [1648750]
- [block] block: Clear kernel memory before copying to user (Ming Lei) [1648752]
- [block] block: respect virtual boundary mask in bvecs (Ming Lei) [1648756]
- [block] xen: don't include <xen/xen.h> from <asm/io.h> and <asm/dma-mapping.h> (Ming Lei) [1648756]
- [block] block: remove ARCH_BIOVEC_PHYS_MERGEABLE (Ming Lei) [1648756]
- [block] xen: provide a prototype for xen_biovec_phys_mergeable in xen.h (Ming Lei) [1648756]
- [block] xen: remove the xen_biovec_phys_mergeable export (Ming Lei) [1648756]
- [block] arm: remove the unused BIOVEC_MERGEABLE define (Ming Lei) [1648756]
- [block] block: don't include bug.h from bio.h (Ming Lei) [1648756]
- [block] block: don't include io.h from bio.h (Ming Lei) [1648756]
- [block] block: remove bvec_to_phys (Ming Lei) [1648756]
- [block] block: merge BIOVEC_SEG_BOUNDARY into biovec_phys_mergeable (Ming Lei) [1648756]
- [block] block: add a missing BIOVEC_SEG_BOUNDARY check in bio_add_pc_page (Ming Lei) [1648756]
- [block] block: simplify BIOVEC_PHYS_MERGEABLE (Ming Lei) [1648756]
- [block] block: move req_gap_back_merge to blk.h (Ming Lei) [1648756]
- [block] block: move req_gap_{back,front}_merge to blk-merge.c (Ming Lei) [1648756]
- [block] block: move integrity_req_gap_{back,front}_merge to blk.h (Ming Lei) [1648756]
- [fs] gfs2: Fix iomap buffer head reference counting bug (Andreas Grunbacher) [1647073]
- [scsi] qla2xxx: Update driver version to 10.00.00.07.08.0-k1 (Himanshu Madhani) [1615896]
- [scsi] scsi: qla2xxx: Initialize port speed to avoid setting lower speed (Himanshu Madhani) [1615896]
- [scsi] scsi: qla2xxx: Fix incorrect port speed being set for FC adapters (Himanshu Madhani) [1615896]
- [block] block: brd: associate with queue until adding disk (Ming Lei) [1644602]
- [block] block: call rq_qos_exit() after queue is frozen (Ming Lei) [1641558]
- [block] block: fix the DISCARD request merge (Ming Lei) [1646776]
- [block] blk-mq: fallback to previous nr_hw_queues when updating fails (Ming Lei) [1642218]
- [block] blk-mq: realloc hctx when hw queue is mapped to another node (Ming Lei) [1642218]
- [block] blk-mq: change gfp flags to GFP_NOIO in blk_mq_realloc_hw_ctxs (Ming Lei) [1642218]
- [block] blk-mq: adjust debugfs and sysfs register when updating nr_hw_queues (Ming Lei) [1642218]
- [block] block: remove bio_rewind_iter() (Ming Lei) [1642208]

* Wed Nov 14 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-39.el8]
- [fs] jbd2: fix use after free in jbd2_log_do_checkpoint() (Lukas Czerner) [1644694]
- [fs] ext4: initialize retries variable in ext4_da_write_inline_data_begin() (Lukas Czerner) [1644694]
- [fs] ext4: fix build error when DX_DEBUG is defined (Lukas Czerner) [1644694]

* Tue Nov 13 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-38.el8]
- [pinctrl] pinctrl: intel: Add Ice Lake PCH pin controller support (David Arcari) [1483413]
- [netdrv] nfp: flower: fix vlan match by checking both vlan id and vlan pcp (Pablo Cascon) [1645220]
- [netdrv] nfp: flower: reject tunnel encap with ipv6 outer headers for offloading (Pablo Cascon) [1646644]
- [netdrv] nfp: populate bus-info on representors (Pablo Cascon) [1643998]
- [powerpc] KVM: PPC: Validate TCEs against preregistered memory page sizes (David Gibson) [1625821]
- [powerpc] KVM: PPC: Inform the userspace about TCE update failures (David Gibson) [1625821]
- [powerpc] KVM: PPC: Book3S: Fix guest DMA when guest partially backed by THP pages (David Gibson) [1625821]

* Fri Nov 09 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-37.el8]
- [kernel] locking/lockdep: Fix debug_locks off performance problem (Waiman Long) [1647560]
- [kernel] locking/lockdep: Remove duplicated 'lock_class_ops' percpu array (Waiman Long) [1647560]
- [kernel] locking/lockdep: Make class->ops a percpu counter and move it under CONFIG_DEBUG_LOCKDEP=y (Waiman Long) [1647560]
- [kernel] locking/lockdep: Add a faster path in __lock_release() (Waiman Long) [1647560]
- [kernel] locking/lockdep: Eliminate redundant IRQs check in __lock_acquire() (Waiman Long) [1647560]
- [kernel] locking/lockdep: Remove add_chain_cache_classes() (Waiman Long) [1647560]
- [fs] gfs2: Put bitmap buffers in put_super (Andreas Grunbacher) [1647073]
- [scsi] scsi: hpsa: limit transfer length to 1MB, not 512kB (Joseph Szczypek) [1643956]
- [netdrv] nfp: report FW vNIC stats in interface stats (Pablo Cascon) [1645032]
- [rpmspec] spec: Add bpftool debuginfo package (Jiri Olsa) [1633018]
- [crypto] crypto: chelsio: Fix memory corruption in DMA Mapped buffers (Arjun Vynipadath) [1631750]
- [cdrom] cdrom: Fix info leak/OOB read in cdrom_ioctl_drive_status (Maurizio Lombardi) [1627732] {CVE-2018-16658}

* Wed Nov 07 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-36.el8]
- [kernel] srcu: Make early-boot call_srcu() reuse workqueue lists (Waiman Long) [1644375]
- [tools] rcutorture: Test early boot call_srcu() (Waiman Long) [1644375]
- [kernel] srcu: Make call_srcu() available during very early boot (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_state.ofl_lock to raw_spinlock_t (Waiman Long) [1644375]
- [kernel] rcu: Remove obsolete ->dynticks_fqs and ->cond_resched_completed (Waiman Long) [1644375]
- [kernel] rcu: Switch ->dynticks to rcu_data structure, remove rcu_dynticks (Waiman Long) [1644375]
- [kernel] rcu: Switch dyntick nesting counters to rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Switch urgent quiescent-state requests to rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Switch lazy counts to rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Switch last accelerate/advance to rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Switch ->tick_nohz_enabled_snap to rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Merge rcu_dynticks structure into rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Remove unused rcu_dynticks_snap() from Tiny RCU (Waiman Long) [1644375]
- [kernel] rcu: Convert "1UL << x" to "BIT(x)" (Waiman Long) [1644375]
- [kernel] rcu: Avoid resched_cpu() when rescheduling the current CPU (Waiman Long) [1644375]
- [kernel] rcu: More aggressively enlist scheduler aid for nohz_full CPUs (Waiman Long) [1644375]
- [kernel] rcu: Compute jiffies_till_sched_qs from other kernel parameters (Waiman Long) [1644375]
- [kernel] rcu: Provide functions for determining if call_rcu() has been invoked (Waiman Long) [1644375]
- [kernel] rcu: Eliminate ->rcu_qs_ctr from the rcu_dynticks structure (Waiman Long) [1644375]
- [kernel] rcu: Motivate Tiny RCU forward progress (Waiman Long) [1644375]
- [kernel] rcutorture: Dump reader protection sequence if failures or close calls (Waiman Long) [1644375]
- [kernel] rcu: Provide improved interrupt-from-idle check in rcu_check_callbacks() (Waiman Long) [1644375]
- [kernel] rcu: Make need_resched() respond to urgent RCU-QS needs (Waiman Long) [1644375]
- [kernel] rcu: Inline _rcu_barrier() into its sole remaining caller (Waiman Long) [1644375]
- [kernel] rcu: Define rcu_all_qs() only in !PREEMPT builds (Waiman Long) [1644375]
- [kernel] rcu: Remove !PREEMPT code from rcu_note_voluntary_context_switch() (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in update.c (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in tree_plugin.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in tree_exp.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in tree.c (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in tiny.c (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in srcutree.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in rcutorture.c (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in rcu.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in Kconfig (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in rcupdate_wait.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in rculist.h (Waiman Long) [1644375]
- [kernel] rcu: Clean up flavor-related definitions and comments in rcupdate.h (Waiman Long) [1644375]
- [kernel] rcu: Remove now-unused rcutorture APIs (Waiman Long) [1644375]
- [kernel] rcuperf: Remove the "rcu_bh" and "sched" torture types (Waiman Long) [1644375]
- [kernel] rcutorture: Remove the "rcu_bh" and "sched" torture types (Waiman Long) [1644375]
- [kernel] rcu: Stop testing RCU-bh and RCU-sched (Waiman Long) [1644375]
- [kernel] rcutorture: Add RCU-bh and RCU-sched support for extended readers (Waiman Long) [1644375]
- [kernel] rcu: Consolidate RCU-sched update-side function definitions (Waiman Long) [1644375]
- [kernel] rcu: Consolidate RCU-bh update-side function definitions (Waiman Long) [1644375]
- [kernel] rcu: Pull rcu_gp_kthread() FQS loop into separate function (Waiman Long) [1644375]
- [kernel] rcu: Inline increment_cpu_stall_ticks() into its sole caller (Waiman Long) [1644375]
- [kernel] rcu: Fix typo in force_qs_rnp()'s parameter's parameter (Waiman Long) [1644375]
- [kernel] rcu: Eliminate initialization-time use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Eliminate RCU-barrier use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Eliminate quiescent-state and grace-period-nonstart use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Eliminate callback-invocation/invocation use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Eliminate grace-period management code use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Eliminate stall-warning use of rsp (Waiman Long) [1644375]
- [kernel] rcu: Restructure rcu_check_gp_kthread_starvation() (Waiman Long) [1644375]
- [kernel] rcu: Simplify rcutorture_get_gp_data() (Waiman Long) [1644375]
- [kernel] rcu: Remove for_each_rcu_flavor() flavor-traversal macro (Waiman Long) [1644375]
- [kernel] rcu: Remove last non-flavor-traversal rsp local variable from tree_plugin.h (Waiman Long) [1644375]
- [kernel] rcu: Remove rcu_data structure's ->rsp field (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_node tree accessor macros (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from expedited grace-period functions (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from no-CBs CPU functions (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from print_cpu_stall_info() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_spawn_one_boost_kthread() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from dump_blkd_tasks() and friend (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_print_detail_task_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_init_one() and friends (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_boot_init_percpu_data() and friends (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from _rcu_barrier() and friends (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from __rcu_pending() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from __call_rcu() and friend (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from __rcu_process_callbacks() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_check_gp_start_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from force-quiescent-state functions (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_do_batch() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from CPU hotplug functions (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_check_quiescent_state() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_gp_kthread() and friends (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_gp_slow() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from note_gp_changes() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from __note_gp_changes() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_advance_cbs() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_accelerate_cbs_unlocked() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_accelerate_cbs() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_gp_kthread_wake() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_future_gp_cleanup() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from check_cpu_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from print_cpu_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from print_other_cpu_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_stall_kick_kthreads() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_dump_cpu_stacks() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_check_gp_kthread_starvation() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from record_gp_stall_check_time() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_get_root() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_gp_in_progress() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_report_qs_rdp() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_report_unblock_qs_rnp() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_report_qs_rsp() (Waiman Long) [1644375]
- [kernel] rcu: Remove rsp parameter from rcu_report_qs_rnp() (Waiman Long) [1644375]
- [kernel] rcu: Remove rcu_data_p pointer to default rcu_data structure (Waiman Long) [1644375]
- [kernel] rcu: Remove rcu_state_p pointer to default rcu_state structure (Waiman Long) [1644375]
- [kernel] rcu: Remove rcu_state structure's ->rda field (Waiman Long) [1644375]
- [kernel] rcu: Eliminate rcu_state structure's ->call field (Waiman Long) [1644375]
- [kernel] rcu: Remove RCU_STATE_INITIALIZER() (Waiman Long) [1644375]
- [kernel] rcu: Express Tiny RCU updates in terms of RCU rather than RCU-sched (Waiman Long) [1644375]
- [kernel] rcu: Define RCU-sched API in terms of RCU for Tree RCU PREEMPT builds (Waiman Long) [1644375]
- [kernel] rcu: Fix typo in rcu_get_gp_kthreads_prio() header comment (Waiman Long) [1644375]
- [kernel] rcu: Drop "wake" parameter from rcu_report_exp_rdp() (Waiman Long) [1644375]
- [kernel] rcu: Update comments and help text for no more RCU-bh updaters (Waiman Long) [1644375]
- [kernel] rcu: Define RCU-bh update API in terms of RCU (Waiman Long) [1644375]
- [kernel] rcu: Report expedited grace periods at context-switch time (Waiman Long) [1644375]
- [kernel] rcu: Apply RCU-bh QSes to RCU-sched and RCU-preempt when safe (Waiman Long) [1644375]
- [kernel] rcu: Add warning to detect half-interrupts (Waiman Long) [1644375]
- [kernel] rcu: Remove now-unused ->b.exp_need_qs field from the rcu_special union (Waiman Long) [1644375]
- [kernel] rcu: Allow processing deferred QSes for exiting RCU-preempt readers (Waiman Long) [1644375]
- [kernel] rcutorture: Test extended "rcu" read-side critical sections (Waiman Long) [1644375]
- [kernel] rcu: Defer reporting RCU-preempt quiescent states when disabled (Waiman Long) [1644375]
- [kernel] rcu: Refactor rcu_{nmi,irq}_{enter,exit}() (Waiman Long) [1644375]
- [documentation] doc: Fix broken HTML directive (Waiman Long) [1644375]
- [documentation] doc: Update removal of RCU-bh/sched update machinery (Waiman Long) [1644375]
- [kernel] rcutorture: Maintain self-propagating CB only during forward-progress test (Waiman Long) [1644375]
- [kernel] rcutorture: Check GP completion at stutter end (Waiman Long) [1644375]
- [kernel] rcutorture: Print forward-progress test interval on error (Waiman Long) [1644375]
- [kernel] rcutorture: Adjust number of reader kthreads per CPU-hotplug operations (Waiman Long) [1644375]
- [kernel] rcutorture: Reduce priority of forward-progress testing (Waiman Long) [1644375]
- [kernel] rcutorture: Limit reader duration if irq or bh disabled (Waiman Long) [1644375]
- [kernel] rcutorture: Increase rcu_read_delay() longdelay_ms (Waiman Long) [1644375]
- [kernel] rcutorture: Add self-propagating callback to forward-progress testing (Waiman Long) [1644375]
- [kernel] rcutorture: Vary forward-progress test interval (Waiman Long) [1644375]
- [kernel] rcutorture: Avoid no-test complaint if too few forward-progress tries (Waiman Long) [1644375]
- [kernel] rcutorture: Also use GP sequence to judge forward progress (Waiman Long) [1644375]
- [kernel] rcutorture: Add forward-progress tests for RCU grace periods (Waiman Long) [1644375]
- [tools] rcutorture: Remove TREE06 and TREE08 from the default test list (Waiman Long) [1644375]
- [kernel] rcuperf: Warn on bad perf type for built-in tests (Waiman Long) [1644375]
- [kernel] rcutorture: Warn on bad torture type for built-in tests (Waiman Long) [1644375]
- [kernel] rcutorture: Force occasional reader waits (Waiman Long) [1644375]
- [tools] torture: Stop overwriting Make.out file with obsolete version (Waiman Long) [1644375]
- [documentation] doc: Improve rcu_dynticks::dynticks documentation (Waiman Long) [1644375]
- [documentation] doc: Fix broken RCU-requirements link to LKML archive (Waiman Long) [1644375]
- [documentation] doc: Add design documentation on interruption of NMI handlers (Waiman Long) [1644375]
- [kernel] rcutorture: Fix rcu_barrier successes counter (Waiman Long) [1644375]
- [kernel] rcutorture: Add support to detect if boost kthread prio is too low (Waiman Long) [1644375]
- [kernel] rcutorture: Use monotonic timestamp for stall detection (Waiman Long) [1644375]
- [kernel] rcutorture: Make boost test more robust (Waiman Long) [1644375]
- [kernel] rcutorture: Disable RT throttling for boost tests (Waiman Long) [1644375]
- [kernel] rcutorture: Emphasize testing of single reader protection type (Waiman Long) [1644375]
- [kernel] rcutorture: Handle extended read-side critical sections (Waiman Long) [1644375]
- [kernel] rcutorture: Make rcu_torture_timer() use rcu_torture_one_read() (Waiman Long) [1644375]
- [kernel] rcutorture: Use per-CPU random state for rcu_torture_timer() (Waiman Long) [1644375]
- [kernel] rcutorture: Use atomic increment for n_rcu_torture_timers (Waiman Long) [1644375]
- [kernel] rcutorture: Extract common code from rcu_torture_reader() (Waiman Long) [1644375]
- [kernel] rcuperf: Remove unused torturing_tasks() function (Waiman Long) [1644375]
- [kernel] rcu: Remove rcutorture test version and sequence number (Waiman Long) [1644375]
- [kernel] rcutorture: Change units of onoff_interval to jiffies (Waiman Long) [1644375]
- [kernel] rcu: Assign higher prio to RCU threads if rcutorture is built-in (Waiman Long) [1644375]
- [documentation] rculist: Improve documentation for list_for_each_entry_from_rcu() (Waiman Long) [1644375]
- [kernel] srcu: Add grace-period number to rcutorture statistics printout (Waiman Long) [1644375]
- [kernel] rcu: Print stall-warning NMI dyntick state in hexadecimal (Waiman Long) [1644375]
- [maintainers] MAINTAINERS: Update RCU, SRCU, and TORTURE-TEST entries (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_seq_diff() more exact (Waiman Long) [1644375]
- [documentation] doc: Update synchronize_rcu() definition in whatisRCU.txt (Waiman Long) [1644375]
- [kernel] rcu: Check the range of jiffies_till_{first, next}_fqs when setting them (Waiman Long) [1644375]
- [kernel] rcu: Add diagnostics for rcutorture writer stall warning (Waiman Long) [1644375]
- [kernel] rcu: Add comment to the last sleep in the rcu tasks loop (Waiman Long) [1644375]
- [kernel] rcu: Speed up calling of RCU tasks callbacks (Waiman Long) [1644375]
- [kernel] rcu: Add comment documenting how rcu_seq_snap works (Waiman Long) [1644375]
- [kernel] rcu: Use RCU CPU stall timeout for rcu_check_gp_start_stall() (Waiman Long) [1644375]
- [kernel] rcu: Remove __maybe_unused from rcu_cpu_has_callbacks() (Waiman Long) [1644375]
- [kernel] rcu: Remove "inline" from rcu_perf_print_module_parms() (Waiman Long) [1644375]
- [kernel] rcu: Remove "inline" from rcu_torture_print_module_parms() (Waiman Long) [1644375]
- [kernel] rcu: Remove "inline" from panic_on_rcu_stall() and rcu_blocking_is_gp() (Waiman Long) [1644375]
- [kernel] rcu: Remove unused local variable "cpu" (Waiman Long) [1644375]
- [kernel] rcu: Remove unused rcu_kick_nohz_cpu() function (Waiman Long) [1644375]
- [kernel] rcu: Clarify and correct the rcu_preempt_qs() header comment (Waiman Long) [1644375]
- [kernel] rcu: Inline rcu_dynticks_momentary_idle() into its sole caller (Waiman Long) [1644375]
- [kernel] rcu: Mark task as .need_qs less aggressively (Waiman Long) [1644375]
- [kernel] rcu: Improve RCU-tasks naming and comments (Waiman Long) [1644375]
- [kernel] rcu: Use pr_fmt to prefix "rcu: " to logging output (Waiman Long) [1644375]
- [kernel] rcu: rcupdate.h: Get rid of Sphinx warnings at rcu_pointer_handoff() (Waiman Long) [1644375]
- [kernel] rcu: Improve rcu_note_voluntary_context_switch() reporting (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_read_unlock_special() static (Waiman Long) [1644375]
- [kernel] rcu: Add diagnostics for offline CPUs failing to report QS (Waiman Long) [1644375]
- [kernel] rcu: Record ->gp_state for both phases of grace-period initialization (Waiman Long) [1644375]
- [kernel] rcu: Add CPU online/offline state to dump_blkd_tasks() (Waiman Long) [1644375]
- [kernel] rcu: Add up-tree information to dump_blkd_tasks() diagnostics (Waiman Long) [1644375]
- [kernel] rcu: Remove CPU-hotplug failsafe from force-quiescent-state code path (Waiman Long) [1644375]
- [kernel] rcu: Remove failsafe check for lost quiescent state (Waiman Long) [1644375]
- [kernel] rcu: Move grace-period pre-init delay after pre-init (Waiman Long) [1644375]
- [kernel] rcu: Add RCU-preempt check for waiting on newly onlined CPU (Waiman Long) [1644375]
- [kernel] rcu: Fix grace-period hangs due to race with CPU offline (Waiman Long) [1644375]
- [kernel] rcu: Fix grace-period hangs from mid-init task resume (Waiman Long) [1644375]
- [kernel] rcu: Suppress false-positive splats from mid-init task resume (Waiman Long) [1644375]
- [kernel] rcu: Suppress more involved false-positive preempted-task splats (Waiman Long) [1644375]
- [kernel] rcu: Suppress false-positive preempted-task splats (Waiman Long) [1644375]
- [kernel] rcu: Suppress false-positive offline-CPU lockdep-RCU splat (Waiman Long) [1644375]
- [kernel] rcu: Prevent useless FQS scan after all CPUs have checked in (Waiman Long) [1644375]
- [kernel] rcu: Replace smp_wmb() with smp_store_release() for stall check (Waiman Long) [1644375]
- [kernel] rcu: Fix typo and add additional debug (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_report_unblock_qs_rnp() warn on violated preconditions (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_init_new_rnp() stop upon already-set bit (Waiman Long) [1644375]
- [kernel] rcu: Fix an obsolete ->qsmaskinit comment (Waiman Long) [1644375]
- [kernel] rcu: Clean up handling of tasks blocked across full-rcu_node offline (Waiman Long) [1644375]
- [kernel] rcu: Identify grace period is in progress as we advance up the tree (Waiman Long) [1644375]
- [kernel] rcu: Use better variable names in funnel locking loop (Waiman Long) [1644375]
- [kernel] rcu: Rename the grace-period-request variables and parameters (Waiman Long) [1644375]
- [kernel] rcu: Regularize resetting of rcu_data wrap indicator (Waiman Long) [1644375]
- [kernel] rcutorture: Correctly handle grace-period sequence wrap (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_start_this_gp() check for grace period already started (Waiman Long) [1644375]
- [kernel] rcu: Fix cpustart tracepoint gp_seq number (Waiman Long) [1644375]
- [kernel] rcu: Produce last "CleanupMore" trace only if late-breaking request (Waiman Long) [1644375]
- [kernel] rcu: Don't funnel-lock above leaf node if GP in progress (Waiman Long) [1644375]
- [documentation] doc: Update RCU CPU stall-warning documentation (Waiman Long) [1644375]
- [documentation] doc: Update memory-ordering documentation for ->gp-seq (Waiman Long) [1644375]
- [documentation] doc: Update data-structure documentation for ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Make simple callback acceleration refer to rdp->gp_seq_needed (Waiman Long) [1644375]
- [kernel] rcu: Remove ->gpnum and ->completed (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_fqs tracepoint to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_quiescent_state_report tracepoint to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_unlock_preempted_task tracepoint to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_preempt_task tracepoint to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_grace_period_init tracepoint to gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_future_grace_period tracepoint to gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_grace_period tracepoint to gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_nocb_wait_gp() check if GP already requested (Waiman Long) [1644375]
- [kernel] rcu: Move from ->need_future_gp[] to ->gp_seq_needed (Waiman Long) [1644375]
- [kernel] rcutorture: Convert rcutorture_get_gp_data() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Make RCU CPU stall warnings use ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert grace-period requests to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert ->completedqs to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert ->rcu_iw_gpnum to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move rcu_gp_in_progress() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move rcu_nocb_gp_get() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move rcu_try_advance_all_cbs() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move rcu_implicit_dynticks_qs() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_gpnum_ovf() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move RCU's grace-period-change code to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert conditional grace-period primitives to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Make quiescent-state reporting use ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Convert rcu_check_gp_kthread_starvation() to GP sequence number (Waiman Long) [1644375]
- [kernel] rcu: Make rcutorture's batches-completed API use ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Move rcu_gp_slow() to ->gp_seq (Waiman Long) [1644375]
- [kernel] rcu: Introduce grace-period sequence numbers (Waiman Long) [1644375]
- [kernel] rcu: Make rcu_gp_cleanup() write only once to ->gp_flags (Waiman Long) [1644375]
- [kernel] rcu: Diagnostics for grace-period startup hangs (Waiman Long) [1644375]
- [kernel] rcu: Exclude near-simultaneous RCU CPU stall warnings (Waiman Long) [1644375]
- [kernel] rcu: Use the proper lockdep annotation in dump_blkd_tasks() (Waiman Long) [1644375]
- [kernel] rcu: Add debugging info to assertion (Waiman Long) [1644375]
- [kernel] torture: Keep old-school dmesg format (Waiman Long) [1644375]
- [kernel] torture: Make online/offline messages appear only for verbose=2 (Waiman Long) [1644375]
- [tools] rcutorture: Make kvm-find-errors.sh find close calls (Waiman Long) [1644375]
- [tools] rcutorture: Remove obsolete TREE08-T.boot file (Waiman Long) [1644375]
- [tools] torture: Use a single build directory for torture scenarios (Waiman Long) [1644375]
- [kernel] srcu: Introduce srcu_read_{un,}lock_notrace() (Waiman Long) [1644375]
- [kernel] srcu: Add address of first callback to rcutorture output (Waiman Long) [1644375]
- [kernel] srcu: Document that srcu_funnel_gp_start() implies srcu_funnel_exp_start() (Waiman Long) [1644375]
- [kernel] srcu: Fix typos in __call_srcu() header comment (Waiman Long) [1644375]
- [kernel] rcu: Make expedited grace period use direct call on last leaf (Waiman Long) [1644375]

* Tue Nov 06 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-35.el8]
- [netdrv] nfp: flower: use offsets provided by pedit instead of index for ipv6 (Pablo Cascon) [1645132]
- [netdrv] nfp: flower: fix multiple keys per pedit action (Pablo Cascon) [1645132]
- [netdrv] nfp: flower: fix pedit set actions for multiple partial masks (Pablo Cascon) [1645132]
- [netdrv] nfp: flower: ignore checksum actions when performing pedit actions (Pablo Cascon) [1644400]
- [kernel] sched/fair: Fix throttle_list starvation with low CFS quota (Phil Auld) [1638526]
- [net] tipc: fix the big/little endian issue in tipc_dest (Jon Maloy) [1640712]
- [rpmspec] kernel.spec: Include kernel-signing-ca.cer public key (Prarit Bhargava) [1638465]
- [block] block: don't deal with discard limit in blkdev_issue_discard() (Ming Lei) [1631255]
- [powerpc] powerpc/mm: Check memblock_add against MAX_PHYSMEM_BITS range (Gustavo Duarte) [1561402]
- [powerpc] powerpc/mm: Increase MAX_PHYSMEM_BITS to 128TB with SPARSEMEM_VMEMMAP config (Gustavo Duarte) [1561402]

* Tue Nov 06 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-34.el8]
- [s390] s390/crypto: Enhance paes cipher to accept variable length key material (Philipp Rudo) [1644387]
- [s390] s390/pkey: move pckmo subfunction available checks away from module init (Philipp Rudo) [1644387]
- [s390] s390/pkey: Load pkey kernel module automatically (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: fix broken zcrypt_send_cprb in-kernel api function (Philipp Rudo) [1644387]
- [s390] s390/pkey: Introduce new API for transforming key blobs (Philipp Rudo) [1644387]
- [s390] s390/pkey: Introduce new API for random protected key verification (Philipp Rudo) [1644387]
- [s390] s390/pkey: Add sysfs attributes to emit secure key blobs (Philipp Rudo) [1644387]
- [s390] s390/pkey: Add sysfs attributes to emit protected key blobs (Philipp Rudo) [1644387]
- [s390] s390/pkey: Define protected key blob format (Philipp Rudo) [1644387]
- [s390] s390/pkey: Introduce new API for random protected key generation (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: add ap_adapter_mask sysfs attribute (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: provide apfs failure code on type 86 error reply (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: zcrypt device driver cleanup (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: multiple zcrypt device nodes support (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: enable AP bus scan without a valid default domain (Philipp Rudo) [1644387]
- [s390] s390/zcrypt: Use kmemdup to replace kmalloc + memcpy (Philipp Rudo) [1644387]
- [s390] s390/qeth: add TSO support for L2 devices (Philipp Rudo) [1644381]
- [s390] s390/qeth: add support for IPv6 TSO (Philipp Rudo) [1644381]
- [s390] s390/qeth: enhance TSO control sequence (Philipp Rudo) [1644381]
- [s390] s390/qeth: make TSO controls protocol-agnostic (Philipp Rudo) [1644381]
- [s390] s390: qeth: Fix potential array overrun in cmd/rc lookup (Philipp Rudo) [1644381]
- [s390] s390: qeth_core_mpc: Use ARRAY_SIZE instead of reimplementing its function (Philipp Rudo) [1644381]
- [scsi] scsi: mpt3sas: Remove unnecessary parentheses and simplify null checks (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Use dma_pool_zalloc (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Remove unused macro MPT3SAS_FMT (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Convert logging uses with MPT3SAS_FMT without logging levels (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Remove KERN_WARNING from panic uses (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Convert logging uses with MPT3SAS_FMT and reply_q_name to s: (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Convert mlsleading uses of pr_<level> with MPT3SAS_FMT (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Convert uses of pr_<level> with MPT3SAS_FMT to ioc_<level> (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Add ioc_<level> logging macros (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Fix calltrace observed while running IO & reset (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Improve kernel-doc headers (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Split _base_reset_handler(), mpt3sas_scsih_reset_handler() and mpt3sas_ctl_reset_handler() (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Fix a race condition in mpt3sas_base_hard_reset_handler() (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Fix _transport_smp_handler() error path (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Introduce struct mpt3sas_nvme_cmd (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Annotate switch/case fall-through (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Remove set-but-not-used variables (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Fix indentation (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Update driver version "26.100.00.00" (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: As per MPI-spec, use combined reply queue for SAS3.5 controllers when HBA supports more than 16 MSI-x vectors (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Fix, False timeout prints for ioctl and other internal commands during controller reset (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Don't access the structure after decrementing it's instance reference count (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Incorrect command status was set/marked as not used (Tomas Henzl) [1638649]
- [scsi] scsi: mpt3sas: Don't abort I/Os issued to NVMe drives while processing Async Broadcast primitive event (Tomas Henzl) [1638649]
- [netdrv] net/mlx5e: Do not ignore netdevice TX/RX queues number (Alaa Hleihel) [1643103]
- [netdrv] net/mlx5e: Use non-delayed work for update stats (Alaa Hleihel) [1643103]
- [netdrv] net/mlx5e: Initialize all netdev common structures in one place (Alaa Hleihel) [1643103]
- [netdrv] net/mlx5e: Always initialize update stats delayed work (Alaa Hleihel) [1643103]
- [netdrv] net/mlx5e: Gather common netdev init/cleanup functionality in one place (Alaa Hleihel) [1643103]
- [infiniband] RDMA/netdev: Fix netlink support in IPoIB (Alaa Hleihel) [1643103]
- [infiniband] RDMA/netdev: Hoist alloc_netdev_mqs out of the driver (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Consolidate checking of the proposed child interface (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Maintain the child_intfs list from ndo_init/uninit (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Do not remove child devices from within the ndo_uninit (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Get rid of the sysfs_mutex (Alaa Hleihel) [1643103]
- [infiniband] RDMA/netdev: Use priv_destructor for netdev cleanup (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Move init code to ndo_init (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Move all uninit code into ndo_uninit (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Use cancel_delayed_work_sync for neigh-clean task (Alaa Hleihel) [1643103]
- [infiniband] IB/ipoib: Get rid of IPOIB_FLAG_GOING_DOWN (Alaa Hleihel) [1643103]
- [infiniband] RDMA/ipoib: Fix use of sizeof() (Alaa Hleihel) [1643103]
- [netdrv] net/mlx5e: Do not recycle RX pages in interface down flow (Alaa Hleihel) [1643103 1643047]
- [netdrv] net/mlx5e: Replace call to MPWQE free with dealloc in interface down flow (Alaa Hleihel) [1643103 1643047]
- [net] net/xdp: Fix suspicious RCU usage warning (Alaa Hleihel) [1643103 1643047]
- [netdrv] net/mlx5: WQ, fixes for fragmented WQ buffers API (Alaa Hleihel) [1643103 1636183]
- [netdrv] net/mlx4_en: Use minimal rx and tx ring sizes on kdump kernel (Alaa Hleihel) [1643103 1615267]
- [x86] mark coffeelake-s/h 8+2 as supported (David Arcari) [1575461 1575460]
- [x86] x86/spec_ctrl: Synchronize STIBP changes with RHEL IBRS code (Waiman Long) [1643233]
- [x86] x86/speculation: Propagate information about RSB filling mitigation to sysfs (Waiman Long) [1643233]
- [x86] x86/speculation: Enable cross-hyperthread spectre v2 STIBP mitigation (Waiman Long) [1643233]
- [x86] x86/speculation: Apply IBPB more strictly to avoid cross-process data leak (Waiman Long) [1643233]
- [x86] x86/speculation: Add RETPOLINE_AMD support to the inline asm CALL_NOSPEC variant (Waiman Long) [1643233]
- [x86] x86/CPU: Fix unused variable warning when !CONFIG_IA32_EMULATION (Waiman Long) [1643233]
- [x86] x86/pti/64: Remove the SYSCALL64 entry trampoline (Waiman Long) [1643233]
- [x86] x86/entry/64: Use the TSS sp2 slot for SYSCALL/SYSRET scratch space (Waiman Long) [1643233]
- [x86] x86/entry/64: Document idtentry (Waiman Long) [1643233]
- [x86] x86/asm-offsets: Move TSS_sp0 and TSS_sp1 to asm-offsets.c (Waiman Long) [1643233]
- [x86] x86: Add entry trampolines to kcore (Waiman Long) [1643233]
- [kernel] kallsyms, x86: Export addresses of PTI entry trampolines (Waiman Long) [1643233]
- [kernel] kallsyms: Simplify update_iter_mod() (Waiman Long) [1643233]
- [scsi] scsi: csiostor: fix incorrect port capabilities (Arjun Vynipadath) [1628866]
- [scsi] scsi: csiostor: add a check for NULL pointer after kmalloc() (Arjun Vynipadath) [1628866]
- [scsi] scsi: csiostor: update ingress pack and pad boundary value (Arjun Vynipadath) [1628866]

* Wed Oct 31 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-33.el8]
- [netdrv] nfp: flower: use host context count provided by firmware (Pablo Cascon) [1639609]
- [netdrv] nfp: flower: use stats array instead of storing stats per flow (Pablo Cascon) [1639609]
- [netdrv] nfp: flower: use rhashtable for flow caching (Pablo Cascon) [1639609]
- [netdrv] nfp: avoid soft lockups under control message storm (Pablo Cascon) [1639609]
- [kernel] sched: disable autogroups by default (Phil Auld) [1568166]
- [s390] s390/keyboard: sanitize array index in do_kdsk_ioctl (Steve Best) [1637591]
- [char] ipmi:ssif: Add support for multi-part transmit messages > 2 parts (Tony Camuso) [1622053]
- [scsi] scsi: libsas: fix a race condition when smp task timeout (Zhou Wang) [1640426]
- [scsi] scsi: libsas: check the ata device status by ata_dev_enabled() (Zhou Wang) [1640426]
- [scsi] scsi: libsas: always unregister the old device if going to discover new (Zhou Wang) [1640426]
- [scsi] scsi: libsas: dynamically allocate and free ata host (Zhou Wang) [1640426]
- [scsi] scsi: libsas: remove irq save in sas_ata_qc_issue() (Zhou Wang) [1640426]

* Sat Oct 27 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-32.el8]
- [video] fbdev: make FB_BACKLIGHT a tristate (Rob Clark) [1643333 1589158]
- [netdrv] Taint kernel if e1000 is loaded (Neil Horman) [1643617]
- [netdrv] iavf: fix a typo (Stefan Assmann) [1627882]
- [netdrv] i40evf: remove ndo_poll_controller (Stefan Assmann) [1627882]
- [netdrv] intel-ethernet: use correct module license (Stefan Assmann) [1627882]
- [netdrv] iavf: finish renaming files to iavf (Stefan Assmann) [1627882]
- [netdrv] iavf: rename most of i40e strings (Stefan Assmann) [1627882]
- [netdrv] iavf: tracing infrastructure rename (Stefan Assmann) [1627882]
- [netdrv] iavf: replace i40e_debug with iavf version (Stefan Assmann) [1627882]
- [netdrv] iavf: rename i40e_hw to iavf_hw (Stefan Assmann) [1627882]
- [netdrv] iavf: rename I40E_ADMINQ_DESC (Stefan Assmann) [1627882]
- [netdrv] iavf: rename device ID defines (Stefan Assmann) [1627882]
- [netdrv] iavf: remove references to old names (Stefan Assmann) [1627882]
- [netdrv] iavf: move i40evf files to new name (Stefan Assmann) [1627882]
- [netdrv] iavf: rename i40e_status to iavf_status (Stefan Assmann) [1627882]
- [netdrv] iavf: rename functions and structs to new name (Stefan Assmann) [1627882]
- [netdrv] iavf: diet and reformat (Stefan Assmann) [1627882]
- [netdrv] configs: enable CONFIG_IAVF=m (Stefan Assmann) [1627882]
- [netdrv] intel-ethernet: rename i40evf to iavf (Stefan Assmann) [1627882]
- [netdrv] i40e(vf): remove i40e_ethtool_stats.h header file (Stefan Assmann) [1627882]
- [netdrv] i40evf: cancel workqueue sync for adminq when a VF is removed (Stefan Assmann) [1627882]
- [netdrv] i40evf: Don't enable vlan stripping when rx offload is turned on (Stefan Assmann) [1627882]
- [netdrv] i40evf: set IFF_UNICAST_FLT flag for the VF (Stefan Assmann) [1627882]
- [netdrv] i40evf: Validate the number of queues a PF sends (Stefan Assmann) [1627882]
- [netdrv] i40evf: Change a VF mac without reloading the VF driver (Stefan Assmann) [1627882]
- [netdrv] i40evf: update ethtool stats code and use helper functions (Stefan Assmann) [1627882]
- [netdrv] i40e: Add AQ command for rearrange NVM structure (Stefan Assmann) [1627882]
- [netdrv] i40e: Add additional return code to i40e_asq_send_command (Stefan Assmann) [1627882]
- [netdrv] i40e/i40evf: remove redundant functions i40evf_aq_(set/get)_phy_register (Stefan Assmann) [1627882]
- [netdrv] cls_flower: fix error values for commands not supported by drivers (Stefan Assmann) [1627882]
- [init] init/main.c: Enable watchdog_thresh control from kernel line (Prarit Bhargava) [1643161]
- [s390] s390/purgatory: Remove duplicate variable definitions (Philipp Rudo) [1642447]
- [s390] s390/purgatory: Add missing FORCE to Makefile targets (Philipp Rudo) [1642447]
- [s390] s390/purgatory: Fix crash with expoline enabled (Philipp Rudo) [1642447]
- [s390] s390: disable asm code expolines if cc does not support it (Philipp Rudo) [1642447]
- [netdrv] Revert be2net: remove desc field from be_eq_obj (Ivan Vecera) [1639867]

* Tue Oct 23 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-31.el8]
- [rpmspec] redhat: add optional bpf_samples package (Jiri Benc) [1611579]
- [powerpc] powerpc/time: Fix clockevent_decrementer initalisation for PR KVM (Steve Best) [1641615]
- [net] ip: frags: fix crash in ip_do_fragment() (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ipfrag: let ip(6)frag_high_thresh in ns be higher than in init_net (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ipv6: discard IP frag queue on more errors (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ip: fail fast on IP defrag errors (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ip: process in-order fragments efficiently (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ip: add helpers to process in-order fragments faster (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ipv6: defrag: drop non-last frags smaller than min mtu (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ipv4: frags: precedence bug in ip_expire() (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ip: use rb trees for IP frag queue (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] modify skb_rbtree_purge to return the truesize of all purged skbs (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [net] ip: discard IPv4 datagrams with overlapping segments (Sabrina Dubroca) [1616058] {CVE-2018-5391}
- [fs] ovl: fix format of setxattr debug (Miklos Szeredi) [1636875]
- [fs] ovl: fix access beyond unterminated strings (Miklos Szeredi) [1636875]
- [fs] ovl: make symbol 'ovl_aops' static (Miklos Szeredi) [1636875]
- [fs] vfs: swap names of (do,vfs)_clone_file_range() (Miklos Szeredi) [1636875]
- [fs] ovl: fix freeze protection bypass in ovl_clone_file_range() (Miklos Szeredi) [1636875]
- [fs] ovl: fix freeze protection bypass in ovl_write_iter() (Miklos Szeredi) [1636875]
- [fs] ovl: fix memory leak on unlink of indexed file (Miklos Szeredi) [1636875]
- [fs] ovl: fix oopses in ovl_fill_super() failure paths (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_fadvise() (Miklos Szeredi) [1636875]
- [fs] vfs: implement readahead(2) using POSIX_FADV_WILLNEED (Miklos Szeredi) [1636875]
- [fs] vfs: add the fadvise() file operation (Miklos Szeredi) [1636875]
- [fs] Documentation/filesystems: update documentation of file_operations (Miklos Szeredi) [1636875]
- [fs] ovl: fix GPF in swapfile_activate of file from overlayfs over xfs (Miklos Szeredi) [1636875]
- [fs] ovl: respect FIEMAP_FLAG_SYNC flag (Miklos Szeredi) [1636875]
- [fs] ovl: Enable metadata only feature (Miklos Szeredi) [1636875]
- [fs] ovl: Do not do metacopy only for ioctl modifying file attr (Miklos Szeredi) [1636875]
- [fs] ovl: Do not do metadata only copy-up for truncate operation (Miklos Szeredi) [1636875]
- [fs] ovl: add helper to force data copy-up (Miklos Szeredi) [1636875]
- [fs] ovl: Check redirect on index as well (Miklos Szeredi) [1636875]
- [fs] ovl: Set redirect on upper inode when it is linked (Miklos Szeredi) [1636875]
- [fs] ovl: Set redirect on metacopy files upon rename (Miklos Szeredi) [1636875]
- [fs] ovl: Do not set dentry type ORIGIN for broken hardlinks (Miklos Szeredi) [1636875]
- [fs] ovl: Add an inode flag OVL_CONST_INO (Miklos Szeredi) [1636875]
- [fs] ovl: Treat metacopy dentries as type OVL_PATH_MERGE (Miklos Szeredi) [1636875]
- [fs] ovl: Check redirects for metacopy files (Miklos Szeredi) [1636875]
- [fs] ovl: Move some dir related ovl_lookup_single() code in else block (Miklos Szeredi) [1636875]
- [fs] ovl: Do not expose metacopy only dentry from d_real() (Miklos Szeredi) [1636875]
- [fs] ovl: Open file with data except for the case of fsync (Miklos Szeredi) [1636875]
- [fs] ovl: Add helper ovl_inode_realdata() (Miklos Szeredi) [1636875]
- [fs] ovl: Store lower data inode in ovl_inode (Miklos Szeredi) [1636875]
- [fs] ovl: Fix ovl_getattr() to get number of blocks from lower (Miklos Szeredi) [1636875]
- [fs] ovl: Add helper ovl_dentry_lowerdata() to get lower data dentry (Miklos Szeredi) [1636875]
- [fs] ovl: Copy up meta inode data from lowest data inode (Miklos Szeredi) [1636875]
- [fs] ovl: Modify ovl_lookup() and friends to lookup metacopy dentry (Miklos Szeredi) [1636875]
- [fs] ovl: Use out_err instead of out_nomem (Miklos Szeredi) [1636875]
- [fs] ovl: A new xattr OVL_XATTR_METACOPY for file on upper (Miklos Szeredi) [1636875]
- [fs] ovl: Add helper ovl_already_copied_up() (Miklos Szeredi) [1636875]
- [fs] ovl: Copy up only metadata during copy up where it makes sense (Miklos Szeredi) [1636875]
- [fs] ovl: During copy up, first copy up metadata and then data (Miklos Szeredi) [1636875]
- [fs] ovl: Provide a mount option metacopy=on/off for metadata copyup (Miklos Szeredi) [1636875]
- [fs] ovl: Move the copy up helpers to copy_up.c (Miklos Szeredi) [1636875]
- [fs] ovl: Initialize ovl_inode->redirect in ovl_get_inode() (Miklos Szeredi) [1636875]
- [fs] ovl: fix documentation of non-standard behavior (Miklos Szeredi) [1636875]
- [fs] ovl: obsolete "check_copy_up" module option (Miklos Szeredi) [1636875]
- [fs] vfs: remove open_flags from d_real() (Miklos Szeredi) [1636875]
- [fs] Revert "fsnotify: support overlayfs" (Miklos Szeredi) [1636875]
- [fs] Partially revert "locks: fix file locking on overlayfs" (Miklos Szeredi) [1636875]
- [fs] Revert "vfs: do get_write_access() on upper layer of overlayfs" (Miklos Szeredi) [1636875]
- [fs] Revert "vfs: add flags to d_real()" (Miklos Szeredi) [1636875]
- [fs] Revert "vfs: update ovl inode before relatime check" (Miklos Szeredi) [1636875]
- [fs] Revert "ovl: fix relatime for directories" (Miklos Szeredi) [1636875]
- [fs] vfs: fix freeze protection in mnt_want_write_file() for overlayfs (Miklos Szeredi) [1636875]
- [fs] Revert "ovl: don't allow writing ioctl on lower layer" (Miklos Szeredi) [1636875]
- [fs] Revert "ovl: fix may_write_real() for overlayfs directories" (Miklos Szeredi) [1636875]
- [fs] vfs: don't open real (Miklos Szeredi) [1636875]
- [fs] ovl: add reflink/copyfile/dedup support (Miklos Szeredi) [1636875]
- [fs] ovl: add O_DIRECT support (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_fiemap() (Miklos Szeredi) [1636875]
- [fs] ovl: add lsattr/chattr support (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_fallocate() (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_mmap() (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_fsync() (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_write_iter() (Miklos Szeredi) [1636875]
- [fs] ovl: add ovl_read_iter() (Miklos Szeredi) [1636875]
- [fs] ovl: add helper to return real file (Miklos Szeredi) [1636875]
- [fs] ovl: stack file ops (Miklos Szeredi) [1636875]
- [fs] ovl: deal with overlay files in ovl_d_real() (Miklos Szeredi) [1636875]
- [fs] ovl: copy up file size as well (Miklos Szeredi) [1636875]
- [fs] Revert "Revert "ovl: get_write_access() in truncate"" (Miklos Szeredi) [1636875]
- [fs] ovl: copy up inode flags (Miklos Szeredi) [1636875]
- [fs] ovl: copy up times (Miklos Szeredi) [1636875]
- [fs] vfs: export vfs_dedupe_file_range_one() to modules (Miklos Szeredi) [1636875]
- [fs] vfs: export vfs_ioctl() to modules (Miklos Szeredi) [1636875]
- [fs] vfs: make open_with_fake_path() not contribute to nr_files (Miklos Szeredi) [1636875]
- [fs] ovl: fix wrong use of impure dir cache in ovl_iterate() (Miklos Szeredi) [1636875]
- [fs] new helper: open_with_fake_path() (Miklos Szeredi) [1636875]
- [fs] now we can fold open_check_o_direct() into do_dentry_open() (Miklos Szeredi) [1636875]
- [fs] lift fput() on late failures into path_openat() (Miklos Szeredi) [1636875]
- [fs] fold put_filp() into fput() (Miklos Szeredi) [1636875]
- [fs] introduce FMODE_OPENED (Miklos Szeredi) [1636875]
- [fs] ->file_open(): lose cred argument (Miklos Szeredi) [1636875]
- [fs] security_file_open(): lose cred argument (Miklos Szeredi) [1636875]
- [fs] get rid of cred argument of vfs_open() and do_dentry_open() (Miklos Szeredi) [1636875]
- [fs] pass ->f_flags value to alloc_empty_file() (Miklos Szeredi) [1636875]
- [fs] pass creds to get_empty_filp(), make sure dentry_open() passes the right creds (Miklos Szeredi) [1636875]
- [fs] alloc_file(): switch to passing O_... flags instead of FMODE_... mode (Miklos Szeredi) [1636875]
- [fs] make sure do_dentry_open() won't return positive as an error (Miklos Szeredi) [1636875]
- [fs] create_pipe_files(): use fput() if allocation of the second file fails (Miklos Szeredi) [1636875]
- [fs] turn filp_clone_open() into inline wrapper for dentry_open() (Miklos Szeredi) [1636875]
- [fs] fold security_file_free() into file_free() (Miklos Szeredi) [1636875]
- [fs] vfs: dedupe: extract helper for a single dedup (Miklos Szeredi) [1636875]
- [fs] vfs: dedupe: rationalize args (Miklos Szeredi) [1636875]
- [fs] vfs: dedupe: return int (Miklos Szeredi) [1636875]
- [fs] vfs: limit size of dedupe (Miklos Szeredi) [1636875]
- [fs] ovl: set I_CREATING on inode being created (Miklos Szeredi) [1636875]

* Tue Oct 23 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-30.el8]
- [rpmspec] redhat spec: Add new perf tools file (Jiri Olsa) [1579484]
- [tools] perf tools: Fix use of alternatives to find JDIR (Jiri Olsa) [1579484]
- [net] net: sock_diag: Fix spectre v1 gadget in __sock_diag_cmd() (Paolo Abeni) [1637576]
- [thunderbolt] thunderbolt: Add Intel as copyright holder (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Convert rest of the driver files to use SPDX identifier (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Print connected devices (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Make the driver less verbose (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Remove a meaningless NULL pointer check before dma_pool_destroy (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Initialize after IOMMUs (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Do not handle ICM events after domain is stopped (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Add support for runtime PM (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Remove redundant variable 'approved' (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Use correct ICM commands in system suspend (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: No need to take tb->lock in domain suspend/complete (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Do not unnecessarily call ICM get route (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Use 64-bit DMA mask if supported by the platform (Jarod Wilson) [1588929]
- [thunderbolt] thunderbolt: Fix small typo in variable name (Jarod Wilson) [1588929]
- [mm] Revert x86/e820: put !E820_TYPE_RAM regions into memblock.reserved (Baoquan He) [1639450]
- [mm] mm: return zero_resv_unavail optimization (Baoquan He) [1639450]
- [mm] mm: zero remaining unavailable struct pages (Baoquan He) [1639450]
- [mm] mm: skip invalid pages block at a time in zero_resv_unresv() (Baoquan He) [1639450]
- [mm] docs/mm: memblock: update kernel-doc comments (Baoquan He) [1639450]
- [mm] mm/memblock: add a name for memblock flags enumeration (Baoquan He) [1639450]
- [block] blk-wbt: wake up all when we scale up, not down (Ming Lei) [1640035]

* Sat Oct 20 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-29.el8]
- [video] fbdev: make FB_BACKLIGHT a tristate (Rob Clark) [1589158]
- [kernel] EDAC: Raise the maximum number of memory controllers (Aristeu Rozanski) [1634077]
- [netdrv] i40e: disallow changing the number of descriptors when AF_XDP is on (Stefan Assmann) [1630760]
- [netdrv] i40e: clean zero-copy XDP Rx ring on shutdown/reset (Stefan Assmann) [1630760]
- [netdrv] i40e: clean zero-copy XDP Tx ring on shutdown/reset (Stefan Assmann) [1630760]
- [netdrv] i40e: Remove unused msglen parameter from virtchnl functions (Stefan Assmann) [1630760]
- [netdrv] i40e: fix double 'NIC Link is Down' messages (Stefan Assmann) [1630760]
- [netdrv] i40e: add a helper function to validate a VF based on the vf id (Stefan Assmann) [1630760]
- [netdrv] i40e: use declared variables for pf and hw (Stefan Assmann) [1630760]
- [netdrv] i40e: Unset promiscuous settings on VF reset (Stefan Assmann) [1630760]
- [netdrv] i40e: Fix VF's link state notification (Stefan Assmann) [1630760]
- [netdrv] intel-ethernet: use correct module license (Stefan Assmann) [1630760]
- [netdrv] i40e(vf): remove i40e_ethtool_stats.h header file (Stefan Assmann) [1630760]
- [netdrv] i40e: fix possible compiler warning in xsk TX path (Stefan Assmann) [1630760]
- [netdrv] i40e: add AF_XDP zero-copy Tx support (Stefan Assmann) [1630760]
- [netdrv] i40e: move common Tx functions to i40e_txrx_common.h (Stefan Assmann) [1630760]
- [netdrv] xsk: i40e: get rid of useless struct xdp_umem_props (Stefan Assmann) [1630760]
- [netdrv] i40e: add AF_XDP zero-copy Rx support (Stefan Assmann) [1630760]
- [netdrv] i40e: move common Rx functions to i40e_txrx_common.h (Stefan Assmann) [1630760]
- [netdrv] i40e: refactor Rx path for re-use (Stefan Assmann) [1630760]
- [netdrv] i40e: added queue pair disable/enable functions (Stefan Assmann) [1630760]
- [netdrv] i40e: Prevent deleting MAC address from VF when set by PF (Stefan Assmann) [1630760]
- [netdrv] i40e: hold the rtnl lock on clearing interrupt scheme (Stefan Assmann) [1630760]
- [netdrv] i40e: Check and correct speed values for link on open (Stefan Assmann) [1630760]
- [netdrv] i40e: report correct statistics when XDP is enabled (Stefan Assmann) [1630760]
- [netdrv] i40e: static analysis report from community (Stefan Assmann) [1630760]
- [netdrv] i40e: use correct length for strncpy (Stefan Assmann) [1630760]
- [netdrv] i40evf: Change a VF mac without reloading the VF driver (Stefan Assmann) [1630760]
- [netdrv] i40e: move ethtool stats boiler plate code to i40e_ethtool_stats.h (Stefan Assmann) [1630760]
- [netdrv] i40e: convert queue stats to i40e_stats array (Stefan Assmann) [1630760]
- [netdrv] i40e: fix condition of WARN_ONCE for stat strings (Stefan Assmann) [1630760]
- [netdrv] i40e_txrx: mark expected switch fall-through (Stefan Assmann) [1630760]
- [netdrv] i40e_main: mark expected switch fall-through (Stefan Assmann) [1630760]
- [netdrv] i40e: fix i40e_add_queue_stats data pointer update (Stefan Assmann) [1630760]
- [netdrv] i40e: Add AQ command for rearrange NVM structure (Stefan Assmann) [1630760]
- [netdrv] i40e: Add additional return code to i40e_asq_send_command (Stefan Assmann) [1630760]
- [netdrv] i40e: fix warning about shadowed ring parameter (Stefan Assmann) [1630760]
- [netdrv] i40e: remove unnecessary i variable causing -Wshadow warning (Stefan Assmann) [1630760]
- [netdrv] i40e: convert priority flow control stats to use helpers (Stefan Assmann) [1630760]
- [netdrv] i40e: convert VEB TC stats to use an i40e_stats array (Stefan Assmann) [1630760]
- [netdrv] i40e: Set fec_config when forcing link state (Stefan Assmann) [1630760]
- [netdrv] i40e: add helper to copy statistic values into ethtool buffer (Stefan Assmann) [1630760]
- [netdrv] i40e: add helper function for copying strings from stat arrays (Stefan Assmann) [1630760]
- [netdrv] i40e: Remove duplicated prepare call in i40e_shutdown (Stefan Assmann) [1630760]
- [netdrv] cls_flower: fix error values for commands not supported by drivers (Stefan Assmann) [1630760]
- [netdrv] net: drivers/net: Convert random_ether_addr to eth_random_addr (Stefan Assmann) [1630760]
- [net] ipv4: don't let PMTU updates increase route MTU (Sabrina Dubroca) [1638845]
- [net] ipv4: update fnhe_pmtu when first hop's MTU changes (Sabrina Dubroca) [1638845]
- [net] xsk: add a simple buffer reuse queue (Ivan Vecera) [1634774]
- [net] samples/bpf: add -c/--copy -z/--zero-copy flags to xdpsock (Ivan Vecera) [1634774]
- [net] add napi_if_scheduled_mark_missed (Ivan Vecera) [1634774]
- [net] xsk: expose xdp_umem_get_(data, dma) to drivers (Ivan Vecera) [1634774]
- [net] xdp: export xdp_rxq_info_unreg_mem_model (Ivan Vecera) [1634774]
- [net] xdp: implement convert_to_xdp_frame for MEM_TYPE_ZERO_COPY (Ivan Vecera) [1634774]
- [net] xdp: Helper function to clear kernel pointers in xdp_frame (Ivan Vecera) [1634774]
- [net] xsk: i40e: get rid of useless struct xdp_umem_props (Ivan Vecera) [1631809]
- [net] xdp: fix uninitialized 'err' variable (Ivan Vecera) [1631805]
- [tools] headers uapi: Update tools's copy of linux/if_link.h (Ivan Vecera) [1631805]
- [tools] selftests/bpf: add test for multiple programs (Ivan Vecera) [1631805]
- [net] netdevsim: add support for simultaneous driver and hw XDP (Ivan Vecera) [1631805]
- [net] xdp: support simultaneous driver and hw XDP attachment (Ivan Vecera) [1631805]
- [net] xdp: factor out common program/flags handling from drivers (Ivan Vecera) [1631805]
- [net] xdp: don't make drivers report attachment mode (Ivan Vecera) [1631805]
- [net] xdp: add per mode attributes for attached programs (Ivan Vecera) [1631805]
- [net] sched: cls_flower: set correct offload data in fl_reoffload (Ivan Vecera) [1631522]
- [net] sched: call reoffload op on block callback reg (Ivan Vecera) [1631522]
- [net] sched: cls_bpf: implement offload tcf_proto_op (Ivan Vecera) [1631522]
- [net] sched: cls_u32: implement offload tcf_proto_op (Ivan Vecera) [1631522]
- [net] sched: cls_matchall: implement offload tcf_proto_op (Ivan Vecera) [1631522]
- [net] sched: cls_flower: implement offload tcf_proto_op (Ivan Vecera) [1631522]
- [net] sched: add tcf_proto_op to offload a rule (Ivan Vecera) [1631522]
- [net] sched: pass extack pointer to block binds and cb registration (Ivan Vecera) [1631522]

* Fri Oct 19 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-28.el8]
- [rpmspec] kernel.spec: s390/zfcpdump: add -zfcpdump kernel variant (Philipp Rudo) [1567291]
- [kernel] rh_taint: correct loaddable module support dependencies (Philipp Rudo) [1567291]
- [powerpc] KVM: PPC: Book3S HV: Avoid crash from THP collapse during radix page fault (David Gibson) [1639555]
- [irqchip] irqchip/gic-v3-its: Allow use of LPI tables in reserved memory (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Register LPI tables with EFI config table (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Check that all RDs have the same property table (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Use pre-programmed redistributor tables with kdump kernels (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Allow use of pre-programmed LPI tables (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Keep track of property table's PA and VA (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Move pending table allocation to init time (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Split property table clearing from allocation (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Simplify LPI_PENDBASE_SZ usage (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Change initialization ordering for LPIs (Jeremy Linton) [1625746]
- [firmware] efi: add API to reserve memory persistently across kexec reboot (Jeremy Linton) [1625746]
- [firmware] efi/arm: libstub: add a root memreserve config table (Jeremy Linton) [1625746]
- [firmware] efi: honour memory reservations passed via a linux specific config table (Jeremy Linton) [1625746]
- [irqchip] irqchip/gic-v3-its: Cap lpi_id_bits to reduce memory footprint (Jeremy Linton) [1625746]
- [infiniband] RDMA/bnxt_re: Fix system crash during RDMA resource initialization (Selvin Xavier) [1637122]
- [infiniband] RDMA/bnxt_re: Fix couple of memory leaks that could lead to IOMMU call traces (Selvin Xavier) [1637120]
- [arm64] arm64: KVM: Sanitize PSTATE.M when being set from userspace (Wei Huang) [1635721] {CVE-2018-18021}
- [arm64] arm64: KVM: Tighten guest core register access from userspace (Wei Huang) [1635721] {CVE-2018-18021}
- [fs] fs/cifs: require sha512 (Leif Sahlberg) [1610619]
- [fs] smb3: simplify code by removing CONFIG_CIFS_SMB311 (Leif Sahlberg) [1610619]
- [fs] smb3: add support for statfs for smb3.1.1 posix extensions (Leif Sahlberg) [1610619]
- [fs] cifs: allow disabling insecure dialects in the config (Leif Sahlberg) [1610619]
- [fs] smb3: if server does not support posix do not allow posix mount option (Leif Sahlberg) [1610619]

* Tue Oct 16 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-27.el8]
- [security] cap_inode_getsecurity: use d_find_any_alias() instead of d_find_alias() (Joe Lawrence) [1638647]
- [powerpc] powerpc/cacheinfo: Report the correct shared_cpu_map on big-cores (Steve Best) [1639265]
- [powerpc] powerpc: Use cpu_smallcore_sibling_mask at SMT level on bigcores (Steve Best) [1639265]
- [powerpc] powerpc: Detect the presence of big-cores via ibm, thread-groups (Steve Best) [1639265]
- [x86] mark amd rome as unsupported (David Arcari) [1638506]
- [netdrv] qed: Add support for virtual link (Chad Dupuis) [1638013]
- [netdrv] qede: Add driver support for 20G link speed (Chad Dupuis) [1638013]
- [netdrv] qed: Add driver support for 20G link speed (Chad Dupuis) [1638013]
- [netdrv] qed: Fix shmem structure inconsistency between driver and the mfw (Chad Dupuis) [1638013]
- [netdrv] qed: Add missing device config for RoCE EDPM in UFP mode (Chad Dupuis) [1638013]
- [netdrv] qed: Add a flag which indicates if offload TC is set (Chad Dupuis) [1638013]
- [netdrv] qed: Do not add VLAN 0 tag to untagged frames in multi-function mode (Chad Dupuis) [1638013]
- [netdrv] qed: Fix populating the invalid stag value in multi function mode (Chad Dupuis) [1638013]
- [tools] perf python: Fix pyrf_evlist__read_on_cpu() interface (Jiri Olsa) [1628229]
- [tools] perf mmap: Store real cpu number in 'struct perf_mmap' (Jiri Olsa) [1628229]

* Tue Oct 16 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-26.el8]
- [fs] gfs2: Fix iomap buffered write support for journaled files (2) (Andreas Grunbacher) [1637944]
- [xen] xen/manage: don't complain about an empty value in control/sysrq node (Vitaly Kuznetsov) [1623344]
- [drm] drm/amdgpu: Silence harmless WARN_ON() during MST disable (Lyude Paul) [1638137]
- [netdrv] net: macb: Fix regression breaking non-MDIO fixed-link PHYs (Petr Oros) [1638259]
- [netdrv] net: macb: do not disable MDIO bus at open/close time (Petr Oros) [1638259]
- [fs] proc: restrict kernel stack dumps to root (Waiman Long) [1638044]
- [base] firmware: Always initialize the fw_priv list object (Waiman Long) [1638044]
- [base] firmware: Fix security issue with request_firmware_into_buf() (Waiman Long) [1638044]
- [fs] sysfs: Do not return POSIX ACL xattrs via listxattr (Waiman Long) [1638044]
- [fs] vfs: don't evict uninitialized inode (Waiman Long) [1638044]
- [fs] new primitive: discard_new_inode() (Waiman Long) [1638044]
- [arm64] arm64: jump_label.h: use asm_volatile_goto macro instead of "asm goto" (Waiman Long) [1638044]
- [kernel] sched/topology: Set correct NUMA topology type (Waiman Long) [1638044]
- [kernel] bpf: 32-bit RSH verification must truncate input before the ALU op (Waiman Long) [1638044]
- [mm] mm: madvise(MADV_DODUMP): allow hugetlbfs pages (Waiman Long) [1638044]
- [x86] x86/pti: Fix section mismatch warning/error (Waiman Long) [1638044]
- [kernel] uaccess: Fix is_source param for check_copy_size() in copy_to_iter_mcsafe() (Waiman Long) [1638044]
- [x86] x86/mm: Expand static page table for fixmap space (Waiman Long) [1638044]
- [fs] fs/lock: skip lock owner pid translation in case we are in init_pid_ns (Waiman Long) [1638044]
- [x86] perf/x86/intel/lbr: Fix incomplete LBR call stack (Waiman Long) [1638044]
- [kernel] perf/hw_breakpoint: Split attribute parse and commit (Waiman Long) [1638044]
- [kernel] bitfield: fix *_encode_bits() (Waiman Long) [1638044]
- [kernel] posix-timers: Sanitize overrun handling (Waiman Long) [1638044]
- [kernel] posix-timers: Make forward callback return s64 (Waiman Long) [1638044]
- [kernel] alarmtimer: Prevent overflow for relative nanosleep (Waiman Long) [1638044]
- [x86] x86/entry/64: Add two more instruction suffixes (Waiman Long) [1638044]
- [powerpc] powerpc/kdump: Handle crashkernel memory reservation failure (Waiman Long) [1638044]
- [s390] s390/mm: correct allocate_pgste proc_handler callback (Waiman Long) [1638044]
- [x86] x86/numa_emulation: Fix emulated-to-physical node mapping (Waiman Long) [1638044]
- [x86] x86/paravirt: Fix some warning messages (Waiman Long) [1638044]
- [kernel] sched/fair: Fix vruntime_normalized() for remote non-migration wakeup (Waiman Long) [1638044]
- [kernel] bpf/verifier: disallow pointer subtraction (Waiman Long) [1638044]
- [mm] mm: shmem.c: Correctly annotate new inodes for lockdep (Waiman Long) [1638044]
- [kernel] sched/core: Use smp_mb() in wake_woken_function() (Waiman Long) [1638044]
- [kernel] bpf: fix rcu annotations in compute_effective_progs() (Waiman Long) [1638044]
- [x86] x86/mm/pti: Add an overflow check to pti_clone_pmds() (Waiman Long) [1638044]
- [x86] x86/pti: Check the return value of pti_user_pagetable_walk_pmd() (Waiman Long) [1638044]
- [x86] x86/pti: Check the return value of pti_user_pagetable_walk_p4d() (Waiman Long) [1638044]
- [powerpc] powerpc/pseries/mm: call H_BLOCK_REMOVE (Steve Best) [1637116]
- [powerpc] powerpc/pseries/mm: factorize PTE slot computation (Steve Best) [1637116]
- [powerpc] powerpc/pseries/mm: Introducing FW_FEATURE_BLOCK_REMOVE (Steve Best) [1637116]
- [watchdog] watchdog/hpwdt: Disable PreTimeout when Timeout is smaller (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Update Driver Documentation (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Update version number (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Module parameter alias (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Display module parameters (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Claim NMI from iLO (Joseph Szczypek) [1632945]
- [watchdog] watchdog: hpwdt: Initialize pretimeout from module parameter (Joseph Szczypek) [1632945]

* Sat Oct 13 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-25.el8]
- [mm] mm/sparse: delete old sparse_init and enable new one (Baoquan He) [1625105]
- [mm] mm/sparse: add new sparse_init_nid() and sparse_init() (Baoquan He) [1625105]
- [mm] mm/sparse: move buffer init/fini to the common place (Baoquan He) [1625105]
- [mm] mm/sparse: use the new sparse buffer functions in non-vmemmap (Baoquan He) [1625105]
- [mm] mm/sparse: abstract sparse buffer allocations (Baoquan He) [1625105]
- [mm] mm/sparse: optimize memmap allocation during sparse_init() (Baoquan He) [1625105]
- [mm] mm/sparse.c: add a new parameter 'data_unit_size' for alloc_usemap_and_memmap (Baoquan He) [1625105]
- [mm] mm/sparsemem.c: defer the ms->section_mem_map clearing (Baoquan He) [1625105]
- [mm] mm/sparse.c: add a static variable nr_present_sections (Baoquan He) [1625105]
- [mm] mm/sparse.c: make sparse_init_one_section void and remove check (Baoquan He) [1625105]
- [target] scsi: target: iscsi: cxgbit: fix csk leak (Arjun Vynipadath) [1628864]
- [target] scsi: target: iscsi: cxgbit: use pr_debug() instead of pr_info() (Arjun Vynipadath) [1628864]
- [infiniband] iw_cxgb4: only allow 1 flush on user qps (Arjun Vynipadath) [1628865]
- [infiniband] iw_cxgb4: pass window scale in flowc work request (Arjun Vynipadath) [1628865]
- [infiniband] iw_cxgb4: remove duplicate memcpy() in c4iw_create_listen() (Arjun Vynipadath) [1628865]
- [netdrv] mlxsw: spectrum_switchdev: Do not leak RIFs when removing bridge (Petr Oros) [1638268]
- [tty] tty: vt_ioctl: fix potential Spectre v1 (Prarit Bhargava) [1637123]
- [powerpc] powerpc/time: Add set_state_oneshot_stopped decrementer callback (Steve Best) [1638287]
- [powerpc] powerpc/time: Use clockevents_register_device(), fixing an issue with large decrementer (Steve Best) [1638287]
- [hwmon] hwmon: (nct6775) Fix potential Spectre v1 (Dean Nelson) [1637464]
- [vfio] vfio-pci: Disable binding to PFs with SR-IOV enabled (Alex Williamson) [1637871]
- [netdrv] net: hns3: fix page_offset overflow when CONFIG_ARM64_64K_PAGES (Petr Oros) [1638385]
- [netdrv] net: hns: fix skb->truesize underestimation (Petr Oros) [1638385]
- [netdrv] net: hns: fix length and page_offset overflow when CONFIG_ARM64_64K_PAGES (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix get_vector ops in hclgevf_main module (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix warning bug when doing lp selftest (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix for mac pause not disable in pfc mode (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix for mailbox message truncated problem (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix return value error in hns3_reset_notify_down_enet (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix for reset_level default assignment probelm (Petr Oros) [1638385]
- [netdrv] net: hns3: Reset net device with rtnl_lock (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix for phy link issue when using marvell phy driver (Petr Oros) [1638385]
- [netdrv] net: hns3: Fix for command format parsing error in hclge_is_all_function_id_zero (Petr Oros) [1638385]
- [net] xprtrdma: Fix disconnect regression (Don Dutile) [1635418]
- [infiniband] RDMA/uverbs: Fix validity check for modify QP (Don Dutile) [1635418]
- [infiniband] IB/srp: Avoid that sg_reset -d $srp_device triggers an infinite loop (Don Dutile) [1635418]
- [infiniband] ucma: fix a use-after-free in ucma_resolve_ip() (Don Dutile) [1635418]
- [infiniband] RDMA/uverbs: Atomically flush and mark closed the comp event queue (Don Dutile) [1635418]
- [infiniband] RDMA/mlx4: Ensure that maximal send/receive SGE less than supported by HW (Don Dutile) [1635418 1623100]
- [infiniband] RDMA/cma: Protect cma dev list with lock (Don Dutile) [1635418]
- [infiniband] IB/ipoib: Avoid a race condition between start_xmit and cm_rep_handler (Don Dutile) [1635418]
- [infiniband] RDMA/ucma: check fd type in ucma_migrate_id() (Don Dutile) [1635418]
- [infiniband] RDMA/rxe: Set wqe->status correctly if an unexpected response is received (Don Dutile) [1635418]
- [infiniband] IB/IPoIB: Set ah valid flag in multicast send flow (Don Dutile) [1635418]
- [infiniband] RDMA/core: Avoid holding lock while initializing fields on stack (Don Dutile) [1635418]
- [infiniband] IB/rxe: Drop QP0 silently (Don Dutile) [1635418]
- [infiniband] RDMA/umem: Don't hold mmap_sem for too long (Don Dutile) [1635418]
- [infiniband] IB/srpt: Fix srpt_cm_req_recv() error path (2/2) (Don Dutile) [1635418]
- [infiniband] IB/srpt: Fix srpt_cm_req_recv() error path (1/2) (Don Dutile) [1635418]
- [infiniband] RDMA: Fix storage of PortInfo CapabilityMask in the kernel (Don Dutile) [1635418]
- [infiniband] IB/core: type promotion bug in rdma_rw_init_one_mr() (Don Dutile) [1635418]
- [infiniband] RDMA/i40w: Hold read semaphore while looking after VMA (Don Dutile) [1635418]
- [infiniband] vmw_pvrdma: Release netdev when vmxnet3 module is removed (Don Dutile) [1635418]
- [infiniband] ib_srpt: Fix a use-after-free in __srpt_close_all_ch() (Don Dutile) [1635418]
- [infiniband] ib_srpt: Fix a use-after-free in srpt_close_ch() (Don Dutile) [1635418]
- [infiniband] IB/srpt: Support HCAs with more than two ports (Don Dutile) [1635418]
- [infiniband] IB/rxe: don't clear the tx queue on every transfer (Don Dutile) [1635418]
- [infiniband] IB/core: add max_send_sge and max_recv_sge attributes (Don Dutile) [1635418 1623100]
- [infiniband] IB/rxe: support for 802.1q VLAN on the listener (Don Dutile) [1635418]
- [netdrv] cxgb4: impose mandatory VLAN usage when non-zero TAG ID (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: when max_tx_rate is 0 disable tx rate limiting (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: do not return DUPLEX_UNKNOWN when link is down (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: expose stats fetched from firmware via debugfs (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: remove stats fetched from firmware (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: specify IQTYPE in fw_iq_cmd (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: Fix the condition to check if the card is T5 (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: Support ethtool private flags (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: Add support for FW_ETH_TX_PKT_VM_WR (Arjun Vynipadath) [1628863]
- [netdrv] cxgb4: Add flag tc_flower_initialized (Arjun Vynipadath) [1628863]
- [s390] s390/zcrypt: remove VLA usage from the AP bus (Philipp Rudo) [1637865]
- [s390] s390/ap_bus: replace PTR_RET with PTR_ERR_OR_ZERO (Philipp Rudo) [1637865]
- [s390] s390/crypto: fix gcc 8 stringop-truncation warning (Philipp Rudo) [1637865]
- [s390] s390/zcrypt: code beautify (Philipp Rudo) [1637865]
- [s390] s390/zcrypt: add copy_from_user length plausibility checks (Philipp Rudo) [1637865]
- [s390] s390/zcrypt: Show load of cards and queues in sysfs (Philipp Rudo) [1637865]
- [s390] s390/kvm: fix deadlock when killed by oom (Philipp Rudo) [1638264]
- [fs] xfs: fix data corruption w/ unaligned reflink ranges (Brian Foster) [1633476]
- [fs] xfs: fix data corruption w/ unaligned dedupe ranges (Brian Foster) [1633476]
- [fs] xfs: update ctime and remove suid before cloning files (Brian Foster) [1633476]
- [fs] xfs: zero posteof blocks when cloning above eof (Brian Foster) [1633476]
- [fs] xfs: refactor clonerange preparation into a separate helper (Brian Foster) [1633476]
- [netdrv] nfp: avoid buffer leak when FW communication fails (Petr Oros) [1638233]
- [netdrv] nfp: don't fail probe on pci_sriov_set_totalvfs() errors (Petr Oros) [1638233]
- [netdrv] nfp: wait for posted reconfigs when disabling the device (Petr Oros) [1638233]
- [netdrv] liquidio: fix hang when re-binding VF host drv after running DPDK VF driver (Petr Oros) [1638224]
- [netdrv] r8169: set RxConfig after tx/rx is enabled for RTL8169sb/8110sb devices (Petr Oros) [1638210]
- [netdrv] r8169: add support for NCube 8168 network card (Petr Oros) [1638210]
- [netdrv] r8169: don't use MSI-X on RTL8106e (Petr Oros) [1638210]
- [netdrv] r8169: don't use MSI-X on RTL8168g (Petr Oros) [1638210]
- [powerpc] KVM: PPC: Book3S HV: Fix guest r11 corruption with POWER9 TM workarounds (David Gibson) [1637766]
- [drm] drm/amdgpu: Suppress keypresses from ACPI_VIDEO events (Lyude Paul) [1631918]
- [infiniband] IB/hfi1: Remove race conditions in user_sdma send path (Alex Estrin) [1637068]
- [infiniband] IB/hfi1: Eliminate races in the SDMA send error path (Alex Estrin) [1637068]
- [infiniband] IB/hfi1: Fix destroy_qp hang after a link down (Alex Estrin) [1637068]
- [infiniband] IB/hfi1: Fix context recovery when PBC has an UnsupportedVL (Alex Estrin) [1637068]
- [infiniband] IB/hfi1: Invalid user input can result in crash (Alex Estrin) [1637068]
- [infiniband] IB/hfi1: Fix SL array bounds check (Alex Estrin) [1637068]
- [powerpc] powerpc/fadump: re-register firmware-assisted dump if already registered (Steve Best) [1637383]
- [powerpc] powerpc/fadump: cleanup crash memory ranges support (Steve Best) [1637383]
- [powerpc] powerpc/fadump: merge adjacent memory ranges to reduce PT_LOAD segements (Steve Best) [1637383]
- [powerpc] powerpc/fadump: handle crash memory ranges array index overflow (Steve Best) [1637383]
- [scsi] scsi: qedi: Initialize the stats mutex lock (Chad Dupuis) [1637245]
- [fs] gfs2: Fix iomap buffered write support for journaled files (Andreas Grunbacher) [1637944]
- [fs] gfs2: eliminate update_rgrp_lvb_unlinked (Andreas Grunbacher) [1637944]
- [fs] gfs2: Fix gfs2_testbit to use clone bitmaps (Andreas Grunbacher) [1637944]
- [fs] gfs2: Get rid of gfs2_ea_strlen (Andreas Grunbacher) [1637944]
- [fs] GFS2: rgrp free blocks used incorrectly (Andreas Grunbacher) [1637944]
- [fs] gfs2: remove redundant variable 'moved' (Andreas Grunbacher) [1637944]
- [fs] gfs2: use iomap_readpage for blocksize == PAGE_SIZE (Andreas Grunbacher) [1637944]
- [fs] gfs2: Use iomap for stuffed direct I/O reads (Andreas Grunbacher) [1637944]
- [fs] gfs2: fallocate_chunk: Always initialize struct iomap (Andreas Grunbacher) [1637944]
- [fs] gfs2: Remove gfs2_write_(begin,end) (Andreas Grunbacher) [1637944]
- [fs] gfs2: iomap direct I/O support (Andreas Grunbacher) [1637944]
- [fs] gfs2: gfs2_extent_length cleanup (Andreas Grunbacher) [1637944]
- [fs] gfs2: iomap buffered write support (Andreas Grunbacher) [1637944]
- [fs] gfs2: Further iomap cleanups (Andreas Grunbacher) [1637944]
- [fs] fs: gfs2: Adding new return type vm_fault_t (Andreas Grunbacher) [1637944]
- [fs] gfs2: using posix_acl_xattr_size instead of posix_acl_to_xattr (Andreas Grunbacher) [1637944]
- [fs] gfs2: Don't reject a supposedly full bitmap if we have blocks reserved (Andreas Grunbacher) [1637944]
- [fs] gfs2: Eliminate redundant ip->i_rgd (Andreas Grunbacher) [1637944]
- [fs] gfs2: Stop messing with ip->i_rgd in the rlist code (Andreas Grunbacher) [1637944]
- [fs] gfs2: call ktime_get_coarse_real_ts64() directly (Andreas Grunbacher) [1637944]
- [fs] gfs2: Minor clarification to __gfs2_punch_hole (Andreas Grunbacher) [1637944]
- [fs] gfs2: Don't withdraw under a spin lock (Andreas Grunbacher) [1637944]
- [fs] gfs2: eliminate rs_inum and reduce the size of gfs2 inodes (Andreas Grunbacher) [1637944]
- [drm] drm/nouveau/drm/nouveau: Grab runtime PM ref in nv50_mstc_detect() (Lyude Paul) [1628749]
- [drm] drm/nouveau/disp: fix DP disable race (Lyude Paul) [1628749]
- [drm] drm/nouveau/drm/nouveau: Don't forget to cancel hpd_work on suspend/unload (Lyude Paul) [1628749]
- [drm] drm/nouveau/drm/nouveau: Prevent handling ACPI HPD events too early (Lyude Paul) [1628749]
- [drm] drm/nouveau: Reset MST branching unit before enabling (Lyude Paul) [1628749]
- [drm] drm/nouveau: Only write DP_MSTM_CTRL when needed (Lyude Paul) [1628749]
- [drm] drm/nouveau: Remove useless poll_enable() call in drm_load() (Lyude Paul) [1628749]
- [drm] drm/nouveau: Remove useless poll_disable() call in switcheroo_set_state() (Lyude Paul) [1628749]
- [drm] drm/nouveau: Remove useless poll_enable() call in switcheroo_set_state() (Lyude Paul) [1628749]
- [drm] drm/nouveau: Fix deadlocks in nouveau_connector_detect() (Lyude Paul) [1628749]
- [drm] drm/nouveau/drm/nouveau: Use pm_runtime_get_noresume() in connector_detect() (Lyude Paul) [1628749]
- [drm] drm/nouveau/drm/nouveau: Fix deadlock with fb_helper with async RPM requests (Lyude Paul) [1628749]
- [drm] drm/nouveau: Remove duplicate poll_enable() in pmops_runtime_suspend() (Lyude Paul) [1628749]
- [drm] drm/nouveau/drm/nouveau: Fix bogus drm_kms_helper_poll_enable() placement (Lyude Paul) [1628749]
- [md] dm table: require that request-based DM be layered on blk-mq devices (Mike Snitzer) [1637682]
- [md] dm: rename DM_TYPE_MQ_REQUEST_BASED to DM_TYPE_REQUEST_BASED (Mike Snitzer) [1637682]
- [md] dm: remove legacy request-based IO path (Mike Snitzer) [1637682]
- [md] dm linear: fix linear_end_io conditional definition (Mike Snitzer) [1637682]
- [md] dm linear: eliminate linear_end_io call if CONFIG_DM_ZONED disabled (Mike Snitzer) [1637682]
- [md] dm: fix report zone remapping to account for partition offset (Mike Snitzer) [1637682]
- [md] dm cache: destroy migration_cache if cache target registration failed (Mike Snitzer) [1637682]
- [md] dm cache: fix resize crash if user doesn't reload cache table (Mike Snitzer) [1637682]
- [md] dm cache metadata: ignore hints array being too small during resize (Mike Snitzer) [1637682]
- [md] dm raid: remove bogus const from decipher_sync_action() return type (Mike Snitzer) [1637682]
- [md] dm mpath: fix attached_handler_name leak and dangling hw_handler_name pointer (Mike Snitzer) [1637682]
- [md] dm thin metadata: fix __udivdi3 undefined on 32-bit (Mike Snitzer) [1637682]
- [md] dm thin metadata: try to avoid ever aborting transactions (Mike Snitzer) [1637682]
- [md] dm raid: bump target version, update comments and documentation (Mike Snitzer) [1637682]
- [md] dm raid: fix RAID leg rebuild errors (Mike Snitzer) [1637682]
- [md] dm raid: fix rebuild of specific devices by updating superblock (Mike Snitzer) [1637682]
- [md] dm raid: fix stripe adding reshape deadlock (Mike Snitzer) [1637682]
- [md] dm raid: fix reshape race on small devices (Mike Snitzer) [1637682]
- [md] dm: disable CRYPTO_TFM_REQ_MAY_SLEEP to fix a GFP_KERNEL recursion deadlock (Mike Snitzer) [1637682]
- [md] dm verity: fix crash on bufio buffer that was allocated with vmalloc (Mike Snitzer) [1637682]
- [md] dm writecache: fix a crash due to reading past end of dirty_bitmap (Mike Snitzer) [1637682]
- [md] dm crypt: don't decrease device limits (Mike Snitzer) [1637682]
- [md] dm cache metadata: set dirty on all cache blocks after a crash (Mike Snitzer) [1637682]
- [md] dm snapshot: remove stale FIXME in snapshot_map() (Mike Snitzer) [1637682]
- [md] dm snapshot: improve performance by switching out_of_order_list to rbtree (Mike Snitzer) [1637682]
- [md] dm kcopyd: avoid softlockup in run_complete_job (Mike Snitzer) [1637682]
- [md] dm cache metadata: save in-core policy_hint_size to on-disk superblock (Mike Snitzer) [1637682]
- [md] dm thin: stop no_space_timeout worker when switching to write-mode (Mike Snitzer) [1637682]
- [md] dm kcopyd: return void from dm_kcopyd_copy() (Mike Snitzer) [1637682]
- [md] dm thin: include metadata_low_watermark threshold in pool status (Mike Snitzer) [1637682]
- [md] dm writecache: report start_sector in status line (Mike Snitzer) [1637682]
- [md] dm crypt: convert essiv from ahash to shash (Mike Snitzer) [1637682]
- [md] dm crypt: use wake_up_process() instead of a wait queue (Mike Snitzer) [1637682]
- [md] dm integrity: recalculate checksums on creation (Mike Snitzer) [1637682]
- [md] dm integrity: flush journal on suspend when using separate metadata device (Mike Snitzer) [1637682]
- [md] dm integrity: use version 2 for separate metadata (Mike Snitzer) [1637682]
- [md] dm integrity: allow separate metadata device (Mike Snitzer) [1637682]
- [md] dm integrity: add ic->start in get_data_sector() (Mike Snitzer) [1637682]
- [md] dm integrity: report provided data sectors in the status (Mike Snitzer) [1637682]
- [md] dm integrity: implement fair range locks (Mike Snitzer) [1637682]
- [md] dm integrity: decouple common code in dm_integrity_map_continue() (Mike Snitzer) [1637682]
- [md] dm integrity: change 'suspending' variable from bool to int (Mike Snitzer) [1637682]
- [md] dm delay: add flush as a third class of IO (Mike Snitzer) [1637682]
- [md] dm delay: refactor repetitive code (Mike Snitzer) [1637682]
- [md] dm cache: only allow a single io_mode cache feature to be requested (Mike Snitzer) [1637682]
- [md] dm thin: update stale "Status" Documentation (Mike Snitzer) [1637682]
- [pci] PCI: Reprogram bridge prefetch registers on resume (Myron Stowe) [1637155]
- [input] Input: xen-kbdfront - fix multi-touch XenStore node's locations (Benjamin Tissoires) [1637027]
- [input] Input: elantech - enable middle button of touchpad on ThinkPad P72 (Benjamin Tissoires) [1637027]
- [hid] HID: i2c-hid: Use devm to allocate i2c_hid struct (Benjamin Tissoires) [1637027]
- [hid] HID: input: fix leaking custom input node name (Benjamin Tissoires) [1637027]
- [hid] HID: core: fix grouping by application (Benjamin Tissoires) [1637027]
- [hid] HID: multitouch: fix Elan panels with 2 input modes declaration (Benjamin Tissoires) [1637027]
- [input] Input: do not use WARN() in input_alloc_absinfo() (Benjamin Tissoires) [1637027]
- [s390] s390: vfio-ap: setup APCB mask using KVM dedicated function (Cornelia Huck) [1508118]
- [s390] KVM: s390: Tracing APCB changes (Cornelia Huck) [1508118]
- [s390] KVM: s390: fix locking for crypto setting error path (Cornelia Huck) [1508118]
- [s390] s390: doc: detailed specifications for AP virtualization (Cornelia Huck) [1508118]
- [s390] KVM: s390: CPU model support for AP virtualization (Cornelia Huck) [1508118]
- [s390] KVM: s390: device attrs to enable/disable AP interpretation (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: allow guest FORMAT-0 CRYCB on host FORMAT-2 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: allow guest FORMAT-1 CRYCB on host FORMAT-2 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: allow guest FORMAT-0 CRYCB on host FORMAT-1 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: allow CRYCB FORMAT-0 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: allow CRYCB FORMAT-1 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: Allow CRYCB FORMAT-2 (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: Make use of CRYCB FORMAT2 clear (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: Do the CRYCB validation first (Cornelia Huck) [1508118]
- [s390] KVM: s390: Clear Crypto Control Block when using vSIE (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: implement VFIO_DEVICE_RESET ioctl (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: zeroize the AP queues (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: implement VFIO_DEVICE_GET_INFO ioctl (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: implement mediated device open callback (Cornelia Huck) [1508118]
- [s390] KVM: s390: interface to clear CRYCB masks (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: sysfs interface to view matrix mdev matrix (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: sysfs interfaces to configure control domains (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: sysfs interfaces to configure domains (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: sysfs interfaces to configure adapters (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: register matrix device with VFIO mdev framework (Cornelia Huck) [1508118]
- [s390] s390: vfio-ap: base implementation of VFIO AP device driver (Cornelia Huck) [1508118]
- [s390] KVM: s390: refactor crypto initialization (Cornelia Huck) [1508118]
- [s390] KVM: s390: introduce and use KVM_REQ_VSIE_RESTART (Cornelia Huck) [1508118]
- [s390] KVM: s390: vsie: simulate VCPU SIE entry/exit (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: hex string mask improvements for apmask and aqmask (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: AP bus support for alternate driver(s) (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: switch return type to bool for ap_instructions_available() (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: fix ap_instructions_available() returncodes (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: Integrate ap_asm.h into include/asm/ap.h (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: Review inline assembler constraints (Cornelia Huck) [1508118]
- [s390] s390/zcrypt: Add ZAPQ inline function (Cornelia Huck) [1508118]
- [net] ipv6: use rt6_info members when dst is set in rt6_fill_node (Xin Long) [1625864 1625803 1625117]

* Thu Oct 11 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-24.el8]
- [netdrv] amd-xgbe: use dma_mapping_error to check map errors (David Arcari) [1637666]
- [crypto] crypto: qat - Fix KASAN stack-out-of-bounds bug in adf_probe() (Waiman Long) [1629547]
- [powerpc] powerpc: fix csum_ipv6_magic() on little endian platforms (Diego Domingos) [1625579]
- [net] smc: generic netlink family should be __ro_after_init (Philipp Rudo) [1632435]
- [net] net/smc: fix sizeof to int comparison (Philipp Rudo) [1632435]
- [net] net/smc: no urgent data check for listen sockets (Philipp Rudo) [1632435]
- [net] net/smc: enable fallback for connection abort in state INIT (Philipp Rudo) [1632435]
- [net] net/smc: remove duplicate mutex_unlock (Philipp Rudo) [1632435]
- [net] net/smc: fix non-blocking connect problem (Philipp Rudo) [1632435]
- [net] net/smc: send response to test link signal (Philipp Rudo) [1632435]
- [net] net: simplify sock_poll_wait (Philipp Rudo) [1632435]
- [net] net/smc: Simplify ib_post_(send|recv|srq_recv)() calls (Philipp Rudo) [1632435]
- [net] net/smc: Remove a WARN_ON() statement (Philipp Rudo) [1632435]
- [powerpc] KVM: PPC: Book3S HV: Add NO_HASH flag to GET_SMMU_INFO ioctl result (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Add a VM capability to enable nested virtualization (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Add nested shadow page tables to debugfs (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Allow HV module to load without hypervisor mode (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Handle differing endianness for H_ENTER_NESTED (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Sanitise hv_regs on nested guest entry (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Add one-reg interface to virtual PTCR register (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Don't access HFSCR, LPIDR or LPCR when running nested (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Invalidate TLB when nested vcpu moves physical cpu (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Use hypercalls for TLB invalidation when nested (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Implement H_TLB_INVALIDATE hcall (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Introduce rmap to track nested guest mappings (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Handle page fault for a nested guest (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Handle hypercalls correctly when nested (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Use XICS hypercalls when running as a nested hypervisor (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Nested guest entry via hypercall (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Framework and hcall stubs for nested virtualization (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Use kvmppc_unmap_pte() in kvm_unmap_radix() (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Refactor radix page fault handler (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Make kvmppc_mmu_radix_xlate process/partition table agnostic (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Clear partition table entry on vm teardown (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Use ccr field in pt_regs struct embedded in vcpu struct (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Add a debugfs file to dump radix mappings (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Handle hypervisor instruction faults better (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Streamlined guest entry/exit path on P9 for radix guests (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Call kvmppc_handle_exit_hv() with vcore unlocked (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S: Rework TM save/restore code and make it C-callable (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Simplify real-mode interrupt handling (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Extract PMU save/restore operations as C-callable functions (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Move interrupt delivery on guest entry to C code (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S HV: Remove left-over code in XICS-on-XIVE emulation (Suraj Jitindar Singh) [1505999]
- [powerpc] KVM: PPC: Book3S: Simplify external interrupt handling (Suraj Jitindar Singh) [1505999]
- [powerpc] powerpc: Turn off CPU_FTR_P9_TM_HV_ASSIST in non-hypervisor mode (Suraj Jitindar Singh) [1505999]
- [powerpc] powerpc/64s: Remove POWER9 DD1 support (Suraj Jitindar Singh) [1505999]
- [netdrv] net/mlx5: Add Fast teardown support (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Set vlan masks for all offloaded TC rules (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: E-Switch, Fix out of bound access when setting vport rate (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Avoid unbounded peer devices when unpairing TC hairpin rules (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Cache the system image guid (Alaa Hleihel) [1636554]
- [netdrv] mlx5: remove ndo_poll_controller (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Check for SQ and not RQ state when modifying hairpin SQ (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix read from coherent memory (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: don't set CHECKSUM_COMPLETE on SCTP packets (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Set ECN for received packets using CQE indication (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix possible deadlock from lockdep when adding fte to fg (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Check for error in mlx5_attach_interface (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Consider PCI domain in search for next dev (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix not releasing read lock when adding flow rules (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: E-Switch, Fix memory leak when creating switchdev mode FDB tables (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Use u16 for Work Queue buffer strides offset (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Use u16 for Work Queue buffer fragment size (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix debugfs cleanup in the device init/remove flow (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix use-after-free in self-healing flow (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Make function mlx5i_grp_sw_update_stats() static (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: IPoIB, Use priv stats in completion rx flow (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: IPoIB, Add ndo stats support for IPoIB child devices (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: IPoIB, Add ndo stats support for IPoIB netdevices (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: IPoIB, Initialize max_opened_tc in mlx5i_init flow (Alaa Hleihel) [1636554]
- [netdrv] IB/mlx5: Fix leaking stack memory to userspace (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Reorganize the makefile (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: clock.c depends on CONFIG_PTP_1588_CLOCK (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: vxlan.c depends on CONFIG_VXLAN (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Move flow steering declarations into en/fs.h (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add CONFIG_MLX5_EN_ARFS for accelerated flow steering support (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add CONFIG_MLX5_EN_RXNFC for ethtool rx nfc (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Ethtool steering, move ethtool callbacks (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Reduce command polling interval (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Use max_num_eqs for calculation of required MSIX vectors (Alaa Hleihel) [1636554]
- [netdrv] RDMA/mlx5: Fix shift overflow in mlx5_ib_create_wq (Alaa Hleihel) [1636554]
- [netdrv] overflow.h: Add arithmetic shift helper (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Fix uninitialized variable (Alaa Hleihel) [1636554]
- [netdrv] RDMA: Fix return code check in rdma_set_cq_moderation (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, move vxlan logic to core driver (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, add sync lock for add/del vxlan port (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, return values for add/del port (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, rename from mlx5e to mlx5 (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, rename struct mlx5e_vxlan to mlx5_vxlan_port (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, move netdev only logic to en_main.c (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, add direct delete function (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, cleanup an unused member in vxlan work (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, replace ports radix-tree with hash table (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, check maximum number of UDP ports (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Vxlan, reflect 4789 UDP port default addition to software database (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Move XDP related code into new XDP files (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Restrict the combination of large MTU and XDP (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Gather all XDP pre-requisite checks in a single function (Alaa Hleihel) [1636554]
- [netdrv] IB/mlx5: avoid excessive warning msgs when creating VFs on 2nd port (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Use PARTIAL_GSO for UDP segmentation (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Remove redundant WARN when we cannot find neigh entry (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Fix tristate and description for MLX5 module (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Better return types for CQE API (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Use ERR_CAST() instead of coding it (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Add missing SET_DRIVER_VERSION command translation (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: fix uaccess beyond "count" in debugfs read/write handlers (Alaa Hleihel) [1636554]
- [netdrv] IB/mlx5: Honor cnt_set_id_valid flag instead of set_id (Alaa Hleihel) [1636554]
- [infiniband] IB/mlx5: fix uaccess beyond "count" in debugfs read/write handlers (Alaa Hleihel) [1636554]
- [infiniband] IB/mlx5: Fix GRE flow specification (Alaa Hleihel) [1636554]
- [infiniband] IB/mlx5: Remove set-but-not-used variables (Alaa Hleihel) [1636554]
- [infiniband] RDMA/mlx5: Don't leak UARs in case of free fails (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Update NIC HW stats on demand only (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add counter for total num of NOP operations (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add counter for MPWQE filler strides (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add channel events counter (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add a counter for congested UMRs (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add NAPI statistics (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add XDP_TX completions statistics (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add TX completions statistics (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: RX, Use existing WQ local variable (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Convert large order kzalloc allocations to kvzalloc (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add UDP GSO remaining counter (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5e: Add UDP GSO support (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Rate limit errors in command interface (Alaa Hleihel) [1636554]
- [netdrv] net/mlx5: Prevent warns in dmesg upon firmware commands (Alaa Hleihel) [1636554]
- [netdrv] mlx4: remove ndo_poll_controller (Alaa Hleihel) [1636553]
- [netdrv] net/mlx4: Use cpumask_available for eq->affinity_mask (Alaa Hleihel) [1636553]
- [netdrv] net/mlx4/en_rx: Mark expected switch fall-throughs (Alaa Hleihel) [1636553]
- [netdrv] net/mlx4/mcg: Mark expected switch fall-throughs (Alaa Hleihel) [1636553]
- [infiniband] IB/mlx4: Use 4K pages for kernel QP's WQE buffer (Alaa Hleihel) [1636553]
- [netdrv] net/mlx4_core: Allow MTTs starting at any index (Alaa Hleihel) [1636553]
- [infiniband] IB/mlx4: Test port number before querying type (Alaa Hleihel) [1636553]
- [powerpc] powerpc/numa: Skip onlining a offline node in kdump path (Steve Best) [1637118]
- [netdrv] net: aquantia: Make function aq_fw1x_set_power() static (David Arcari) [1636533]
- [netdrv] net: aquantia: memory corruption on jumbo frames (David Arcari) [1636533 1630377]
- [netdrv] net: aquantia: bump driver version (David Arcari) [1636533]
- [netdrv] net: aquantia: renaming for better visibility (David Arcari) [1636533]
- [netdrv] net: aquantia: whitespace changes (David Arcari) [1636533]
- [netdrv] net: aquantia: implement EEE support (David Arcari) [1636533]
- [netdrv] net: aquantia: implement WOL support (David Arcari) [1636533]
- [netdrv] net: aquantia: definitions for WOL (David Arcari) [1636533]
- [netdrv] net: aquantia: fix hw_atl_utils_fw_upload_dwords (David Arcari) [1636533]
- [netdrv] net: aquantia: Make some functions static (David Arcari) [1636533]
- [netdrv] net: aquantia: bump driver version (David Arcari) [1636533]
- [netdrv] net: aquantia: Add renegotiate ethtool operation support (David Arcari) [1636533]
- [netdrv] net: aquantia: Implement rx/tx flow control ethtools callback (David Arcari) [1636533]
- [netdrv] net: aquantia: Improve adapter init/deinit logic (David Arcari) [1636533]
- [netdrv] net: aquantia: Ethtool based ring size configuration (David Arcari) [1636533]
- [wireless] ath10k: fix memory leak of tpc_stats (Petr Oros) [1637528]
- [wireless] ath10k: snoc: use correct bus-specific pointer in RX retry (Petr Oros) [1637528]
- [wireless] ath10k: fix incorrect size of dma_free_coherent in ath10k_ce_alloc_src_ring_64 (Petr Oros) [1637528]
- [wireless] brcmsmac: fix wrap around in conversion from constant to s16 (Petr Oros) [1637528]
- [wireless] mt76x2: fix mrr idx/count estimation in mt76x2_mac_fill_tx_status() (Petr Oros) [1637528]
- [wireless] ath10k: transmit queued frames after processing rx packets (Petr Oros) [1637528]
- [wireless] ath10k: protect ath10k_htt_rx_ring_free with rx_ring.lock (Petr Oros) [1637528]
- [wireless] ath10k: use locked skb_dequeue for rx completions (Petr Oros) [1637528]
- [wireless] ath10k: sdio: set skb len for all rx packets (Petr Oros) [1637528]
- [wireless] ath10k: sdio: use same endpoint id for all packets in a bundle (Petr Oros) [1637528]
- [wireless] iwlwifi: cancel the injective function between hw pointers to tfd entry index (Petr Oros) [1637528]
- [wireless] ath10k: disable bundle mgmt tx completion event support (Petr Oros) [1637528]
- [wireless] ath10k: prevent active scans on potential unusable channels (Petr Oros) [1637528]
- [wireless] ath9k_hw: fix channel maximum power level test (Petr Oros) [1637528]
- [wireless] ath9k: report tx status on EOSP (Petr Oros) [1637528]
- [wireless] iwlwifi: pcie: don't access periphery registers when not available (Petr Oros) [1637528]
- [wireless] brcmfmac: fix brcmf_wiphy_wowl_params() NULL pointer dereference (Petr Oros) [1637528]
- [netdrv] be2net: don't flip hw_features when VXLANs are added/deleted (Petr Oros) [1637133]
- [netdrv] be2net: Fix memory leak in be_cmd_get_profile_config() (Petr Oros) [1637133]
- [netdrv] be2net: Mark expected switch fall-through (Petr Oros) [1637133]
- [netdrv] be2net: fix spelling mistake "seqence" -> "sequence" (Petr Oros) [1637133]
- [netdrv] be2net: Update the driver version to 12.0.0.0 (Petr Oros) [1637133]
- [netdrv] be2net: gather debug info and reset adapter (only for Lancer) on a tx-timeout (Petr Oros) [1637133]
- [netdrv] be2net: move rss_flags field in rss_info to ensure proper alignment (Petr Oros) [1637133]
- [netdrv] be2net: re-order fields in be_error_recovert to avoid hole (Petr Oros) [1637133]
- [netdrv] be2net: remove unused tx_jiffies field from be_tx_stats (Petr Oros) [1637133]
- [netdrv] be2net: move txcp field in be_tx_obj to eliminate holes in the struct (Petr Oros) [1637133]
- [netdrv] be2net: reorder fields in be_eq_obj structure (Petr Oros) [1637133]
- [netdrv] be2net: remove desc field from be_eq_obj (Petr Oros) [1637133]
- [netdrv] be2net: remove unused old custom busy-poll fields (Petr Oros) [1637133]
- [netdrv] be2net: remove unused old AIC info (Petr Oros) [1637133]
- [x86] x86/spec_ctrl/compat: Call IBRS_ENTRY only after valid kernel stack (Waiman Long) [1636843]
- [acpi] ACPI/PPTT: Handle architecturally unknown cache types (Jeremy Linton) [1636567]
- [base] drivers: base: cacheinfo: Do not populate sysfs for unknown cache types (Jeremy Linton) [1636567]
- [fs] getxattr: use correct xattr length (Lukas Czerner) [1637049]
- [x86] Mark Intel Cascade Lake supported (Steve Best) [1636651]
- [x86] x86/boot: Fix kexec booting failure in the SEV bit detection code (Kairui Song) [1632514]
- [scsi] scsi: megaraid_sas: driver version upgrade (Tomas Henzl) [1635565]
- [scsi] scsi: megaraid_sas: Support FW provided TM timeout values (Tomas Henzl) [1635565]
- [scsi] scsi: megaraid_sas: Return immediately from wait_for_adapter_operational after kill adapter (Tomas Henzl) [1635565]
- [scsi] scsi: megaraid_sas: Update controller info during resume (Tomas Henzl) [1635565]
- [scsi] scsi: megaraid_sas: Do not do Kill adapter if GET_CTRL_INFO times out (Tomas Henzl) [1635565]
- [scsi] qla2xxx: Update driver version to 10.00.00.07.08.0-k (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Check for Register disconnect (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix driver hang when FC-NVMe LUNs are configured (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix re-using LoopID when handle is in use (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix duplicate switch database entries (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix NVMe session hang on unload (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix iIDMA error (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix stalled relogin (Himanshu Madhani) [1633373]
- [scsi] scsi: qla2xxx: Fix unintended Logout (Himanshu Madhani) [1633373]
- [powerpc] powerpc/pseries: Disable CPU hotplug across migrations (Steve Best) [1633587]
- [block] blk-mq: I/O and timer unplugs are inverted in blktrace (Ming Lei) [1634330]
- [block] block: fix deadline elevator drain for zoned block devices (Ming Lei) [1634333]
- [block] blk-mq: Allow blocking queue tag iter callbacks (Ming Lei) [1634328]
- [block] block: use nanosecond resolution for iostat (Ming Lei) [1634329]
- [block] null_blk: fix zoned support for non-rq based operation (Ming Lei) [1634324]
- [block] blk-cgroup: increase number of supported policies (Ming Lei) [1634335]
- [block] block: bfq: swap puts in bfqg_and_blkg_put (Ming Lei) [1634334]
- [block] block: don't warn when doing fsync on read-only devices (Ming Lei) [1634331]
- [block] blkcg: use tryget logic when associating a blkg with a bio (Ming Lei) [1634332]
- [block] blkcg: delay blkg destruction until after writeback has (Ming Lei) [1634332]
- [block] Revert "blk-throttle: fix race between (Ming Lei) [1634332]
- [block] blk-wbt: remove dead code (Ming Lei) [1634326]
- [block] blk-wbt: improve waking of tasks (Ming Lei) [1634326]
- [block] blk-wbt: abstract out end IO completion handler (Ming Lei) [1634326]

* Tue Oct 09 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-23.el8]
- [dma] driver/dma/ioat: Call del_timer_sync() without holding prep_lock (Waiman Long) [1607654]
- [netdrv] bnxt_en: Fix VF mac address regression (Jonathan Toppins) [1635846]
- [netdrv] bnxt_en: Do not adjust max_cp_rings by the ones used by RDMA (Jonathan Toppins) [1635846]
- [netdrv] bnxt_en: Clean up unused functions (Jonathan Toppins) [1635846]
- [fs] fsnotify: fix ignore mask logic in fsnotify() (Lukas Czerner) [1635537]
- [net] net/af_iucv: locate IUCV header via skb_network_header() (Philipp Rudo) [1635332]
- [net] net/af_iucv: drop inbound packets with invalid flags (Philipp Rudo) [1635332]
- [net] net/af_iucv: fix skb handling on HiperTransport xmit error (Philipp Rudo) [1635332]
- [hid] HID: i2c-hid: Fix flooded incomplete report after S3 on Rayd touchscreen (David Arcari) [1635746]
- [i2c] i2c: core: ACPI: Make acpi_gsb_i2c_read_bytes() check i2c_transfer return value (David Arcari) [1635746]
- [i2c] i2c: designware: Re-init controllers with pm_disabled set on resume (David Arcari) [1635746]
- [i2c] i2c: core: ACPI: Properly set status byte to 0 for multi-byte writes (David Arcari) [1635746]
- [fs] fs/quota: Fix spectre gadget in do_quotactl (Lukas Czerner) [1635521]
- [fs] xfs: fix error handling in xfs_bmap_extents_to_btree (Brian Foster) [1633171]
- [fs] xfs: remove invalid log recovery first/last cycle check (Brian Foster) [1633171]
- [fs] xfs: validate inode di_forkoff (Brian Foster) [1633171]
- [fs] xfs: skip delalloc COW blocks in xfs_reflink_end_cow (Brian Foster) [1633171]
- [fs] xfs: don't treat unknown di_flags2 as corruption in scrub (Brian Foster) [1633171]
- [fs] xfs: remove duplicated include from alloc.c (Brian Foster) [1633171]
- [fs] xfs: don't bring in extents in xfs_bmap_punch_delalloc_range (Brian Foster) [1633171]
- [fs] xfs: fix transaction leak in xfs_reflink_allocate_cow() (Brian Foster) [1633171]
- [fs] xfs: avoid lockdep false positives in xfs_trans_alloc (Brian Foster) [1633171]
- [fs] xfs: refactor xfs_buf_log_item reference count handling (Brian Foster) [1633171]
- [fs] xfs: clean up xfs_trans_brelse() (Brian Foster) [1633171]
- [fs] xfs: don't unlock invalidated buf on aborted tx commit (Brian Foster) [1633171]
- [fs] xfs: remove last of unnecessary xfs_defer_cancel() callers (Brian Foster) [1633171]
- [fs] xfs: don't crash the vfs on a garbage inline symlink (Brian Foster) [1633171]
- [fs] iomap: set page dirty after partial delalloc on mkwrite (Brian Foster) [1633171]
- [fs] xfs: sanity check ag header values in xrep_calc_ag_resblks (Brian Foster) [1633171]
- [fs] xfs: recalculate summary counters at mount time if icount is bad (Brian Foster) [1633171]
- [fs] xfs: fix a null pointer dereference in xfs_bmap_extents_to_btree (Brian Foster) [1633171]
- [fs] xfs: remove b_last_holder & associated macros (Brian Foster) [1633171]
- [fs] xfs: repair the AGI (Brian Foster) [1633171]
- [fs] xfs: repair the AGFL (Brian Foster) [1633171]
- [fs] xfs: repair the AGF (Brian Foster) [1633171]
- [fs] xfs: remove dead error handling code in xfs_dquot_disk_alloc() (Brian Foster) [1633171]
- [fs] xfs: use WRITE_ONCE to update if_seq (Brian Foster) [1633171]
- [fs] xfs: fix a comment in xfs_log_reserve (Brian Foster) [1633171]
- [fs] xfs: only validate summary counts on primary superblock (Brian Foster) [1633171]
- [fs] xfs: substitute spaces with tabs (Brian Foster) [1633171]
- [fs] xfs: fold dfops into the transaction (Brian Foster) [1633171]
- [fs] xfs: always defer agfl block frees (Brian Foster) [1633171]
- [fs] xfs: pass transaction to xfs_defer_add() (Brian Foster) [1633171]
- [fs] xfs: replace xfs_defer_ops ->dop_pending with on-stack list (Brian Foster) [1633171]
- [fs] xfs: cancel dfops on xfs_defer_finish() error (Brian Foster) [1633171]
- [fs] xfs: clean out superfluous dfops dop params/vars (Brian Foster) [1633171]
- [fs] xfs: drop dop param from xfs_defer_op_type ->finish_item() callback (Brian Foster) [1633171]
- [fs] xfs: automatic dfops inode relogging (Brian Foster) [1633171]
- [fs] xfs: automatic dfops buffer relogging (Brian Foster) [1633171]
- [fs] xfs: add missing defer ijoins for held inodes (Brian Foster) [1633171]
- [fs] xfs: replace dop_low with transaction flag (Brian Foster) [1633171]
- [fs] xfs: pass transaction to dfops reset/move helpers (Brian Foster) [1633171]
- [fs] xfs: remove unused __xfs_defer_cancel() internal helper (Brian Foster) [1633171]
- [fs] xfs: use transaction for intent recovery instead of raw dfops (Brian Foster) [1633171]
- [fs] xfs: refactor internal dfops initialization (Brian Foster) [1633171]
- [fs] xfs: check da node magic in _node_lookup_int (Brian Foster) [1633171]
- [fs] xfs: use a local variable for magic number in xfs_da3_node_lookup_int (Brian Foster) [1633171]
- [fs] xfs: refactor log recovery check (Brian Foster) [1633171]
- [fs] xfs: move extent busy tree initialization to xfs_initialize_perag (Brian Foster) [1633171]
- [fs] xfs: avoid COW fork extent lookups in writeback if the fork didn't change (Brian Foster) [1633171]
- [fs] xfs: maintain a sequence count for inode fork manipulations (Brian Foster) [1633171]
- [fs] xfs: check for unknown v5 feature bits in superblock write verifier (Brian Foster) [1633171]
- [fs] xfs: verify icount in superblock write (Brian Foster) [1633171]
- [fs] libxfs: add more bounds checking to sb sanity checks (Brian Foster) [1633171]
- [fs] xfs: refactor superblock verifiers (Brian Foster) [1633171]
- [fs] xfs: refactor the xrep_extent_list into xfs_bitmap (Brian Foster) [1633171]
- [fs] xfs: introduce a new xfs_inode_has_cow_data helper (Brian Foster) [1633171]
- [fs] xfs: remove the xfs_ifork_t typedef (Brian Foster) [1633171]
- [fs] xfs: simplify xfs_idata_realloc (Brian Foster) [1633171]
- [fs] xfs: remove if_real_bytes (Brian Foster) [1633171]
- [fs] xfs: move the repair extent list into its own file (Brian Foster) [1633171]
- [fs] xfs: pass transaction lock while setting up agresv on cyclic metadata (Brian Foster) [1633171]
- [fs] xfs: remove deprecated barrier/nobarrier mount (Brian Foster) [1633171]
- [fs] xfs: clean up IRELE/iput callsites (Brian Foster) [1633171]
- [fs] xfs: kill IHOLD (Brian Foster) [1633171]
- [fs] xfs: bypass final dfops roll in trans commit path (Brian Foster) [1633171]
- [fs] xfs: drop unnecessary xfs_defer_finish() dfops parameter (Brian Foster) [1633171]
- [fs] xfs: remove unnecessary dfops init calls in xattr code (Brian Foster) [1633171]
- [fs] xfs: remove all boilerplate defer init/finish code (Brian Foster) [1633171]
- [fs] xfs: use internal dfops during (b|c)ui recovery (Brian Foster) [1633171]
- [fs] xfs: use internal dfops in attr code (Brian Foster) [1633171]
- [fs] xfs: use internal dfops in cow blocks cancel (Brian Foster) [1633171]
- [fs] xfs: support embedded dfops in transaction (Brian Foster) [1633171]
- [fs] xfs: pack holes in xfs_defer_ops and xfs_trans (Brian Foster) [1633171]
- [fs] xfs: reset dfops to initial state after finish (Brian Foster) [1633171]
- [fs] xfs: remove unused deferred ops committed field (Brian Foster) [1633171]
- [fs] xfs: make deferred processing safe for embedded dfops (Brian Foster) [1633171]
- [fs] xfs: fix transaction leak on remote attr set/remove failure (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops in log recovery intent processing (Brian Foster) [1633171]
- [fs] xfs: pull up dfops from xfs_itruncate_extents() (Brian Foster) [1633171]
- [fs] xfs: force summary counter recalc at next mount (Brian Foster) [1633171]
- [fs] xfs: refactor unmount record write (Brian Foster) [1633171]
- [fs] xfs: detect and fix bad summary counts at mount (Brian Foster) [1633171]
- [fs] xfs: fix indentation and other whitespace problems in scrub/repair (Brian Foster) [1633171]
- [fs] xfs: shorten struct xfs_scrub_context to struct xfs_scrub (Brian Foster) [1633171]
- [fs] xfs: shorten xfs_repair_ prefix to xrep_ (Brian Foster) [1633171]
- [fs] xfs: shorten xfs_scrub_ prefix (Brian Foster) [1633171]
- [fs] xfs: clean up xfs_btree_del_cursor callers (Brian Foster) [1633171]
- [fs] xfs: trivial xfs_btree_del_cursor cleanups (Brian Foster) [1633171]
- [fs] xfs: return from _defer_finish with a clean transaction (Brian Foster) [1633171]
- [fs] xfs: check leaf attribute block freemap in verifier (Brian Foster) [1633171]
- [fs] libxfs: Fix a couple of sparse complaintis (Brian Foster) [1633171]
- [fs] xfs: use swap macro in xfs_dir2_leafn_rebalance (Brian Foster) [1633171]
- [fs] xfs_bmap_util: use swap macro (Brian Foster) [1633171]
- [fs] xfs_attr_leaf: use swap macro in xfs_attr3_leaf_rebalance (Brian Foster) [1633171]
- [fs] xfs: don't assume a left rmap when allocating a new rmap (Brian Foster) [1633171]
- [fs] xfs: kill __xfs_buf_submit_common() (Brian Foster) [1633171]
- [fs] xfs: combine (a)sync buffer submission apis (Brian Foster) [1633171]
- [fs] xfs: use sync buffer I/O for sync delwri queue submission (Brian Foster) [1633171]
- [fs] xfs: refactor buffer submission into a common helper (Brian Foster) [1633171]
- [fs] xfs: remove xfs_defer_init() firstblock param (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in inode inactivate (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in extent swap (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in reflink cow block cancel (Brian Foster) [1633171]
- [fs] xfs: replace no-op firstblock init with ->t_firstblock (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in dq alloc (Brian Foster) [1633171]
- [fs] xfs: remove xfs_alloc_arg firstblock field (Brian Foster) [1633171]
- [fs] xfs: remove xfs_btree_cur private firstblock field (Brian Foster) [1633171]
- [fs] xfs: remove bmap format helpers firstblock params (Brian Foster) [1633171]
- [fs] xfs: remove bmap extent add helper firstblock params (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bmalloca firstblock field (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in bmap extent split (Brian Foster) [1633171]
- [fs] xfs: remove bmap insert/collapse firstblock param (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bunmapi() firstblock param (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bmapi_write() firstblock param (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in insert/collapse range (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in xfs_bmapi_remap() (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock for all xfs_bunmapi() callers (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock for all xfs_bmapi_write() callers (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in xattr ops (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in attrfork add (Brian Foster) [1633171]
- [fs] xfs: remove firstblock param from xfs dir ops (Brian Foster) [1633171]
- [fs] xfs: use ->t_firstblock in dir ops (Brian Foster) [1633171]
- [fs] xfs: add firstblock field to xfs_trans (Brian Foster) [1633171]
- [fs] xfs: allow null firstblock in xfs_bmapi_write() when tp is null (Brian Foster) [1633171]
- [fs] xfs: refactor dfops init to attach to transaction (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops in reflink cow recover path (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops in cancel cow blocks operation (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for rmap extent swap operations (Brian Foster) [1633171]
- [fs] xfs: remove unused btree cursor bc_private.a.dfops field (Brian Foster) [1633171]
- [fs] xfs: remove xfs_btree_cur bmbt dfops field (Brian Foster) [1633171]
- [fs] xfs: remove dfops param from internal bmap extent helpers (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for collapse/insert range operations (Brian Foster) [1633171]
- [fs] xfs: remove struct xfs_bmalloca dfops field (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bmapi_remap() dfops param (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bunmapi() dfops param (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for all xfs_bunmapi() callers (Brian Foster) [1633171]
- [fs] xfs: remove xfs_bmapi_write() dfops param (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for all xfs_bmapi_write() callers (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops in dqalloc transaction (Brian Foster) [1633171]
- [fs] xfs: replace xfs_da_args->dfops accesses with ->t_dfops and remove (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops in extent split tx and remove param (Brian Foster) [1633171]
- [fs] xfs: remove dfops param in attr fork add path (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for attr set/remove operations (Brian Foster) [1633171]
- [fs] xfs: use ->t_dfops for recovery of (b|c)ui log items (Brian Foster) [1633171]
- [fs] xfs: remove dfops param from high level dirname calls (Brian Foster) [1633171]
- [fs] xfs: remove dfops parameter from ifree call stack (Brian Foster) [1633171]
- [fs] xfs: rename xfs_trans ->t_agfl_dfops to ->t_dfops (Brian Foster) [1633171]
- [fs] xfs: cow unwritten conversion uses uninitialized dfops (Brian Foster) [1633171]
- [fs] xfs: update my copyrights for the writeback and iomap code (Brian Foster) [1633171]
- [fs] xfs: add support for sub-pagesize writeback without buffer_heads (Brian Foster) [1633171]
- [fs] xfs: allow writeback on pages without buffer heads (Brian Foster) [1633171]
- [fs] xfs: refactor the tail of xfs_writepage_map (Brian Foster) [1633171]
- [fs] xfs: remove xfs_start_page_writeback (Brian Foster) [1633171]
- [fs] xfs: move all writeback buffer_head manipulation into xfs_map_at_offset (Brian Foster) [1633171]
- [fs] xfs: don't look at buffer heads in xfs_add_to_ioend (Brian Foster) [1633171]
- [fs] xfs: remove the imap_valid flag (Brian Foster) [1633171]
- [fs] xfs: simplify xfs_map_blocks by using xfs_iext_lookup_extent directly (Brian Foster) [1633171]
- [fs] xfs: remove xfs_reflink_find_cow_mapping (Brian Foster) [1633171]
- [fs] xfs: remove the now unused XFS_BMAPI_IGSTATE flag (Brian Foster) [1633171]
- [fs] xfs: make xfs_writepage_map extent map centric (Brian Foster) [1633171]
- [fs] xfs: rename the offset variable in xfs_writepage_map (Brian Foster) [1633171]
- [fs] xfs: remove xfs_map_cow (Brian Foster) [1633171]
- [fs] xfs: remove xfs_reflink_trim_irec_to_next_cow (Brian Foster) [1633171]
- [fs] xfs: don't use XFS_BMAPI_IGSTATE in xfs_map_blocks (Brian Foster) [1633171]
- [fs] xfs: don't clear imap_valid for a non-uptodate buffers (Brian Foster) [1633171]
- [fs] xfs: do not set the page uptodate in xfs_writepage_map (Brian Foster) [1633171]
- [fs] xfs: move locking into xfs_bmap_punch_delalloc_range (Brian Foster) [1633171]
- [fs] xfs: simplify xfs_aops_discard_page (Brian Foster) [1633171]
- [fs] xfs: use iomap for blocksize == PAGE_SIZE readpage and readpages (Brian Foster) [1633171]
- [fs] iomap: fix WARN_ON_ONCE on uninitialized variable (Brian Foster) [1633171]
- [fs] iomap: Switch to offset_in_page for clarity (Brian Foster) [1633171]
- [fs] iomap: add support for sub-pagesize buffered I/O without buffer heads (Brian Foster) [1633171]
- [fs] iomap: add inline data support to iomap_readpage_actor (Brian Foster) [1633171]
- [fs] iomap: support direct I/O to inline data (Brian Foster) [1633171]
- [fs] iomap: refactor iomap_dio_actor (Brian Foster) [1633171]
- [fs] iomap: add initial support for writes without buffer heads (Brian Foster) [1633171]
- [fs] iomap: add an iomap-based readpage and readpages implementation (Brian Foster) [1633171]
- [fs] iomap: add private pointer to struct iomap (Brian Foster) [1633171]
- [fs] iomap: add a page_done callback (Brian Foster) [1633171]
- [fs] iomap: generic inline data handling (Brian Foster) [1633171]
- [fs] iomap: complete partial direct I/O writes synchronously (Brian Foster) [1633171]
- [fs] iomap: mark newly allocated buffer heads as new (Brian Foster) [1633171]
- [fs] fs: factor out a __generic_write_end helper (Brian Foster) [1633171]
- [netdrv] amd-xgbe: mark driver as tech preview (David Arcari) [1633209]
- [fs] ext4, dax: set ext4_dax_aops for dax files (Lukas Czerner) [1633239]
- [fs] ext4, dax: add ext4_bmap to ext4_dax_aops (Lukas Czerner) [1633239]
- [fs] ext4: don't mark mmp buffer head dirty (Lukas Czerner) [1633239]
- [fs] ext4: show test_dummy_encryption mount option in /proc/mounts (Lukas Czerner) [1633239]
- [fs] ext4: fix online resizing for bigalloc file systems with a 1k block size (Lukas Czerner) [1633239]
- [fs] ext4: fix online resize's handling of a too-small final block group (Lukas Czerner) [1633239]
- [fs] ext4: recalucate superblock checksum after updating free blocks/inodes (Lukas Czerner) [1633239]
- [fs] ext4: avoid arithemetic overflow that can trigger a BUG (Lukas Czerner) [1633239]
- [fs] ext4: avoid divide by zero fault when deleting corrupted inline directories (Lukas Czerner) [1633239]
- [fs] ext4: check to make sure the rename(2)'s destination is not freed (Lukas Czerner) [1633239]
- [fs] ext4: remove unneeded variable "err" in ext4_mb_release_inode_pa() (Lukas Czerner) [1633239]
- [fs] ext4: fix spectre gadget in ext4_mb_regular_allocator() (Lukas Czerner) [1633239]
- [fs] ext4: check for NUL characters in extended attribute's name (Lukas Czerner) [1633239]
- [fs] ext4: use ext4_warning() for sb_getblk failure (Lukas Czerner) [1633239]
- [fs] ext4: fix race when setting the bitmap corrupted flag (Lukas Czerner) [1633239]
- [fs] ext4: reset error code in ext4_find_entry in fallback (Lukas Czerner) [1633239]
- [fs] ext4: check allocation failure when duplicating "data" in ext4_remount() (Lukas Czerner) [1633239]
- [fs] ext4: sysfs: print ext4_super_block fields as little-endian (Lukas Czerner) [1633239]
- [firmware] efi/x86: Handle page faults occurring while running EFI runtime services (Bhupesh Sharma) [1627557]
- [firmware] efi: Make efi_rts_work accessible to efi page fault handler (Bhupesh Sharma) [1627557]
- [firmware] efi: Remove the declaration of efi_late_init() as the function is unused (Bhupesh Sharma) [1627557]
- [firmware] efi: Use a work queue to invoke EFI Runtime Services (Bhupesh Sharma) [1627557]
- [firmware] efi/x86: Use non-blocking SetVariable() for efi_delete_dummy_variable() (Bhupesh Sharma) [1627557]
- [fs] gfs2: Special-case rindex for gfs2_grow (Robert S Peterson) [1628360]
- [fs] GFS2: Fix recovery issues for spectators (Robert S Peterson) [1628298]

* Fri Oct 05 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-22.el8]
- [powerpc] powerpc/pkeys: Fix reading of ibm, processor-storage-keys property (Steve Best) [1633551]
- [powerpc] powerpc/pseries: Remove unneeded uses of dlpar work queue (Steve Best) [1633544]
- [powerpc] powerpc/pseries: Remove prrn_work workqueue (Steve Best) [1633544]
- [pci] ACPI / hotplug / PCI: Don't scan for non-hotplug bridges if slot is not bridge (Myron Stowe) [1634816]
- [pci] PCI: Fix enabling of PASID on RC integrated endpoints (Myron Stowe) [1634816]
- [pci] IB/hfi1,PCI: Allow bus reset while probing (Myron Stowe) [1634816]
- [pci] PCI: Fix faulty logic in pci_reset_bus() (Myron Stowe) [1634816]
- [pci] PCI: pciehp: Fix hot-add vs powerfault detection order (Myron Stowe) [1634816]
- [pci] Revert "PCI: Add ACS quirk for Intel 300 series" (Myron Stowe) [1634816]
- [powerpc] powerpc/numa: Use associativity if VPHN hcall is successful (Steve Best) [1633569]
- [pci] PCI: vmd: White list for fast interrupt handlers (Myron Stowe) [1632816]
- [pci] PCI: Add function 1 DMA alias quirk for Marvell 88SS9183 (Myron Stowe) [1632816]
- [pci] PCI: Rename pci_try_reset_bus() to pci_reset_bus() (Myron Stowe) [1632816]
- [pci] PCI: Deprecate pci_reset_bus() and pci_reset_slot() functions (Myron Stowe) [1632816]
- [pci] PCI: Unify try slot and bus reset API (Myron Stowe) [1632816]
- [pci] PCI: Hide pci_reset_bridge_secondary_bus() from drivers (Myron Stowe) [1632816]
- [pci] IB/hfi1: Use pci_try_reset_bus() for initiating PCI Secondary Bus Reset (Myron Stowe) [1632816]
- [pci] PCI: Handle error return from pci_reset_bridge_secondary_bus() (Myron Stowe) [1632816]
- [pci] PCI/IOV: Tidy pci_sriov_set_totalvfs() (Myron Stowe) [1632816]
- [pci] PCI: Enable PASID only if entire path supports End-End TLP prefixes (Myron Stowe) [1632816]
- [pci] PCI: Expand documentation for pci_add_dma_alias() (Myron Stowe) [1632816]
- [pci] PCI: Add DMA alias quirk for Microsemi Switchtec NTB (Myron Stowe) [1632816]
- [pci] switchtec: Use generic PCI Vendor ID and Class Code (Myron Stowe) [1632816]
- [pci] PCI: Make pci_get_rom_size() static (Myron Stowe) [1632816]
- [pci] PCI: Add check code for last image indicator not set (Myron Stowe) [1632816]
- [pci] PCI: Avoid accessing memory outside the ROM BAR (Myron Stowe) [1632816]
- [pci] PCI: Make early dump functionality generic (Myron Stowe) [1632816]
- [pci] PCI: Cleanup PCI_REBAR_CTRL_BAR_SHIFT handling (Myron Stowe) [1632816]
- [pci] PCI: Restore resized BAR state on resume (Myron Stowe) [1632816]
- [pci] PCI: Clean up resource allocation in devm_of_pci_get_host_bridge_resources() (Myron Stowe) [1632816]
- [pci] PCI: Add ACS Redirect disable quirk for Intel Sunrise Point (Myron Stowe) [1632816]
- [pci] PCI: Add device-specific ACS Redirect disable infrastructure (Myron Stowe) [1632816]
- [pci] PCI: Convert device-specific ACS quirks from NULL termination to ARRAY_SIZE (Myron Stowe) [1632816]
- [pci] PCI: Add "pci=disable_acs_redir=" parameter for peer-to-peer support (Myron Stowe) [1632816]
- [pci] PCI: Allow specifying devices using a base bus and path of devfns (Myron Stowe) [1632816]
- [pci] PCI: Make specifying PCI devices in kernel parameters reusable (Myron Stowe) [1632816]
- [pci] PCI: Hide ACS quirk declarations inside PCI core (Myron Stowe) [1632816]
- [pci] PCI: Document ACPI description of PCI host bridges (Myron Stowe) [1632816]
- [pci] PCI/MSI: Set IRQCHIP_ONESHOT_SAFE for PCI-MSI irqchips (Myron Stowe) [1632816]
- [pci] PCI: Limit config space size for Netronome NFP5000 (Myron Stowe) [1632816]
- [pci] PCI: Add PCI_DEVICE_DATA() macro to fully describe device ID entry (Myron Stowe) [1632816]
- [pci] PCI: Unify PCI and normal DMA direction definitions (Myron Stowe) [1632816]
- [pci] PCI: Use IRQF_ONESHOT if pci_request_irq() called with no handler (Myron Stowe) [1632816]
- [pci] PCI: Call dma_debug_add_bus() for pci_bus_type from PCI core (Myron Stowe) [1632816]
- [pci] PCI: Mark fall-through switch cases before enabling -Wimplicit-fallthrough (Myron Stowe) [1632816]

* Thu Oct 04 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-21.el8]
- [s390] s390/sclp: Allow to request adapter reset (Philipp Rudo) [1635273]
- [char] ipmi: Fix NULL pointer dereference in ssif_probe (Tony Camuso) [1635366]
- [char] ipmi: Fix I2C client removal in the SSIF driver (Tony Camuso) [1635366]
- [char] ipmi: kcs_bmc: don't change device name (Tony Camuso) [1635366]
- [kernel] timers: Clear timer_base::must_forward_clk with timer_base::lock held (Waiman Long) [1632820]
- [pci] switchtec: Fix Spectre v1 vulnerability (Waiman Long) [1632820]
- [kernel] cpu/hotplug: Prevent state corruption on error rollback (Waiman Long) [1632820]
- [kernel] cpu/hotplug: Adjust misplaced smb() in cpuhp_thread_fun() (Waiman Long) [1632820]
- [base] memory_hotplug: fix kernel_panic on offline page processing (Waiman Long) [1632820]
- [mm] mm/hugetlb: filter out hugetlb pages if HUGEPAGE migration is not supported (Waiman Long) [1632820]
- [lib] debugobjects: Make stack check warning more informative (Waiman Long) [1632820]
- [fs] fs/dcache.c: fix kmemcheck splat at take_dentry_name_snapshot() (Waiman Long) [1632820]
- [x86] x86/process: Don't mix user/kernel regs in 64bit __show_regs() (Waiman Long) [1632820]
- [x86] x86/dumpstack: Don't dump kernel memory based on usermode RIP (Waiman Long) [1632820]
- [x86] x86: Avoid pr_cont() in show_opcodes() (Waiman Long) [1632820]
- [x86] x86/entry/64: Wipe KASAN stack shadow before rewind_stack_do_exit() (Waiman Long) [1632820]
- [x86] x86/speculation/l1tf: Increase l1tf memory limit for Nehalem+ (Waiman Long) [1632820]
- [x86] x86/spectre: Add missing family 6 check to microcode check (Waiman Long) [1632820]
- [x86] x86/nmi: Fix NMI uaccess race against CR3 switching (Waiman Long) [1632820]
- [x86] x86/vdso: Fix lsl operand order (Waiman Long) [1632820]
- [x86] x86/vdso: Fix vDSO build if a retpoline is emitted (Waiman Long) [1632820]
- [x86] x86/speculation/l1tf: Suggest what to do on systems with too much RAM (Waiman Long) [1632820]
- [x86] x86/speculation/l1tf: Fix off-by-one error when warning that system has too much RAM (Waiman Long) [1632820]
- [x86] x86/speculation/l1tf: Fix overflow in l1tf_pfn_limit() on 32bit (Waiman Long) [1632820]
- [x86] x86/speculation/l1tf: Exempt zeroed PTEs from inversion (Waiman Long) [1632820]
- [x86] x86/mm/pti: Clear Global bit more aggressively (Waiman Long) [1632820]
- [x86] x86/paravirt: Fix spectre-v2 mitigations for paravirt guests (Waiman Long) [1632820]
- [target] scsi: target: iscsi: Use bin2hex instead of a re-implementation (Maurizio Lombardi) [1632184] {CVE-2018-14633}
- [target] scsi: target: iscsi: Use hex2bin instead of a re-implementation (Maurizio Lombardi) [1632184] {CVE-2018-14633}

* Wed Oct 03 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-20.el8]
- [netdrv] ibmvnic: Include missing return code checks in reset function (Steve Best) [1633553]
- [netdrv] ibmvnic: Update firmware error reporting with cause string (Steve Best) [1633553]
- [netdrv] ibmvnic: Remove code to request error information (Steve Best) [1633553]
- [s390] s390/qeth: remove duplicated carrier state tracking (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: clean up drop conditions for received cmds (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: re-indent qeth_check_ipa_data() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: consume local address events (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove various redundant code (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove CARD_FROM_CDEV helper (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: pass card pointer in iob callback (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: re-use qeth_notify_skbs() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove additional skb refcount (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: replace open-coded skb_queue_walk() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: on gdev release, reset drvdata (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fix discipline unload after setup error (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: use DEFINE_MUTEX for qeth_mod_mutex (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: convert layer attribute to enum (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: reduce 0-initializing when building IPA cmds (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fine-tune spinlocks (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fix typo in return value (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: invoke softirqs after napi_schedule() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: uninstall IRQ handler on device removal (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove qeth_hdr_chk_and_bounce() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: speed up TSO transmission (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: prepare for copy-free TSO transmission (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: check size of required HW header cache object (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fix up protocol headers early (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: limit csum offload erratum to L3 devices (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove qeth_get_elements_no() (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove unused L3 xmit code (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: run non-offload L3 traffic over common xmit path (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: move L2 xmit code to core module (Hendrik Brueckner) [1633841]
- [s390] s390/qdio: reset old sbal_state flags (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: don't dump past end of unknown HW header (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: use vzalloc for QUERY OAT buffer (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: switch on SG by default for IQD devices (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: indicate error when netdev allocation fails (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: use true and false for boolean values (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: don't restrict qeth_card to DMA memory (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: clean up card initialization (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: do basic setup for data channel (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: use qeth_setup_ccw() to set up all CCWs (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: reduce hard-coded access to ccw channels (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: extract helper for MPC protocol type (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: speed up L2 IQD xmit (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: add support for constrained HW headers (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: merge linearize-check into HW header construction (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: add statistics for consumed buffer elements (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: use core MTU range checking (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: simplify max MTU handling (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: don't cache HW port number (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: allocate netdevice early (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove redundant netif_carrier_ok() checks (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: reset layer2 attribute on layer switch (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fix race in used-buffer accounting (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: speed-up IPv4 OSA xmit (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: speed-up L3 IQD xmit (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: add a L3 xmit wrapper (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: increase GSO max size for eligible L3 devices (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: clean up exported symbols (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: consolidate ccwgroup driver definition (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: clean up Output Queue selection (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: fine-tune RX modesetting (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: remove unused buffer->aob pointer (Hendrik Brueckner) [1633841]
- [s390] s390/qeth: various buffer management cleanups (Hendrik Brueckner) [1633841]
- [powerpc] powerpc: Avoid code patching freed init sections (Steve Best) [1633545]
- [powerpc] powerpc/tm: Fix userspace r13 corruption (Steve Best) [1633543]
- [powerpc] powerpc/tm: Avoid possible userspace r1 corruption on reclaim (Steve Best) [1633543]
- [drm] drm/i915/cfl: Add a new CFL PCI ID (Rob Clark) [1626883]
- [drm] drm/i915/aml: Introducing Amber Lake platform (Rob Clark) [1626883]
- [drm] drm/i915/whl: Introducing Whiskey Lake platform (Rob Clark) [1626883]
- [char] ipmi: Move BT capabilities detection to the detect call (Frank Ramsay) [1618774]
- [char] ipmi: Rework SMI registration failure (Frank Ramsay) [1618774]

* Tue Oct 02 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-19.el8]
- [s390] s390: detect etoken facility (Thomas Huth) [1634069]
- [s390] s390/lib: use expoline for all bcr instructions (Thomas Huth) [1634069]
- [documentation] vm.txt: Adding 'nr_hugepages_mempolicy' parameter description (Prashant Dhamdhere) [1626547]

* Mon Oct 01 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-18.el8]
- [scsi] scsi: ipr: System hung while dlpar adding primary ipr adapter back (Steve Best) [1633217]
- [target] scsi: iscsi: target: Don't use stack buffer for scatterlist (Maurizio Lombardi) [1631342]
- [rpmspec] Forward port weak-modules support from RHEL 7 to RHEL 8 ("Herton R. Krzesinski") [1596884]
- [fs] xfs: Close race between direct IO and xfs_break_layouts() (Eric Sandeen) [1622191]
- [fs] xfs: remove unused iolock arg from xfs_break_dax_layouts (Eric Sandeen) [1622191]
- [fs] ext4: Close race between direct IO and ext4_break_layouts() (Eric Sandeen) [1616303]
- [fs] ext4: handle layout changes to pinned DAX mappings (Eric Sandeen) [1614154]
- [fs] dax: dax_layout_busy_page() warn on !exceptional (Eric Sandeen) [1614154]
- [fs] dax: mark tech preview (Eric Sandeen) [1627455]
- [mm] usercopy: Allow boot cmdline disabling of hardening (Christoph von Recklinghausen) [1589928]

* Thu Sep 27 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-17.el8]
- [s390] s390/crypto: Fix return code checking in cbc_paes_crypt() (Philipp Rudo) [1633266]
- [drm] amd/display/dc/basics/logger.c: fix build error with CONFIG_FORTIFY_SOURCE=y ("Herton R. Krzesinski") [1548068]
- [acpi] ACPICA: AML Parser: skip opcodes that open a scope upon parse failure (Jeremy Linton) [1609885]
- [acpi] ACPICA: ACPICA: add status check for acpi_hw_read before assigning return value (Jeremy Linton) [1609885]
- [acpi] ACPICA: AML Parser: ignore all exceptions resulting from incorrect AML during table load (Jeremy Linton) [1609885]
- [rpmspec] spec: Add missing BuildRequires for bpftool (Jiri Olsa) [1632756]
- [powerpc] KVM: PPC: Avoid marking DMA-mapped pages dirty in real mode (David Gibson) [1628412]
- [powerpc] powerpc/powernv/ioda: Allocate indirect TCE levels on demand (David Gibson) [1628412]
- [powerpc] powerpc/powernv: Rework TCE level allocation (David Gibson) [1628412]
- [powerpc] powerpc/powernv: Add indirect levels to it_userspace (David Gibson) [1628412]
- [powerpc] KVM: PPC: Make iommu_table::it_userspace big endian (David Gibson) [1628412]
- [powerpc] powerpc/powernv: Move TCE manupulation code to its own file (David Gibson) [1628412]
- [net] net_sched: fix NULL pointer dereference when delete tcindex filter (Andrea Claudi) [1627648]
- [net] net_sched: Fix missing res info when create new tc_index filter (Andrea Claudi) [1627648]
- [samples] samples/bpf: xdpsock: order memory on AArch64 (Jesper Brouer) [1615959]
- [samples] samples/bpf: xdp_redirect_cpu load balance like Suricata (Jesper Brouer) [1615959]
- [samples] samples/bpf: add Paul Hsieh's (LGPL 2.1) hash function SuperFastHash (Jesper Brouer) [1615959]
- [samples] samples/bpf: xdp_redirect_cpu handle parsing of double VLAN tagged packets (Jesper Brouer) [1615959]
- [samples] samples/bpf: all XDP samples should unload xdp/bpf prog on SIGTERM (Jesper Brouer) [1615959]
- [samples] samples/bpf: xdp_rxq_info action XDP_TX must adjust MAC-addrs (Jesper Brouer) [1615959]
- [samples] samples/bpf: extend xdp_rxq_info to read packet payload (Jesper Brouer) [1615959]
- [powerpc] KVM: PPC: Book3S HV: Use correct pagesize in kvm_unmap_radix() (David Gibson) [1625498]
- [net] igmp: fix incorrect unsolicit report count after link down and up (Hangbin Liu) [1625538]
- [net] igmp: fix incorrect unsolicit report count when join group (Hangbin Liu) [1625538]
- [netdrv] cxgb4: update 1.20.8.0 as the latest firmware supported (Arjun Vynipadath) [1622555]
- [virt] svm: nested virt support off by default (Bandan Das) [1571993]

* Wed Sep 26 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-16.el8]
- [powerpc] KVM: PPC: Book3S HV: Don't use compound_order to determine host mapping size (David Gibson) [1625860]
- [virt] arm64: KVM: Remove pgd_lock (Wei Huang) [1627474]
- [virt] KVM: Remove obsolete kvm_unmap_hva notifier backend (Wei Huang) [1627474]
- [virt] arm64: KVM: Only force FPEXC32_EL2.EN if trapping FPSIMD (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Clean dcache to PoC when changing PTE due to CoW (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Skip updating PTE entry if no change (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Skip updating PMD entry if no change (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Move DEBUG_SPINLOCK_BUG_ON to vgic.h (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Do not use spin_lock_irqsave/restore with irq disabled (Wei Huang) [1627474]
- [virt] KVM: arm: vgic-v3: Add support for ICC_SGI0R and ICC_ASGI1R accesses (Wei Huang) [1627474]
- [virt] KVM: arm64: vgic-v3: Add support for ICC_SGI0R_EL1 and ICC_ASGI1R_EL1 accesses (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic-v3: Add core support for Group0 SGIs (Wei Huang) [1627474]
- [virt] KVM: arm64: Remove non-existent AArch32 ICC_SGI1R encoding (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Fix lost IRQs from emulated physcial timer when blocked (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Fix potential loss of ptimer interrupts (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Fix possible spectre-v1 write in vgic_mmio_write_apr() (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Update documentation of the GIC devices wrt IIDR (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Let userspace opt-in to writable v2 IGROUPR (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Allow configuration of interrupt groups (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Return error on incompatible uaccess GICD_IIDR writes (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Permit uaccess writes to return errors (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Signal IRQs using their configured group (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Add group field to struct irq (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: GICv2 IGROUPR should read as zero (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Keep track of implementation revision (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic: Define GICD_IIDR fields for GICv2 and GIv3 (Wei Huang) [1627474]
- [virt] arm64: KVM: Cleanup tpidr_el2 init on non-VHE (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: vgic-debug: Show LPI status (Wei Huang) [1627474]
- [virt] KVM: arm64: vgic-its: Remove VLA usage (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Fix vgic init race (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Enable adaptative WFE trapping (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Remove unnecessary CMOs when creating HYP page tables (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Stop using the kernel's (pmd, pud, pgd)_populate helpers (Wei Huang) [1627474]
- [virt] KVM: arm/arm64: Consolidate page-table accessors (Wei Huang) [1627474]
- [virt] arm64: KVM: Avoid marking pages as XN in Stage-2 if CTR_EL0.DIC is set (Wei Huang) [1627474]
- [tools] radix tree test suite: Enable ubsan (Waiman Long) [1630244]
- [tools] radix tree test suite: Fix compilation (Waiman Long) [1630244]
- [block] blk-wbt: don't maintain inflight counts if disabled (Ming Lei) [1622790]
- [block] blk-wbt: fix has-sleeper queueing check (Ming Lei) [1622790]
- [block] blk-wbt: use wq_has_sleeper() for wq active check (Ming Lei) [1622790]
- [block] blk-wbt: move disable check into get_limit() (Ming Lei) [1622790]
- [block] block/DAC960.c: make some arrays static const, shrinks object (Ming Lei) [1622790]
- [block] blk-mq: sync the update nr_hw_queues with (Ming Lei) [1617959]
- [block] blk-mq: init hctx sched after update ctx and hctx mapping (Ming Lei) [1617959]
- [block] block: remove duplicate initialization (Ming Lei) [1622790]
- [block] tracing/blktrace: Fix to allow setting same value (Ming Lei) [1622790]
- [block] pktcdvd: fix setting of 'ret' error return for a few cases (Ming Lei) [1622790]
- [block] block: change return type to bool (Ming Lei) [1622790]
- [block] block, bfq: return nbytes and not zero from struct cftype (Ming Lei) [1622790]
- [block] block, bfq: improve code of bfq_bfqq_charge_time (Ming Lei) [1622790]
- [block] block, bfq: reduce write overcharge (Ming Lei) [1622790]
- [block] block, bfq: always update the budget of an entity when needed (Ming Lei) [1622790]
- [block] block, bfq: readd missing reset of parent-entity service (Ming Lei) [1622790]
- [block] block: don't warn for flush on read-only device (Ming Lei) [1622809]

* Tue Sep 25 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-15.el8]
- [kernel] locking/rwsem: Make owner store task pointer of last owning reader (Waiman Long) [1631842]
- [kernel] locking/rwsem: Exit read lock slowpath if queue empty & no writer (Waiman Long) [1631842]
- [x86] x86/microcode: Update the new microcode revision unconditionally (Prarit Bhargava) [1630931]
- [x86] x86/microcode: Make sure boot_cpu_data.microcode is up-to-date (Prarit Bhargava) [1630931]
- [arm64] arm64: tlb: Provide forward declaration of tlb_flush() before including tlb.h (Waiman Long) [1630521]
- [x86] x86/mm: Only use tlb_remove_table() for paravirt (Waiman Long) [1630521]
- [mm] mm: mmu_notifier fix for tlb_end_vma (Waiman Long) [1630521]
- [mm] mm/tlb, x86/mm: Support invalidating TLB caches for RCU_TABLE_FREE (Waiman Long) [1630521]
- [mm] mm/tlb: Remove tlb_remove_table() non-concurrent condition (Waiman Long) [1630521]
- [mm] mm: move tlb_table_flush to tlb_flush_mmu_free (Waiman Long) [1630521]
- [kernel] clocksource: Revert Remove kthread (Waiman Long) [1628402]
- [cpuidle] cpuidle: menu: Retain tick when shallow state is selected (Waiman Long) [1628402]
- [cpufreq] cpufreq: governor: Avoid accessing invalid governor_data (Waiman Long) [1628402]
- [cpuidle] cpuidle: menu: Handle stopped tick more aggressively (Waiman Long) [1628402]
- [kernel] sched: idle: Avoid retaining the tick when it has been stopped (Waiman Long) [1628402]
- [net] netfilter: xt_hashlimit: do not crash when reading proc file (Florian Westphal) [1630131]
- [x86] x86/boot/KASLR: Skip specified number of 1GB huge pages when doing physical randomization (KASLR) (Baoquan He) [1564824]
- [x86] x86/boot/KASLR: Add two new functions for 1GB huge pages handling (Baoquan He) [1564824]
- [mfd] mfd: intel-lpss: Add Ice Lake PCI IDs (Gopal Tiwari) [1483477]
- [mmc] mmc: sdhci-pci: Add support for Intel ICP (Gopal Tiwari) [1483496]

* Mon Sep 24 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-14.el8]
- [mm] mm: get rid of vmacache_flush_all() entirely (Waiman Long) [1631297] {CVE-2018-17182}
- [mm] mm, vmacache: hash addresses based on pmd (Waiman Long) [1631297] {CVE-2018-17182}
- [mm] mm: Allocate the mm_cpumask (mm->cpu_bitmap) dynamically based on nr_cpu_ids (Waiman Long) [1631297] {CVE-2018-17182}
- [infiniband] IB/hfi1: Invalid NUMA node information can cause a divide by zero (Alex Estrin) [1622222]
- [nvdimm] libnvdimm: Export max available extent (Jeff Moyer) [1627874]
- [nvdimm] libnvdimm: Use max contiguous area for namespace size (Jeff Moyer) [1627874]
- [netdrv] ice: Fix and update driver version string (Jonathan Toppins) [1611786]
- [netdrv] ice: Introduce SERVICE_DIS flag and service routine functions (Jonathan Toppins) [1611786]
- [netdrv] ice: Enable VSI Rx/Tx pruning only when VLAN 0 is active (Jonathan Toppins) [1611786]
- [netdrv] ice: Enable firmware logging during device initialization (Jonathan Toppins) [1611786]
- [netdrv] ice: Implement ice_bridge_getlink and ice_bridge_setlink (Jonathan Toppins) [1611786]
- [netdrv] ice: Add support for Tx hang, Tx timeout and malicious driver detection (Jonathan Toppins) [1611786]
- [netdrv] ice: Clean up register file (Jonathan Toppins) [1611786]
- [netdrv] ice: Implement handlers for ethtool PHY/link operations (Jonathan Toppins) [1611786]
- [netdrv] ice: Refactor VSI allocation, deletion and rebuild flow (Jonathan Toppins) [1611786]
- [netdrv] ice: Refactor switch rule management structures and functions (Jonathan Toppins) [1611786]
- [netdrv] ice: Code optimization for ice_fill_sw_rule() (Jonathan Toppins) [1611786]
- [netdrv] ice: Prevent control queue operations during reset (Jonathan Toppins) [1611786]
- [netdrv] ice: Update request resource command to latest specification (Jonathan Toppins) [1611786]
- [netdrv] ice: Updates to Tx scheduler code (Jonathan Toppins) [1611786]
- [netdrv] ice: Rework flex descriptor programming (Jonathan Toppins) [1611786]
- [netdrv] net/mlx5: Fix SQ offset in QPs with small RQ (Alaa Hleihel) [1623367]
- [x86] x86/spec_ctrl: Make IBRS code work with SSBD mitigation (Waiman Long) [1565180]
- [x86] x86/spec_ctrl: Auto-enable IBRS on Skylake (Waiman Long) [1565180]
- [x86] x86/spec_ctrl: Extend spectre_v2 boot option to support IBRS (Waiman Long) [1565180]
- [x86] x86/spec_ctrl: Boot time IBRS initialization (Waiman Long) [1565180]
- [x86] x86/spec_ctrl: Add IBRS code to the 64-bit assembly entry code (Waiman Long) [1565180]
- [x86] x86/cpufeatures: Increase NCAPINTS for future extension (Waiman Long) [1565180]
- [netdrv] ice: Trivial formatting fixes (Jonathan Toppins) [1611783]
- [netdrv] ice: Change struct members from bool to u8 (Jonathan Toppins) [1611783]
- [netdrv] ice: Fix potential return of uninitialized value (Jonathan Toppins) [1611783]
- [netdrv] ice: Fix a few null pointer dereference issues (Jonathan Toppins) [1611783]
- [netdrv] ice: Update to interrupts enabled in OICR (Jonathan Toppins) [1611783]
- [netdrv] ice: Set VLAN flags correctly (Jonathan Toppins) [1611783]
- [netdrv] ice: Use order_base_2 to calculate higher power of 2 (Jonathan Toppins) [1611783]
- [netdrv] ice: Fix bugs in control queue processing (Jonathan Toppins) [1611783]
- [netdrv] ice: Clean control queues only when they are initialized (Jonathan Toppins) [1611783]
- [netdrv] ice: Report stats for allocated queues via ethtool stats (Jonathan Toppins) [1611783]
- [netdrv] ice: Cleanup magic number (Jonathan Toppins) [1611783]
- [netdrv] ice: Remove unnecessary node owner check (Jonathan Toppins) [1611783]
- [netdrv] ice: Fix multiple static analyser warnings (Jonathan Toppins) [1611783]
- [virt] KVM: VMX: fixes for vmentry_l1d_flush module parameter (Waiman Long) [1616248] {CVE-2018-15572}
- [virt] KVM: x86: SVM: Call x86_spec_ctrl_set_guest/host() with interrupts disabled (Waiman Long) [1616248] {CVE-2018-15572}
- [virt] x86/kvm/vmx: Fix coding style in vmx_setup_l1d_flush() (Waiman Long) [1616248] {CVE-2018-15572}
- [x86] x86/speculation: Support Enhanced IBRS on future CPUs (Waiman Long) [1614144]
- [x86] x86/speculation: Protect against userspace-userspace spectreRSB (Waiman Long) [1616248] {CVE-2018-15572}
- [x86] x86/speculation: Remove SPECTRE_V2_IBRS in enum spectre_v2_mitigation (Waiman Long) [1616248] {CVE-2018-15572}
- [cpufreq] cpufreq: Fix a circular lock dependency problem (Waiman Long) [1599154]
- [kernel] cpu/hotplug: Add a cpus_read_trylock() function (Waiman Long) [1599154]
- [virt] xen/spinlock: Don't use pvqspinlock if only 1 vCPU (Waiman Long) [1618486]

* Thu Sep 20 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-13.el8]
- [mailbox] mailbox: PCC: handle parse error (David Arcari) [1630382]
- [hv] vmbus: don't return values for uninitalized channels (Vitaly Kuznetsov) [1617954]
- [mm] kernel/memremap, kasan: make ZONE_DEVICE with work with KASAN (Bill O'Donnell) [1629578]
- [mm] mm: fix BUG_ON() in vmf_insert_pfn_pud() from VM_MIXEDMAP removal (Jeff Moyer) [1622171]
- [mm] dax: remove VM_MIXEDMAP for fsdax and device dax (Jeff Moyer) [1622171]

* Wed Sep 19 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-12.el8]
- [i2c] i2c: i801: fix DNV's SMBCTRL register offset (David Arcari) [1628861]
- [fs] ceph: avoid a use-after-free in ceph_destroy_options() (Ilya Dryomov) [1629884]
- [fs] ceph: fix incorrect use of strncpy (Ilya Dryomov) [1629884]
- [block] rbd: support cloning across namespaces (Ilya Dryomov) [1629884]
- [block] rbd: factor out get_parent_info() (Ilya Dryomov) [1629884]
- [block] rbd: support for images within namespaces (Ilya Dryomov) [1629884]
- [block] rbd: pass rbd_spec into parse_rbd_opts_token() (Ilya Dryomov) [1629884]
- [net] libceph: weaken sizeof check in ceph_x_verify_authorizer_reply() (Ilya Dryomov) [1629884]
- [net] libceph: check authorizer reply/challenge length before reading (Ilya Dryomov) [1629884]
- [net] libceph: implement CEPHX_V2 calculation mode (Ilya Dryomov) [1629884]
- [net] libceph: add authorizer challenge (Ilya Dryomov) [1629884]
- [net] libceph: factor out encrypt_authorizer() (Ilya Dryomov) [1629884]
- [net] libceph: factor out __ceph_x_decrypt() (Ilya Dryomov) [1629884]
- [net] libceph: factor out __prepare_write_connect() (Ilya Dryomov) [1629884]
- [net] libceph: store ceph_auth_handshake pointer in ceph_connection (Ilya Dryomov) [1629884]
- [pci] PCI: pciehp: Deduplicate presence check on probe & resume (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Avoid implicit fallthroughs in switch statements (Myron Stowe) [1583983]
- [pci] PCI: Whitelist Thunderbolt ports for runtime D3 (Myron Stowe) [1583983]
- [pci] PCI: Whitelist native hotplug ports for runtime D3 (Myron Stowe) [1583983]
- [pci] PCI: sysfs: Resume to D0 on function reset (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Resume parent to D0 on config space access (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Resume to D0 on enable/disable (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Support interrupts sent from D3hot (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Obey compulsory command delay after resume (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Clear spurious events earlier on resume (Myron Stowe) [1583983]
- [pci] PCI: portdrv: Deduplicate PM callback iterator (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Avoid slot access during reset (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Always enable occupied slot on probe (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Become resilient to missed events (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Tolerate initially unstable link (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Declare pciehp_enable/disable_slot() static (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Drop enable/disable lock (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Enable/disable exclusively from IRQ thread (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Track enable/disable status (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Publish to user space last on probe (Myron Stowe) [1583983]
- [pci] PCI: hotplug: Demidlayer registration with the core (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Drop slot workqueue (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Handle events synchronously (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Stop blinking on slot enable failure (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Convert to threaded polling (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Convert to threaded IRQ (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Document struct slot and struct controller (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Declare pciehp_unconfigure_device() void (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Drop unnecessary NULL pointer check (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Fix unprotected list iteration in IRQ handler (Myron Stowe) [1583983]
- [pci] PCI: pciehp: Fix use-after-free on unplug (Myron Stowe) [1583983]
- [pci] PCI: hotplug: Don't leak pci_slot on registration failure (Myron Stowe) [1583983]
- [pci] PCI: hotplug: Delete skeleton driver (Myron Stowe) [1583983]
- [netdrv] be2net: Use Kconfig flag to support for enabling/disabling adapters (Petr Oros) [1611768]
- [acpi] ACPICA: Reference Counts: increase max to 0x4000 for large servers (Frank Ramsay) [1618760]

* Tue Sep 18 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-11.el8]
- [net] udp6: add missing checks on edumux packet processing (Paolo Abeni) [1625954]
- [net] udp4: fix IP_CMSG_CHECKSUM for connected sockets (Paolo Abeni) [1625954]
- [s390] s390/pci: fix out of bounds access during irq setup (Hendrik Brueckner) [1627462]
- [nvdimm] libnvdimm: fix ars_status output length calculation (Jeff Moyer) [1616307]

* Mon Sep 17 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-10.el8]
- [scsi] scsi: lpfc: Correct MDS diag and nvmet configuration (Dick Kennedy) [1628323]
- [iommu] iommu/arm-smmu: workaround DMA mode issues (Mark Salter) [1624077]
- [x86] x86/microcode: Allow late microcode loading with SMT disabled (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] tools headers: Synchronise x86 cpufeatures.h for L1TF additions (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/mm/kmmio: Make the tracer robust against L1TF (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/mm/pat: Make set_memory_np() L1TF safe (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Make pmd/pud_mknotpresent() invert (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Invert all not present mappings (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Fix SMT supported evaluation (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] KVM: VMX: Tell the nested hypervisor to skip L1D flush on vmentry (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation: Use ARCH_CAPABILITIES to skip L1D flush on vmentry (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation: Simplify sysfs report of VMX L1TF vulnerability (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] Documentation/l1tf: Remove Yonah processors from not vulnerable list (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Don't set l1tf_flush_l1d from vmx_handle_external_intr() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/irq: Let interrupt handlers set kvm_cpu_l1tf_flush_l1d (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86: Don't include linux/irq.h from asm/hardirq.h (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Introduce per-host-cpu analogue of l1tf_flush_l1d (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/irq: Demote irq_cpustat_t::__softirq_pending to u16 (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Move the l1tf_flush_l1d test to vmx_l1d_flush() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Replace 'vmx_l1d_flush_always' with 'vmx_l1d_flush_cond' (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Don't set l1tf_flush_l1d to true from vmx_l1d_flush() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: detect SMT disabled by BIOS (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] Documentation/l1tf: Fix typos (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Initialize the vmx_l1d_flush_pages' content (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Unbreak !__HAVE_ARCH_PFN_MODIFY_ALLOWED architectures (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] Documentation: Add section about CPU vulnerabilities (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/bugs, kvm: Introduce boot-time control of L1TF mitigations (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Set CPU_SMT_NOT_SUPPORTED early (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Expose SMT control init function (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/kvm: Allow runtime control of L1D flush (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/kvm: Serialize L1D flush parameter setter (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/kvm: Add static key for flush always (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/kvm: Move l1tf setup function (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/l1tf: Handle EPT disabled state proper (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/kvm: Drop L1TF MSR list approach (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/litf: Introduce vmx status variable (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Online siblings when SMT control is turned on (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Use MSR save list for IA32_FLUSH_CMD if required (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Extend add_atomic_switch_msr() to allow VMENTER only MSRs (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Separate the VMX AUTOLOAD guest/host number accounting (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Add find_msr() helper function (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Split the VMX MSR LOAD structures to have an host/guest numbers (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Add L1D flush logic (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Add L1D MSR based flush (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Add L1D flush algorithm (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM/VMX: Add module argument for L1TF mitigation (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/KVM: Warn user if KVM is loaded SMT and L1TF CPU bug being present (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Boot HT siblings at least once (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] Revert "x86/apic: Ignore secondary threads if nosmt=force" (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Fix up pte->pfn conversion for PAE (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Protect PAE swap entries against L1TF (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/CPU/AMD: Move TOPOEXT reenablement before reading smp_num_siblings (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpufeatures: Add detection of L1D cache flush support (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Extend 64bit swap file size limit (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/apic: Ignore secondary threads if nosmt=force (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu/AMD: Evaluate smp_num_siblings early (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/CPU/AMD: Do not check CPUID max ext level before parsing SMP info (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu/intel: Evaluate smp_num_siblings early (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu/topology: Provide detect_extended_topology_early() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu/common: Provide detect_ht_early() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu/AMD: Remove the pointless detect_ht() call (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/cpu: Remove the pointless CPU printout (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Provide knobs to control SMT (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Split do_cpu_down() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] cpu/hotplug: Make bringup/teardown of smp threads symmetric (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/topology: Provide topology_smt_supported() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/smp: Provide topology_is_primary_thread() (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] sched/smt: Update sched_smt_present at runtime (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/bugs: Move the l1tf function and define pr_fmt properly (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Limit swap file size to MAX_PA/2 (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Disallow non privileged high MMIO PROT_NONE mappings (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Add sysfs reporting for l1tf (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Make sure the first page is always reserved (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Protect PROT_NONE PTEs against speculation (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Protect swap entries against L1TF (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Change order of offset/type in swap entry (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}
- [x86] x86/speculation/l1tf: Increase 32bit PAE __PHYSICAL_PAGE_SHIFT (Waiman Long) [1616046] {CVE-2018-3620 CVE-2018-3646}

* Thu Sep 13 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-9.el8]
- [pci] PCI/DPC: Remove indirection waiting for inactive link (Myron Stowe) [1485556]
- [pci] PCI/DPC: Use threaded IRQ for bottom half handling (Myron Stowe) [1485556]
- [pci] PCI/DPC: Print AER status in DPC event handling (Myron Stowe) [1485556]
- [pci] PCI/DPC: Remove rp_pio_status from dpc struct (Myron Stowe) [1485556]
- [pci] PCI/DPC: Defer event handling to work queue (Myron Stowe) [1485556]
- [pci] PCI/DPC: Leave interrupts enabled while handling event (Myron Stowe) [1485556]
- [net] net/mlx5e: Offload TC matching on tos/ttl for ip tunnels (Erez Alfasi) [1615121]
- [net] net/mlx5e: Support setup of tos and ttl for tunnel key TC action offload (Erez Alfasi) [1615121]
- [net] net/mlx5e: Use ttl from route lookup on tc encap offload only if needed (Erez Alfasi) [1615121]
- [net] net/sched: cls_flower: Support matching on ip tos and ttl for tunnels (Erez Alfasi) [1615121]
- [net] flow_dissector: Dissect tos and ttl from the tunnel info (Erez Alfasi) [1615121]
- [net] net/sched: tunnel_key: Allow to set tos and ttl for tc based ip tunnels (Erez Alfasi) [1615121]
- [net] net/sched: act_tunnel_key: disambiguate metadata dst error cases (Erez Alfasi) [1615121]
- [net] net/sched: add tunnel option support to act_tunnel_key (Erez Alfasi) [1615121]
- [iommu] iommu/amd: Add support for IOMMU XT mode (Suravee Suthikulpanit) [1504485]
- [iommu] iommu/amd: Add support for higher 64-bit IOMMU Control Register (Suravee Suthikulpanit) [1504485]
- [x86] x86: irq_remapping: Move irq remapping mode enum (Suravee Suthikulpanit) [1504485]
- [firmware] dcdbas: Add support for WSMT ACPI table (Charles Rose) [1502286]

* Wed Sep 12 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-8.el8]
- [documentation] scsi: documentation: add scsi_mod.use_blk_mq to scsi-parameters (Ewan Milne) [1600014]
- [scsi] scsi: core: Update SCSI_MQ_DEFAULT help text to match default (Ewan Milne) [1600014]
- [scsi] scsi: core: switch to scsi-mq by default (Ewan Milne) [1600014]
- [pci] PCI: Match Root Port's MPS to endpoint's MPSS as necessary (Myron Stowe) [1502324]
- [pci] PCI: Skip MPS logic for Virtual Functions (VFs) (Myron Stowe) [1502324]
- [pci] PCI: Check for PCIe Link downtraining (Myron Stowe) [1502324]
- [pci] PCI: Workaround IDT switch ACS Source Validation erratum (Myron Stowe) [1502324]
- [of] OF: Don't set default coherent DMA mask (Mark Salter) [1581822]
- [acpi] ACPI/IORT: Don't set default coherent DMA mask (Mark Salter) [1581822]
- [iommu] iommu/dma: Respect bus DMA limit for IOVAs (Mark Salter) [1581822]
- [of] of/device: Set bus DMA mask as appropriate (Mark Salter) [1581822]
- [acpi] ACPI/IORT: Set bus DMA mask as appropriate (Mark Salter) [1581822]
- [kernel] dma-mapping: Generalise dma_32bit_limit flag (Mark Salter) [1581822]
- [acpi] ACPI/IORT: Support address size limit for root complexes (Mark Salter) [1581822]
- [of] of/platform: Initialise default DMA masks (Mark Salter) [1581822]
- [net] Bluetooth: hidp: buffer overflow in hidp_process_report (Gopal Tiwari) [1623073] {CVE-2018-9363}
- [irqchip] irqchip/gic-v3-its: Reduce minimum LPI allocation to 1 for PCI devices (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3-its: Honor hypervisor enforced LPI range (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3: Expose GICD_TYPER in the rdist structure (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3-its: Drop chunk allocation compatibility (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3-its: Move minimum LPI requirements to individual busses (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3-its: Use full range of LPIs (Mark Salter) [1550500]
- [irqchip] irqchip/gic-v3-its: Refactor LPI allocator (Mark Salter) [1550500]

* Tue Sep 11 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-7.el8]
- [netdrv] hv_netvsc: Fix a deadlock by getting rtnl lock earlier in netvsc_probe() (Vitaly Kuznetsov) [1625609]
- [netdrv] hv_netvsc: ignore devices that are not PCI (Vitaly Kuznetsov) [1625609]
- [netdrv] hv/netvsc: Fix NULL dereference at single queue mode fallback (Vitaly Kuznetsov) [1625609]
- [netdrv] hv_netvsc: Add per-cpu ethtool stats for netvsc (Vitaly Kuznetsov) [1625609]
- [pci] PCI: shpchp: Separate existence of SHPC and permission to use it (Steve Best) [1622953]
- [powerpc] KVM: PPC: Book3S HV: Don't truncate HPTE index in xlate function (David Gibson) [1625513]
- [kernel] rh_kabi: Add macros to size and extend structs (Prarit Bhargava) [1564570]
- [pci] PCI: Remove unnecessary include of <linux/pci-aspm.h> (Myron Stowe) [1622672]
- [wireless] iwlwifi: Remove unnecessary include of <linux/pci-aspm.h> (Myron Stowe) [1622672]
- [wireless] ath9k: Remove unnecessary include of <linux/pci-aspm.h> (Myron Stowe) [1622672]
- [netdrv] igb: Remove unnecessary include of <linux/pci-aspm.h> (Myron Stowe) [1622672]
- [pci] PCI/ASPM: Convert to use sysfs_match_string() helper (Myron Stowe) [1622672]
- [virt] KVM: s390: Properly lock mm context allow_gmap_hpage_1m setting (Thomas Huth) [1623513]
- [virt] KVM: s390: vsie: copy wrapping keys to right place (Thomas Huth) [1623513]
- [virt] KVM: s390: Fix pfmf and conditional skey emulation (Thomas Huth) [1623513]
- [virt] KVM: s390: Fix storage attributes migration with memory slots (Thomas Huth) [1623513]
- [virt] KVM: s390: a utility function for migration (Thomas Huth) [1623513]

* Mon Sep 10 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-6.el8]
- [lib] vsprintf: Add command line option debug_boot_weak_hash (Prarit Bhargava) [1625687]
- [netdrv] i40e: Fix for Tx timeouts when interface is brought up if DCB is enabled (Stefan Assmann) [1616147]
- [misc] ocxl: Fix page fault handler in case of fault on dying process (Steve Best) [1624644]
- [edac] EDAC, sb_edac: Add support for systems with segmented PCI buses (Aristeu Rozanski) [1621849]
- [netdrv] xen-netfront: fix warn message as irq device name has '/' (Vitaly Kuznetsov) [1576160]
- [arm64] arm64, kaslr: export offset in VMCOREINFO ELF notes (Bhupesh Sharma) [1624246]
- [rpmspec] redhat: Move gfs2 and dlm out of kernel-modules-extra (Andrew Price) [1623511]
- [powerpc] powerpc/topology: Get topology for shared processors at boot (Steve Best) [1620039]
- [fs] gfs2: Don't set GFS2_RDF_UPTODATE when the lvb is updated (Robert S Peterson) [1622057]
- [fs] gfs2: improve debug information when lvb mismatches are found (Robert S Peterson) [1622057]
- [fs] gfs2: cleanup: call gfs2_rgrp_ondisk2lvb from gfs2_rgrp_out (Robert S Peterson) [1622057]
- [x86] Fix x86 32-bit invalid cpu boot failure message (Prarit Bhargava) [1571456]
- [net] net/ipv6: init ip6 anycast rt->dst.input as ip6_input (Hangbin Liu) [1615671]
- [pci] PCI/AER: Don't clear AER bits if error handling is Firmware-First (Myron Stowe) [1621933]
- [pci] PCI/AER: Remove duplicate PCI_EXP_AER_FLAGS definition (Myron Stowe) [1621933]
- [pci] PCI/portdrv: Remove pcie_portdrv_err_handler.slot_reset (Myron Stowe) [1621933]
- [pci] PCI/AER: Clear device status bits during ERR_COR handling (Myron Stowe) [1621933]
- [pci] PCI/AER: Clear device status bits during ERR_FATAL and ERR_NONFATAL (Myron Stowe) [1621933]
- [pci] PCI/AER: Remove ERR_FATAL code from ERR_NONFATAL path (Myron Stowe) [1621933]
- [pci] PCI/AER: Factor out ERR_NONFATAL status bit clearing (Myron Stowe) [1621933]
- [pci] PCI/AER: Clear only ERR_NONFATAL bits during non-fatal recovery (Myron Stowe) [1621933]
- [pci] PCI/AER: Clear only ERR_FATAL status bits during fatal recovery (Myron Stowe) [1621933]
- [pci] PCI/AER: Honor "pcie_ports=native" even if HEST sets FIRMWARE_FIRST (Myron Stowe) [1621933]
- [pci] PCI/AER: Add sysfs attributes for rootport cumulative stats (Myron Stowe) [1621933]
- [pci] PCI/AER: Add sysfs attributes to provide AER stats and breakdown (Myron Stowe) [1621933]
- [pci] PCI/AER: Define aer_stats structure for AER capable devices (Myron Stowe) [1621933]
- [pci] PCI/AER: Move internal declarations to drivers/pci/pci.h (Myron Stowe) [1621933]
- [pci] PCI/AER: Adopt lspci names for AER error decoding (Myron Stowe) [1621933]
- [pci] PCI/AER: Expose internal API for obtaining AER information (Myron Stowe) [1621933]
- [kernel] rcu: Make expedited GPs handle CPU 0 being offline (Gustavo Duarte) [1610262]
- [rpmspec] Generate BootLoaderSpec config fragments ("Herton R. Krzesinski") [1619766]

* Wed Aug 29 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-5.el8]
- [net] erspan: set erspan_ver to 1 by default when adding an erspan dev (Xin Long) [1619118]
- [hv] x86/hyper-v: Fix wrong merge conflict resolution (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Check for VP_INVAL in hyperv_flush_tlb_others() (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Check cpumask_to_vpset() return value in hyperv_flush_tlb_others_ex() (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Trace PV IPI send (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Use cheaper HVCALL_SEND_IPI hypercall when possible (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Use 'fast' hypercall for HVCALL_SEND_IPI (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Implement hv_do_fast_hypercall16 (Vitaly Kuznetsov) [1597652]
- [hv] x86/hyper-v: Use cheaper HVCALL_FLUSH_VIRTUAL_ADDRESS_(LIST, SPACE) hypercalls when possible (Vitaly Kuznetsov) [1597652]
- [netdrv] xen-netfront: fix queue name setting (Vitaly Kuznetsov) [1576160]
- [scsi] lfpc: add Lancer FCoE to the removed devices (Tomas Henzl) [1602033]
- [scsi] megaraid_sas: add removed id table (Tomas Henzl) [1602033]
- [scsi] aacraid: add removed id table (Tomas Henzl) [1602033]
- [scsi] qla4xxx: add removed id table (Tomas Henzl) [1602033]
- [scsi] lpfc: add removed id table (Tomas Henzl) [1602033]
- [scsi] qla2xxx: add removed id table (Tomas Henzl) [1602033]
- [scsi] mpt3sas: add removed id table (Tomas Henzl) [1602033]
- [scsi] be2iscsi: add removed id table (Tomas Henzl) [1602033]
- [scsi] rh_taint, pci : add information about removed hardware (Tomas Henzl) [1602033]
- [kernel] kernel: add SUPPORT_REMOVED kernel taint (Tomas Henzl) [1602033]
- [net] sunrpc: Change rpc_print_iostats to rpc_clnt_show_stats and handle rpc_clnt clones (Dave Wysochanski) [1610373]
- [net] sunrpc: Add _add_rpc_iostats() to add rpc_iostats metrics (Dave Wysochanski) [1610373]
- [net] sunrpc: add _print_rpc_iostats() to output metrics for one RPC op (Dave Wysochanski) [1610373]

* Mon Aug 27 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-4.el8]
- [net] xdp: exclude XDP from kABI guarantee (Jiri Benc) [1568551]
- [kernel] rh_kabi: introduce RH_KABI_EXCLUDE (Jiri Benc) [1568551]
- [powerpc] powerpc/powernv/pci: Work around races in PCI bridge enabling (Steve Best) [1620035]
- [block] blk-wbt: fix IO hang in wbt_wait() (Ming Lei) [1614198]
- [block] blkcg: Make blkg_root_lookup() work for queues in bypass mode (Ming Lei) [1614198]
- [block] null_blk: add lock drop/acquire annotation (Ming Lei) [1614198]
- [block] Blk-throttle: reduce tail io latency when iops limit is (Ming Lei) [1614198]
- [block] block: paride: pd: mark expected switch fall-throughs (Ming Lei) [1614198]
- [block] block: Ensure that a request queue is dissociated from the (Ming Lei) [1614198]
- [block] block: Introduce blk_exit_queue() (Ming Lei) [1614198]
- [block] blkcg: Introduce blkg_root_lookup() (Ming Lei) [1614198]
- [block] block: Remove two superfluous #include directives (Ming Lei) [1614198]
- [block] blk-mq: count the hctx as active before allocating tag (Ming Lei) [1614198]
- [block] block: bvec_nr_vecs() returns value for wrong slab (Ming Lei) [1614198]
- [block] drivers/block/drbd: remove the null check for (Ming Lei) [1614198]
- [block] drivers/block/aoe/aoedev: NULL check is not needed for (Ming Lei) [1614198]
- [block] drivers/block/mtip32xx: remove the null check for (Ming Lei) [1614198]
- [block] cfq: Suppress compiler warnings about comparisons (Ming Lei) [1614198]
- [block] cfq: Annotate fall-through in a switch statement (Ming Lei) [1614198]
- [block] blk-wbt: Avoid lock contention and thundering herd issue in (Ming Lei) [1590363]
- [block] target/loop: depend on SCSI (Ming Lei) [1614198]
- [block] xen-blkfront: use true and false for boolean values (Ming Lei) [1614198]
- [block] lightnvm: remove minor version check for 2.0 (Ming Lei) [1614198]
- [block] scsi: Check sense buffer size at build time (Ming Lei) [1614198]
- [block] libata-scsi: Move sense buffers onto stack (Ming Lei) [1614198]
- [block] cdrom: Use struct scsi_sense_hdr internally (Ming Lei) [1614198]
- [block] ide-cd: Remove redundant sense buffer (Ming Lei) [1614198]
- [block] block: Switch struct packet_command to use struct (Ming Lei) [1614198]
- [block] target: don't depend on SCSI (Ming Lei) [1614198]
- [block] scsi: build scsi_common.o for all scsi passthrough request (Ming Lei) [1614198]
- [block] scsi: cxlflash: Drop unused sense buffers (Ming Lei) [1614198]
- [block] ide-cd: Drop unused sense buffers (Ming Lei) [1614198]
- [block] blk-mq: fix updating tags depth (Ming Lei) [1611900]
- [block] block: really disable runtime-pm for blk-mq (Ming Lei) [1611902]
- [block] aoe: mark expected switch fall-through (Ming Lei) [1614198]
- [block] block: make iolatency avg_lat exponentially decay (Ming Lei) [1614198]
- [block] blk-cgroup: clear the throttle queue on fork (Ming Lei) [1614198]
- [block] blk-cgroup: hold the queue ref during throttling (Ming Lei) [1614198]
- [block] blk-iolatency: fix blkg leak in timer_fn (Ming Lei) [1614198]
- [block] block/bsg-lib: use PTR_ERR_OR_ZERO to simplify the flow path (Ming Lei) [1614198]
- [block] t10-pi: provide empty t10_pi_complete() for (Ming Lei) [1614198]
- [block] block: blk_init_allocated_queue() set q->fq as NULL in the (Ming Lei) [1614198]
- [block] nvme: use blk API to remap ref tags for IOs with metadata (Ming Lei) [1614198]
- [block] block: move dif_prepare/dif_complete functions to block layer (Ming Lei) [1614198]
- [block] block: move ref_tag calculation func to the block layer (Ming Lei) [1614198]
- [block] block: don't account for split bio's size in cgroup stats (Ming Lei) [1614198]
- [block] pktcdvd: Fix possible Spectre-v1 for pkt_devs (Ming Lei) [1614198]
- [block] partitions/aix: append null character to print data from disk (Ming Lei) [1614198]
- [block] partitions/aix: fix usage of uninitialized lv_info and lvname (Ming Lei) [1614198]
- [block] readahead: stricter check for bdi io_pages (Ming Lei) [1614198]
- [block] scsi: virtio_scsi: fix pi_bytes(out, in) on 4 KiB block size (Ming Lei) [1614198]
- [block] block: move bio_integrity_(intervals, bytes) into blkdev.h (Ming Lei) [1614198]
- [block] xen/blkfront: remove unused macros (Ming Lei) [1614198]
- [block] block: allow max_discard_segments to be stacked (Ming Lei) [1614198]
- [block] block: unexport bio_clone_bioset (Ming Lei) [1614198]
- [block] md: remove a bogus comment (Ming Lei) [1614198]
- [block] block: remove bio_clone_kmalloc (Ming Lei) [1614198]
- [block] exofs: use bio_clone_fast in _write_mirror (Ming Lei) [1614198]
- [block] bcache: don't clone bio in bch_data_verify (Ming Lei) [1614198]
- [block] block: bio_set_pages_dirty can't see NULL bv_page in a valid (Ming Lei) [1614198]
- [block] block: simplify bio_check_pages_dirty (Ming Lei) [1614198]
- [block] block: Rename the null_blk_mod kernel module back into (Ming Lei) [1614198]
- [block] blk-mq: fail the request in case issue failure (Ming Lei) [1614305]
- [block] blk-rq-qos: make depth comparisons unsigned (Ming Lei) [1614198]
- [block] blkcg: Track DISCARD statistics and output them in cgroup (Ming Lei) [1614198]
- [block] block: Track DISCARD statistics and output them in stat and (Ming Lei) [1614198]
- [block] block: Add and use op_stat_group() for indexing disk_stat (Ming Lei) [1614198]
- [block] block: Define and use STAT_READ and STAT_WRITE (Ming Lei) [1614198]
- [block] block: Add part_stat_read_accum to read across field entries (Ming Lei) [1614198]
- [block] block: make bdev_ops->rw_page() take a REQ_OP instead of bool (Ming Lei) [1614198]
- [block] pktcdvd: remove assignment in if condition (Ming Lei) [1614198]
- [block] blk-mq: issue directly if hw queue isn't busy in case of (Ming Lei) [1614305]
- [block] blk-iolatency: truncate our current time (Ming Lei) [1614198]
- [block] blk-iolatency: don't change the latency window (Ming Lei) [1614198]
- [block] block: remove blkdev_entry_to_request() macro (Ming Lei) [1614198]
- [block] block: skd: Use pad printk format for dma_addr_t values (Ming Lei) [1614198]
- [block] bsg: remove read/write support (Ming Lei) [1614198]
- [block] blk-iolatency: fix max_depth comparisons (Ming Lei) [1614198]
- [block] block: iolatency: avoid 64-bit division (Ming Lei) [1614198]
- [block] block/DAC960.c: fix defined but not used build warnings (Ming Lei) [1614198]
- [block] null_blk: add zone support (Ming Lei) [1614198]
- [block] null_blk: move shared definitions to header file (Ming Lei) [1614198]
- [block] block: Add default switch case to blk_pm_allow_request() to (Ming Lei) [1614198]
- [block] block: fix infinite loop if the device loses discard (Ming Lei) [1614198]
- [block] block, mm: remove unnecessary __GFP_HIGH flag (Ming Lei) [1614198]
- [block] null_blk: remove NULLB_DEV_FL_CONFIGURED on turning off nullb (Ming Lei) [1614198]
- [block] mm: skip readahead if the cgroup is congested (Ming Lei) [1614198]
- [block] Documentation: add a doc for blk-iolatency (Ming Lei) [1614198]
- [block] block: introduce blk-iolatency io controller (Ming Lei) [1614198]
- [block] rq-qos: introduce dio_bio callback (Ming Lei) [1614198]
- [block] block: remove external dependency on wbt_flags (Ming Lei) [1614198]
- [block] blk-rq-qos: refactor out common elements of blk-wbt (Ming Lei) [1614198]
- [block] blk-stat: export helpers for modifying blk_rq_stat (Ming Lei) [1614198]
- [block] memcontrol: schedule throttling if we are congested (Ming Lei) [1614198]
- [block] blkcg: add generic throttling mechanism (Ming Lei) [1614198]
- [block] swap, blkcg: issue swap io with the appropriate context (Ming Lei) [1614198]
- [block] blk: introduce REQ_SWAP (Ming Lei) [1614198]
- [block] blk-cgroup: allow controllers to output their own stats (Ming Lei) [1614198]
- [block] block: introduce bio_issue_as_root_blkg (Ming Lei) [1614198]
- [block] block: add bi_blkg to the bio for cgroups (Ming Lei) [1614198]
- [block] blk-mq: dequeue request one by one from sw queue if hctx is (Ming Lei) [1614305]
- [block] block/loop: mark expected switch fall-through (Ming Lei) [1614198]
- [block] drbd: mark expected switch fall-throughs (Ming Lei) [1614198]
- [block] blk-mq: only attempt to merge bio if there is rq in sw queue (Ming Lei) [1614305]
- [block] blk-mq: use list_splice_tail_init() to insert requests (Ming Lei) [1614305]
- [block] blk-mq: fix typo in a function comment (Ming Lei) [1614198]
- [block] blk-mq: code clean-up by adding an API to clear set->mq_map (Ming Lei) [1614198]
- [block] paride: remove redundant variable n (Ming Lei) [1614198]
- [block] partitions/ldm: remove redundant pointer dgrp (Ming Lei) [1614198]
- [block] loop: remove redundant pointer inode (Ming Lei) [1614198]
- [block] block/floppy: remove redundant variable dflags (Ming Lei) [1614198]
- [block] Block: blk-throttle: set low_valid immediately once one (Ming Lei) [1614198]
- [block] Blktrace: bail out early if block debugfs is not configured (Ming Lei) [1614198]
- [block] block: Document how blk_update_request() handles (Ming Lei) [1614198]
- [block] drbd: Do not redefine __must_hold() (Ming Lei) [1614198]
- [block] blk-mq: avoid to synchronize rcu inside blk_cleanup_queue() (Ming Lei) [1597067]
- [block] blk-mq: remove synchronize_rcu() from (Ming Lei) [1597067]
- [block] blk-mq: introduce new lock for protecting hctx->dispatch_wait (Ming Lei) [1597067]
- [block] blk-mq: don't pass **hctx to blk_mq_mark_tag_wait() (Ming Lei) [1597067]
- [block] blk-mq: cleanup blk_mq_get_driver_tag() (Ming Lei) [1597067]
- [block] block, bfq: give a better name to bfq_bfqq_may_idle (Ming Lei) [1614198]
- [block] block, bfq: fix service being wrongly set to zero in case of (Ming Lei) [1614198]
- [block] block, bfq: do not expire a queue that will deserve dispatch (Ming Lei) [1614198]
- [block] block, bfq: add/remove entity weights correctly (Ming Lei) [1614198]
- [block] block: Make struct request_queue smaller for (Ming Lei) [1614198]
- [block] block: Inline blk_queue_nr_zones() (Ming Lei) [1614198]
- [block] block: Remove bdev_nr_zones() (Ming Lei) [1614198]
- [block] include/uapi/linux/blkzoned.h: Remove a superfluous __packed (Ming Lei) [1614198]
- [block] block: Remove a superfluous cast from blkdev_report_zones() (Ming Lei) [1614198]

* Fri Aug 24 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-3.el8]
- [net] tls: mark as Tech Preview (Sabrina Dubroca) [1570255]
- [pci] PCI/VPD: Check for VPD access completion before checking for timeout (Myron Stowe) [1618820]
- [rpmspec] redhat: remove bootwrapper subpackage (Gustavo Duarte) [1578399]
- [virt] kvm: x86: Set highest physical address bits in non-present/reserved SPTEs (Paolo Bonzini) [1614808]
- [virt] KVM/x86: Use CC_SET()/CC_OUT in arch/x86/kvm/vmx.c (Paolo Bonzini) [1614808]
- [virt] KVM: X86: Implement PV IPIs in linux guest (Paolo Bonzini) [1614808]
- [virt] KVM: X86: Add kvm hypervisor init time platform setup callback (Paolo Bonzini) [1614808]
- [virt] KVM: X86: Implement "send IPI" hypercall (Paolo Bonzini) [1614808]
- [virt] KVM/x86: Move X86_CR4_OSXSAVE check into kvm_valid_sregs() (Paolo Bonzini) [1614808]
- [virt] KVM: x86: Skip pae_root shadow allocation if tdp enabled (Paolo Bonzini) [1614808]
- [virt] KVM/MMU: Combine flushing remote tlb in mmu_set_spte() (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: skip VMWRITE of HOST_(FS, GS)_BASE when possible (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: skip VMWRITE of HOST_(FS, GS)_SEL when possible (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: always initialize HOST_(FS, GS)_BASE to zero during setup (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: move struct host_state usage to struct loaded_vmcs (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: compute need to reload FS/GS/LDT on demand (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: remove a misleading comment regarding vmcs02 fields (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: rename __vmx_load_host_state() and vmx_save_host_state() (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: add dedicated utility to access guest's kernel_gs_base (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: track host_state.loaded using a loaded_vmcs pointer (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: refactor segmentation code in vmx_save_host_state() (Paolo Bonzini) [1614808]
- [virt] kvm: nVMX: Fix fault priority for VMX operations (Paolo Bonzini) [1614808]
- [virt] kvm: nVMX: Fix fault vector for VMX operation at CPL > 0 (Paolo Bonzini) [1614808]
- [virt] KVM: try __get_user_pages_fast even if not in atomic context (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: Add tlb_remote_flush callback support (Paolo Bonzini) [1614808]
- [virt] KVM: x86: Add tlb remote flush callback in kvm_x86_ops (Paolo Bonzini) [1614808]
- [virt] X86/Hyper-V: Add hyperv_nested_flush_guest_mapping ftrace support (Paolo Bonzini) [1614808]
- [virt] X86/Hyper-V: Add flush HvFlushGuestPhysicalAddressSpace hypercall support (Paolo Bonzini) [1614808]
- [virt] x86/kvm: Don't use pvqspinlock code if only 1 vCPU (Paolo Bonzini) [1614808]
- [virt] KVM/MMU: Simplify __kvm_sync_page() function (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Remove CR3_PCID_INVD flag (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Add multi-entry LRU cache for previous CR3s (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Flush only affected TLB entries in kvm_mmu_invlpg* (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Skip shadow page resync on CR3 switch when indicated by guest (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Support selectively freeing either current or previous MMU root (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Add a root_hpa parameter to kvm_mmu->invlpg() (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Skip TLB flush on fast CR3 switch when indicated by guest (Paolo Bonzini) [1614808]
- [virt] kvm: vmx: Support INVPCID in shadow paging mode (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Propagate guest PCIDs to host PCIDs (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Add ability to skip TLB flush when switching CR3 (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Use fast CR3 switch for nested VMX (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Support resetting the MMU context without resetting roots (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Add support for fast CR3 switch across different MMU modes (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Introduce KVM_REQ_LOAD_CR3 (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Introduce kvm_mmu_calc_root_page_role() (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Add fast CR3 switch code path (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Avoid taking MMU lock in kvm_mmu_sync_roots if no sync is needed (Paolo Bonzini) [1614808]
- [virt] kvm: x86: Make sync_page() flush remote TLBs once only (Paolo Bonzini) [1614808]
- [virt] KVM: MMU: drop vcpu param in gpte_access (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Separate logic allocating shadow vmcs to a function (Paolo Bonzini) [1614808]
- [virt] KVM: VMX: Mark vmcs header as shadow in case alloc_vmcs_cpu() allocate shadow vmcs (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Expose VMCS shadowing to L1 guest (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Do not forward VMREAD/VMWRITE VMExits to L1 if required so by vmcs12 vmread/vmwrite bitmaps (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: vmread/vmwrite: Use shadow vmcs12 if running L2 (Paolo Bonzini) [1614808]
- [virt] KVM: selftests: add tests for shadow VMCS save/restore (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: include shadow vmcs12 in nested state (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Cache shadow vmcs12 on VMEntry and flush to memory on VMExit (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Verify VMCS shadowing VMCS link pointer (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Verify VMCS shadowing controls (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Introduce nested_cpu_has_shadow_vmcs() (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Fail VMLAUNCH and VMRESUME on shadow VMCS (Paolo Bonzini) [1614808]
- [virt] KVM: nVMX: Allow VMPTRLD for shadow VMCS if vCPU supports VMCS shadowing (Paolo Bonzini) [1614808]
- [virt] KVM: VMX: Change vmcs12(read, write)_any() to receive vmcs12 as parameter (Paolo Bonzini) [1614808]
- [virt] KVM: VMX: Create struct for VMCS header (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: add test for nested state save/restore (Paolo Bonzini) [1614808]
- [virt] kvm: nVMX: Introduce KVM_CAP_NESTED_STATE (Paolo Bonzini) [1614808]
- [virt] KVM: x86: do not load vmcs12 pages while still in SMM (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: add basic test for state save and restore (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: ensure vcpu file is released (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: actually use all of lib/vmx.c (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: create a GDT and TSS (Paolo Bonzini) [1614808]
- [virt] KVM: x86: ensure all MSRs can always be KVM_GET/SET_MSR'd (Paolo Bonzini) [1614808]
- [virt] KVM: vmx: remove save/restore of host BNDCGFS MSR (Paolo Bonzini) [1614808]
- [virt] KVM: Switch 'requests' to be 64-bit (explicitly) (Paolo Bonzini) [1614808]
- [virt] kvm: selftests: add cr4_cpuid_sync_test (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S HV: Read kvm->arch.emul_smt_mode under kvm->lock (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S HV: Allow creating max number of VCPUs on POWER9 (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S HV: Pack VCORE IDs to access full VCPU ID space (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S HV: Fix constant size warning (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S HV: Add of_node_put() in success path (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Book3S: Fix matching of hardware and emulated TCE tables (Paolo Bonzini) [1614808]
- [virt] KVM: PPC: Remove mmio_vsx_tx_sx_enabled in KVM MMIO emulation (Paolo Bonzini) [1614808]

* Fri Aug 17 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-2.el8]
- [net] tcp: Add tcp_clamp_rto_to_user_timeout() helper to improve accuracy (Michael Cambria) [1605024]
- [net] tcp: Add tcp_retransmit_stamp() helper routine (Michael Cambria) [1605024]
- [net] tcp: convert icsk_user_timeout from jiffies to msecs (Michael Cambria) [1605024]
- [kernel] Revert sched/fair: Consider SD_NUMA when selecting the most idle group to schedule on (Lauro Ramos Venancio) [1585746]
- [kernel] redhat: makefile: adjust KBUILD_CFLAGS to reflect kernel.spec for powerpc builds (Gustavo Duarte) [1582568]
- [rpmspec] redhat: spec: build ppc64le kernel with -O3 (Gustavo Duarte) [1582568]
- [scsi] scsi: csiostor: update csio_get_flash_params() (Arjun Vynipadath) [1503574]
- [scsi] csiostor: Add a soft dep on cxgb4 driver (Arjun Vynipadath) [1503574]
- [firmware] dell_rbu: make firmware payload memory uncachable (Charles Rose) [1584401]

* Mon Aug 13 2018 Herton R. Krzesinski <herton@redhat.com> [4.18.0-1.el8]
- [scsi] scsi: lpfc: update driver version to 12.0.0.6 (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Remove lpfc_enable_pbde as module parameter (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Correct LCB ACCept payload (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Limit tracking of tgt queue depth in fast path (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Fix driver crash when re-registering NVME rports (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Fix list corruption on the completion queue (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Fix sysfs Speed value on CNA ports (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: Fix ELS abort on SLI-3 adapters (Dick Kennedy) [1613913]
- [scsi] scsi: lpfc: remove null check on nvmebuf (Dick Kennedy) [1613913]
- [arm64] arm64: fix ACPI dependencies (Bhupesh Sharma) [1556832]
- [arm64] arm64: acpi: fix alignment fault in accessing ACPI (Bhupesh Sharma) [1556832]
- [firmware] efi/arm: map UEFI memory map even w/o runtime services enabled (Bhupesh Sharma) [1556832]
- [firmware] efi/arm: preserve early mapping of UEFI memory map longer for BGRT (Bhupesh Sharma) [1556832]
- [acpi] drivers: acpi: add dependency of EFI for arm64 (Bhupesh Sharma) [1556832]
- [arm64] arm64: export memblock_reserve()d regions via /proc/iomem (Bhupesh Sharma) [1556832]
- [arm64] arm64: kconfig: Ensure spinlock fastpaths are inlined if !PREEMPT (Waiman Long) [1607924]
- [arm64] arm64: locking: Replace ticket lock implementation with qspinlock (Waiman Long) [1607924]
- [arm64] arm64: barrier: Implement smp_cond_load_relaxed (Waiman Long) [1607924]
- [scsi] scsi: lpfc: Revise copyright for new company language (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: update driver version to 12.0.0.5 (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: devloss timeout race condition caused null pointer reference (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Fix NVME Target crash in defer rcv logic (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Support duration field in Link Cable Beacon V1 command (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Make PBDE optimizations configurable (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Fix abort error path for NVMET (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Fix panic if driver unloaded when port is offline (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Fix driver not setting dpp bits correctly in doorbell word (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: Add Buffer overflow check, when nvme_info larger than PAGE_SIZE (Dick Kennedy) [1600946]
- [scsi] scsi: lpfc: use monotonic timestamps for statistics (Dick Kennedy) [1600946]
- [x86] mark intel knights landing and knights mill unsupported (David Arcari) [1610493]
- [netdrv] igb: Remove superfluous reset to PHY and page 0 selection (Corinna Vinschen) [1612824]
- [tools] selftests/powerpc: Fix ptrace-pkey for default execute permission change (Steve Best) [1498799]
- [tools] selftests/powerpc: Fix core-pkey for default execute permission change (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: make protection key 0 less special (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: Preallocate execute-only key (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: Fix calculation of total pkeys (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: Save the pkey registers before fork (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: key allocation/deallocation must not change pkey registers (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: Deny read/write/execute by default (Steve Best) [1498799]
- [powerpc] powerpc/pkeys: Give all threads control of their key permissions (Steve Best) [1498799]
- [s390] KVM: s390: Add huge page enablement control (David Hildenbrand) [1508102]
- [s390] s390/mm: Add huge page gmap linking support (David Hildenbrand) [1508102]
- [s390] s390/mm: hugetlb pages within a gmap can not be freed (David Hildenbrand) [1508102]
- [s390] KVM: s390: Beautify skey enable check (David Hildenbrand) [1508102]
- [s390] KVM: s390: Add skey emulation fault handling (David Hildenbrand) [1508102]
- [s390] s390/mm: Add huge pmd storage key handling (David Hildenbrand) [1508102]
- [s390] s390/mm: Clear skeys for newly mapped huge guest pmds (David Hildenbrand) [1508102]
- [s390] s390/mm: Clear huge page storage keys on enable_skey (David Hildenbrand) [1508102]
- [s390] s390/mm: Add huge page dirty sync support (David Hildenbrand) [1508102]
- [s390] s390/mm: Add gmap pmd invalidation and clearing (David Hildenbrand) [1508102]
- [s390] s390/mm: Add gmap pmd notification bit setting (David Hildenbrand) [1508102]
- [s390] s390/mm: Add gmap pmd linking (David Hildenbrand) [1508102]
- [s390] s390/mm: Abstract gmap notify bit setting (David Hildenbrand) [1508102]
- [s390] s390/mm: Make gmap_protect_range more modular (David Hildenbrand) [1508102]
- [s390] KVM: s390: Replace clear_user with kvm_clear_guest (David Hildenbrand) [1508102]
- [hwmon] hwmon: (ibmpowernv) Add attributes to enable/disable sensor groups (Steve Best) [1524684]
- [powerpc] powerpc/powernv: Add support to enable sensor groups (Steve Best) [1524684]
- [net] net/smc: improve delete link processing (Hendrik Brueckner) [1548452]
- [net] net/smc: provide fallback reason code (Hendrik Brueckner) [1548452]
- [net] net/smc: use correct vlan gid of RoCE device (Hendrik Brueckner) [1548452]
- [net] net/smc: fewer parameters for smc_llc_send_confirm_link() (Hendrik Brueckner) [1548452]
- [net] net/smc: remove local variable page in smc_rx_splice() (Hendrik Brueckner) [1548452]
- [net] net/smc: use DECLARE_BITMAP for rtokens_used_mask (Hendrik Brueckner) [1548452]
- [net] net/smc: add function to get link group from link (Hendrik Brueckner) [1548452]
- [net] net/smc: eliminate cursor read and write calls (Hendrik Brueckner) [1548452]
- [net] net/smc: provide smc mode in smc_diag.c (Hendrik Brueckner) [1548452]
- [s390] s390/ism: add device driver for internal shared memory (Hendrik Brueckner) [1548452]
- [net] net/smc: add SMC-D diag support (Hendrik Brueckner) [1548452]
- [net] net/smc: add SMC-D support in af_smc (Hendrik Brueckner) [1548452]
- [net] net/smc: add SMC-D support in data transfer (Hendrik Brueckner) [1548452]
- [net] net/smc: add SMC-D support in CLC messages (Hendrik Brueckner) [1548452]
- [net] net/smc: add pnetid support for SMC-D and ISM (Hendrik Brueckner) [1548452]
- [net] net/smc: add base infrastructure for SMC-D and ISM (Hendrik Brueckner) [1548452]
- [net] net/smc: add pnetid support (Hendrik Brueckner) [1548452]
- [net] net/smc: determine port attributes independent from pnet table (Hendrik Brueckner) [1548452]
- [x86] mark whiskey-lake processor supported (David Arcari) [1609604]
- [s390] KVM: s390: add etoken support for guests (Thomas Huth) [1612110]
- [char] ipmi: do not configure ipmi for HPE m400 (Tony Camuso) [1583537]
- [scsi] scsi: ipr: Format HCAM overlay ID 0x41 (Steve Best) [1498222]
- [x86] x86/stacktrace: Enable HAVE_RELIABLE_STACKTRACE for the ORC unwinder (Joe Lawrence) [1587952]
- [x86] x86/unwind/orc: Detect the end of the stack (Joe Lawrence) [1587952]
- [x86] x86/stacktrace: Do not fail for ORC with regs on stack (Joe Lawrence) [1587952]
- [x86] x86/stacktrace: Clarify the reliable success paths (Joe Lawrence) [1587952]
- [x86] x86/stacktrace: Remove STACKTRACE_DUMP_ONCE (Joe Lawrence) [1587952]
- [x86] x86/stacktrace: Do not unwind after user regs (Joe Lawrence) [1587952]
- [infiniband] IB/rxe: Mark Soft-RoCE Transport driver as tech-preview (Don Dutile) [1605216]
- [scsi] scsi: smartpqi: bump driver version to 1.1.4-130 (Don Brace) [1503736]
- [scsi] scsi: smartpqi: fix critical ARM issue reading PQI index registers (Don Brace) [1503736]
- [scsi] scsi: smartpqi: add inspur advantech ids (Don Brace) [1503736]
- [scsi] scsi: smartpqi: improve error checking for sync requests (Don Brace) [1503736]
- [scsi] scsi: smartpqi: improve handling for sync requests (Don Brace) [1503736]
- [netdrv] ice: mark driver as tech-preview (Jonathan Toppins) [1495347]
- [init] init/Kconfig: remove EXPERT from CHECKPOINT_RESTORE (Adrian Reber) [1568995 1557617 1525389]
- [scsi] be2iscsi: remove BE3 family support (Maurizio Lombardi) [1598366]
- [x86] update rh_check_supported processor list (David Arcari) [1595918]
- [kernel] kABI: Add generic kABI macros to use for kABI workarounds (Myron Stowe) [1546831]
- [pci] add pci_hw_vendor_status() (Maurizio Lombardi) [1590829]
- [ata] ahci: thunderx2: Fix for errata that affects stop engine (Robert Richter) [1563590]
- [pci] Vulcan: AHCI PCI bar fix for Broadcom Vulcan early silicon (Robert Richter) [1563590]
- [kernel] bpf: set default values for bpf_jit_harden and bpf_jit_kallsyms (Eugene Syromiatnikov) [1569061]
- [kernel] bpf: Add tech preview taint for syscall (Eugene Syromiatnikov) [1559877]
- [kernel] bpf: set unprivileged_bpf_disabled to 1 by default, add a boot parameter (Eugene Syromiatnikov) [1561171]
- [kernel] add Red Hat-specific taint flags (Eugene Syromiatnikov) [1559877]
- [tools] perf tests: Add Python 3 support to attr.py ("Herton R. Krzesinski") [1561505]
- [tools] perf scripts python: Add Python 3 support to stat-cpi.py ("Herton R. Krzesinski") [1561505]
- [kernel] kdump: fix a grammar issue in a kernel message (Dave Young) [1507353]
- [scripts] tags.sh: Ignore redhat/rpm (Prarit Bhargava) [1582586]
- [kernel] put RHEL info into generated headers (Prarit Bhargava) [1544999]
- [kernel] kdump: add support for crashkernel=auto (Dave Young) [1507353]
- [kernel] kdump: round up the total memory size to 128M for crashkernel reservation (Dave Young) [1507353]
- [arm64] acpi: prefer booting with ACPI over DTS (Mark Salter) [1576869]
- [acpi] aarch64: acpi scan: Fix regression related to X-Gene UARTs (Mark Salter) [1519554]
- [acpi] ACPI / irq: Workaround firmware issue on X-Gene based m400 (Mark Salter) [1519554]
- [x86] add rh_check_supported (David Arcari) [1565717]
- [scsi] qla2xxx: Remove PCI IDs of deprecated adapter (Himanshu Madhani) [1572233]
- [scsi] be2iscsi: remove unsupported device IDs (Chris Leech) [1574502]
- [scsi] Removing Obsolete hba pci-ids from rhel8 (Dick Kennedy) [1572321]
- [scsi] hpsa: modify hpsa driver version (Joseph Szczypek) [1471185]
- [scsi] hpsa: remove old cciss-based smartarray pci ids (Joseph Szczypek) [1471185]
- [kernel] rh_taint: add support for marking driver as unsupported (Jonathan Toppins) [1565704]
- [kernel] rh_taint: add support (David Arcari) [1565704]
- [scsi] qla4xxx: Remove deprecated PCI IDs from RHEL 8 (Chad Dupuis) [1518874]
- [scsi] aacraid: Remove depreciated device and vendor PCI id's (Raghava Aditya Renukunta) [1495307]
- [scsi] megaraid_sas: remove deprecated pci-ids (Tomas Henzl) [1509329]
- [scsi] mpt*: remove certain deprecated pci-ids (Tomas Henzl) [1511953]
- [kernel] modules: add rhelversion MODULE_INFO tag (Prarit Bhargava) [1544999]
- [acpi] ACPI: APEI: arm64: Ignore broken HPE moonshot APEI support (Al Stone) [1518076]
- [rpmspec] compute content hash for kernel-headers (Rafael Aquini) [1613003]
- [rpmspec] compress modules on all architectures ("Herton R. Krzesinski") [1614556]
- [rpmspec] add gcov rpm packaging support (Jan Stancek) [1601733]
- [rpmspec] don't ship spdxcheck.py (Jakub Racek)
- [rpmspec] clean stray bpf files (Jakub Racek) [1593309]
- [rpmspec] Copy symvers.gz to /lib/modules (Eugene Syromiatnikov) [1609695]
- [rpmspec] Add kabi-dup related code into specfile (Petr Oros) [1585672]
- [rpmspec] kernel spec: Add and enable kabi check (Petr Oros) [1585672]
- [rpmspec] Enable warning checks for configs in rpm build (Prarit Bhargava) [1589858]
- [rpmspec] remove workaround for rst2man-3 from python3-docutils ("Herton R. Krzesinski") [1602148]
- [rpmspec] fix dist tag used for hardlink in kernel-devel post ("Herton R. Krzesinski") [1596397]
- [scripts] get_maintainer.pl: Add optional .get_maintainer.MAINTAINERS override (Prarit Bhargava) [1595727]
- [rpmspec] drop kernel package dependency on python2 ("Herton R. Krzesinski") [1561505]
- [kernel] Makefile: Move RHEL definitions down (Jakub Racek) [1576568]
- [rpmspec] eBPF: Add bpftool package to spec file (Jerome Marchand) [1559607]
- [rpmspec] fix conflicts with COPYING file while installing newer 4.17 kernel ("Herton R. Krzesinski") [1579563]
- [rpmspec] do not build kernel meta-package on noarch ("Herton R. Krzesinski") [1579512]
- [rpmspec] kernel spec: remove copy of arch/x86/purgatory/sha256.* ("Herton R. Krzesinski")
- [rpmspec] spec: Add new arch/powerpc/kernel/module.lds file to kernel-devel rpm (Steve Best) [1572553]
- [rpmspec] kernel spec: fix recent build errors from brp-mangle-shebangs ("Herton R. Krzesinski") [1575966]
- [rpmspec] Add i386 to ExclusiveArch to fix noarch package build ("Herton R. Krzesinski") [1575152]
- [rpmspec] Build kernel-abi-whitelists package (Petr Oros) [1571189]
- [rpmspec] kernel spec: build bzImage for s390 (Hendrik Brueckner) [1570041]
- [rpmspec] kernel spec: arm64: package module.lds in kernel-devel (Mark Salter) [1569014]
- [rpmspec] Re-enable debuginfo packages and fix build with current dist tag ("Herton R. Krzesinski") [1568901]
- [rpmspec] kernel spec: build kernel-debug on all architectures ("Herton R. Krzesinski") [1567367]
- [rpmspec] don't build kernel meta-package if we are only building kernel headers ("Herton R. Krzesinski")
- [rpmspec] remove use_vdso macro ("Herton R. Krzesinski")
- [rpmspec] build perf and tools man pages instead of relying on a separate tarball ("Herton R. Krzesinski")
- [rpmspec] disable debug build if arch is in nobuildarches list ("Herton R. Krzesinski")
- [rpmspec] remove fedora changelog from spec file ("Herton R. Krzesinski")
- [rpmspec] only support ppc64le builds ("Herton R. Krzesinski")
- [rpmspec] remove x86 32-bit package support ("Herton R. Krzesinski")
- [rpmspec] remove arm 32-bit package support ("Herton R. Krzesinski")
- [rpmspec] remove configuration generation support from kernel spec file ("Herton R. Krzesinski")
- [rpmspec] remove broken out patches from kernel spec file ("Herton R. Krzesinski")
- [rpmspec] import kernel spec from rhel8 bootstrap dist-git ("Herton R. Krzesinski")

###
# The following Emacs magic makes C-c C-e use UTC dates.
# Local Variables:
# rpm-change-log-uses-utc: t
# End:
###
